@@ -15,10 +15,13 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol;
 
+import org.eclipse.ui.application.IWorkbenchConfigurer;
 import org.eclipse.ui.application.IWorkbenchWindowConfigurer;
 import org.eclipse.ui.application.WorkbenchAdvisor;
 import org.eclipse.ui.application.WorkbenchWindowAdvisor;
 
+import com.clustercontrol.startup.ui.StartUpPerspective;
+
 /**
  * 
  * WorkbenchAdvisorクラスを継承するクラス<BR>
@@ -29,6 +32,14 @@ import org.eclipse.ui.application.WorkbenchWindowAdvisor;
  */
 public class ClusterControlWorkbenchAdvisor extends WorkbenchAdvisor {
 
+	@Override
+	public void initialize( IWorkbenchConfigurer configurer ){
+		super.initialize( configurer );
+
+		// Save and restore workbench state ( default Off on RAP )
+		configurer.setSaveAndRestore(true);
+	}
+
 	/*
 	 * (non-Javadoc)
 	 * 
@@ -36,7 +47,7 @@ public class ClusterControlWorkbenchAdvisor extends WorkbenchAdvisor {
 	 */
 	@Override
 	public String getInitialWindowPerspectiveId() {
-		return "com.clustercontrol.ClusterControlPerspective";
+		return StartUpPerspective.ID;
 	}
 
 	/* (non-Javadoc)
@@ -46,4 +57,4 @@ public class ClusterControlWorkbenchAdvisor extends WorkbenchAdvisor {
 	public WorkbenchWindowAdvisor createWorkbenchWindowAdvisor(IWorkbenchWindowConfigurer configurer) {
 		return new ClusterControlWorkbenchWindowAdvisor(configurer);
 	}
-}
\ No newline at end of file
+}
