@@ -18,7 +18,7 @@ package com.clustercontrol.bean;
 /**
  * クライアント表示サイズの定数クラス<BR>
  * 
- * @version 1.0.0
+ * @version 5.0.0
  * @since 1.0.0
  */
 public class SizeConstant {
@@ -33,4 +33,10 @@ public class SizeConstant {
 
 	/** ラベル 高さ */
 	public static final int SIZE_LABEL_HEIGHT = 15;
-}
\ No newline at end of file
+
+	/** URL入力 幅*/
+	public static final int SIZE_TEXT_USERID_WIDTH = 100;
+
+	/** URL入力 幅*/
+	public static final int SIZE_TEXT_URL_WIDTH = 250;
+}
