@@ -17,6 +17,7 @@ package com.clustercontrol.dialog;
 
 import java.util.Calendar;
 import java.util.Date;
+import java.util.regex.Pattern;
 
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
@@ -27,10 +28,11 @@ import org.vafada.swtcalendar.SWTCalendarEvent;
 import org.vafada.swtcalendar.SWTCalendarListener;
 
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.util.WidgetTestUtil;
 
 /**
  * カレンダーダイアログクラス<BR>
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  */
@@ -45,7 +47,7 @@ public class CalendarDialog extends CommonDialog {
 
 	/**
 	 * コンストラクタ
-	 * 
+	 *
 	 * @param parent
 	 * @since 1.0.0
 	 */
@@ -55,7 +57,7 @@ public class CalendarDialog extends CommonDialog {
 
 	/**
 	 * ダイアログ作成
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#customizeDialog(org.eclipse.swt.widgets.Composite)
 	 * @since 1.0.0
 	 */
@@ -63,12 +65,16 @@ public class CalendarDialog extends CommonDialog {
 	protected void customizeDialog(Composite composite) {
 		composite.getShell().setText(Messages.getString("calendar"));
 
+		Pattern.compile("[^\\w\\.]").matcher(this.getClass().getName()).replaceAll("-");
+
 		GridLayout gridLayout = new GridLayout(1, true);
 		composite.setLayout(gridLayout);
 		gridLayout.marginWidth = 10;
 		gridLayout.marginHeight = 10;
 
 		swtcal = new SWTCalendar(composite);
+		WidgetTestUtil.setTestId(this, null, swtcal);
+
 		GridData gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
@@ -93,7 +99,7 @@ public class CalendarDialog extends CommonDialog {
 
 	/**
 	 * 日付設定
-	 * 
+	 *
 	 * @param date
 	 * @since 1.0.0
 	 */
@@ -103,7 +109,7 @@ public class CalendarDialog extends CommonDialog {
 
 	/**
 	 * 日付取得
-	 * 
+	 *
 	 * @return
 	 * @since 1.0.0
 	 */
@@ -113,7 +119,7 @@ public class CalendarDialog extends CommonDialog {
 
 	/**
 	 * キャンセルボタンクリック時の処理
-	 * 
+	 *
 	 * @see org.eclipse.jface.dialogs.Dialog#cancelPressed()
 	 * @since 1.0.0
 	 */
@@ -126,7 +132,7 @@ public class CalendarDialog extends CommonDialog {
 
 	/**
 	 * OKボタンクリック時の処理
-	 * 
+	 *
 	 * @see org.eclipse.jface.dialogs.Dialog#okPressed()
 	 * @since 1.0.0
 	 */
@@ -142,4 +148,4 @@ public class CalendarDialog extends CommonDialog {
 	protected ValidateResult validate() {
 		return null;
 	}
-}
\ No newline at end of file
+}
