@@ -32,21 +32,18 @@ public class HinemosObjectValidator {
 	 * @return
 	 */
 	public static ArrayList<Property> objectToArrayListProperty(Object obj) {
-		/** ローカル変数 */
-		Object element = null;
-
-		/** メイン処理 */
-		if (obj instanceof ArrayList) {
-			for (int i = 0; i < ((ArrayList<Object>)obj).size(); i++) {
-				element = ((ArrayList<Object>)obj).get(i);
-				if (! (element instanceof Property)) {
-					return new ArrayList<Property>();
-				}
-			}
-			return (ArrayList<Property>)obj;
-		} else {
+		if (!(obj instanceof ArrayList)) {
 			return new ArrayList<Property>();
 		}
-	}
 
+		ArrayList<Property> properties = new ArrayList<Property>();
+		for (Object element : (ArrayList<?>)obj) {
+			if (!(element instanceof Property)) {
+				return new ArrayList<Property>();
+			}
+
+			properties.add((Property)element);
+		}
+		return properties;
+	}
 }
