@@ -18,9 +18,6 @@ package com.clustercontrol.util;
 import java.util.ArrayList;
 import java.util.HashMap;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-
 import com.clustercontrol.bean.Property;
 import com.clustercontrol.bean.PropertyDefineConstant;
 import com.clustercontrol.editor.PropertyDefine;
@@ -32,8 +29,6 @@ import com.clustercontrol.editor.PropertyDefine;
  * @since 1.0.0
  */
 public class PropertyUtil {
-	private static Log m_log = LogFactory.getLog(PropertyUtil.class);
-
 	/**
 	 * プロパティ値の取得
 	 * 
@@ -41,8 +36,8 @@ public class PropertyUtil {
 	 * @param id
 	 * @return プロパティの配列
 	 */
-	public static ArrayList getPropertyValue(Property property, String id) {
-		ArrayList list = new ArrayList();
+	public static ArrayList<?> getPropertyValue(Property property, String id) {
+		ArrayList<Object> list = new ArrayList<Object>();
 
 		getPropertyValue(property, id, list);
 
@@ -57,7 +52,7 @@ public class PropertyUtil {
 	 * @param list
 	 */
 	public static void getPropertyValue(Property property, String id,
-			ArrayList list) {
+			ArrayList<Object> list) {
 
 		//IDが一致するプロパティをリストに追加
 		if (id != null && property.getID() != null) {
@@ -73,7 +68,7 @@ public class PropertyUtil {
 			Object[][] value = property.getSelectValues();
 			for (int j = 0; j < value[PropertyDefineConstant.SELECT_VALUE].length; j++) {
 				if (value[PropertyDefineConstant.SELECT_VALUE][j] instanceof HashMap) {
-					HashMap map = (HashMap) value[PropertyDefineConstant.SELECT_VALUE][j];
+					HashMap<String, Object> map = (HashMap<String, Object>) value[PropertyDefineConstant.SELECT_VALUE][j];
 
 					//子Propertyを取得
 					ArrayList<Property> propertyList = (ArrayList<Property>) map
@@ -134,7 +129,7 @@ public class PropertyUtil {
 			Object[][] value = property.getSelectValues();
 			for (int j = 0; j < value[PropertyDefineConstant.SELECT_VALUE].length; j++) {
 				if (value[PropertyDefineConstant.SELECT_VALUE][j] instanceof HashMap) {
-					HashMap map = (HashMap) value[PropertyDefineConstant.SELECT_VALUE][j];
+					HashMap<String, Object> map = (HashMap<String, Object>) value[PropertyDefineConstant.SELECT_VALUE][j];
 
 					//子Propertyを取得
 					ArrayList<Property> propertyList = (ArrayList<Property>) map.get(PropertyDefineConstant.MAP_PROPERTY);
@@ -171,10 +166,10 @@ public class PropertyUtil {
 			Object[][] value = property.getSelectValues();
 			for (int j = 0; j < value[PropertyDefineConstant.SELECT_VALUE].length; j++) {
 				if (value[PropertyDefineConstant.SELECT_VALUE][j] instanceof HashMap) {
-					HashMap map = (HashMap) value[PropertyDefineConstant.SELECT_VALUE][j];
+					HashMap<String, Object> map = (HashMap<String, Object>) value[PropertyDefineConstant.SELECT_VALUE][j];
 
 					//子Propertyを取得
-					ArrayList<Property> propertyList = (ArrayList) map
+					ArrayList<Property> propertyList = (ArrayList<Property>) map
 							.get(PropertyDefineConstant.MAP_PROPERTY);
 					if (propertyList != null) {
 						for (int k = 0; k < propertyList.size(); k++) {
@@ -241,7 +236,6 @@ public class PropertyUtil {
 
 		Object[][] selectValues = original.getSelectValues();
 		Object[] childrens = original.getChildren();
-		PropertyDefine define = original.getDefine();
 
 		if (selectValues != null) {
 			Object[][] cloneSelectValues = {
@@ -252,11 +246,11 @@ public class PropertyUtil {
 			}
 			for (int i = 0; i < selectValues[PropertyDefineConstant.SELECT_VALUE].length; i++) {
 				if (selectValues[PropertyDefineConstant.SELECT_VALUE][i] instanceof HashMap) {
-					HashMap cloneMap = new HashMap();
-					ArrayList clonPropertyList = new ArrayList();
+					HashMap<String, Object> cloneMap = new HashMap<String, Object>();
+					ArrayList<Property> clonPropertyList = new ArrayList<Property>();
 
-					HashMap map = (HashMap) selectValues[PropertyDefineConstant.SELECT_VALUE][i];
-					ArrayList<Property> propertyList = (ArrayList) map
+					HashMap<String, Object> map = (HashMap<String, Object>) selectValues[PropertyDefineConstant.SELECT_VALUE][i];
+					ArrayList<Property> propertyList = (ArrayList<Property>) map
 							.get(PropertyDefineConstant.MAP_PROPERTY);
 					if (propertyList != null) {
 						for (int j = 0; j < propertyList.size(); j++) {
@@ -285,94 +279,7 @@ public class PropertyUtil {
 		}
 
 		/*
-        if (define instanceof ComboPropertyDefine) {
-            int index = 0;
-
-            if (original.getValue() != null) {
-//                String dispText = (String) original.getValue();
-//                for (int i = 0; i < selectValues[PropertyConstant.SELECT_DISP_TEXT].length; i++) {
-//                    if (dispText
-//                            .compareTo((String)selectValues[PropertyConstant.SELECT_DISP_TEXT][i]) == 0) {
-//                        index = i;
-//                        break;
-//                    }
-//                }
-                String value = (String) original.getValue();
-                for (int i = 0; i < selectValues[PropertyConstant.SELECT_VALUE].length; i++) {
-                    if (value.compareTo((String)selectValues[PropertyConstant.SELECT_VALUE][i]) == 0) {
-                        index = i;
-                        break;
-                    }
-                }
-
-            }
-
-            clone.setDefine(new ComboPropertyDefine(clone.getSelectValues()));
-
-            if (selectValues[PropertyConstant.SELECT_VALUE][index] instanceof HashMap) {
-                HashMap map = (HashMap) selectValues[PropertyConstant.SELECT_VALUE][index];
-                clone.setValue(map.get(PropertyConstant.MAP_VALUE));
-
-                ArrayList propertyList = (ArrayList) map
-                        .get(PropertyConstant.MAP_PROPERTY);
-                if (propertyList instanceof ArrayList) {
-                    clone.removeChildren();
-                    for (int i = 0; i < propertyList.size(); i++) {
-                        clone.addChildren((Property) propertyList.get(i));
-                    }
-                }
-            } else {
-                clone.removeChildren();
-//                Object select = selectValues[PropertyConstant.SELECT_DISP_TEXT][index];
-                Object select = selectValues[PropertyConstant.SELECT_VALUE][index];
-                clone.setValue(select);
-            }
-        } else if (define instanceof FilePropertyDefine) {
-            clone.setDefine(new FilePropertyDefine());
-            clone.setValue(original.getValue());
-        } else if (define instanceof TextPropertyDefine) {
-            clone.setDefine(new TextPropertyDefine());
-            clone.setValue(original.getValue());
-        } else if (define instanceof PasswordPropertyDefine) {
-            clone.setDefine(new PasswordPropertyDefine());
-            clone.setValue(original.getValue());
-        } else if (define instanceof ScopePropertyDefine) {
-            clone.setDefine(new ScopePropertyDefine());
-            clone.setValue(original.getValue());
-        } else if (define instanceof BooleanPropertyDefine) {
-            clone.setDefine(new BooleanPropertyDefine());
-            clone.setValue(original.getValue());
-        } else if (define instanceof IntegerPropertyDefine) {
-            clone.setDefine(new IntegerPropertyDefine());
-            clone.setValue(original.getValue());
-        } else if (define instanceof DatePropertyDefine) {
-            clone.setDefine(new DatePropertyDefine());
-            clone.setValue(original.getValue());
-        } else if (define instanceof DateTimePropertyDefine) {
-            clone.setDefine(new DateTimePropertyDefine());
-            clone.setValue(original.getValue());
-        } else if (define instanceof TimePropertyDefine) {
-            clone.setDefine(new TimePropertyDefine());
-            clone.setValue(original.getValue());
-        } else if (define instanceof TextAreaPropertyDefine) {
-
-        	//テキストエリアの場合、独自にフラグを持っている（デフォルトfalse）ので、コピー時に変更する
-        	TextAreaPropertyDefine def = new TextAreaPropertyDefine();
-        	if (clone.getModify() == PropertyConstant.MODIFY_OK) {
-            	def.setModify(true);
-        	}
-            clone.setDefine(def);
-            clone.setValue(original.getValue());
-        } else {
-            clone.setValue(original.getValue());
-        }
-		 */
-		/*
-		 * ここの修正は怪しい。
-		 * 後で調査すること！！！
-		 * TODO
-		 * TODO
-		 * TODO
+		 * TODO ここの修正は怪しい。後で調査すること！！！
 		 */
 		clone.setDefine(original.getDefine());
 		clone.setValue(original.getValue());
@@ -395,7 +302,7 @@ public class PropertyUtil {
 			Object[][] value = property.getSelectValues();
 			for (int j = 0; j < value[PropertyDefineConstant.SELECT_VALUE].length; j++) {
 				if (value[PropertyDefineConstant.SELECT_VALUE][j] instanceof HashMap) {
-					HashMap map = (HashMap) value[PropertyDefineConstant.SELECT_VALUE][j];
+					HashMap<String, Object> map = (HashMap<String, Object>) value[PropertyDefineConstant.SELECT_VALUE][j];
 
 					//子Propertyを取得
 					ArrayList<Property> propertyList = (ArrayList<Property>) map
@@ -444,7 +351,7 @@ public class PropertyUtil {
 			Object[][] selectValue = property.getSelectValues();
 			for (int j = 0; j < selectValue[PropertyDefineConstant.SELECT_VALUE].length; j++) {
 				if (selectValue[PropertyDefineConstant.SELECT_VALUE][j] instanceof HashMap) {
-					HashMap map = (HashMap) selectValue[PropertyDefineConstant.SELECT_VALUE][j];
+					HashMap<String, Object> map = (HashMap<String, Object>) selectValue[PropertyDefineConstant.SELECT_VALUE][j];
 
 					//子Propertyを取得
 					ArrayList<Property> propertyList = (ArrayList<Property>) map
@@ -467,4 +374,4 @@ public class PropertyUtil {
 			}
 		}
 	}
-}
\ No newline at end of file
+}
