@@ -1,17 +1,17 @@
 /*
  * SWTDayChooser.java - A day chooser component for SWT Author: Mark Bryan Yu
  * Modified by: Sergey Prigogin swtcalendar.sourceforge.net
- * 
+ *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
  * Software Foundation; either version 2 of the License, or (at your option) any
  * later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but WITHOUT
  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
  * details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software Foundation, Inc.,
  * 675 Mass Ave, Cambridge, MA 02139, USA.
@@ -24,9 +24,9 @@ import java.util.ArrayList;
 import java.util.Calendar;
 import java.util.List;
 import java.util.Locale;
+import java.util.regex.Pattern;
 
 import org.eclipse.draw2d.ColorConstants;
-import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.DisposeEvent;
 import org.eclipse.swt.events.DisposeListener;
 import org.eclipse.swt.events.FocusEvent;
@@ -50,6 +50,8 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Listener;
 import org.eclipse.swt.widgets.Widget;
 
+import com.clustercontrol.client.swt.SWT;
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.ws.calendar.Ymd;
 
 public class SWTDayChooser extends Composite implements MouseListener,
@@ -91,7 +93,7 @@ FocusListener, TraverseListener, KeyListener {
 
 	private Locale locale;
 
-	private List listeners;
+	private List<SWTCalendarListener> listeners;
 
 	private int style;
 
@@ -100,7 +102,9 @@ FocusListener, TraverseListener, KeyListener {
 	public SWTDayChooser(Composite parent, int style) {
 		super(parent, style & ~RED_WEEKEND);
 		this.style = style;
-		listeners = new ArrayList(3);
+		listeners = new ArrayList<SWTCalendarListener>(3);
+
+		Pattern.compile("[^\\w\\.]").matcher(this.getClass().getName()).replaceAll("-");
 
 		setBackground(getDisplay().getSystemColor(SWT.COLOR_WHITE));
 
@@ -127,12 +131,15 @@ FocusListener, TraverseListener, KeyListener {
 		dayTitles = new Label[7];
 		for (int i = 0; i < dayTitles.length; i++) {
 			Label label = new Label(this, SWT.CENTER);
+			WidgetTestUtil.setTestId(this, "daytitles" + i, label);
 			dayTitles[i] = label;
 			label.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_FILL));
 			label.addMouseListener(this);
+			WidgetTestUtil.setTestId(this, "label" + i, label);
 		}
 		{
 			final Composite spacer = new Composite(this, SWT.NO_FOCUS);
+			WidgetTestUtil.setTestId(this, "spacer", spacer);
 			spacer.setBackground(getBackground());
 			final GridData gridData = new GridData(GridData.FILL_HORIZONTAL);
 			gridData.heightHint = 2;
@@ -144,6 +151,7 @@ FocusListener, TraverseListener, KeyListener {
 
 		{
 			final Label label = new Label(this, SWT.HORIZONTAL | SWT.SEPARATOR);
+			WidgetTestUtil.setTestId(this, null, label);
 			final GridData gridData = new GridData(GridData.FILL_HORIZONTAL);
 			gridData.horizontalSpan = 7;
 			label.setLayoutData(gridData);
@@ -151,7 +159,8 @@ FocusListener, TraverseListener, KeyListener {
 
 		days = new DayControl[42];
 		for (int i = 0; i < days.length; i++) {
-			DayControl day = new DayControl(this);
+			DayControl day = new DayControl(this, i);
+			WidgetTestUtil.setTestId(this, "day" + i, day);
 			days[i] = day;
 			day.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_FILL
 					| GridData.VERTICAL_ALIGN_FILL));
@@ -402,7 +411,7 @@ FocusListener, TraverseListener, KeyListener {
 
 	/*
 	 * (non-Javadoc)
-	 * 
+	 *
 	 * @see org.eclipse.swt.events.MouseListener#mouseDown(org.eclipse.swt.events.MouseEvent)
 	 */
 	@Override
@@ -419,7 +428,7 @@ FocusListener, TraverseListener, KeyListener {
 
 	/*
 	 * (non-Javadoc)
-	 * 
+	 *
 	 * @see org.eclipse.swt.events.MouseListener#mouseDoubleClick(org.eclipse.swt.events.MouseEvent)
 	 */
 	@Override
@@ -428,7 +437,7 @@ FocusListener, TraverseListener, KeyListener {
 
 	/*
 	 * (non-Javadoc)
-	 * 
+	 *
 	 * @see org.eclipse.swt.events.MouseListener#mouseUp(org.eclipse.swt.events.MouseEvent)
 	 */
 	@Override
@@ -437,31 +446,33 @@ FocusListener, TraverseListener, KeyListener {
 
 	/*
 	 * (non-Javadoc)
-	 * 
+	 *
 	 * @see org.eclipse.swt.events.FocusListener#focusGained(org.eclipse.swt.events.FocusEvent)
 	 */
 	@Override
 	public void focusGained(FocusEvent event) {
 		DayControl selectedDay = getSelectedDayControl();
+		WidgetTestUtil.setTestId(this, "selected", selectedDay);
 		selectedDay.setBackground(getSelectionBackgroundColor());
 		selectedDay.setForeground(getSelectionForegroundColor());
 	}
 
 	/*
 	 * (non-Javadoc)
-	 * 
+	 *
 	 * @see org.eclipse.swt.events.FocusListener#focusLost(org.eclipse.swt.events.FocusEvent)
 	 */
 	@Override
 	public void focusLost(FocusEvent event) {
 		DayControl selectedDay = getSelectedDayControl();
+		WidgetTestUtil.setTestId(this, "selected", selectedDay);
 		selectedDay.setBackground(getSelectionBackgroundColor());
 		selectedDay.setForeground(getSelectionForegroundColor());
 	}
 
 	/*
 	 * (non-Javadoc)
-	 * 
+	 *
 	 * @see org.eclipse.swt.events.TraverseListener#keyTraversed(org.eclipse.swt.events.TraverseEvent)
 	 */
 	@Override
@@ -473,7 +484,6 @@ FocusListener, TraverseListener, KeyListener {
 		case SWT.TRAVERSE_PAGE_NEXT:
 			event.doit = false;
 			break;
-
 		case SWT.TRAVERSE_TAB_NEXT:
 		case SWT.TRAVERSE_TAB_PREVIOUS:
 			event.doit = true;
@@ -482,7 +492,7 @@ FocusListener, TraverseListener, KeyListener {
 
 	/*
 	 * (non-Javadoc)
-	 * 
+	 *
 	 * @see org.eclipse.swt.events.KeyListener#keyPressed(org.eclipse.swt.events.KeyEvent)
 	 */
 	@Override
@@ -516,7 +526,7 @@ FocusListener, TraverseListener, KeyListener {
 
 	/*
 	 * (non-Javadoc)
-	 * 
+	 *
 	 * @see org.eclipse.swt.events.KeyListener#keyReleased(org.eclipse.swt.events.KeyEvent)
 	 */
 	@Override
@@ -525,7 +535,7 @@ FocusListener, TraverseListener, KeyListener {
 
 	/**
 	 * Finds position of a control in <code>days</code> array.
-	 * 
+	 *
 	 * @param dayControl
 	 *            a control to find.
 	 * @return an index of <code>dayControl</code> in <code>days</code>
@@ -548,6 +558,7 @@ FocusListener, TraverseListener, KeyListener {
 			int dayOfWeek = calendar.get(Calendar.DAY_OF_WEEK);
 			// Stay on the same month.
 			DayControl selectedDay = getSelectedDayControl();
+			WidgetTestUtil.setTestId(this, "selected", selectedDay);
 			selectedDay.setBackground(getBackground());
 			if (dayOfWeek == Calendar.SUNDAY) {
 				selectedDay.setForeground(getDisplay().getSystemColor(
@@ -587,7 +598,7 @@ FocusListener, TraverseListener, KeyListener {
 
 	/*
 	 * (non-Javadoc)
-	 * 
+	 *
 	 * @see org.eclipse.swt.widgets.Control#isFocusControl()
 	 */
 	@Override
@@ -636,7 +647,7 @@ FocusListener, TraverseListener, KeyListener {
 
 	/*
 	 * (non-Javadoc)
-	 * 
+	 *
 	 * @see org.eclipse.swt.widgets.Control#setFont(org.eclipse.swt.graphics.Font)
 	 */
 	@Override
@@ -657,7 +668,7 @@ FocusListener, TraverseListener, KeyListener {
 
 		private Label label;
 
-		public DayControl(Composite parent) {
+		public DayControl(Composite parent, int suffix) {
 			super(parent, SWT.NO_FOCUS);
 			{
 				final GridLayout gridLayout = new GridLayout();
@@ -666,7 +677,10 @@ FocusListener, TraverseListener, KeyListener {
 				setLayout(gridLayout);
 			}
 
+			Pattern.compile("[^\\w\\.]").matcher(this.getClass().getName()).replaceAll("-");
+
 			filler = new Composite(this, SWT.NO_FOCUS);
+			WidgetTestUtil.setTestId(this, "filler", filler);
 			filler.setLayoutData(new GridData(GridData.FILL_BOTH));
 			{
 				final GridLayout gridLayout = new GridLayout();
@@ -679,6 +693,7 @@ FocusListener, TraverseListener, KeyListener {
 			filler.addListener(SWT.MouseDoubleClick, this);
 
 			label = new DayLabel(filler, SWT.RIGHT | SWT.NO_FOCUS);
+			WidgetTestUtil.setTestId(this, null, label);
 			label.setLayoutData(new GridData(GridData.GRAB_HORIZONTAL
 					| GridData.HORIZONTAL_ALIGN_CENTER));
 			label.addListener(SWT.MouseDown, this);
@@ -700,7 +715,7 @@ FocusListener, TraverseListener, KeyListener {
 
 		/*
 		 * (non-Javadoc)
-		 * 
+		 *
 		 * @see org.eclipse.swt.widgets.Control#setFont(org.eclipse.swt.graphics.Font)
 		 */
 		@Override
@@ -712,7 +727,7 @@ FocusListener, TraverseListener, KeyListener {
 
 		/*
 		 * (non-Javadoc)
-		 * 
+		 *
 		 * @see org.eclipse.swt.widgets.Control#setBackground(org.eclipse.swt.graphics.Color)
 		 */
 		@Override
@@ -723,7 +738,7 @@ FocusListener, TraverseListener, KeyListener {
 
 		/*
 		 * (non-Javadoc)
-		 * 
+		 *
 		 * @see org.eclipse.swt.widgets.Control#setForeground(org.eclipse.swt.graphics.Color)
 		 */
 		@Override
@@ -737,7 +752,7 @@ FocusListener, TraverseListener, KeyListener {
 
 		/*
 		 * (non-Javadoc)
-		 * 
+		 *
 		 * @see org.eclipse.swt.widgets.Listener#handleEvent(org.eclipse.swt.widgets.Event)
 		 */
 		@Override
@@ -753,7 +768,7 @@ FocusListener, TraverseListener, KeyListener {
 
 		/*
 		 * (non-Javadoc)
-		 * 
+		 *
 		 * @see org.eclipse.swt.widgets.Control#computeSize(int, int, boolean)
 		 */
 		@Override
@@ -769,11 +784,11 @@ FocusListener, TraverseListener, KeyListener {
 
 		/*
 		 * (non-Javadoc)
-		 * 
+		 *
 		 * @see org.eclipse.swt.widgets.Widget#checkSubclass()
 		 */
 		@Override
 		protected void checkSubclass() {
 		}
 	}
-}
\ No newline at end of file
+}
