@@ -18,6 +18,8 @@ package com.clustercontrol.accesscontrol.composite;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.List;
+import java.util.Map;
+import java.util.concurrent.ConcurrentHashMap;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -34,16 +36,19 @@ import com.clustercontrol.accesscontrol.action.GetUserListTableDefine;
 import com.clustercontrol.accesscontrol.composite.action.UserDoubleClickListener;
 import com.clustercontrol.accesscontrol.util.AccessEndpointWrapper;
 import com.clustercontrol.bean.Property;
+import com.clustercontrol.util.EndpointManager;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.util.UIManager;
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.viewer.CommonTableViewer;
 import com.clustercontrol.ws.access.InvalidRole_Exception;
 import com.clustercontrol.ws.access.UserInfo;
 
 /**
  * アクセス[ユーザ]ビュー用のコンポジットクラスです。
- * 
+ *
  * クライアントのビューを構成します。
- * 
+ *
  * @version 2.0.0
  * @since 2.0.0
  */
@@ -63,10 +68,10 @@ public class UserListComposite extends Composite {
 
 	/**
 	 * コンストラクタ
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @param style スタイル
-	 * 
+	 *
 	 * @see org.eclipse.swt.SWT
 	 * @see org.eclipse.swt.widgets.Composite#Composite(Composite parent, int style)
 	 * @see #initialize()
@@ -86,6 +91,7 @@ public class UserListComposite extends Composite {
 		layout.marginWidth = 0;
 
 		m_labelType = new Label(this, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "type", m_labelType);
 		GridData gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
@@ -93,7 +99,8 @@ public class UserListComposite extends Composite {
 
 		// テーブルの作成
 		Table table = new Table(this, SWT.H_SCROLL | SWT.V_SCROLL
-				| SWT.FULL_SELECTION | SWT.SINGLE);
+				| SWT.FULL_SELECTION | SWT.MULTI);
+		WidgetTestUtil.setTestId(this, null, table);
 		table.setHeaderVisible(true);
 		table.setLinesVisible(true);
 
@@ -106,6 +113,7 @@ public class UserListComposite extends Composite {
 
 		// 合計ラベルの作成
 		m_labelCount = new Label(this, SWT.RIGHT);
+		WidgetTestUtil.setTestId(this, "count", m_labelCount);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
@@ -114,9 +122,13 @@ public class UserListComposite extends Composite {
 		// テーブルビューアの作成
 		m_viewer = new CommonTableViewer(table);
 		m_viewer.createTableColumn(GetUserListTableDefine.get(),
-				GetUserListTableDefine.SORT_COLUMN_INDEX,
+				GetUserListTableDefine.SORT_COLUMN_INDEX1,
+				GetUserListTableDefine.SORT_COLUMN_INDEX2,
 				GetUserListTableDefine.SORT_ORDER);
 
+		for (int i = 0; i < table.getColumnCount(); i++){
+			table.getColumn(i).setMoveable(true);
+		}
 		// ダブルクリックリスナの追加
 		m_viewer.addDoubleClickListener(new UserDoubleClickListener(this));
 	}
@@ -124,7 +136,7 @@ public class UserListComposite extends Composite {
 	/**
 	 * テーブルビューアーを更新します。<BR>
 	 * ユーザ一覧情報を取得し、共通テーブルビューアーにセットします。
-	 * 
+	 *
 	 * @see com.clustercontrol.accesscontrol.action.GetUserList#getAll()
 	 */
 	@Override
@@ -132,36 +144,55 @@ public class UserListComposite extends Composite {
 
 		//ジョブ履歴情報取得
 		List<UserInfo> infoList = null;
-		try {
-			infoList = AccessEndpointWrapper.getUserInfoList();
-		} catch (InvalidRole_Exception e) {
-			// 権限なし
-			MessageDialog.openInformation(null, Messages.getString("message"),
-					Messages.getString("message.accesscontrol.16"));
+		Map<String, List<UserInfo>> dispDataMap= new ConcurrentHashMap<String, List<UserInfo>>();
+		Map<String, String> errorMsgs = new ConcurrentHashMap<>();
 
-			// 一覧の参照権限がない場合、ユーザ自身の情報を表示する
-			infoList = getOwnUserList();
+		//実行契機情報取得
+		for(String managerName : EndpointManager.getActiveManagerSet()) {
+			try {
+				AccessEndpointWrapper wrapper = AccessEndpointWrapper.getWrapper(managerName);
+				infoList = wrapper.getUserInfoList();
+			} catch (InvalidRole_Exception e) {
+				// 権限なし
+				errorMsgs.put( managerName, Messages.getString("message.accesscontrol.16") );
 
-		} catch (Exception e) {
-			// 上記以外の例外
-			m_log.warn("update(), " + e.getMessage(), e);
-			MessageDialog.openError(
-					null,
-					Messages.getString("failed"),
-					Messages.getString("message.hinemos.failure.unexpected") + ", " + e.getMessage());
+				// 一覧の参照権限がない場合、ユーザ自身の情報を表示する
+				infoList = getOwnUserList(managerName);
+
+			} catch (Exception e) {
+				// 上記以外の例外
+				m_log.warn("update(), " + e.getMessage(), e);
+				errorMsgs.put( managerName, Messages.getString("message.hinemos.failure.unexpected") + ", " + e.getMessage());
+			}
+			
+			if (infoList == null) {
+				infoList = new ArrayList<UserInfo>();
+			}
+
+			dispDataMap.put(managerName, infoList);
+		}
+
+		//メッセージ表示
+		if( 0 < errorMsgs.size() ){
+			UIManager.showMessageBox(errorMsgs, true);
 		}
 
 		ArrayList<Object> listInput = new ArrayList<Object>();
-		for (UserInfo info : infoList) {
-			ArrayList<Object> obj = new ArrayList<Object>();
-			obj.add(info.getId());
-			obj.add(info.getName());
-			obj.add(info.getDescription());
-			obj.add(info.getCreateUserId());
-			obj.add(new Date(info.getCreateDate()));
-			obj.add(info.getModifyUserId());
-			obj.add(new Date(info.getModifyDate()));
-			listInput.add(obj);
+
+		for(Map.Entry<String, List<UserInfo>> map : dispDataMap.entrySet()) {
+			for (UserInfo info : map.getValue()) {
+				ArrayList<Object> obj = new ArrayList<Object>();
+				obj.add(map.getKey());
+				obj.add(info.getId());
+				obj.add(info.getName());
+				obj.add(info.getDescription());
+				obj.add(info.getCreateUserId());
+				obj.add(new Date(info.getCreateDate()));
+				obj.add(info.getModifyUserId());
+				obj.add(new Date(info.getModifyDate()));
+				obj.add(null);
+				listInput.add(obj);
+			}
 		}
 
 		m_viewer.setInput(listInput);
@@ -175,17 +206,17 @@ public class UserListComposite extends Composite {
 	 * テーブルビューアーを更新します。<BR>
 	 * フィルタ条件に一致するユーザ一覧情報を取得し、<BR>
 	 * 共通テーブルビューアーにセットします。
-	 * 
+	 *
 	 * @param condition フィルタ条件
-	 * 
-	 * @see com.clustercontrol.accesscontrol.action.GetUserList#get(Property)
+	 *
+	 * @see com.clustercontrol.accesscontrol.action.GetUserList#getJobEditState(Property)
 	 */
 	public void update(Property condition) {
 	}
 
 	/**
 	 * このコンポジットが利用するテーブルビューアを返します。
-	 * 
+	 *
 	 * @return テーブルビューア
 	 */
 	public TableViewer getTableViewer() {
@@ -194,7 +225,7 @@ public class UserListComposite extends Composite {
 
 	/**
 	 * このコンポジットが利用するテーブルを返します。
-	 * 
+	 *
 	 * @return テーブル
 	 */
 	public Table getTable() {
@@ -203,7 +234,7 @@ public class UserListComposite extends Composite {
 
 	/**
 	 * ユーザIDを返します。
-	 * 
+	 *
 	 * @return ユーザID
 	 */
 	public String getUid() {
@@ -212,7 +243,7 @@ public class UserListComposite extends Composite {
 
 	/**
 	 * ユーザIDを設定します。
-	 * 
+	 *
 	 * @param uid ユーザID
 	 */
 	public void setUid(String uid) {
@@ -222,16 +253,17 @@ public class UserListComposite extends Composite {
 
 	/**
 	 * ユーザ自身の情報をリストとして取得します。<BR>
-	 * 
+	 *
 	 * @return ユーザ情報一覧
 	 */
-	public List<UserInfo> getOwnUserList() {
+	public List<UserInfo> getOwnUserList(String managerName) {
 
 		//ユーザ情報一覧
 		List<UserInfo> infoList = new ArrayList<UserInfo>();
 		UserInfo info = null;
 		try {
-			info = AccessEndpointWrapper.getOwnUserInfo();
+			AccessEndpointWrapper wrapper = AccessEndpointWrapper.getWrapper(managerName);
+			info = wrapper.getOwnUserInfo();
 		} catch (InvalidRole_Exception e) {
 			// 権限なし
 			MessageDialog.openInformation(null, Messages.getString("message"),
@@ -254,4 +286,4 @@ public class UserListComposite extends Composite {
 
 		return infoList;
 	}
-}
\ No newline at end of file
+}
