@@ -24,12 +24,34 @@ import javax.persistence.EntityExistsException;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import com.clustercontrol.accesscontrol.bean.ObjectPrivilegeFilterInfo;
+import com.clustercontrol.accesscontrol.bean.ObjectPrivilegeInfo;
+import com.clustercontrol.accesscontrol.bean.PrivilegeConstant.ObjectPrivilegeMode;
+import com.clustercontrol.accesscontrol.bean.RoleIdConstant;
+import com.clustercontrol.accesscontrol.bean.RoleInfo;
+import com.clustercontrol.accesscontrol.bean.RoleTreeItem;
+import com.clustercontrol.accesscontrol.bean.SystemPrivilegeInfo;
+import com.clustercontrol.accesscontrol.bean.UserInfo;
+import com.clustercontrol.accesscontrol.factory.LoginUserModifier;
+import com.clustercontrol.accesscontrol.factory.LoginUserSelector;
+import com.clustercontrol.accesscontrol.factory.RoleModifier;
+import com.clustercontrol.accesscontrol.factory.RoleSelector;
+import com.clustercontrol.accesscontrol.util.ObjectPrivilegeUtil;
+import com.clustercontrol.accesscontrol.util.ObjectPrivilegeValidator;
+import com.clustercontrol.accesscontrol.util.RoleValidator;
+import com.clustercontrol.accesscontrol.util.UserRoleCache;
+import com.clustercontrol.accesscontrol.util.UserRoleCacheRefreshCallback;
+import com.clustercontrol.accesscontrol.util.UserValidator;
+import com.clustercontrol.accesscontrol.util.VersionUtil;
+import com.clustercontrol.bean.HinemosModuleConstant;
+import com.clustercontrol.commons.util.HinemosSessionContext;
+import com.clustercontrol.commons.util.JpaTransactionManager;
 import com.clustercontrol.fault.FacilityDuplicate;
 import com.clustercontrol.fault.FacilityNotFound;
 import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.fault.InvalidRole;
-import com.clustercontrol.fault.InvalidUserPass;
 import com.clustercontrol.fault.InvalidSetting;
+import com.clustercontrol.fault.InvalidUserPass;
 import com.clustercontrol.fault.JobMasterNotFound;
 import com.clustercontrol.fault.ObjectPrivilege_InvalidRole;
 import com.clustercontrol.fault.PrivilegeDuplicate;
@@ -50,38 +72,15 @@ import com.clustercontrol.repository.bean.FacilitySortOrderConstant;
 import com.clustercontrol.repository.bean.FacilityTreeAttributeConstant;
 import com.clustercontrol.repository.bean.ScopeInfo;
 import com.clustercontrol.repository.factory.FacilityModifier;
-import com.clustercontrol.repository.factory.FacilitySelector;
 import com.clustercontrol.repository.session.RepositoryControllerBean;
-import com.clustercontrol.repository.util.FacilityTreeCache;
-import com.clustercontrol.repository.util.RepositoryManagerUtil;
-import com.clustercontrol.repository.util.RepositoryUpdateTime;
+import com.clustercontrol.repository.util.FacilityIdCacheInitCallback;
+import com.clustercontrol.repository.util.FacilityTreeCacheRefreshCallback;
+import com.clustercontrol.repository.util.RepositoryChangedNotificationCallback;
 import com.clustercontrol.repository.util.RepositoryValidator;
 
-import com.clustercontrol.accesscontrol.bean.ObjectPrivilegeFilterInfo;
-import com.clustercontrol.accesscontrol.bean.ObjectPrivilegeInfo;
-import com.clustercontrol.accesscontrol.bean.PrivilegeConstant.ObjectPrivilegeMode;
-import com.clustercontrol.accesscontrol.bean.RoleIdConstant;
-import com.clustercontrol.accesscontrol.bean.RoleInfo;
-import com.clustercontrol.accesscontrol.bean.RoleTreeItem;
-import com.clustercontrol.accesscontrol.bean.SystemPrivilegeInfo;
-import com.clustercontrol.accesscontrol.bean.UserInfo;
-import com.clustercontrol.accesscontrol.factory.LoginUserModifier;
-import com.clustercontrol.accesscontrol.factory.LoginUserSelector;
-import com.clustercontrol.accesscontrol.factory.RoleModifier;
-import com.clustercontrol.accesscontrol.factory.RoleSelector;
-import com.clustercontrol.accesscontrol.util.ObjectPrivilegeUtil;
-import com.clustercontrol.accesscontrol.util.ObjectPrivilegeValidator;
-import com.clustercontrol.accesscontrol.util.RoleValidator;
-import com.clustercontrol.accesscontrol.util.UserRoleCache;
-import com.clustercontrol.accesscontrol.util.UserValidator;
-import com.clustercontrol.accesscontrol.util.VersionUtil;
-import com.clustercontrol.bean.HinemosModuleConstant;
-import com.clustercontrol.commons.util.HinemosSessionContext;
-import com.clustercontrol.commons.util.JpaTransactionManager;
-
 /**
  * アカウント機能を実現するSession Bean<BR>
- * 
+ *
  */
 public class AccessControllerBean {
 
@@ -90,7 +89,7 @@ public class AccessControllerBean {
 
 	/**
 	 * ログインチェックの為、本メソッドを使用します。
-	 * 
+	 *
 	 */
 	public void checkLogin() {
 
@@ -98,11 +97,11 @@ public class AccessControllerBean {
 
 	/**
 	 * ユーザ検索条件に基づき、ユーザ一覧情報を取得する。<BR>
-	 * 
-	 * 
+	 *
+	 *
 	 * @return ユーザ情報のリスト
 	 * @throws HinemosUnknown
-	 * 
+	 *
 	 * @see com.clustercontrol.accesscontrol.factory.LoginUserSelector#getUserList(Property)
 	 */
 	public ArrayList<UserInfo> getUserInfoList() throws HinemosUnknown {
@@ -127,8 +126,8 @@ public class AccessControllerBean {
 
 	/**
 	 * 自身のユーザ情報を取得する。<BR>
-	 * 
-	 * 
+	 *
+	 *
 	 * @return 自身のユーザ情報
 	 * @throws HinemosUnknown
 	 */
@@ -160,14 +159,14 @@ public class AccessControllerBean {
 
 	/**
 	 * ユーザ情報を取得する。<BR>
-	 * 
-	 * 
+	 *
+	 *
 	 * @param userId ユーザID
 	 * @param mode 取得モード
 	 * @param locale ロケール情報
 	 * @return ユーザ情報
 	 * @throws HinemosUnknown
-	 * 
+	 *
 	 * @see com.clustercontrol.bean.PropertyConstant
 	 * @see com.clustercontrol.accesscontrol.factory.UserProperty#getProperty(String, int, Locale)
 	 */
@@ -195,8 +194,8 @@ public class AccessControllerBean {
 
 	/**
 	 * ユーザ認証する<BR>
-	 * 
-	 * 
+	 *
+	 *
 	 * @param username ユーザ名
 	 * @param password パスワード
 	 * @param systemPrivilegeList システム権限情報
@@ -234,20 +233,19 @@ public class AccessControllerBean {
 
 	/**
 	 * ユーザを追加する。<BR>
-	 * 
-	 * 
+	 *
+	 *
 	 * @param info ユーザ情報
 	 * @throws HinemosUnknown
 	 * @throws UserDuplicate
 	 * @throws InvalidSetting
-	 * 
+	 *
 	 * @see com.clustercontrol.accesscontrol.factory.LoginUserModifier#addUser(Property, String, String)
 	 */
 	public void addUserInfo(UserInfo info) throws HinemosUnknown, UserDuplicate, InvalidSetting {
 		m_log.info("user=" + HinemosSessionContext.instance().getProperty(HinemosSessionContext.LOGIN_USER_ID));
 
 		JpaTransactionManager jtm = null;
-		boolean commit = false;
 		try {
 			jtm = new JpaTransactionManager();
 			jtm.begin();
@@ -256,8 +254,9 @@ public class AccessControllerBean {
 
 			/** メイン処理 */
 			LoginUserModifier.addUserInfo(info, (String)HinemosSessionContext.instance().getProperty(HinemosSessionContext.LOGIN_USER_ID));
+			
+			jtm.addCallback(new UserRoleCacheRefreshCallback());
 			jtm.commit();
-			commit = true;
 		} catch (UserDuplicate e) {
 			jtm.rollback();
 			throw e;
@@ -273,24 +272,20 @@ public class AccessControllerBean {
 			jtm.rollback();
 			throw new HinemosUnknown(e.getMessage(), e);
 		} finally {
-			if (commit) {
-				// ユーザロールキャッシュ情報を変更する
-				UserRoleCache.refresh();
-			}
 			jtm.close();
 		}
 	}
 
 	/**
 	 * ユーザ情報を変更する。<BR>
-	 * 
-	 * 
+	 *
+	 *
 	 * @param info ユーザ情報
 	 * @throws HinemosUnknown
 	 * @throws UserNotFound
 	 * @throws UnEditableUser
 	 * @throws InvalidSetting
-	 * 
+	 *
 	 * @see com.clustercontrol.accesscontrol.factory.LoginUserModifier#modifyUser(Property, String)
 	 */
 	public void modifyUserInfo(UserInfo info) throws HinemosUnknown, UserNotFound, UnEditableUser, InvalidSetting {
@@ -333,29 +328,31 @@ public class AccessControllerBean {
 
 	/**
 	 * ユーザ情報を削除する。<BR>
-	 * 
-	 * 
-	 * @param userId ユーザID
+	 *
+	 *
+	 * @param userIdList ユーザIDリスト
 	 * @throws HinemosUnknown
 	 * @throws UserNotFound
 	 * @throws UsedUser
 	 * @throws UnEditableUser
-	 * 
+	 *
 	 * @see com.clustercontrol.accesscontrol.factory.LoginUserModifier#deleteUser(String, String)
 	 */
-	public void deleteUserInfo(String userId) throws HinemosUnknown, UserNotFound, UsedUser, UnEditableUser {
+	public void deleteUserInfo(List<String> userIdList) throws HinemosUnknown, UserNotFound, UsedUser, UnEditableUser {
 		JpaTransactionManager jtm = null;
-		boolean commit = false;
 
 		/** メイン処理 */
 		try {
 			jtm = new JpaTransactionManager();
 			jtm.begin();
 
-			LoginUserModifier.deleteUserInfo(userId, (String)HinemosSessionContext.instance().getProperty(HinemosSessionContext.LOGIN_USER_ID));
+			for(String userId : userIdList) {
+				LoginUserModifier.deleteUserInfo(userId, (String)HinemosSessionContext.instance().getProperty(HinemosSessionContext.LOGIN_USER_ID));
+			}
 
+			jtm.addCallback(new UserRoleCacheRefreshCallback());
+			
 			jtm.commit();
-			commit = true;
 		} catch (UserNotFound e) {
 			jtm.rollback();
 			throw e;
@@ -374,23 +371,19 @@ public class AccessControllerBean {
 			jtm.rollback();
 			throw new HinemosUnknown(e.getMessage(), e);
 		} finally {
-			if (commit) {
-				// ユーザロールキャッシュ情報を変更する
-				UserRoleCache.refresh();
-			}
 			jtm.close();
 		}
 	}
 
 	/**
 	 * 自分自身のパスワードを変更する。<BR>
-	 * 
-	 * 
+	 *
+	 *
 	 * @param userId ユーザID
 	 * @param password パスワード
 	 * @throws HinemosUnknown
 	 * @throws UserNotFound
-	 * 
+	 *
 	 */
 	public void changeOwnPassword(String password) throws HinemosUnknown, UserNotFound {
 		m_log.debug("changeOwnPassword() password = " + password);
@@ -424,13 +417,13 @@ public class AccessControllerBean {
 
 	/**
 	 * パスワードを変更する。<BR>
-	 * 
-	 * 
+	 *
+	 *
 	 * @param userId ユーザID
 	 * @param password パスワード
 	 * @throws HinemosUnknown
 	 * @throws UserNotFound
-	 * 
+	 *
 	 * @see com.clustercontrol.accesscontrol.factory.LoginUserModifier#modifyUserPassword(String, String)
 	 */
 	public void changePassword(String userId, String password) throws HinemosUnknown, UserNotFound {
@@ -462,8 +455,8 @@ public class AccessControllerBean {
 
 	/**
 	 * ログインしているユーザがADMINISTRATORSロールかHINEMOS_MODULEロールに所属しているかを確認する。<BR>
-	 * 
-	 * 
+	 *
+	 *
 	 * @return ADMINISTRATORSロールに所属していればtrue, そうでなければfalse
 	 * @throws HinemosUnknown
 	 */
@@ -504,8 +497,8 @@ public class AccessControllerBean {
 
 	/**
 	 * ログインしているユーザが指定したユーザ権限を持っているかどうかを確認する。<BR>
-	 * 
-	 * 
+	 *
+	 *
 	 * @param systemPrivilege システム権限情報
 	 * @return ユーザ権限を保持していればtrue, そうでなければfalse
 	 * @throws HinemosUnknown
@@ -538,12 +531,12 @@ public class AccessControllerBean {
 
 	/**
 	 * ログインユーザのユーザ名を取得する。<BR>
-	 * 
-	 * 
+	 *
+	 *
 	 * @return ユーザ名
 	 * @throws HinemosUnknown
 	 * @throws UserNotFound
-	 * 
+	 *
 	 * @see com.clustercontrol.accesscontrol.factory.LoginUserSelector#getUserName(String)
 	 */
 	public String getUserName() throws HinemosUnknown, UserNotFound {
@@ -573,8 +566,8 @@ public class AccessControllerBean {
 
 	/**
 	 * バージョン番号を取得する。<BR>
-	 * 
-	 * 
+	 *
+	 *
 	 */
 	public String getVersion() {
 		return VersionUtil.getVersion();
@@ -582,11 +575,11 @@ public class AccessControllerBean {
 
 	/**
 	 * ログインユーザ所属するロール一覧情報を取得する。<BR>
-	 * 
-	 * 
+	 *
+	 *
 	 * @return ロール情報のリスト
 	 * @throws HinemosUnknown
-	 * 
+	 *
 	 * @see com.clustercontrol.accesscontrol.factory.LoginUserSelector#getRoleList(Property)
 	 */
 	public ArrayList<String> getOwnerRoleIdList() throws HinemosUnknown {
@@ -615,11 +608,11 @@ public class AccessControllerBean {
 
 	/**
 	 * ロール一覧情報を取得する。<BR>
-	 * 
-	 * 
+	 *
+	 *
 	 * @return ロール情報のリスト
 	 * @throws HinemosUnknown
-	 * 
+	 *
 	 * @see com.clustercontrol.accesscontrol.factory.LoginUserSelector#getRoleList(Property)
 	 */
 	public ArrayList<RoleInfo> getRoleInfoList() throws HinemosUnknown {
@@ -645,12 +638,12 @@ public class AccessControllerBean {
 
 	/**
 	 * ロール情報を取得する。<BR>
-	 * 
-	 * 
+	 *
+	 *
 	 * @param roleId ロールID
 	 * @return ユーザ情報
 	 * @throws HinemosUnknown
-	 * 
+	 *
 	 */
 	public RoleInfo getRoleInfo(String roleId) throws HinemosUnknown {
 		JpaTransactionManager jtm = null;
@@ -677,9 +670,7 @@ public class AccessControllerBean {
 	/**
 	 * ロールを新規に作成する。
 	 * ロール作成時にロールスコープも新規に追加します。<BR>
-	 * 
-	 * Database commit後に実施すべきユーザ実装が存在するため、トランザクション開始はユーザが制御する。
-	 * 
+	 *
 	 * @param roleInfo
 	 * @throws RoleDuplicate
 	 * @throws FacilityDuplicate
@@ -689,15 +680,12 @@ public class AccessControllerBean {
 	 */
 	public void addRoleInfo(RoleInfo roleInfo)
 			throws RoleDuplicate, FacilityDuplicate, InvalidSetting, InvalidRole, HinemosUnknown {
-		boolean commit = false;
-
 		JpaTransactionManager jtm = null;
 
 		/** メイン処理 */
 		try {
-			// トランザクションがすでに開始されている場合は処理終了
 			jtm = new JpaTransactionManager();
-			jtm.begin(true);
+			jtm.begin();
 
 			// ロール入力チェック
 			RoleValidator.validateRoleInfo(roleInfo);
@@ -725,9 +713,13 @@ public class AccessControllerBean {
 					(String)HinemosSessionContext.instance().getProperty(HinemosSessionContext.LOGIN_USER_ID),
 					FacilitySortOrderConstant.DEFAULT_SORT_ORDER_ROLE_SCOPE,
 					false);
-
+			
+			jtm.addCallback(new FacilityIdCacheInitCallback());
+			jtm.addCallback(new FacilityTreeCacheRefreshCallback());
+			jtm.addCallback(new RepositoryChangedNotificationCallback());
+			jtm.addCallback(new UserRoleCacheRefreshCallback());
+			
 			jtm.commit();
-			commit = true;
 		} catch (RoleDuplicate e) {
 			jtm.rollback();
 			throw e;
@@ -755,39 +747,15 @@ public class AccessControllerBean {
 			jtm.rollback();
 			throw new HinemosUnknown(e.getMessage(),e);
 		} finally {
-			if (commit) {
-				try {
-					// ファシリティの木情報のキャッシュを初期化する
-					FacilitySelector.initCacheFacilityTree();
-					
-					// ファシリティツリー情報を更新する
-					FacilityTreeCache.refresh();
-					
-					// read-committedのため、commit後に外部コンポーネントに通知する
-					RepositoryManagerUtil.broadcastConfigured();
-				} catch (Exception e) {
-					m_log.warn("addScope() transaction failure.", e);
-					throw new HinemosUnknown(e.getMessage(),e);
-				} finally {
-					// ユーザロールキャッシュ情報を変更する
-					UserRoleCache.refresh();
-					jtm.close();
-				}
-			}
 			jtm.close();
 		}
-
-		// リポジトリ更新時刻リフレッシュ
-		RepositoryUpdateTime.refreshUpdateTime();
 	}
 
 	/**
 	 * ロール情報を変更する。<BR>
 	 * ロール変更時にロールスコープも変更します。<BR>
-	 * 
-	 * Database commit後に実施すべきユーザ実装が存在するため、トランザクション開始はユーザが制御する。
-	 * 
-	 * 
+	 *
+	 *
 	 * @param info ロール情報
 	 * @throws HinemosUnknown
 	 * @throws RoleNotFound
@@ -796,13 +764,11 @@ public class AccessControllerBean {
 	 * @throws InvalidSetting
 	 */
 	public void modifyRoleInfo(RoleInfo roleInfo) throws InvalidSetting, InvalidRole, RoleNotFound, UnEditableRole, FacilityNotFound, HinemosUnknown {
-		boolean commit = false;
 		JpaTransactionManager jtm = null;
 
 		try{
-			// トランザクションがすでに開始されている場合は処理終了
 			jtm = new JpaTransactionManager();
-			jtm.begin(true);
+			jtm.begin();
 
 			// ロール入力チェック
 			RoleValidator.validateRoleInfo(roleInfo);
@@ -824,9 +790,13 @@ public class AccessControllerBean {
 
 			// ロールスコープ更新
 			FacilityModifier.modifyScope(scopeInfo, (String)HinemosSessionContext.instance().getProperty(HinemosSessionContext.LOGIN_USER_ID), false);
-
+			
+			jtm.addCallback(new FacilityIdCacheInitCallback());
+			jtm.addCallback(new FacilityTreeCacheRefreshCallback());
+			jtm.addCallback(new RepositoryChangedNotificationCallback());
+			jtm.addCallback(new UserRoleCacheRefreshCallback());
+			
 			jtm.commit();
-			commit = true;
 		} catch (InvalidSetting e) {
 			jtm.rollback();
 			throw e;
@@ -851,40 +821,16 @@ public class AccessControllerBean {
 			jtm.rollback();
 			throw new HinemosUnknown(e.getMessage(),e);
 		} finally {
-			if (commit) {
-				try {
-
-					// ファシリティの木情報のキャッシュを初期化する
-					FacilitySelector.initCacheFacilityTree();
-					
-					// ファシリティツリー情報を更新する
-					FacilityTreeCache.refresh();
-					
-					// read-committedのため、commit後に外部コンポーネントに通知する
-					RepositoryManagerUtil.broadcastConfigured();
-				} catch (Exception e) {
-					m_log.warn("modifyScope() transaction failure."
-							+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
-					throw new HinemosUnknown(e.getMessage(),e);
-				} finally {
-					jtm.close();
-				}
-			}
 			jtm.close();
 		}
-
-		// リポジトリ更新時刻リフレッシュ
-		RepositoryUpdateTime.refreshUpdateTime();
 	}
 
 	/**
 	 * ロール情報を削除する。<BR>
 	 * ロール削除時にロールスコープも削除します。<BR>
-	 * 
-	 * Database commit後に実施すべきユーザ実装が存在するため、トランザクション開始はユーザが制御する。
-	 * 
-	 * 
-	 * @param roleId ロールID
+	 *
+	 *
+	 * @param roleIdList ロールIDリスト
 	 * @throws UsedFacility
 	 * @throws RoleNotFound
 	 * @throws UnEditableRole
@@ -893,30 +839,34 @@ public class AccessControllerBean {
 	 * @throws FacilityNotFound
 	 * @throws InvalidRole
 	 * @throws HinemosUnknown
-	 * 
+	 *
 	 */
-	public void deleteRoleInfo(String roleId) throws UsedFacility, RoleNotFound, UnEditableRole, UsedRole, UsedOwnerRole, FacilityNotFound, InvalidRole, HinemosUnknown {
-		boolean commit = false;
+	public void deleteRoleInfo(List<String> roleIdList) throws UsedFacility, RoleNotFound, UnEditableRole, UsedRole, UsedOwnerRole, FacilityNotFound, InvalidRole, HinemosUnknown {
 		JpaTransactionManager jtm = null;
 
 		/** メイン処理 */
 		try {
-			// トランザクションがすでに開始されている場合は処理終了
 			jtm = new JpaTransactionManager();
-			jtm.begin(true);
-			
-			// ロールスコープが他機能で使用されているか確認
-			new RepositoryControllerBean().checkIsUseFacility(roleId);
-			// ロールスコープ削除
-			FacilityModifier.deleteOwnerRoleScope(roleId, (String)HinemosSessionContext.instance().getProperty(HinemosSessionContext.LOGIN_USER_ID), true);
+			jtm.begin();
 
-			// ロールがオーナーロールとして使用されているか確認
-			RoleValidator.validateDeleteRole(roleId);
-			// ロール削除
-			RoleModifier.deleteRoleInfo(roleId, (String)HinemosSessionContext.instance().getProperty(HinemosSessionContext.LOGIN_USER_ID));
+			for(String roleId : roleIdList) {
+				// ロールスコープが他機能で使用されているか確認
+				new RepositoryControllerBean().checkIsUseFacility(roleId);
+				// ロールスコープ削除
+				FacilityModifier.deleteOwnerRoleScope(roleId, (String)HinemosSessionContext.instance().getProperty(HinemosSessionContext.LOGIN_USER_ID), true);
+
+				// ロールがオーナーロールとして使用されているか確認
+				RoleValidator.validateDeleteRole(roleId);
+				// ロール削除
+				RoleModifier.deleteRoleInfo(roleId, (String)HinemosSessionContext.instance().getProperty(HinemosSessionContext.LOGIN_USER_ID));
+			}
+			
+			jtm.addCallback(new FacilityIdCacheInitCallback());
+			jtm.addCallback(new FacilityTreeCacheRefreshCallback());
+			jtm.addCallback(new RepositoryChangedNotificationCallback());
+			jtm.addCallback(new UserRoleCacheRefreshCallback());
 			
 			jtm.commit();
-			commit = true;
 		} catch (UsedFacility e) {
 			jtm.rollback();
 			throw e;
@@ -944,36 +894,13 @@ public class AccessControllerBean {
 			jtm.rollback();
 			throw new HinemosUnknown(e.getMessage(),e);
 		} finally {
-			if (commit) {
-				try {
-					// ファシリティの木情報のキャッシュを初期化する
-					FacilitySelector.initCacheFacilityTree();
-					
-					// ファシリティツリー情報を更新する
-					FacilityTreeCache.refresh();
-
-					// read-committedのため、commit後に外部コンポーネントに通知する
-					RepositoryManagerUtil.broadcastConfigured();
-				} catch (Exception e) {
-					m_log.warn("deleteScope() transaction failure."
-							+ e.getClass().getSimpleName() +", " + e.getMessage(), e);
-					throw new HinemosUnknown(e.getMessage(),e);
-				} finally {
-					// ユーザロールキャッシュ情報を変更する
-					UserRoleCache.refresh();
-					jtm.close();
-				}
-			}
 			jtm.close();
 		}
-
-		// リポジトリ更新時刻リフレッシュ
-		RepositoryUpdateTime.refreshUpdateTime();
 	}
 
 	/**
 	 * ロールツリー情報を取得する。<BR>
-	 * 
+	 *
 	 * @param locale ロケール情報
 	 * @return ロールツリー情報{@link com.clustercontrol.accesscontrol.bean.RoleTreeItem}の階層オブジェクト
 	 * @throws HinemosUnknown
@@ -1011,7 +938,7 @@ public class AccessControllerBean {
 
 	/**
 	 * システム権限一覧情報を取得する。<BR>
-	 * 
+	 *
 	 * @return システム権限情報のリスト
 	 * @throws HinemosUnknown
 	 */
@@ -1037,7 +964,7 @@ public class AccessControllerBean {
 
 	/**
 	 * 指定されたロールIDを条件としてシステム権限一覧情報を取得する。<BR>
-	 * 
+	 *
 	 * @param ロールID
 	 * @return システム権限情報のリスト
 	 * @throws HinemosUnknown
@@ -1067,7 +994,7 @@ public class AccessControllerBean {
 
 	/**
 	 * 指定されたユーザIDを条件としてシステム権限一覧情報を取得する。<BR>
-	 * 
+	 *
 	 * @param ユーザID
 	 * @return システム権限情報のリスト
 	 * @throws HinemosUnknown
@@ -1094,7 +1021,7 @@ public class AccessControllerBean {
 
 	/**
 	 * ロールへのユーザの割り当てを行います<BR>
-	 * 
+	 *
 	 * @param roleId　ユーザを割り当てるノード
 	 * @param userIds 割り当てさせるユーザ(群)
 	 * @throws UnEditableRole
@@ -1103,7 +1030,6 @@ public class AccessControllerBean {
 	public void assignUserRole(String roleId, String[] userIds)
 			throws UnEditableRole, HinemosUnknown {
 		JpaTransactionManager jtm = null;
-		boolean commit = false;
 
 		try{
 			// トランザクション開始
@@ -1112,8 +1038,11 @@ public class AccessControllerBean {
 
 			/** メイン処理 */
 			RoleModifier.assignUserToRole(roleId, userIds);
+			
+			jtm.addCallback(new UserRoleCacheRefreshCallback());
+			jtm.addCallback(new FacilityTreeCacheRefreshCallback());
+			
 			jtm.commit();
-			commit = true;
 		} catch (UnEditableRole e) {
 			jtm.rollback();
 			throw e;
@@ -1129,20 +1058,13 @@ public class AccessControllerBean {
 			jtm.rollback();
 			throw new HinemosUnknown(e.getMessage(),e);
 		} finally {
-			if (commit) {
-				// ユーザロールキャッシュ情報を変更する
-				UserRoleCache.refresh();
-				// ファシリティツリーのオブジェクト権限情報をリフレッシュする
-				FacilityTreeCache.refresh();
-			}
-
 			jtm.close();
 		}
 	}
 
 	/**
 	 * ロールへのシステム権限の割り当てを行います<BR>
-	 * 
+	 *
 	 * @param roleId　システム権限を割り当てるノード
 	 * @param systemPrivileges 割り当てさせるシステム権限(群)
 	 * @throws UnEditableRole
@@ -1151,8 +1073,7 @@ public class AccessControllerBean {
 	public void replaceSystemPrivilegeRole(String roleId, List<SystemPrivilegeInfo> systemPrivileges)
 			throws UnEditableRole, HinemosUnknown {
 		JpaTransactionManager jtm = null;
-		boolean commit = false;
-
+		
 		try{
 			// トランザクション開始
 			jtm = new JpaTransactionManager();
@@ -1160,9 +1081,10 @@ public class AccessControllerBean {
 
 			/** メイン処理 */
 			RoleModifier.replaceSystemPrivilegeToRole(roleId, systemPrivileges);
-
+			
+			jtm.addCallback(new UserRoleCacheRefreshCallback());
+			
 			jtm.commit();
-			commit = true;
 		} catch (UnEditableRole e) {
 			jtm.rollback();
 			throw e;
@@ -1178,22 +1100,18 @@ public class AccessControllerBean {
 			jtm.rollback();
 			throw new HinemosUnknown(e.getMessage(),e);
 		} finally {
-			if (commit) {
-				// ユーザロールキャッシュ情報を変更する
-				UserRoleCache.refresh();
-			}
 			jtm.close();
 		}
 	}
 
 	/**
 	 * オブジェクト権限検索条件に基づき、オブジェクト権限一覧情報を取得する。<BR>
-	 * 
-	 * 
+	 *
+	 *
 	 * @param filter オブジェクト権限検索条件
 	 * @return オブジェクト権限のリスト
 	 * @throws HinemosUnknown
-	 * 
+	 *
 	 */
 	public ArrayList<ObjectPrivilegeInfo> getObjectPrivilegeInfoList(ObjectPrivilegeFilterInfo filter) throws HinemosUnknown {
 
@@ -1218,15 +1136,15 @@ public class AccessControllerBean {
 
 	/**
 	 * オブジェクト権限情報を取得する。<BR>
-	 * 
-	 * 
+	 *
+	 *
 	 * @param objectType
 	 * @param objectId
 	 * @param roleId
 	 * @param objectPrivilege
 	 * @return ユーザ情報
 	 * @throws HinemosUnknown
-	 * 
+	 *
 	 */
 	public ObjectPrivilegeInfo getObjectPrivilegeInfo(
 			String objectType, String objectId, String roleId, String objectPrivilege) throws HinemosUnknown {
@@ -1253,7 +1171,7 @@ public class AccessControllerBean {
 
 	/**
 	 * オブジェクト種別、オブジェクトIDに紐づくオブジェクト権限情報を差し替える。<BR>
-	 * 
+	 *
 	 * @param objectType オブジェクト種別
 	 * @param objectId オブジェクトID
 	 * @param info オブジェクト権限情報リスト
@@ -1261,13 +1179,12 @@ public class AccessControllerBean {
 	 * @throws HinemosUnknown
 	 * @throws InvalidSetting
 	 * @throws InvalidRole
-	 * 
+	 *
 	 */
 	public void replaceObjectPrivilegeInfo(String objectType, String objectId, List<ObjectPrivilegeInfo> list)
 			throws PrivilegeDuplicate, UsedObjectPrivilege, HinemosUnknown, InvalidSetting, InvalidRole, JobMasterNotFound {
 		m_log.info("user=" + HinemosSessionContext.instance().getProperty(HinemosSessionContext.LOGIN_USER_ID));
 		JpaTransactionManager jtm = null;
-		boolean commit = false;
 		/** メイン処理 */
 		try {
 			jtm = new JpaTransactionManager();
@@ -1280,7 +1197,7 @@ public class AccessControllerBean {
 			}
 
 			// オブジェクトWRITE権限チェック
-			ObjectPrivilegeUtil.getObjectPrivilegeObject(objectType, objectId, ObjectPrivilegeMode.WRITE);
+			ObjectPrivilegeUtil.getObjectPrivilegeObject(objectType, objectId, ObjectPrivilegeMode.MODIFY);
 
 			//入力チェック
 			ObjectPrivilegeValidator.validateObjectPrivilegeInfo(objectType, objectId, list);
@@ -1288,10 +1205,15 @@ public class AccessControllerBean {
 			/** メイン処理 */
 			RoleModifier.replaceObjectPrivilegeInfo(objectType, objectId, list,
 					(String)HinemosSessionContext.instance().getProperty(HinemosSessionContext.LOGIN_USER_ID));
-
-			jtm.commit();
-			commit = true;
 			
+			// スコープのオブジェクト権限処理の場合はファシリティツリー情報、最終更新時刻を更新する
+			if (HinemosModuleConstant.PLATFORM_REPOSITORY.equals(objectType)) {
+				jtm.addCallback(new FacilityTreeCacheRefreshCallback());
+				jtm.addCallback(new RepositoryChangedNotificationCallback());
+			}
+			
+			jtm.commit();
+
 		} catch (InvalidSetting e) {
 			jtm.rollback();
 			throw e;
@@ -1316,13 +1238,6 @@ public class AccessControllerBean {
 			jtm.rollback();
 			throw new HinemosUnknown(e.getMessage(), e);
 		} finally {
-			if (commit) {
-				// スコープのオブジェクト権限処理の場合はファシリティツリー情報、最終更新時刻を更新する
-				if (HinemosModuleConstant.PLATFORM_REPOSITORY.equals(objectType)) {
-					RepositoryUpdateTime.refreshUpdateTime();
-					FacilityTreeCache.refresh();
-				}
-			}
 			jtm.close();
 		}
 	}
