@@ -2,18 +2,20 @@ package com.clustercontrol.accesscontrol.util;
 
 /**
  * オブジェクト権限情報(オブジェクト種別、オブジェクトID)をまとめたクラス
- * 
+ *
  */
 
 
 public class ObjectBean{
+	private String m_managerName = "";
 	private String m_objectType = "";
 	private String m_objectId = "";
 
 	public ObjectBean() {
 	}
 
-	public ObjectBean(String objectType, String objectId) {
+	public ObjectBean(String managerName, String objectType, String objectId) {
+		this.m_managerName = managerName;
 		this.m_objectType = objectType;
 		this.m_objectId = objectId;
 	}
@@ -36,4 +38,18 @@ public class ObjectBean{
 		this.m_objectId = objectId;
 	}
 
-}
\ No newline at end of file
+	/**
+	 * @return the m_managerName
+	 */
+	public String getManagerName() {
+		return m_managerName;
+	}
+
+	/**
+	 * @param m_managerName the m_managerName to set
+	 */
+	public void setManagerName(String m_managerName) {
+		this.m_managerName = m_managerName;
+	}
+
+}
