@@ -1,14 +1,10 @@
 package com.clustercontrol.accesscontrol.viewer;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
 import org.eclipse.jface.viewers.TreeViewer;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Tree;
 
 public class RoleSettingTreeViewer extends TreeViewer{
-	// ログ
-	private static Log m_log = LogFactory.getLog( RoleSettingTreeViewer.class );
 
 	public RoleSettingTreeViewer(Composite parent) {
 		super(parent);
