@@ -41,6 +41,9 @@ import java.util.concurrent.Executors;
 import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.TimeUnit;
 
+import javax.net.ssl.HostnameVerifier;
+import javax.net.ssl.HttpsURLConnection;
+
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.apache.log4j.PropertyConfigurator;
@@ -85,15 +88,17 @@ public class Agent {
 
 	private static AgentInfo agentInfo = new AgentInfo();
 
-	public static final Integer DEFAULT_CONNECT_TIMEOUT = 10;
-	public static final Integer DEFAULT_REQUEST_TIMEOUT = 60;
+	public static final Integer DEFAULT_CONNECT_TIMEOUT = 10000;
+	public static final Integer DEFAULT_REQUEST_TIMEOUT = 60000;
 
 	public static final String DEFAULT_PROXY_HOST = "";
-	public static final int DEFAULT_PROXY_PORT = 8080;
+	public static final int DEFAULT_PROXY_PORT = 8081;
 	public static final String DEFAULT_PROXY_USER = "";
 	public static final String DEFAULT_PROXY_PASSWORD = "";
 	
 	private static final String REPLACE_VALUE_MANAGER_IP = "${ManagerIP}";
+	
+	private static int awakePort = 24005;
 
 	/*
 	 * AgentHome
@@ -173,6 +178,13 @@ public class Agent {
 		}
 	}
 
+	public static void setAwakePort(int awakePort) {
+		if (0 < awakePort && Agent.awakePort != awakePort) {
+			m_log.info("awakePort=" + awakePort);
+			Agent.awakePort = awakePort;
+		}
+	}
+	
 	/**
 	 * マネージャのawakeAgentを待つメソッド。
 	 * Agent.propertiesに指定されたUDPポート（デフォルト：24005）にパケットが送られてきたら、ラッチを開放する(releaseLatch)。
@@ -180,18 +192,13 @@ public class Agent {
 	 */
 	public void waitAwakeAgent () {
 		final int BUFSIZE = 1;
-		int port = 24005;
-
-		// awakeAgentを待つポート番号を Agent.propertiesから取得する
-		String portStr = AgentProperties.getProperty("awake.port",
-				Integer.toString(port));
-		port = Integer.parseInt(portStr);
 
 		byte[] buf = new byte[BUFSIZE];
 		InetAddress cAddr;		// マネージャのIPアドレス
 		int cPort;				// マネージャのポート
 		DatagramSocket sock = null;
 		boolean flag = true;
+		int port = 24005;
 		while (true) {
 			/*
 			 * UDPパケットを受信したらflagがtrueになる。
@@ -201,7 +208,12 @@ public class Agent {
 			 * このような実装とする。
 			 */
 			try {
+				if (sock != null && port != awakePort) {
+					sock.close();
+					sock = null;
+				}
 				if (sock == null || !sock.isBound()) {
+					port = awakePort;
 					sock = new DatagramSocket(port);
 					sock.setSoTimeout(1000);
 				}
@@ -211,7 +223,7 @@ public class Agent {
 				cPort = recvPacket.getPort();
 				flag = true;
 				m_log.info("waitAwakeAgent (" + cAddr.getHostAddress() +
-						" onPort=" + cPort + ") buf.length=" + buf.toString().length());
+						" onPort=" + cPort + ") buf.length=" + buf.length);
 			} catch (SocketTimeoutException e) {
 				if (flag) {
 					m_log.info("waitAwakeAgent packet end");
@@ -219,8 +231,8 @@ public class Agent {
 					flag = false;
 				}
 			} catch (Exception e) {
-				String msg = "waitAwakeAgent " + e.getClass().getSimpleName() + ", " + e.getMessage();
-				m_log.warn(msg);
+				String msg = "waitAwakeAgent port=" + awakePort + ", " + e.getClass().getSimpleName() + ", " + e.getMessage();
+				m_log.warn(msg, e);
 				m_log.debug(msg, e);
 				try {
 					Thread.sleep(60*1000);
@@ -327,6 +339,58 @@ public class Agent {
 		int proxyPort = DEFAULT_PROXY_PORT;
 		String proxyUser = DEFAULT_PROXY_USER;
 		String proxyPassword = DEFAULT_PROXY_PASSWORD;
+		
+		// ホスト認証回避のhostnameVerifierを登録する（HTTPS接続時以外は特に効果は無い）
+		{
+			HostnameVerifier hv = new HostnameVerifier() {
+				public boolean verify(String urlHostName,
+						javax.net.ssl.SSLSession session) {
+					return true;
+				}
+			};
+			
+			// Create the trust manager.
+			javax.net.ssl.TrustManager[] trustAllCerts = new javax.net.ssl.TrustManager[1];
+			class AllTrustManager implements
+					javax.net.ssl.TrustManager,
+					javax.net.ssl.X509TrustManager {
+				public java.security.cert.X509Certificate[] getAcceptedIssuers() {
+					return null;
+				}
+				
+				public void checkServerTrusted(
+						java.security.cert.X509Certificate[] certs,
+						String authType)
+						throws java.security.cert.CertificateException {
+					return;
+				}
+				
+				public void checkClientTrusted(
+						java.security.cert.X509Certificate[] certs,
+						String authType)
+						throws java.security.cert.CertificateException {
+					return;
+				}
+			}
+			javax.net.ssl.TrustManager tm = new AllTrustManager();
+			trustAllCerts[0] = tm;
+			// Create the SSL context
+			javax.net.ssl.SSLContext sc = javax.net.ssl.SSLContext.getInstance("SSL");
+			// Create the session context
+			javax.net.ssl.SSLSessionContext sslsc = sc.getServerSessionContext();
+			// Initialize the contexts; the session context takes the
+			// trust manager.
+			sslsc.setSessionTimeout(0);
+			sc.init(null, trustAllCerts, null);
+			// Use the default socket factory to create the socket for
+			// the secure
+			// connection
+			javax.net.ssl.HttpsURLConnection.setDefaultSSLSocketFactory(sc.getSocketFactory());
+
+			// Set the default host name verifier to enable the connection.
+			HttpsURLConnection.setDefaultHostnameVerifier(hv);
+
+		}
 
 		try {
 			String strConnect = AgentProperties.getProperty("connect.timeout");
@@ -520,12 +584,7 @@ public class Agent {
 		RunHistoryUtil.logHistory();
 
 		try {
-			// deleteAgentを行った直後に別スレッドのgetTopicと競合するとエージェントが重複した
-			// と認識されるため、deleteAgentとgetoTopicを排他する
-			synchronized(ReceiveTopic.lockTopicReceiveTiming) {
-				AgentEndPointWrapper.deleteAgent();
-				ReceiveTopic.terminate();
-			}
+			AgentEndPointWrapper.deleteAgent();
 		} catch (InvalidRole_Exception e) {
 			m_log.info("InvalidRoleException " + e.getMessage());
 		} catch (InvalidUserPass_Exception e) {
@@ -556,19 +615,22 @@ public class Agent {
 		String[] command = null;
 
 		if (agentCommand == AgentCommandConstant.UPDATE) {
+			command = new String[5];
+			command[0] = "CMD";
+			command[1] = "/C";
+			command[2] = "cscript";
+			command[3] = getAgentHome() + "/bin/RestartAgent.vbs";
+			command[4] = "copy";
+			m_log.info("restartWin.command for update = " + command[0] + " " + command[1] + " " + command[2] +
+					" " + command[3] + " " + command[4]);
+		} else {
 			command = new String[4];
 			command[0] = "CMD";
 			command[1] = "/C";
-			command[2] = getAgentHome() + "/bin/RestartAgent.vbs";
-			command[3] = "copy";
-			m_log.info("command = " + command[0] + " " + command[1] + " " + command[2] +
-					" " + command[3]);
-		} else {
-			command = new String[3];
-			command[0] = "CMD";
-			command[1] = "/C";
-			command[2] = getAgentHome() + "/bin/RestartAgent.vbs";
-			m_log.info("command = " + command[0] + " " + command[1] + " " + command[2]);
+			command[2] = "cscript";
+			command[3] = getAgentHome() + "/bin/RestartAgent.vbs";
+			m_log.info("restartWin.command for create = " + command[0] + " " + command[1] + " " + command[2] +
+			" " + command[3]);
 		}
 		try {
 			Runtime.getRuntime().exec(command);
@@ -584,6 +646,7 @@ public class Agent {
 		command[0] = "sh";
 		command[1] = "-c";
 		command[2] = getAgentHome() + "bin/" + script;
+		command[2] += " -q";
 		if (agentCommand == AgentCommandConstant.UPDATE) {
 			command[2] += " copy";
 		}
@@ -631,7 +694,6 @@ public class Agent {
 
 	/**
 	 * ログ設定を再読み込みするタスク
-	 * @author Hinemos
 	 *
 	 */
 	protected class ReloadLog4jTask implements Runnable {
@@ -661,9 +723,9 @@ public class Agent {
 			if(configURL != null){
 
 				// File Check
-				URLConnection conn = null;
+				URLConnection conn = null; 
 				try{
-					conn = configURL.openConnection();
+					conn = configURL.openConnection(); 
 					long lastModified = conn.getLastModified();
 
 					if (lastConfigured < lastModified)
@@ -675,14 +737,14 @@ public class Agent {
 				} catch (IOException e) {
 					m_log.warn("ReloadLog4jTask.run() Failed to check URL: " + configURL, e);
 				} finally {
-					
-					// close
+				
+					// close  
 					try{
 						if(conn != null && conn.getInputStream() != null){
 							conn.getInputStream().close();
 						}
 					} catch (IOException e){
-						m_log.warn("ReloadLog4jTask.run() Failed to close inputStream: " + configURL, e);
+						m_log.warn("ReloadLog4jTask.run() Failed to close inputStream: " + configURL, e);  
 					}
 				}
 			}
@@ -716,61 +778,57 @@ public class Agent {
 	}
 
 	public static AgentInfo getAgentInfo() {
-		
-		// OS情報以外の情報は、毎回セットする
-		agentInfo.setFacilityId(AgentProperties.getProperty("facilityId"));
-		
-		if (m_receiveTopic != null) {
-			agentInfo.setInterval(m_receiveTopic.getTopicInterval());
+		// IPアドレスが変更されて設定の再取得中はagentInfoを書き換えない
+		if (ReceiveTopic.isReloadFlg()) {
+			return agentInfo;
 		}
 		
+		agentInfo.setFacilityId(AgentProperties.getProperty("facilityId"));
+
 		// OS情報(識別したホスト名、IPアドレス)
-		// IPアドレスが変更されて設定の再取得中はagentInfo内のOS情報を書き換えない
-		if (!ReceiveTopic.isReloadFlg()) {
-			try {
-				// ホスト名取得
-				String hostname = System.getProperty("hostname");
-				m_log.debug("hostname=[" + hostname + "]");
-				agentInfo.setHostname(hostname);
-	
-				// IPアドレス取得
-				Enumeration<NetworkInterface> networkInterfaces = NetworkInterface.getNetworkInterfaces();
-				String newIpAddressStr = "";
-				ArrayList<String> newIpAddressList = new ArrayList<String>();
-				if (null != networkInterfaces) {
-					while (networkInterfaces.hasMoreElements()) {
-						NetworkInterface ni = networkInterfaces.nextElement();
-						Enumeration<InetAddress> inetAddresses = ni.getInetAddresses();
-						while (inetAddresses.hasMoreElements()) {
-							InetAddress in = inetAddresses.nextElement();
-							String hostAddress = in.getHostAddress();
-							if (hostAddress != null && !hostAddress.equals("127.0.0.1") &&
-									!hostAddress.startsWith("0:0:0:0:0:0:0:1") &&
-									!hostAddress.equals("::1")) {
-								newIpAddressList.add(hostAddress);
-								newIpAddressStr += "," + hostAddress;
-							}
+		try {
+			// ホスト名取得
+			String hostname = System.getProperty("hostname");
+			m_log.debug("hostname=[" + hostname + "]");
+			agentInfo.setHostname(hostname);
+
+			// IPアドレス取得
+			Enumeration<NetworkInterface> networkInterfaces = NetworkInterface.getNetworkInterfaces();
+			ArrayList<String> newIpAddressList = new ArrayList<String>();
+			if (null != networkInterfaces) {
+				while (networkInterfaces.hasMoreElements()) {
+					NetworkInterface ni = networkInterfaces.nextElement();
+					Enumeration<InetAddress> inetAddresses = ni.getInetAddresses();
+					while (inetAddresses.hasMoreElements()) {
+						InetAddress in = inetAddresses.nextElement();
+						String hostAddress = in.getHostAddress();
+						if (hostAddress != null && !hostAddress.equals("127.0.0.1") &&
+								!hostAddress.startsWith("0:0:0:0:0:0:0:1") &&
+								!hostAddress.equals("::1")) {
+							newIpAddressList.add(hostAddress);
 						}
 					}
 				}
-				if (agentInfo.getIpAddress().size() != newIpAddressList.size()) {
-					m_log.info("ipAddress change : " + agentInfo.getIpAddress().size() +
-							"," + newIpAddressList.size());
+			}
+			if (agentInfo.getIpAddress().size() != newIpAddressList.size()) {
+				m_log.info("ipAddress change : " + agentInfo.getIpAddress().size() +
+						"," + newIpAddressList.size());
+				agentInfo.getIpAddress().clear();
+				agentInfo.getIpAddress().addAll(newIpAddressList);
+				ReceiveTopic.setReloadFlg(true);
+			} else {
+				if (!agentInfo.getIpAddress().containsAll(newIpAddressList)) {
+					m_log.info("ipAddress change");
 					agentInfo.getIpAddress().clear();
 					agentInfo.getIpAddress().addAll(newIpAddressList);
 					ReceiveTopic.setReloadFlg(true);
-				} else {
-					if (!agentInfo.getIpAddress().containsAll(newIpAddressList)) {
-						m_log.info("ipAddress change");
-						agentInfo.getIpAddress().clear();
-						agentInfo.getIpAddress().addAll(newIpAddressList);
-						ReceiveTopic.setReloadFlg(true);
-					}
 				}
-			} catch (SocketException e) {
-				m_log.error(e,e);
 			}
+		} catch (SocketException e) {
+			m_log.error(e,e);
 		}
+		agentInfo.setInterval(ReceiveTopic.getTopicInterval());
+
 		m_log.debug(getAgentStr());
 
 		return agentInfo;
