@@ -72,8 +72,8 @@ public class ReceiveTopic extends Thread {
 	//protected ArrayList<String> m_facilityIdList;
 	private SendQueue m_sendQueue;
 
-	private int m_topicInterval = 30000;
-	private long m_runhistoryClearDelay = -1;
+	private static int m_topicInterval = 30000;
+	private long m_runhistoryClearDelay = 604800000;
 	
 	// Topicを4.1モードで動作させる。
 	private boolean newTopicMode = true; 
@@ -82,31 +82,11 @@ public class ReceiveTopic extends Thread {
 	private long disconnectCounter = 1;
 	private static boolean m_clearFlg = false;
 	private static boolean m_reloadFlg = false;
-	
-	// topic受信とエージェント終了時の通信コンフリクトを防ぐためのロック
-	public static final Object lockTopicReceiveTiming = new Object();
-	// エージェント終了フラグ
-	private static boolean isTerminated = false;
-	public static void terminate() {
-		isTerminated = true;
-	}
 
 	// 最後に受信した設定情報更新日時
 	private static SettingUpdateInfo settingLastUpdateInfo = null;
 
-	/**
-	 * コンストラクタ
-	 * @param agent ジョブエージェント
-	 * @param facilityIdList ファシリティIDのリスト
-	 * @param sendQueue　メッセージ送信用クラス
-	 * @param props　プロパティファイル情報
-	 */
-	public ReceiveTopic(SendQueue sendQueue) {
-		super();
-		m_sendQueue = sendQueue;
-
-		m_log.info("create ReceiveTopic ");
-
+	static {
 		// 再接続処理実行間隔取得
 		String interval, str;
 		str = "topic.interval";
@@ -120,16 +100,30 @@ public class ReceiveTopic extends Thread {
 				m_log.error(str,e);
 			}
 		}
+	}
+	
+	/**
+	 * コンストラクタ
+	 * @param agent ジョブエージェント
+	 * @param facilityIdList ファシリティIDのリスト
+	 * @param sendQueue　メッセージ送信用クラス
+	 * @param props　プロパティファイル情報
+	 */
+	public ReceiveTopic(SendQueue sendQueue) {
+		super();
+		m_sendQueue = sendQueue;
+
+		m_log.info("create ReceiveTopic ");
 
 		// ジョブ実行履歴の削除実行時間を取得
-		String delay = AgentProperties.getProperty("runhistory.clear.delay");
+		String delay = AgentProperties.getProperty("job.history.period");
 		if (delay != null) {
 			try {
-				// プロパティファイルには秒で記述
-				m_runhistoryClearDelay = Integer.parseInt(delay);
-				m_log.info("runhistory.clear.delay = " + m_runhistoryClearDelay + " sec");
+				// プロパティファイルにはmsecで記述
+				m_runhistoryClearDelay = Long.parseLong(delay);
+				m_log.info("job.history.period = " + m_runhistoryClearDelay + " msec");
 			} catch (NumberFormatException e) {
-				m_log.error("runhistory.clear.delay",e);
+				m_log.error("job.history.period",e);
 			}
 		}
 
@@ -187,14 +181,7 @@ public class ReceiveTopic extends Thread {
 				List<TopicInfo> topicInfoList = null;
 				SettingUpdateInfo updateInfo = null;
 				try {
-					// エージェントの終了処理が行われているにもかかわらずtopicをとりにいってしまう競合を防ぐため、synchronizedする
-					synchronized(lockTopicReceiveTiming) {
-						if (isTerminated == true) {
-							// エージェントの終了処理が行われている場合、このスレッドを即時終了する
-							return;
-						}
-						hinemosTopicInfo = AgentEndPointWrapper.getHinemosTopic();
-					}
+					hinemosTopicInfo = AgentEndPointWrapper.getHinemosTopic();
 				} catch (Exception e) {
 					/*
 					 * マネージャが停止している、もしくはマネージャと通信ができないと、
@@ -204,7 +191,7 @@ public class ReceiveTopic extends Thread {
 						disconnectCounter++;
 					}
 					// 一定時間、マネージャが応答していないと、ジョブ履歴を削除する。
-					if (disconnectCounter * m_topicInterval / 1000 > m_runhistoryClearDelay) {
+					if (disconnectCounter * m_topicInterval > m_runhistoryClearDelay) {
 						clearJobHistory();
 					}
 
@@ -214,8 +201,9 @@ public class ReceiveTopic extends Thread {
 					 * StackTraceはつけない。
 					 * どうしても見たかったらdebugにする。
 					 */
-					String message = "run() getTopic : " + e.getClass().getSimpleName() +
-							", " + e.getMessage();
+					String message = "run() getTopic : " + 
+							", " + disconnectCounter + "*" + m_topicInterval + ":" + m_runhistoryClearDelay + ", " +
+							e.getClass().getSimpleName() + ", " + e.getMessage();
 					m_log.warn(message);
 					m_log.debug(message, e);
 					continue; // whileまで戻る。
@@ -224,6 +212,7 @@ public class ReceiveTopic extends Thread {
 				// マネージャから取得した情報を関連クラスに配置する
 				topicInfoList = hinemosTopicInfo.getTopicInfoList();
 				updateInfo = hinemosTopicInfo.getSettingUpdateInfo();
+				Agent.setAwakePort(hinemosTopicInfo.getAwakePort());
 
 				/*
 				 * マネージャと接続直後の場合、ここで転送ログファイル、カスタム監視情報、Windowsイベント監視情報のリストを受け取り、
@@ -243,7 +232,7 @@ public class ReceiveTopic extends Thread {
 
 				m_log.debug("run : topicInfoList.size=" + topicInfoList.size());
 				for (TopicInfo topicInfo : topicInfoList) {
-					m_log.info("getTopic facilityId=" + topicInfo.getFacilityId() + ", flag=" + topicInfo.getFlag());
+					m_log.info("getTopic flag=" + topicInfo.getFlag());
 
 					RunInstructionInfo runInstructionInfo = topicInfo.getRunInstructionInfo();
 					if (runInstructionInfo != null) {
@@ -260,7 +249,9 @@ public class ReceiveTopic extends Thread {
 								agentCommand = 0;
 							}
 						}
-						Agent.restart(agentCommand);
+						if (agentCommand != 0) {
+							Agent.restart(agentCommand);
+						}
 					}
 					if ((topicFlag & TopicFlagConstant.NEW_FACILITY) != 0) {
 						UpdateModuleUtil.setAgentLibMd5();
@@ -447,10 +438,11 @@ public class ReceiveTopic extends Thread {
 				m_log.info("logfile: " +
 						"directory=" + info.getLogfileCheckInfo().getDirectory() +
 						", filename=" + info.getLogfileCheckInfo().getFileName() +
+						", fileencoding=" + info.getLogfileCheckInfo().getFileEncoding() +
 						", monitorId=" + info.getMonitorId() +
 						", monitorFlg=" + info.getMonitorFlg());
 			}
-			LogfileMonitorManager.setLogfileMonitor(list);
+			LogfileMonitorManager.setMonitorInfoList(list);
 
 		} catch (HinemosUnknown_Exception e) {
 			m_log.error(e,e);
@@ -610,8 +602,8 @@ public class ReceiveTopic extends Thread {
 					DeleteProcessThread thread = new DeleteProcessThread(info, m_sendQueue);
 					thread.start();
 				} else {
-					// ここは通らないはず
-					m_log.warn("runJob() : logical error, runHistory != null");
+					// タイミングによりジョブ実行命令を2つ受信した場合にここに入る
+					m_log.info("runJob() : logical error, runHistory != null");
 				}
 			}
 		} catch(Throwable e) {
@@ -669,7 +661,7 @@ public class ReceiveTopic extends Thread {
 		}
 	}
 
-	public int getTopicInterval() {
+	public static int getTopicInterval() {
 		return m_topicInterval;
 	}
 }
