@@ -22,8 +22,6 @@ import java.util.concurrent.ConcurrentHashMap;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
-import javax.xml.ws.WebServiceException;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
@@ -303,51 +301,29 @@ public class FileCheck {
 	private static String jobFileCheckResultRetry(JobFileCheck jobFileCheck)
 			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, MonitorNotFound_Exception, JobMasterNotFound_Exception, FacilityNotFound_Exception, JobInfoNotFound_Exception {
 		if (resultRetryCount < 0) {
-			String str = AgentProperties.getProperty("filecheck.retry.count", "15");
+			String str = AgentProperties.getProperty("job.filecheck.sender.tries", "15");
 			resultRetryCount = Integer.parseInt(str);
 			m_log.info("filecheck.retry.count=" + resultRetryCount);
 		}
 		if (resultRetrySleep < 0) {
-			String str = AgentProperties.getProperty("filecheck.retry.sleep", "60000");
+			String str = AgentProperties.getProperty("job.filecheck.sender.interval", "60000");
 			resultRetrySleep = Integer.parseInt(str);
 			m_log.info("filecheck.retry.sleep=" + resultRetrySleep);
 		}
-		
-		Exception lastEx = null;
-		
+
 		for (int i = 0; i < resultRetryCount; i++) {
-			lastEx = null;
 			try {
 				return AgentEndPointWrapper.jobFileCheckResult(jobFileCheck);
-			} catch (JobSessionDuplicate_Exception e) {
-				m_log.warn("jobFileCheckResultRetry " + e.getMessage());
-			} catch (Exception e) {
-				lastEx = e;
-				m_log.warn("jobFileCheckResultRetry " + e.getMessage());
+			}  catch (JobSessionDuplicate_Exception e) {
+				m_log.warn("sendNotifyRetry " + e.getMessage());
+			} catch (Throwable t) {
 				try {
 					Thread.sleep(resultRetrySleep);
 				} catch (InterruptedException e1) {
-					m_log.warn("jobFileCheckResultRetry " + e1.getMessage());
+					m_log.warn("sendNotifyRetry " + e1.getMessage());
 				}
 			}
 		}
-		
-		if (lastEx instanceof HinemosUnknown_Exception) {
-			throw (HinemosUnknown_Exception)lastEx;
-		} else if (lastEx instanceof InvalidRole_Exception) {
-			throw (InvalidRole_Exception)lastEx;
-		} else if (lastEx instanceof InvalidUserPass_Exception) {
-			throw (InvalidUserPass_Exception)lastEx;
-		} else if (lastEx instanceof MonitorNotFound_Exception) {
-			throw (MonitorNotFound_Exception)lastEx;
-		} else if (lastEx instanceof JobMasterNotFound_Exception) {
-			throw (JobMasterNotFound_Exception)lastEx;
-		} else if (lastEx instanceof FacilityNotFound_Exception) {
-			throw (FacilityNotFound_Exception)lastEx;
-		} else if (lastEx instanceof JobInfoNotFound_Exception) {
-			throw (JobInfoNotFound_Exception)lastEx;
-		}
-		
 		m_log.warn("give up jobFileCheckResultRetry. Maybe, manager is down");
 		return null;
 	}
