@@ -20,16 +20,14 @@ import java.math.BigDecimal;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import com.clustercontrol.accesscontrol.util.RoleValidator;
+import com.clustercontrol.bean.ScheduleConstant;
+import com.clustercontrol.commons.bean.Schedule;
 import com.clustercontrol.fault.CalendarNotFound;
 import com.clustercontrol.fault.InvalidRole;
 import com.clustercontrol.fault.InvalidSetting;
 import com.clustercontrol.fault.NotifyNotFound;
 import com.clustercontrol.fault.RoleNotFound;
-import com.clustercontrol.accesscontrol.util.RoleValidator;
-import com.clustercontrol.bean.ScheduleConstant;
-import com.clustercontrol.calendar.model.CalInfoEntity;
-import com.clustercontrol.commons.bean.Schedule;
-import com.clustercontrol.notify.model.NotifyInfoEntity;
 import com.clustercontrol.util.Messages;
 
 /**
@@ -42,7 +40,7 @@ public class CommonValidator {
 
 	/**
 	 * 指定されたIDがHinemosのID規則にマッチするかを確認する。
-	 * [a-z,A-Z,0-9,-,_]のみ許可する
+	 * [a-z,A-Z,0-9,-,_,.,@]のみ許可する (Hinemos5.0で「.」と「@」を追加)
 	 * 
 	 * @param id
 	 * @throws InvalidSetting
@@ -62,7 +60,7 @@ public class CommonValidator {
 		validateString(name, id, false, 1, maxSize);
 
 		/** メイン処理 */
-		if(!id.matches("^[A-Za-z0-9-_]+$")){
+		if(!id.matches("^[A-Za-z0-9-_.@]+$")){
 			Object[] args = { id, name };
 			InvalidSetting e = new InvalidSetting(Messages.getString("message.common.6", args));
 			m_log.info("validateId() : "
@@ -173,8 +171,7 @@ public class CommonValidator {
 		else{
 			try {
 				//対象のカレンダ設定を取得できない場合にExceptionエラーを発生させる。
-				@SuppressWarnings("unused")
-				CalInfoEntity entity = com.clustercontrol.calendar.util.QueryUtil.getCalInfoPK_OR(calendarId, ownerRoleId);
+				com.clustercontrol.calendar.util.QueryUtil.getCalInfoPK_OR(calendarId, ownerRoleId);
 			} catch (CalendarNotFound e) {
 				Object[] args = {calendarId};
 				m_log.warn("validateCalenderId() : "
@@ -211,7 +208,7 @@ public class CommonValidator {
 		}
 		else{
 			try {
-				NotifyInfoEntity entity = com.clustercontrol.notify.util.QueryUtil.getNotifyInfoPK_OR(notifyId, ownerRoleId);
+				com.clustercontrol.notify.util.QueryUtil.getNotifyInfoPK_OR(notifyId, ownerRoleId);
 			} catch (NotifyNotFound e) {
 				Object[] args = {notifyId};
 				throw new InvalidSetting(Messages.getString("message.common.10", args));
@@ -312,7 +309,7 @@ public class CommonValidator {
 			throw e;
 		}
 	}
-	
+
 	/**
 	 * ownerRoleIdがnullまたは、対象のロールが存在するかを確認する
 	 * さらに、変更時には、オーナーロールIDが変更されていないかを確認する
@@ -337,17 +334,17 @@ public class CommonValidator {
 			try {
 				// 存在確認
 				com.clustercontrol.accesscontrol.util.QueryUtil.getRolePK(ownerRoleId);
-				
+
 				// 変更時にオーナーロールIDが変わっていないか確認する
 				RoleValidator.validateModifyOwnerRole(pk, objectType, ownerRoleId);
 			} catch (RoleNotFound e) {
 				throw new InvalidSetting(e.getMessage(), e);
-			} 
+			}
 		}
 		return;
 	}
 
-	
+
 	/**
 	 * for debug
 	 * @param args
