@@ -32,6 +32,7 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.accesscontrol.annotation.HinemosObjectPrivilege;
+import com.clustercontrol.accesscontrol.bean.PrivilegeConstant.ObjectPrivilegeMode;
 import com.clustercontrol.accesscontrol.bean.RoleIdConstant;
 import com.clustercontrol.accesscontrol.jpql.compile.QueryPreparator;
 import com.clustercontrol.accesscontrol.model.ObjectPrivilegeEntity;
@@ -39,7 +40,6 @@ import com.clustercontrol.accesscontrol.model.ObjectPrivilegeEntityPK;
 import com.clustercontrol.accesscontrol.model.ObjectPrivilegeTargetEntity;
 import com.clustercontrol.accesscontrol.util.UserRoleCache;
 import com.clustercontrol.bean.HinemosModuleConstant;
-import com.clustercontrol.accesscontrol.bean.PrivilegeConstant.ObjectPrivilegeMode;
 import com.clustercontrol.fault.ObjectPrivilege_InvalidRole;
 import com.clustercontrol.jobmanagement.factory.CreateJobSession;
 
@@ -73,7 +73,6 @@ public class HinemosEntityManager implements EntityManager {
 	}
 
 	@Override
-	@Deprecated
 	public Query createNamedQuery(String arg0) {
 		return em.createNamedQuery(arg0);
 	}
@@ -476,7 +475,7 @@ public class HinemosEntityManager implements EntityManager {
 		if (hinemosObjectPrivilege == null) {
 			return;
 		}
-		
+
 		if(RoleIdConstant.isAdministratorRole(ownerRoleId)) {
 			// オーナーロールが特権ロールの場合、オブジェクト権限による絞込みを行わない。
 			return;
@@ -571,8 +570,9 @@ public class HinemosEntityManager implements EntityManager {
 		if (!(before_entity instanceof ObjectPrivilegeTargetEntity)) {
 			// オブジェクト権限エラー
 			ObjectPrivilege_InvalidRole e = new ObjectPrivilege_InvalidRole(
-					"targetClass = " + entityClass.getSimpleName()
-					+ ", pk = " + primaryKey.toString());
+					"user=" + loginUser
+					+ ", targetClass=" + entityClass.getSimpleName()
+					+ ", pk=" + primaryKey.toString());
 			m_log.info("checkObjectPrivilege() object privilege invalid. : "
 					+ e.getClass().getSimpleName() + ", " + e.getMessage());
 			throw e;
@@ -606,7 +606,7 @@ public class HinemosEntityManager implements EntityManager {
 		// 所属ロールが設定されている場合はオブジェクト権限有り
 		boolean existsflg = false;
 		for (String roleId : roleIdList) {
-			objectPrivilegeEntityPK 
+			objectPrivilegeEntityPK
 			= new ObjectPrivilegeEntityPK(objectType, ((ObjectPrivilegeTargetEntity)before_entity).getObjectId(), roleId, mode.name());
 			objectPrivilegeEntity = em.find(ObjectPrivilegeEntity.class, objectPrivilegeEntityPK);
 			if (objectPrivilegeEntity != null) {
@@ -617,8 +617,9 @@ public class HinemosEntityManager implements EntityManager {
 		if (!existsflg) {
 			// オブジェクト権限エラー
 			ObjectPrivilege_InvalidRole e = new ObjectPrivilege_InvalidRole(
-					"targetClass = " + entityClass.getSimpleName()
-					+ ", pk = " + primaryKey.toString());
+					"user=" + loginUser
+					+ ", targetClass=" + entityClass.getSimpleName()
+					+ ", pk=" + primaryKey.toString());
 			m_log.info("checkObjectPrivilege() object privilege invalid. : "
 					+ e.getClass().getSimpleName() + ", " + e.getMessage());
 			throw e;
@@ -704,10 +705,10 @@ public class HinemosEntityManager implements EntityManager {
 			JpqlFrom jpqlFrom = null;
 			JpqlWhere jpqlWhere = null;
 			JpqlStatement statement = jpqlParser.parseQuery(jpqlString);
-			
-			if (statement.jjtGetChild(0) instanceof JpqlSelect 
+
+			if (statement.jjtGetChild(0) instanceof JpqlSelect
 					|| statement.jjtGetChild(0) instanceof JpqlUpdate) {
-			
+
 				if (statement.jjtGetChild(0) instanceof JpqlSelect) {
 					JpqlSelect jpqlSelect = (JpqlSelect)statement.jjtGetChild(0);
 					for(int i=0 ; i<jpqlSelect.jjtGetNumChildren() ; i++ ) {
@@ -772,7 +773,7 @@ public class HinemosEntityManager implements EntityManager {
 	 *  JPQLでは、Listでパラメータ値を設定することが可能だが、
 	 *  JPASecurityでの構文解析時に上記が正常に動かない。
 	 *  そのための対応。
-	 *  
+	 * 
 	 *  例） paramName = aaa
 	 *     paramValue = {1,3,5,7}とすると
 	 *     ":aaa0, :aaa1, :aaa2, :aaa3"が返される。
@@ -796,7 +797,7 @@ public class HinemosEntityManager implements EntityManager {
 		}
 		return rtnString;
 	}
-	
+
 
 	/**
 	 * JPQLのIN句にパラメータ値を設定したTypedQueryを返す。
@@ -804,7 +805,7 @@ public class HinemosEntityManager implements EntityManager {
 	 *  JPQLでは、Listでパラメータ値を設定することが可能だが、
 	 *  JPASecurityでの構文解析時に上記が正常に動かない。
 	 *  そのための対応。
-	 *  
+	 * 
 	 *  例） paramName = aaa
 	 *     paramValue = {1,3,5,7}とすると
 	 *     :aaa0 に 1、:aaa2に3、．．．と値を設定して返す。
