@@ -28,6 +28,7 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.bean.YesNoConstant;
@@ -35,15 +36,15 @@ import com.clustercontrol.composite.TextWithParameterComposite;
 import com.clustercontrol.http.action.AddHttp;
 import com.clustercontrol.http.action.GetHttp;
 import com.clustercontrol.http.action.ModifyHttp;
+import com.clustercontrol.monitor.bean.MonitorTypeMstConstant;
 import com.clustercontrol.monitor.run.dialog.CommonMonitorStringDialog;
-import com.clustercontrol.notify.util.NotifyGroupIdGenerator;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.monitor.HttpCheckInfo;
 import com.clustercontrol.ws.monitor.MonitorInfo;
 
 /**
  * HTTP監視（文字列）作成・変更ダイアログクラス<BR>
- * 
+ *
  * @version 4.0.0
  * @since 4.0.0
  */
@@ -56,40 +57,46 @@ public class HttpStringCreateDialog extends CommonMonitorStringDialog {
 	/** URL */
 	private TextWithParameterComposite m_textRequestUrl = null;
 
+	/** マネージャ名 */
+	private String managerName = null;
 	// ----- コンストラクタ ----- //
 
 	/**
 	 * 作成用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のシェルオブジェクト
 	 */
 	public HttpStringCreateDialog(Shell parent) {
-		super(parent);
+		super(parent, null);
 	}
 
 	/**
 	 * 作成用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
+	 * @param managerName マネージャ名
 	 * @param monitorType 監視判定タイプ
 	 */
-	public HttpStringCreateDialog(Shell parent, int monitorType) {
-		super(parent);
+	public HttpStringCreateDialog(Shell parent, String managerName, int monitorType) {
+		super(parent, managerName);
 
+		this.managerName = managerName;
 		this.m_monitorType = monitorType;
 	}
 
 	/**
 	 * 変更用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
+	 * @param managerName マネージャ名
 	 * @param monitorId 変更する監視項目ID
 	 * @param updateFlg 更新するか否か（true:変更、false:新規登録）
 	 */
-	public HttpStringCreateDialog(Shell parent, String monitorId, boolean updateFlg) {
-		super(parent);
+	public HttpStringCreateDialog(Shell parent, String managerName, String monitorId, boolean updateFlg) {
+		super(parent, managerName);
 
+		this.managerName = managerName;
 		this.monitorId = monitorId;
 		this.updateFlg = updateFlg;
 	}
@@ -98,7 +105,7 @@ public class HttpStringCreateDialog extends CommonMonitorStringDialog {
 
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent 親のインスタンス
 	 */
 	@Override
@@ -118,13 +125,14 @@ public class HttpStringCreateDialog extends CommonMonitorStringDialog {
 		 * チェック設定グループ（条件グループの子グループ）
 		 */
 		Group groupCheckRule = new Group(groupRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "checkrule", groupCheckRule);
 		GridLayout layout = new GridLayout(1, true);
-		layout.marginWidth = 5;
-		layout.marginHeight = 5;
-		layout.numColumns = 15;
+		layout.marginWidth = HALF_MARGIN;
+		layout.marginHeight = HALF_MARGIN;
+		layout.numColumns = BASIC_UNIT;
 		groupCheckRule.setLayout(layout);
 		gridData = new GridData();
-		gridData.horizontalSpan = 15;
+		gridData.horizontalSpan = BASIC_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		groupCheckRule.setLayoutData(gridData);
@@ -135,16 +143,19 @@ public class HttpStringCreateDialog extends CommonMonitorStringDialog {
 		 */
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "requesturl", label);
+		WidgetTestUtil.setTestId(this, "url", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("request.url") + " : ");
 		// テキスト
 		this.m_textRequestUrl = new TextWithParameterComposite(groupCheckRule, SWT.BORDER | SWT.LEFT | SWT.SINGLE);
+		WidgetTestUtil.setTestId(this, "requesturl", m_textRequestUrl);
 		gridData = new GridData();
-		gridData.horizontalSpan = 10;
+		gridData.horizontalSpan = LONG_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.m_textRequestUrl.setLayoutData(gridData);
@@ -163,8 +174,9 @@ public class HttpStringCreateDialog extends CommonMonitorStringDialog {
 		 */
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "timeout", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -172,8 +184,9 @@ public class HttpStringCreateDialog extends CommonMonitorStringDialog {
 
 		// テキスト
 		this.m_textTimeout = new Text(groupCheckRule, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "timeout", m_textTimeout);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_VALUE;
+		gridData.horizontalSpan = WIDTH_VALUE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.m_textTimeout.setLayoutData(gridData);
@@ -186,8 +199,9 @@ public class HttpStringCreateDialog extends CommonMonitorStringDialog {
 
 		// ラベル（単位）
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "millisec", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_VALUE;
+		gridData.horizontalSpan = WIDTH_VALUE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -195,8 +209,9 @@ public class HttpStringCreateDialog extends CommonMonitorStringDialog {
 
 		// 空白
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "blankmillisec", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = 7;
+		gridData.horizontalSpan = BASIC_UNIT - WIDTH_TEXT_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -213,7 +228,7 @@ public class HttpStringCreateDialog extends CommonMonitorStringDialog {
 		}
 		else{
 			// 変更の場合、情報取得
-			info = new GetHttp().getHttp(this.monitorId);
+			info = new GetHttp().getHttp(this.managerName, this.monitorId, MonitorTypeMstConstant.MONITOR_TYPE_STRING);
 		}
 		this.setInputData(info);
 
@@ -221,7 +236,7 @@ public class HttpStringCreateDialog extends CommonMonitorStringDialog {
 
 	/**
 	 * 更新処理
-	 * 
+	 *
 	 */
 	@Override
 	public void update(){
@@ -242,7 +257,7 @@ public class HttpStringCreateDialog extends CommonMonitorStringDialog {
 
 	/**
 	 * 各項目に入力値を設定します。
-	 * 
+	 *
 	 * @param monitor 設定値として用いる監視情報
 	 */
 	@Override
@@ -274,7 +289,7 @@ public class HttpStringCreateDialog extends CommonMonitorStringDialog {
 
 	/**
 	 * 入力値を用いて通知情報を生成します。
-	 * 
+	 *
 	 * @return 入力値を保持した通知情報
 	 */
 	@Override
@@ -285,7 +300,7 @@ public class HttpStringCreateDialog extends CommonMonitorStringDialog {
 		}
 
 		// HTTP監視（文字列）固有情報を設定
-		monitorInfo.setMonitorTypeId(HinemosModuleConstant.MONITOR_HTTP);
+		monitorInfo.setMonitorTypeId(HinemosModuleConstant.MONITOR_HTTP_S);
 
 		// 監視条件 HTTP監視情報
 		HttpCheckInfo httpInfo = new HttpCheckInfo();
@@ -318,8 +333,6 @@ public class HttpStringCreateDialog extends CommonMonitorStringDialog {
 		}
 
 		// 通知関連情報とアプリケーションの設定
-		// 通知グループIDの設定
-		monitorInfo.setNotifyGroupId(NotifyGroupIdGenerator.createNotifyGroupId(HinemosModuleConstant.MONITOR_HTTP, monitorInfo.getMonitorId()));
 		validateResult = m_notifyInfo.createInputData(monitorInfo);
 		if (validateResult != null) {
 			if(validateResult.getID() == null){	// 通知ID警告用出力
@@ -338,9 +351,9 @@ public class HttpStringCreateDialog extends CommonMonitorStringDialog {
 
 	/**
 	 * 入力値をマネージャに登録します。
-	 * 
+	 *
 	 * @return true：正常、false：異常
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#action()
 	 */
 	@Override
@@ -348,14 +361,15 @@ public class HttpStringCreateDialog extends CommonMonitorStringDialog {
 		boolean result = false;
 
 		MonitorInfo info = this.inputData;
+		String managerName = this.getManagerName();
 		if(info != null){
 			if(!this.updateFlg){
 				// 作成の場合
-				result = new AddHttp().add(info);
+				result = new AddHttp().add(managerName, info);
 			}
 			else{
 				// 変更の場合
-				result = new ModifyHttp().modify(info);
+				result = new ModifyHttp().modify(managerName, info);
 			}
 		}
 
@@ -364,7 +378,7 @@ public class HttpStringCreateDialog extends CommonMonitorStringDialog {
 
 	/**
 	 * MonitorInfoに初期値を設定します
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonMonitorDialog#setInfoInitialValue()
 	 */
 	@Override
@@ -383,4 +397,4 @@ public class HttpStringCreateDialog extends CommonMonitorStringDialog {
 		httpCheckInfo.setProxyPort(0);
 		monitor.setHttpCheckInfo(httpCheckInfo);
 	}
-}
\ No newline at end of file
+}
