@@ -15,18 +15,17 @@
 
 package com.clustercontrol.http.factory;
 
+import java.io.IOException;
 import java.util.Map;
 
-import javax.persistence.EntityManager;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import com.clustercontrol.commons.util.JpaTransactionManager;
 import com.clustercontrol.fault.MonitorNotFound;
 import com.clustercontrol.http.model.MonitorHttpInfoEntity;
 import com.clustercontrol.http.util.GetHttpResponse;
 import com.clustercontrol.http.util.QueryUtil;
+import com.clustercontrol.maintenance.util.HinemosPropertyUtil;
 import com.clustercontrol.monitor.run.factory.RunMonitor;
 import com.clustercontrol.monitor.run.factory.RunMonitorStringValueType;
 import com.clustercontrol.repository.util.RepositoryUtil;
@@ -36,7 +35,7 @@ import com.clustercontrol.util.StringBinder;
 /**
  * HTTP監視 文字列監視を実行するクラス<BR>
  *
- * @version 4.0.0
+ * @version 5.0.0
  * @since 2.1.0
  */
 public class RunMonitorHttpString extends RunMonitorStringValueType {
@@ -95,8 +94,6 @@ public class RunMonitorHttpString extends RunMonitorStringValueType {
 		m_unKnownMessage = "";
 		m_messageOrg = "";
 
-		GetHttpResponse m_request = new GetHttpResponse();
-
 		String url = m_requestUrl;
 		// 変数を置換したURLの生成
 		if (nodeInfo != null && nodeInfo.containsKey(facilityId)) {
@@ -106,34 +103,45 @@ public class RunMonitorHttpString extends RunMonitorStringValueType {
 			if (m_log.isTraceEnabled()) m_log.trace("http request. (nodeInfo = " + nodeInfo + ", facilityId = " + facilityId + ", url = " + url + ")");
 		}
 
-		boolean result = m_request.execute(url, m_httpTimeout);
+		boolean result = false;
+		try (GetHttpResponse m_request = GetHttpResponse.custom()
+				.setRequestTimeout(m_httpTimeout)
+				.setNeedAuthSSLCert(! HinemosPropertyUtil.getHinemosPropertyBool("monitor.http.ssl.trustall", true))
+				.build()) {
+			result = m_request.execute(url);
+			if(result && m_request.getErrorMessage().equals("")){
+				m_value = m_request.getResponseBody();
+				if (m_value == null) { // 404などの場合はbodyがnullになってしまう。
+					m_value = "";
+				}
 
-		if(result){
-			m_value = m_request.getResponseBody();
+				StringBuffer response = new StringBuffer();
+				response.append(Messages.getString("request.url") + " : " + url);
+				response.append("\n" + Messages.getString("status.code") + " : " + m_request.getStatusCode());
+				if(m_request.getHeaderString() != null && !"".equals(m_request.getHeaderString().trim())){
+					response.append("\n" + Messages.getString("header") + " :\n" + m_request.getHeaderString().trim());
+				}
+				if(m_request.getResponseBody() != null && !"".equals(m_request.getResponseBody().trim())){
+					response.append("\n" + Messages.getString("response.body") + " :\n" + m_request.getResponseBody().trim());
+				}
+				m_messageOrg = response.toString();
+			}
+			else{
+				m_unKnownMessage = Messages.getString("message.http.3");
 
-			StringBuffer response = new StringBuffer();
-			response.append(Messages.getString("request.url") + " : " + url);
-			response.append("\n" + Messages.getString("status.code") + " : " + m_request.getStatusCode());
-			if(m_request.getHeader() != null && !"".equals(m_request.getHeader().trim())){
-				response.append("\n" + Messages.getString("header") + " :\n" + m_request.getHeader().trim());
+				StringBuffer response = new StringBuffer();
+				response.append(m_request.getErrorMessage());
+				response.append("\n");
+				response.append("\n" + Messages.getString("request.url") + " : " + url);
+				response.append("\n" + Messages.getString("status.code") + " :\n" + m_request.getStatusCode());
+				if(m_request.getHeaderString() != null && !"".equals(m_request.getHeaderString().trim())){
+					response.append("\n" + Messages.getString("header") + " :\n" + m_request.getHeaderString().trim());
+				}
+				m_messageOrg = response.toString();
 			}
-			if(m_request.getResponseBody() != null && !"".equals(m_request.getResponseBody().trim())){
-				response.append("\n" + Messages.getString("response.body") + " :\n" + m_request.getResponseBody().trim());
-			}
-			m_messageOrg = response.toString();
 		}
-		else{
-			m_unKnownMessage = Messages.getString("message.http.3");
-
-			StringBuffer response = new StringBuffer();
-			response.append(m_request.getErrorMessage());
-			response.append("\n");
-			response.append("\n" + Messages.getString("request.url") + " : " + url);
-			response.append("\n" + Messages.getString("status.code") + " :\n" + m_request.getStatusCode());
-			if(m_request.getHeader() != null && !"".equals(m_request.getHeader().trim())){
-				response.append("\n" + Messages.getString("header") + " :\n" + m_request.getHeader().trim());
-			}
-			m_messageOrg = response.toString();
+		catch (IOException e) {
+			m_log.warn("fail to close HttpClient : " + e.getMessage(), e);
 		}
 		return result;
 	}
@@ -144,8 +152,6 @@ public class RunMonitorHttpString extends RunMonitorStringValueType {
 	 */
 	@Override
 	protected void setCheckInfo() throws MonitorNotFound {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
-
 		if(m_http == null){
 			// HTTP監視情報を取得
 			m_http = QueryUtil.getMonitorHttpInfoPK(m_monitorId);
