@@ -18,7 +18,6 @@ package com.clustercontrol.jobmanagement.dialog;
 import java.util.ArrayList;
 
 import org.eclipse.swt.SWT;
-import org.eclipse.swt.custom.TableTree;
 import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
@@ -26,6 +25,7 @@ import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
+import org.eclipse.swt.widgets.Tree;
 
 import com.clustercontrol.bean.Property;
 import com.clustercontrol.dialog.CommonDialog;
@@ -35,10 +35,11 @@ import com.clustercontrol.jobmanagement.bean.OperationConstant;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.PropertyUtil;
 import com.clustercontrol.viewer.PropertySheet;
+import com.clustercontrol.util.WidgetTestUtil;
 
 /**
  * ジョブ[開始]及びジョブ[停止]のダイアログクラスです。
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  */
@@ -52,7 +53,7 @@ public class JobOperationDialog extends CommonDialog {
 
 	/**
 	 * コンストラクタ
-	 * 
+	 *
 	 * @param parent 親シェル
 	 */
 	public JobOperationDialog(Shell parent) {
@@ -61,9 +62,9 @@ public class JobOperationDialog extends CommonDialog {
 
 	/**
 	 * ダイアログの初期サイズを返します。
-	 * 
+	 *
 	 * @return 初期サイズ
-	 * 
+	 *
 	 * @see org.eclipse.jface.window.Window#getInitialSize()
 	 */
 	@Override
@@ -73,7 +74,7 @@ public class JobOperationDialog extends CommonDialog {
 
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent 親コンポジット
 	 */
 	@Override
@@ -88,21 +89,23 @@ public class JobOperationDialog extends CommonDialog {
 		parent.setLayout(layout);
 
 		// プロパティシート
-		TableTree table = new TableTree(parent, SWT.H_SCROLL | SWT.V_SCROLL
+		Tree tree = new Tree(parent, SWT.H_SCROLL | SWT.V_SCROLL
 				| SWT.FULL_SELECTION | SWT.MULTI | SWT.BORDER);
+		WidgetTestUtil.setTestId(this, null, tree);
 		GridData gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		gridData.grabExcessVerticalSpace = true;
 		gridData.horizontalSpan = 1;
-		table.setLayoutData(gridData);
-		m_propertySheet = new PropertySheet(table);
+		tree.setLayoutData(gridData);
+		m_propertySheet = new PropertySheet(tree);
 		m_propertySheet.setInput(m_property);
 		m_propertySheet.expandAll();
 
 		// ラインを引く
 		Label line = new Label(parent, SWT.SEPARATOR | SWT.HORIZONTAL);
+		WidgetTestUtil.setTestId(this, "line", line);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
@@ -117,7 +120,7 @@ public class JobOperationDialog extends CommonDialog {
 
 	/**
 	 * ジョブ操作用プロパティを返します。
-	 * 
+	 *
 	 * @return ジョブ操作用プロパティ
 	 */
 	public Property getProperty() {
@@ -126,7 +129,7 @@ public class JobOperationDialog extends CommonDialog {
 
 	/**
 	 * ジョブ操作用プロパティを設定します。
-	 * 
+	 *
 	 * @param property ジョブ操作用プロパティ
 	 */
 	public void setProperty(Property property) {
@@ -135,7 +138,7 @@ public class JobOperationDialog extends CommonDialog {
 
 	/**
 	 * ダイアログタイトルを返します。
-	 * 
+	 *
 	 * @return ダイアログタイトル
 	 */
 	public String getTitleText() {
@@ -144,7 +147,7 @@ public class JobOperationDialog extends CommonDialog {
 
 	/**
 	 * ダイアログタイトルを設定します。
-	 * 
+	 *
 	 * @param title ダイアログタイトル
 	 */
 	public void setTitleText(String title) {
@@ -153,7 +156,7 @@ public class JobOperationDialog extends CommonDialog {
 
 	/**
 	 * ＯＫボタンテキスト取得
-	 * 
+	 *
 	 * @return ＯＫボタンのテキスト
 	 */
 	@Override
@@ -163,7 +166,7 @@ public class JobOperationDialog extends CommonDialog {
 
 	/**
 	 * キャンセルボタンテキスト取得
-	 * 
+	 *
 	 * @return キャンセルボタンのテキスト
 	 */
 	@Override
@@ -173,9 +176,9 @@ public class JobOperationDialog extends CommonDialog {
 
 	/**
 	 * 入力値チェックをします。
-	 * 
+	 *
 	 * @return 検証結果
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#validate()
 	 */
 	@Override
@@ -183,7 +186,7 @@ public class JobOperationDialog extends CommonDialog {
 		ValidateResult result = null;
 
 		//制御取得
-		ArrayList values = PropertyUtil.getPropertyValue(m_property, JobOperationConstant.CONTROL);
+		ArrayList<?> values = PropertyUtil.getPropertyValue(m_property, JobOperationConstant.CONTROL);
 		Integer control = null;
 		if(values.get(0) instanceof String){
 			String controlString = (String)values.get(0);
@@ -218,4 +221,4 @@ public class JobOperationDialog extends CommonDialog {
 
 		return result;
 	}
-}
\ No newline at end of file
+}
