@@ -16,23 +16,20 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.jobmanagement.factory;
 
 import java.util.ArrayList;
-import java.util.List;
 
 import javax.persistence.EntityExistsException;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import com.clustercontrol.fault.FacilityNotFound;
-import com.clustercontrol.fault.HinemosUnknown;
-import com.clustercontrol.fault.InvalidRole;
-import com.clustercontrol.fault.JobInfoNotFound;
 import com.clustercontrol.bean.EndStatusConstant;
 import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.bean.StatusConstant;
 import com.clustercontrol.bean.YesNoConstant;
-import com.clustercontrol.commons.util.HinemosProperties;
 import com.clustercontrol.commons.util.JpaTransactionManager;
+import com.clustercontrol.fault.FacilityNotFound;
+import com.clustercontrol.fault.HinemosUnknown;
+import com.clustercontrol.fault.JobInfoNotFound;
 import com.clustercontrol.jobmanagement.bean.CommandStopTypeConstant;
 import com.clustercontrol.jobmanagement.bean.ConditionTypeConstant;
 import com.clustercontrol.jobmanagement.bean.DelayNotifyConstant;
@@ -43,15 +40,12 @@ import com.clustercontrol.jobmanagement.bean.OperationConstant;
 import com.clustercontrol.jobmanagement.bean.ProcessingMethodConstant;
 import com.clustercontrol.jobmanagement.model.JobEndInfoEntity;
 import com.clustercontrol.jobmanagement.model.JobInfoEntity;
-import com.clustercontrol.jobmanagement.model.JobNoticeInfoEntity;
 import com.clustercontrol.jobmanagement.model.JobSessionEntity;
 import com.clustercontrol.jobmanagement.model.JobSessionJobEntity;
 import com.clustercontrol.jobmanagement.model.JobSessionNodeEntity;
 import com.clustercontrol.jobmanagement.model.JobStartJobInfoEntity;
-import com.clustercontrol.jobmanagement.util.QueryUtil;
-import com.clustercontrol.notify.bean.NotifyRelationInfo;
-import com.clustercontrol.notify.session.NotifyControllerBean;
-import com.clustercontrol.notify.util.NotifyGroupIdGenerator;
+import com.clustercontrol.jobmanagement.util.JobUtil;
+import com.clustercontrol.maintenance.util.HinemosPropertyUtil;
 import com.clustercontrol.repository.bean.NodeInfo;
 import com.clustercontrol.repository.session.RepositoryControllerBean;
 
@@ -93,41 +87,42 @@ public class CreateHulftJob {
 	private static final int WARNING = 1;
 	/** 異常の終了値及び終了値の範囲 */
 	private static final int ABNORMAL = -1;
-	
-	private static boolean hulftMode = false;
-	/** HULFT用のスクリプト配置ディレクトリ */
-	private static String SCRIPT_DIR_LINUX = "../../hulft/sh/";
-	/** HULFT用のスクリプト配置ディレクトリ */
-	private static String SCRIPT_DIR_WIN = "C:\\Program Files (x86)\\Hinemos\\Agent4.1.0\\hulft\\vbs\\";
-	
-	static {
-		String hulftModeStr = HinemosProperties.getProperty("job.hulft.mode");
-		if (hulftModeStr != null && "true".equals(hulftModeStr)) {
-			hulftMode = true;
-		}
-		m_log.info("hulftMode=" + hulftMode);
 
-		String dir = HinemosProperties.getProperty("job.hulft.script.dir.linux", SCRIPT_DIR_LINUX);
+	private String getScriptDirLinux() {
+		/** HULFT用のスクリプト配置ディレクトリ */
+		String SCRIPT_DIR_LINUX = "../../hulft/sh/";
+		String dir = HinemosPropertyUtil.getHinemosPropertyStr("job.hulft.script.dir.linux", SCRIPT_DIR_LINUX);
 		if (dir != null && dir.length() >0) {
 			SCRIPT_DIR_LINUX = dir + "/";
 		}
 		m_log.info("job.hulft.script.dir.linux=" + SCRIPT_DIR_LINUX);
-		
-		dir = HinemosProperties.getProperty("job.hulft.script.dir.windows", SCRIPT_DIR_WIN);
+
+		return SCRIPT_DIR_LINUX;
+	}
+
+	private String getScriptDirWin() {
+		/** HULFT用のスクリプト配置ディレクトリ */
+		String SCRIPT_DIR_WIN = "C:\\Program Files (x86)\\Hinemos\\Agent5.0.0\\hulft\\vbs\\";
+		String dir = HinemosPropertyUtil.getHinemosPropertyStr("job.hulft.script.dir.windows", SCRIPT_DIR_WIN);
+
 		if (dir != null && dir.length() >0) {
 			SCRIPT_DIR_WIN = dir + "\\";
 		}
 		m_log.info("job.hulft.script.dir.windows=" + SCRIPT_DIR_WIN);
+
+		return SCRIPT_DIR_WIN;
 	}
-	
+
 	public static boolean isHulftMode() {
+		boolean hulftMode = HinemosPropertyUtil.getHinemosPropertyBool("job.hulft.mode", false);
+		m_log.info("hulftMode=" + hulftMode);
 		return hulftMode;
 	}
-	
+
 	protected void createHulftDetailJob(JobInfoEntity parentJobInfo)throws FacilityNotFound, EntityExistsException, HinemosUnknown, JobInfoNotFound {
 
 		JpaTransactionManager jtm = new JpaTransactionManager();
-		
+
 		//親ジョブのセッションジョブからファイル転送情報を取得
 		JobSessionJobEntity parentSessionJob = parentJobInfo.getJobSessionJobEntity();
 		JobInfoEntity job = parentSessionJob.getJobInfoEntity();
@@ -146,7 +141,9 @@ public class CreateHulftJob {
 				job.getCheckFlg(),
 				job.getSpecifyUser(),
 				job.getEffectiveUser(),
-				job.getMessageRetry());
+				job.getMessageRetry(),
+				job.getCommandRetry(),
+				job.getCommandRetryFlg());
 		RepositoryControllerBean repository = new RepositoryControllerBean();
 		ArrayList<String> nodeIdList = repository.getExecTargetFacilityIdList(
 				fileData.getDest_facility_id(), parentSessionJob.getOwnerRoleId());
@@ -162,10 +159,10 @@ public class CreateHulftJob {
 		String command;
 		if (repository.getNode(parentJobInfo.getSrcFacilityId()).getPlatformFamily().equals("WINDOWS")) {
 			// Windowsの場合の起動コマンド
-			command = "cscript.exe //nologo \"" + SCRIPT_DIR_WIN + UTILIUPDT_S_VBS + "\" " + parentJobInfo.getId().getJobId();
+			command = "cscript.exe //nologo \"" + getScriptDirWin() + UTILIUPDT_S_VBS + "\" " + parentJobInfo.getId().getJobId();
 		} else {
 			// Linuxの場合の起動コマンド
-			command = SCRIPT_DIR_LINUX + UTILIUPDT_S_SH + " " + parentJobInfo.getId().getJobId();
+			command = getScriptDirLinux() + UTILIUPDT_S_SH + " " + parentJobInfo.getId().getJobId();
 		}
 		m_log.info("startCommand=" + command);
 		jobUtiliupdtS.setStartCommand(command);
@@ -173,8 +170,10 @@ public class CreateHulftJob {
 		jobUtiliupdtS.setEffectiveUser(parentJobInfo.getEffectiveUser());
 		jobUtiliupdtS.setArgument(parentJobInfo.getSrcFile());
 		jobUtiliupdtS.setMessageRetry(parentJobInfo.getMessageRetry());
+		jobUtiliupdtS.setCommandRetry(parentJobInfo.getCommandRetry());
+		jobUtiliupdtS.setCommandRetryFlg(YesNoConstant.TYPE_NO);
 		//通知メッセージを作成
-		subCreateJobNoticeInfoEntity(jobUtiliupdtS, job.getId().getJobId());
+		JobUtil.copyJobNoticeProperties(jobUtiliupdtS, job.getId().getJobId());
 
 		//ジョブユニットのジョブIDは親のものと同じとする。
 		String jobunitId = parentSessionJob.getId().getJobunitId();
@@ -215,7 +214,7 @@ public class CreateHulftJob {
 			nodeJobInfoEntity.setMultiplicityNotify(job.getMultiplicityNotify());
 			nodeJobInfoEntity.setMultiplicityNotifyPriority(job.getMultiplicityNotifyPriority());
 			nodeJobInfoEntity.setMultiplicityOperation(job.getMultiplicityOperation());
-			
+
 			//処理方法により待ち条件を作成する
 			if(fileData.getProcess_mode() == ProcessingMethodConstant.TYPE_ALL_NODE){
 				//全ノードで受信
@@ -312,7 +311,7 @@ public class CreateHulftJob {
 			nodeJobSessionJob.setScopeText(repository.getFacilityPath(nodeIdList.get(i), null));
 
 			//通知メッセージを作成
-			subCreateJobNoticeInfoEntity(nodeJobInfoEntity, job.getId().getJobId());
+			JobUtil.copyJobNoticeProperties(nodeJobInfoEntity, job.getId().getJobId());
 
 			//終了状態を作成
 			// インスタンス生成
@@ -361,10 +360,10 @@ public class CreateHulftJob {
 
 		//配信側にホスト管理情報の登録(UTILIUPDT_H)
 		waitJobId = utliupdtH_snd(nodeJobSessionJob, waitJobId, destFacilityId, fileInfo);
-		
+
 		//配信側にホスト管理情報の登録(UTILIUPDT_H)
 		waitJobId = utliupdtH_rcv(nodeJobSessionJob, waitJobId, destFacilityId, fileInfo);
-		
+
 		//ファイル転送(UTLSEND)
 		waitJobId = utlsend(nodeJobSessionJob, waitJobId, destFacilityId,
 						filePath, String.valueOf(1), fileInfo, parentJobId);
@@ -433,10 +432,10 @@ public class CreateHulftJob {
 		String command;
 		if (repository.getNode(fileInfo.getSrc_facility_id()).getPlatformFamily().equals("WINDOWS")) {
 			// Windowsの場合の起動コマンド
-			command = "cscript.exe //nologo \"" + SCRIPT_DIR_WIN + UTLSEND_VBS + "\" " + parentJobId + " \"" + filePath+ "\" " + info.getNodeName();
+			command = "cscript.exe //nologo \"" + getScriptDirWin() + UTLSEND_VBS + "\" " + parentJobId + " \"" + filePath+ "\" " + info.getNodeName();
 		} else {
 			// Linuxの場合の起動コマンド
-			command = SCRIPT_DIR_LINUX + UTLSEND_SH + " " + parentJobId + " " + filePath+ " " + info.getNodeName();
+			command = getScriptDirLinux() + UTLSEND_SH + " " + parentJobId + " " + filePath+ " " + info.getNodeName();
 		}
 		m_log.info("startCommand=" + command);
 		jobInfoEntity.setStartCommand(command);
@@ -444,9 +443,12 @@ public class CreateHulftJob {
 		jobInfoEntity.setEffectiveUser(fileInfo.getEffective_user());
 		jobInfoEntity.setArgument(filePath);
 		jobInfoEntity.setMessageRetry(fileInfo.getMessage_retry());
+		jobInfoEntity.setCommandRetry(fileInfo.getCommand_retry());
+		jobInfoEntity.setCommandRetryFlg(YesNoConstant.TYPE_NO);
+		
 
 		//通知メッセージを作成
-		subCreateJobNoticeInfoEntity(jobInfoEntity, fileInfo.job_id);
+		JobUtil.copyJobNoticeProperties(jobInfoEntity, fileInfo.job_id);
 
 		return jobInfoEntity.getId().getJobId();
 	}
@@ -459,7 +461,7 @@ public class CreateHulftJob {
 
 		//リポジトリ(RepositoryControllerBean)を取得
 		RepositoryControllerBean repository = new RepositoryControllerBean();
-		
+
 		// インスタンス生成
 		JobInfoEntity jobInfoEntity = subCreateJobInfoEntityForJob (nodeJobSessionJob,
 				UTILIUPDT_R, destFacilityId);
@@ -474,32 +476,34 @@ public class CreateHulftJob {
 		String command;
 		if (repository.getNode(destFacilityId).getPlatformFamily().equals("WINDOWS")) {
 			// Windowsの場合の起動コマンド
-			command = "cscript.exe //nologo \"" + SCRIPT_DIR_WIN + UTILIUPDT_R_VBS + "\" " + parentJobId + " \"" + fileInfo.getDest_directory() + "\"";
+			command = "cscript.exe //nologo \"" + getScriptDirWin() + UTILIUPDT_R_VBS + "\" " + parentJobId + " \"" + fileInfo.getDest_directory() + "\"";
 		} else {
 			// Linuxの場合の起動コマンド
-			command = SCRIPT_DIR_LINUX + UTILIUPDT_R_SH + " " + parentJobId + " " + fileInfo.getDest_directory();
+			command = getScriptDirLinux() + UTILIUPDT_R_SH + " " + parentJobId + " " + fileInfo.getDest_directory();
 		}
 		m_log.info("startCommand=" + command);
 		jobInfoEntity.setStartCommand(command);
 		jobInfoEntity.setSpecifyUser(fileInfo.getSpecify_user());
 		jobInfoEntity.setEffectiveUser(fileInfo.getEffective_user());
 		jobInfoEntity.setMessageRetry(fileInfo.getMessage_retry());
+		jobInfoEntity.setCommandRetry(fileInfo.getCommand_retry());
+		jobInfoEntity.setCommandRetryFlg(YesNoConstant.TYPE_NO);
 
 		//通知メッセージを作成
-		subCreateJobNoticeInfoEntity(jobInfoEntity, fileInfo.job_id);
+		JobUtil.copyJobNoticeProperties(jobInfoEntity, fileInfo.job_id);
 
 		return jobInfoEntity.getId().getJobId();
 	}
-	
+
 	private String utliupdtH_snd(
 			JobSessionJobEntity nodeJobSessionJob,
 			String waitJobId,
 			String destFacilityId,
 			JobFileInfoData fileInfo
 			) throws FacilityNotFound, HinemosUnknown {
-		
+
 		// 配信側に集信側のホスト管理情報を登録する
-		
+
 		JpaTransactionManager jtm = new JpaTransactionManager();
 
 		// インスタンス生成
@@ -528,7 +532,7 @@ public class CreateHulftJob {
 		//リポジトリ(RepositoryControllerBean)を取得
 		RepositoryControllerBean repository = new RepositoryControllerBean();
 		NodeInfo info = repository.getNode(destFacilityId);
-		
+
 		// ホスト種を指定 (H:汎用機　U:UNIX  N:WindowsNT  W:Windows A:AS/400  K:富士通K)
 		String hosttype;
 		if (info.getPlatformFamily().equals("WINDOWS")) {
@@ -536,7 +540,7 @@ public class CreateHulftJob {
 		} else {
 			hosttype = "U";
 		}
-		
+
 		// 漢字コード種 (S:SHIFT-JIS  E:EUC  8:UTF-8  J:JEF  I:IBM  K:KEIS  N:NEC)
 		String encoding = "";
 		if (info.getCharacterSet().contains("UTF")) {
@@ -555,32 +559,34 @@ public class CreateHulftJob {
 		String command;
 		if (repository.getNode(fileInfo.getSrc_facility_id()).getPlatformFamily().equals("WINDOWS")) {
 			// Windowsの場合の起動コマンド
-			command = "cscript.exe //nologo \"" + SCRIPT_DIR_WIN + UTILIUPDT_H_VBS + "\" " + info.getNodeName() + " " + hosttype + " " + encoding;
+			command = "cscript.exe //nologo \"" + getScriptDirWin() + UTILIUPDT_H_VBS + "\" " + info.getNodeName() + " " + hosttype + " " + encoding;
 		} else {
 			// Linuxの場合の起動コマンド
-			command = SCRIPT_DIR_LINUX + UTILIUPDT_H_SH + " " + info.getNodeName() + " " + hosttype + " " + encoding;
+			command = getScriptDirLinux() + UTILIUPDT_H_SH + " " + info.getNodeName() + " " + hosttype + " " + encoding;
 		}
 		m_log.info("startCommand=" + command);
 		jobInfoEntity.setStartCommand(command);
 		jobInfoEntity.setSpecifyUser(fileInfo.getSpecify_user());
 		jobInfoEntity.setEffectiveUser(fileInfo.getEffective_user());
 		jobInfoEntity.setMessageRetry(fileInfo.getMessage_retry());
+		jobInfoEntity.setCommandRetry(fileInfo.getCommand_retry());
+		jobInfoEntity.setCommandRetryFlg(YesNoConstant.TYPE_NO);
 
 		//通知メッセージを作成
-		subCreateJobNoticeInfoEntity(jobInfoEntity, fileInfo.job_id);
+		JobUtil.copyJobNoticeProperties(jobInfoEntity, fileInfo.job_id);
 
 		return jobInfoEntity.getId().getJobId();
 	}
-	
+
 	private String utliupdtH_rcv(
 			JobSessionJobEntity nodeJobSessionJob,
 			String waitJobId,
 			String destFacilityId,
 			JobFileInfoData fileInfo
 			) throws FacilityNotFound, HinemosUnknown {
-		
+
 		// 集信側に配信側のホスト管理情報を登録する
-		
+
 		JpaTransactionManager jtm = new JpaTransactionManager();
 
 		// インスタンス生成
@@ -609,7 +615,7 @@ public class CreateHulftJob {
 		//リポジトリ(RepositoryControllerBean)を取得
 		RepositoryControllerBean repository = new RepositoryControllerBean();
 		NodeInfo info = repository.getNode(fileInfo.getSrc_facility_id());
-		
+
 		// ホスト種を指定 (H:汎用機　U:UNIX  N:WindowsNT  W:Windows A:AS/400  K:富士通K)
 		String hosttype;
 		if (info.getPlatformFamily().equals("WINDOWS")) {
@@ -617,7 +623,7 @@ public class CreateHulftJob {
 		} else {
 			hosttype = "U";
 		}
-		
+
 		// 漢字コード種 (S:SHIFT-JIS  E:EUC  8:UTF-8  J:JEF  I:IBM  K:KEIS  N:NEC)
 		String encoding = "";
 		if (info.getCharacterSet().contains("UTF")) {
@@ -636,19 +642,21 @@ public class CreateHulftJob {
 		String command;
 		if (repository.getNode(destFacilityId).getPlatformFamily().equals("WINDOWS")) {
 			// Windowsの場合の起動コマンド
-			command = "cscript.exe //nologo \"" + SCRIPT_DIR_WIN + UTILIUPDT_H_VBS + "\" " + info.getNodeName() + " " + hosttype + " " + encoding;
+			command = "cscript.exe //nologo \"" + getScriptDirWin() + UTILIUPDT_H_VBS + "\" " + info.getNodeName() + " " + hosttype + " " + encoding;
 		} else {
 			// Linuxの場合の起動コマンド
-			command = SCRIPT_DIR_LINUX + UTILIUPDT_H_SH + " " + info.getNodeName() + " " + hosttype + " " + encoding;
+			command = getScriptDirLinux() + UTILIUPDT_H_SH + " " + info.getNodeName() + " " + hosttype + " " + encoding;
 		}
 		m_log.info("startCommand=" + command);
 		jobInfoEntity.setStartCommand(command);
 		jobInfoEntity.setSpecifyUser(fileInfo.getSpecify_user());
 		jobInfoEntity.setEffectiveUser(fileInfo.getEffective_user());
 		jobInfoEntity.setMessageRetry(fileInfo.getMessage_retry());
+		jobInfoEntity.setCommandRetry(fileInfo.getCommand_retry());
+		jobInfoEntity.setCommandRetryFlg(YesNoConstant.TYPE_NO);
 
 		//通知メッセージを作成
-		subCreateJobNoticeInfoEntity(jobInfoEntity, fileInfo.job_id);
+		JobUtil.copyJobNoticeProperties(jobInfoEntity, fileInfo.job_id);
 
 		return jobInfoEntity.getId().getJobId();
 	}
@@ -692,10 +700,10 @@ public class CreateHulftJob {
 		String command;
 		if (repository.getNode(fileInfo.getSrc_facility_id()).getPlatformFamily().equals("WINDOWS")) {
 			// Windowsの場合の起動コマンド
-			command = "cscript.exe //nologo \"" + SCRIPT_DIR_WIN + HULOPLCMD_VBS +"\"";
+			command = "cscript.exe //nologo \"" + getScriptDirWin() + HULOPLCMD_VBS +"\"";
 		} else {
 			// Linuxの場合の起動コマンド
-			command = SCRIPT_DIR_LINUX + HULOPLCMD_SH;
+			command = getScriptDirLinux() + HULOPLCMD_SH;
 		}
 		m_log.info("startCommand=" + command);
 		jobInfoEntity.setStartCommand(command);
@@ -704,9 +712,11 @@ public class CreateHulftJob {
 		jobInfoEntity.setArgument(filePath);
 		jobInfoEntity.setArgumentJobId(waitJobId);
 		jobInfoEntity.setMessageRetry(fileInfo.getMessage_retry());
+		jobInfoEntity.setCommandRetry(fileInfo.getCommand_retry());
+		jobInfoEntity.setCommandRetryFlg(YesNoConstant.TYPE_NO);
 
 		//通知メッセージを作成
-		subCreateJobNoticeInfoEntity(jobInfoEntity, fileInfo.job_id);
+		JobUtil.copyJobNoticeProperties(jobInfoEntity, fileInfo.job_id);
 
 		return jobInfoEntity.getId().getJobId();
 	}
@@ -751,8 +761,8 @@ public class CreateHulftJob {
 		jobInfoEntity.setEndDelayNotifyPriority(PriorityConstant.TYPE_CRITICAL);
 		jobInfoEntity.setEndDelayOperationType(OperationConstant.TYPE_STOP_AT_ONCE);
 		jobInfoEntity.setProcessMode(ProcessingMethodConstant.TYPE_ALL_NODE);
-		jobInfoEntity.setErrorEndFlg(YesNoConstant.TYPE_YES);
-		jobInfoEntity.setErrorEndValue(ABNORMAL);
+		jobInfoEntity.setMessageRetryEndFlg(YesNoConstant.TYPE_YES);
+		jobInfoEntity.setMessageRetryEndValue(ABNORMAL);
 		jobInfoEntity.setFacilityId(facilityId);
 		// ファイル転送を中止する場合は、プロセス停止とする。
 		jobInfoEntity.setStopType(CommandStopTypeConstant.DESTROY_PROCESS);
@@ -802,51 +812,6 @@ public class CreateHulftJob {
 		return jobInfoEntity;
 	}
 
-	/**
-	 * JobNoticeInfoEntityを作成する。
-	 * 
-	 * @param jobInfoEntity 親のJobInfoEntity
-	 * @return
-	 * @throws HinemosUnknown 
-	 */
-	private void subCreateJobNoticeInfoEntity (JobInfoEntity jobInfoEntity, String parentJobId) throws HinemosUnknown {
-		JpaTransactionManager jtm = new JpaTransactionManager();
-
-		String sessionId = jobInfoEntity.getId().getSessionId();
-		String jobunitId = jobInfoEntity.getId().getJobunitId();
-		String jobId = jobInfoEntity.getId().getJobId();
-
-		m_log.info("subCreateJobNoticeInfoEntity() : jobInfoEntity="+sessionId+",jobunitId="+jobunitId+",jobId="+jobId+",parentJobId="+parentJobId);
-		try {
-			 //JobNoticeInfoEntity(通知メッセージ)を作成 
-			JobInfoEntity parentJobInfoEntity = QueryUtil.getJobSessionJobPK(sessionId, jobunitId, parentJobId).getJobInfoEntity();
-			List<JobNoticeInfoEntity> noticeInfoEntities = new ArrayList<JobNoticeInfoEntity>(parentJobInfoEntity.getJobNoticeInfoEntities());
-			for (JobNoticeInfoEntity notice : noticeInfoEntities) {
-				// インスタンス生成 
-				JobNoticeInfoEntity jobNoticeInfoEntity = new JobNoticeInfoEntity(jobInfoEntity, notice.getId().getNoticeType()); 
-				// 重複チェック 
-				jtm.checkEntityExists(JobNoticeInfoEntity.class, jobNoticeInfoEntity.getId()); 
-				
-				String infoNotifyGroupId = NotifyGroupIdGenerator.createNotifyGroupIdJobInfo(sessionId, jobunitId, jobId, 0);
-				jobNoticeInfoEntity.setNotifyGroupId(infoNotifyGroupId); 
-				jobNoticeInfoEntity.setPriority(notice.getPriority());
-			} 
-			String infoNotifyGroupId = NotifyGroupIdGenerator.createNotifyGroupIdJobInfo(
-					sessionId, jobunitId, jobId, 0);
-			// 取得したマスタ情報の通知グループIDで、通知関連情報を取得する
-			List<NotifyRelationInfo> ct = new NotifyControllerBean().getNotifyRelation(NotifyGroupIdGenerator.createNotifyGroupIdJobInfo(sessionId, jobunitId, parentJobId, 0));
-			// JobNoticeInfo用の通知グループIDで、通知関連テーブルのコピーを作成する
-			for (NotifyRelationInfo relation : ct) {
-				relation.setNotifyGroupId(infoNotifyGroupId);
-			}
-			// JobからNotifyRelationInfoは１件のみ登録すればよい。
-			new NotifyControllerBean().addNotifyRelation(ct);
-		} catch (InvalidRole e) {
-			throw new HinemosUnknown(e.getMessage());
-		} catch (JobInfoNotFound e) {
-			throw new HinemosUnknown(e.getMessage());
-		}
-	}
 	private class JobFileInfoData
 	{
 		private String session_id;
@@ -861,9 +826,11 @@ public class CreateHulftJob {
 		private Integer specify_user;
 		private String effective_user;
 		private Integer message_retry;
+		private Integer command_retry;
+		private Integer command_retry_flg;
 
 		public JobFileInfoData(
-				String session_id,String jobunit_id,String job_id,String src_facility_id,String dest_facility_id,Integer process_mode,String src_file,String src_work_dir,String dest_directory,String dest_work_dir,Integer compression_flg,Integer check_flg,Integer specify_user, String effective_user, Integer message_retry)
+				String session_id,String jobunit_id,String job_id,String src_facility_id,String dest_facility_id,Integer process_mode,String src_file,String src_work_dir,String dest_directory,String dest_work_dir,Integer compression_flg,Integer check_flg,Integer specify_user, String effective_user, Integer message_retry, Integer command_retry, Integer command_retry_flg)
 		{
 			setSession_id(session_id);
 			setJobunit_id(jobunit_id);
@@ -877,6 +844,8 @@ public class CreateHulftJob {
 			setSpecify_user(specify_user);
 			setEffective_user(effective_user);
 			setMessage_retry(message_retry);
+			setCommand_retry(command_retry);
+			setCommand_retry_flg(command_retry_flg);
 		}
 
 		public void setSession_id( String session_id )
@@ -930,10 +899,6 @@ public class CreateHulftJob {
 			this.dest_directory = dest_directory;
 		}
 
-		public Integer getCompression_flg()
-		{
-			return this.compression_flg;
-		}
 		public void setCompression_flg( Integer compression_flg )
 		{
 			this.compression_flg = compression_flg;
@@ -972,6 +937,22 @@ public class CreateHulftJob {
 		public void setMessage_retry(Integer message_retry) {
 			this.message_retry = message_retry;
 		}
+		
+		public Integer getCommand_retry() {
+			return command_retry;
+		}
+
+		public void setCommand_retry(Integer command_retry) {
+			this.command_retry = command_retry;
+		}
+
+		public Integer getCommand_retry_flg() {
+			return command_retry_flg;
+		}
+
+		public void setCommand_retry_flg(Integer command_retry_flg) {
+			this.command_retry_flg = command_retry_flg;
+		}
 
 		@Override
 		public String toString()
