@@ -15,6 +15,7 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.jobmanagement.factory;
 
+import java.io.Serializable;
 import java.sql.Timestamp;
 import java.util.ArrayList;
 import java.util.Calendar;
@@ -23,8 +24,6 @@ import java.util.Date;
 import java.util.TimeZone;
 import java.util.concurrent.ConcurrentHashMap;
 
-import javax.persistence.EntityManager;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
@@ -32,8 +31,16 @@ import com.clustercontrol.bean.EndStatusConstant;
 import com.clustercontrol.bean.StatusConstant;
 import com.clustercontrol.bean.YesNoConstant;
 import com.clustercontrol.calendar.session.CalendarControllerBean;
+import com.clustercontrol.commons.util.AbstractCacheManager;
+import com.clustercontrol.commons.util.CacheManagerFactory;
+import com.clustercontrol.commons.util.HinemosEntityManager;
+import com.clustercontrol.commons.util.ICacheManager;
+import com.clustercontrol.commons.util.ILock;
+import com.clustercontrol.commons.util.ILockManager;
 import com.clustercontrol.commons.util.JpaTransactionManager;
+import com.clustercontrol.commons.util.LockManagerFactory;
 import com.clustercontrol.fault.CalendarNotFound;
+import com.clustercontrol.fault.FacilityNotFound;
 import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.fault.InvalidRole;
 import com.clustercontrol.fault.JobInfoNotFound;
@@ -59,6 +66,73 @@ public class JobSessionJobImpl {
 	/** タイムゾーン*/
 	private static final long TIMEZONE = TimeZone.getDefault().getRawOffset();
 
+	private static final ILock _lock;
+	
+	static {
+		ILockManager lockManager = LockManagerFactory.instance().create();
+		_lock = lockManager.create(JobSessionJobImpl.class.getName());
+		
+		try {
+			_lock.writeLock();
+			
+			ArrayList<String> cache = getForceCheckCache();
+			if (cache == null) {	// not null when clustered
+				storeForceCheckCache(new ArrayList<String>());
+			}
+		} finally {
+			_lock.writeUnlock();
+		}
+	}
+	
+	
+	
+	// 次回のrunningCheckを強制的に動作させるためのリスト。
+	// このリストがないと、次回時刻(待ち条件、遅延監視)になるまではrunnincCheckは動作しない。
+	@SuppressWarnings("unchecked")
+	private static ArrayList<String> getForceCheckCache() {
+		ICacheManager cm = CacheManagerFactory.instance().create();
+		Serializable cache = cm.get(AbstractCacheManager.KEY_JOB_FORCE_CHECK);
+		if (m_log.isDebugEnabled()) m_log.debug("get cache " + AbstractCacheManager.KEY_JOB_FORCE_CHECK + " : " + cache);
+		return cache == null ? null : (ArrayList<String>)cache;
+	}
+	
+	private static void storeForceCheckCache(ArrayList<String> newCache) {
+		ICacheManager cm = CacheManagerFactory.instance().create();
+		if (m_log.isDebugEnabled()) m_log.debug("store cache " + AbstractCacheManager.KEY_JOB_FORCE_CHECK + " : " + newCache);
+		cm.store(AbstractCacheManager.KEY_JOB_FORCE_CHECK, newCache);
+	}
+
+	public static void addForceCheck(String sessionId) {
+		try {
+			_lock.writeLock();
+			
+			ArrayList<String> cache = getForceCheckCache();
+			if (cache.contains(sessionId)) {
+				return;
+			}
+			
+			cache.add(sessionId);
+			storeForceCheckCache(cache);
+		} finally {
+			_lock.writeUnlock();
+		}
+	}
+
+	public static boolean checkRemoveForceCheck(String sessionId) {
+		try {
+			_lock.writeLock();
+			
+			ArrayList<String> cache = getForceCheckCache();
+			boolean flag = cache.remove(sessionId);
+			if (flag) {
+				m_log.debug("checkRemoveForceCheck " + sessionId);
+			}
+			return flag; // forceCheckに含まれている場合はtrueを返す。
+		} finally {
+			_lock.writeUnlock();
+		}
+	}
+
 	private static ConcurrentHashMap <String, Long> checkTimeMap = new ConcurrentHashMap<String, Long>();
 
 	public static boolean isSkipCheck(String sessionId) {
@@ -103,26 +177,17 @@ public class JobSessionJobImpl {
 		checkTimeMap.put(sessionId, Long.MAX_VALUE);
 	}
 
-	/**
-	 * 操作(保留解除など)をした後の定期チェックでstartJobを実行してもらいたい場合に、
-	 * このメソッドを実行する。
-	 * @param sessionId
-	 */
-	public static void clearCheckDate(String sessionId) {
-		m_log.debug("clearCheckDate " + sessionId);
-		checkTimeMap.remove(sessionId);
-	}
-
 	/**
 	 * ジョブ開始処理メイン1を行います。
-	 * 
+	 *
 	 * @param sessionId
 	 * @param jobId
 	 * @throws JobInfoNotFound
 	 * @throws HinemosUnknown
 	 * @throws InvalidRole
+	 * @throws FacilityNotFound 
 	 */
-	public void startJob(String sessionId, String jobunitId, String jobId) throws JobInfoNotFound, HinemosUnknown, InvalidRole {
+	public void startJob(String sessionId, String jobunitId, String jobId) throws JobInfoNotFound, HinemosUnknown, InvalidRole, FacilityNotFound {
 		m_log.debug("startJob() : sessionId=" + sessionId + ", jobunitId=" + jobunitId + ", jobId=" + jobId);
 
 		//セッションIDとジョブIDから、セッションジョブを取得
@@ -136,7 +201,7 @@ public class JobSessionJobImpl {
 					checkCalendar(sessionId, jobunitId, jobId) &&
 					sessionJob.getStatus() == StatusConstant.TYPE_WAIT){
 				//実行状態に遷移した場合は、1分後に終了遅延のチェックをする必要がある。
-				clearCheckDate(sessionId);
+				addForceCheck(sessionId);
 				//実行状態を実行中にする
 				sessionJob.setStatus(StatusConstant.TYPE_RUNNING);
 				//開始・再実行日時を設定
@@ -166,6 +231,15 @@ public class JobSessionJobImpl {
 					startJob(sessionId, jobunitId, childJobId);
 				}
 			}
+			if(sessionJob.getJobInfoEntity().getJobType() == JobConstant.TYPE_JOB){
+				//ノードへの実行指示(終了していたらendJobを実行)
+				// ここはジョブを中断にして、ノード詳細で終了した後に、ジョブの中断解除をしたら、
+				// RUNNINGのままで止まってしまう。
+				// それを回避するために下記の実装を加える。
+				if (new JobSessionNodeImpl().startNode(sessionId, jobunitId, jobId)) {
+					endJob(sessionId, jobunitId, jobId, "", true);
+				}
+			}
 		} else if(sessionJob.getStatus() == StatusConstant.TYPE_SKIP){
 			//スキップの場合
 			//開始条件をチェックする
@@ -176,15 +250,12 @@ public class JobSessionJobImpl {
 			if (job.getStartDelay() == YesNoConstant.TYPE_YES &&
 					job.getStartDelayOperation() == YesNoConstant.TYPE_YES &&
 					job.getStartDelayOperationType() == OperationConstant.TYPE_STOP_SKIP) {
+				// 開始遅延によるスキップの場合
 				endStatus = job.getStartDelayOperationEndStatus();
 				endValue = job.getStartDelayOperationEndValue();
 				status = StatusConstant.TYPE_END_START_DELAY;
-			} else if (job.getSkip() == YesNoConstant.TYPE_YES) {
-				endStatus = job.getSkipEndStatus();
-				endValue = job.getSkipEndValue();
-				status = StatusConstant.TYPE_END_SKIP;
 			} else {
-				m_log.warn("invalid jobinfo(skip)");
+				// 制御によるスキップor停止[スキップ]の場合
 				endStatus = job.getSkipEndStatus();
 				endValue = job.getSkipEndValue();
 				status = StatusConstant.TYPE_END_SKIP;
@@ -201,16 +272,17 @@ public class JobSessionJobImpl {
 
 	/**
 	 * ジョブの待ち条件のチェックを行います。
-	 * 
+	 *
 	 * @param sessionId セッションID
 	 * @param jobId ジョブID
 	 * @return true：実行可、false：実行不可
 	 * @throws JobInfoNotFound
 	 * @throws InvalidRole
 	 * @throws HinemosUnknown
+	 * @throws FacilityNotFound 
 	 */
 	private boolean checkWaitCondition(String sessionId, String jobunitId, String jobId)
-			throws JobInfoNotFound, InvalidRole, HinemosUnknown {
+			throws JobInfoNotFound, InvalidRole, HinemosUnknown, FacilityNotFound {
 		m_log.debug("checkWaitCondition() : sessionId=" + sessionId + ", jobunitId=" + jobunitId + ", jobId=" + jobId);
 
 		//セッションIDとジョブIDから、セッションジョブを取得
@@ -242,7 +314,7 @@ public class JobSessionJobImpl {
 		boolean possibilityCheck = true;
 
 		//待ち条件が設定されていない場合
-		if((startJobs == null || startJobs.size() == 0) && job.getStartTime() == null){
+		if((startJobs == null || startJobs.size() == 0) && job.getStartTime() == null && job.getStartMinute() == null){
 			return true;
 		}
 
@@ -267,7 +339,7 @@ public class JobSessionJobImpl {
 					if(endStatus != null){
 						//対象セッションジョブの実行状態と待ち条件の終了状態を比較
 						if((startJob.getId().getTargetJobEndValue() == EndStatusConstant.TYPE_ANY)
-								|| (endStatus == startJob.getId().getTargetJobEndValue())){
+								|| (endStatus.equals(startJob.getId().getTargetJobEndValue()))){
 							jobResult.add(true);
 							//OR条件の場合、これ以上ループを回す必要はない
 							if(job.getConditionType() == ConditionTypeConstant.TYPE_OR) {
@@ -284,7 +356,7 @@ public class JobSessionJobImpl {
 					Integer endValue = targetSessionJob.getEndValue();
 					if(endValue != null){
 						//対象セッションジョブの実行状態と待ち条件の終了値を比較
-						if(endValue == startJob.getId().getTargetJobEndValue()){
+						if(endValue.equals(startJob.getId().getTargetJobEndValue())){
 							jobResult.add(true);
 							//OR条件の場合、これ以上ループを回す必要はない
 							if(job.getConditionType() == ConditionTypeConstant.TYPE_OR){
@@ -345,7 +417,7 @@ public class JobSessionJobImpl {
 					possibilityCheck = false;
 				}else{
 					//ORの場合：待ち条件がジョブのみで、全てのジョブが終了し、実行結果がNGである場合
-					if(job.getStartTime() == null && allEndCheck){
+					if(job.getStartTime() == null && allEndCheck && job.getStartMinute() == null){
 						possibilityCheck = false;
 					}
 				}
@@ -365,6 +437,21 @@ public class JobSessionJobImpl {
 					startCheck = checkWaitTime(startCheck,sessionId, job.getStartTime());
 				}
 			}
+
+			// 待ち条件－セッション開始時の時間（分）のチェック
+			if(job.getConditionType() == ConditionTypeConstant.TYPE_AND){
+				// 待ち条件が「AND」の場合
+				//待ち条件ジョブ判定を満たしていたら、待ち条件－セッション開始時の時間（分）をチェック
+				if(startCheck &&job.getStartMinute() != null){
+					startCheck = checkStartMinute(startCheck,sessionId, job.getStartMinute());
+				}
+			}else {
+				// 待ち条件が「OR」の場合
+				//待ち条件ジョブ判定を満たしていたら、待ち条件－セッション開始時の時間（分）をチェック
+				if(!startCheck && job.getStartMinute() != null){
+					startCheck = checkStartMinute(startCheck,sessionId, job.getStartMinute());
+				}
+			}
 		}
 
 		//開始チェック結果が開始NGの場合
@@ -387,6 +474,42 @@ public class JobSessionJobImpl {
 		return startCheck;
 	}
 
+	/**
+	 * 待ち条件（セッション開始時の時間（分））のチェック
+	 * @param startCheck
+	 * @param sessionId
+	 * @param startMinute
+	 * @return true or false
+	 * @throws JobInfoNotFound
+	 */
+	private Boolean checkStartMinute(Boolean startCheck,
+			String sessionId, Integer startMinute) throws JobInfoNotFound {
+
+		m_log.trace("startCheck : " + startCheck);
+
+		//セッションIDから、セッションを取得
+		JobSessionEntity session = QueryUtil.getJobSessionPK(sessionId);
+		//セッションの開始時刻
+		Date sessionDate = session.getScheduleDate();
+		m_log.trace("sessionDate : " + sessionDate);
+
+		Calendar work = Calendar.getInstance();
+		work.setTime(sessionDate);
+		work.getTime();
+		work.add(Calendar.MINUTE, startMinute);
+		Long check = work.getTimeInMillis();
+		Boolean startMinuteCheck = check <= System.currentTimeMillis();
+		/*
+		 * セッション開始時の時間（分）が実行されない場合は、
+		 * checkDateMapに追加する。
+		 */
+		if (!startMinuteCheck) {
+			addCheckDate(sessionId, check);
+		}
+
+		return startMinuteCheck;
+	}
+
 	/**
 	 * 待ち条件（時刻）のチェック
 	 * @param startCheck
@@ -421,7 +544,7 @@ public class JobSessionJobImpl {
 		 * 例
 		 * セッション開始日：2013/01/09 00:00:00
 		 * 待ち条件（時刻）：40:00:00(1970/01/02 16:00:00)
-		 * 
+		 *
 		 * セッション開始日 +待ち条件(時刻) + TIMEZONE = 2013/01/10 16:00:00
 		 */
 		long overMidnight = sessionDate0h.getTime() + startTime.getTime() + TIMEZONE;
@@ -442,7 +565,7 @@ public class JobSessionJobImpl {
 
 	/**
 	 * 開始遅延処理を行います。
-	 * 
+	 *
 	 * @param sessionId セッションID
 	 * @param jobId ジョブID
 	 * @return true=操作あり, false=操作なし
@@ -481,7 +604,7 @@ public class JobSessionJobImpl {
 
 	/**
 	 * 開始遅延をチェックします。
-	 * 
+	 *
 	 * @param sessionId セッションID
 	 * @param jobId ジョブID
 	 * @return true=操作あり, false=操作なし
@@ -632,16 +755,17 @@ public class JobSessionJobImpl {
 
 	/**
 	 * 終了遅延処理を行います。
-	 * 
+	 *
 	 * @param sessionId セッションID
 	 * @param jobId ジョブID
 	 * @return true=操作あり, false=操作なし
 	 * @throws HinemosUnknown
 	 * @throws JobInfoNotFound
 	 * @throws InvalidRole
+	 * @throws FacilityNotFound 
 	 */
 	private boolean checkEndDelay(String sessionId, String jobunitId, String jobId)
-			throws HinemosUnknown, JobInfoNotFound, InvalidRole {
+			throws HinemosUnknown, JobInfoNotFound, InvalidRole, FacilityNotFound {
 		m_log.debug("checkEndDelay() : sessionId=" + sessionId + ", jobId=" + jobId);
 
 		//セッションIDとジョブIDから、セッションジョブを取得
@@ -829,7 +953,7 @@ public class JobSessionJobImpl {
 
 	/**
 	 * 終了状態をチェックします
-	 * 
+	 *
 	 * @param sessionId セッションID
 	 * @param jobId ジョブID
 	 * @return 終了状態
@@ -837,7 +961,7 @@ public class JobSessionJobImpl {
 	 */
 	protected Integer checkEndStatus(String sessionId, String jobunitId, String jobId) throws JobInfoNotFound, InvalidRole {
 
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 
 		m_log.debug("checkEndStatus() : sessionId=" + sessionId + ", jobId=" + jobId);
 
@@ -979,15 +1103,16 @@ public class JobSessionJobImpl {
 
 	/**
 	 * カレンダチェックを行います。
-	 * 
+	 *
 	 * @param sessionId セッションID
 	 * @param jobId ジョブID
 	 * @return true:実行可 false:実行不可
 	 * @throws JobInfoNotFound
 	 * @throws InvalidRole
 	 * @throws HinemosUnknown
+	 * @throws FacilityNotFound 
 	 */
-	private boolean checkCalendar(String sessionId, String jobunitId, String jobId) throws JobInfoNotFound, InvalidRole, HinemosUnknown {
+	private boolean checkCalendar(String sessionId, String jobunitId, String jobId) throws JobInfoNotFound, InvalidRole, HinemosUnknown, FacilityNotFound {
 		m_log.debug("checkCalendar() : sessionId=" + sessionId + ", jobunitId=" + jobunitId + ", jobId=" + jobId);
 
 		boolean check = false;
@@ -1033,7 +1158,7 @@ public class JobSessionJobImpl {
 
 	/**
 	 * 終了状態を設定します。
-	 * 
+	 *
 	 * @param sessionId セッションID
 	 * @param jobId ジョブID
 	 * @param status 実行状態
@@ -1065,12 +1190,13 @@ public class JobSessionJobImpl {
 		//実行状態を設定
 		sessionJob.setStatus(status);
 		//終了状態を設定
+		Integer preEndStatus = sessionJob.getEndStatus();
 		sessionJob.setEndStatus(endStatus);
 		if (endValue != null) {
 			sessionJob.setEndValue(endValue);
 		} else {
 			//終了値を設定
-			if(endInfoNormal.getId().getEndStatus() == endStatus){
+			if(endInfoNormal.getId().getEndStatus().equals(endStatus)){
 				sessionJob.setEndValue(endInfoNormal.getEndValue());
 			}else if(endInfoWarning.getId().getEndStatus() == endStatus){
 				sessionJob.setEndValue(endInfoWarning.getEndValue());
@@ -1084,21 +1210,25 @@ public class JobSessionJobImpl {
 		sessionJob.setResult(result);
 
 		//通知処理
-		new Notice().notify(sessionId, jobunitId, jobId, endStatus);
+		//状態が変わったときのみ通知する
+		if (preEndStatus == null || !preEndStatus.equals(endStatus)) {
+			new Notice().notify(sessionId, jobunitId, jobId, endStatus);
+		}
 	}
 
 	/**
 	 * ジョブ終了時関連処理を行います。
-	 * 
+	 *
 	 * @param sessionId セッションID
 	 * @param jobId ジョブID
 	 * @throws JobInfoNotFound
 	 * @throws InvalidRole
 	 * @throws HinemosUnknown
+	 * @throws FacilityNotFound 
 	 */
 	protected void endJob(String sessionId, String jobunitId, String jobId, String result, boolean normalEndFlag)
-			throws JobInfoNotFound, InvalidRole, HinemosUnknown {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+			throws JobInfoNotFound, InvalidRole, HinemosUnknown, FacilityNotFound {
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		m_log.info("endJob() : sessionId=" + sessionId + ", jobunitId=" + jobunitId + ", jobId=" + jobId);
 
 		////////// 状態遷移、通知 //////////
@@ -1147,8 +1277,7 @@ public class JobSessionJobImpl {
 		//親ジョブのジョブIDを取得
 		String parentJobunitId = null;
 		String parentJobId = null;
-		JobSessionJobEntity parentSessionJob 
-			= QueryUtil.getJobSessionJobPK(sessionId, sessionJob.getParentJobunitId(), sessionJob.getParentJobId());
+		QueryUtil.getJobSessionJobPK(sessionId, sessionJob.getParentJobunitId(), sessionJob.getParentJobId());
 		parentJobunitId = sessionJob.getParentJobunitId();
 		parentJobId = sessionJob.getParentJobId();
 		//同一階層のジョブが全て完了したかチェック
@@ -1166,10 +1295,8 @@ public class JobSessionJobImpl {
 		//同一階層のジョブが全て完了の場合
 		if(!CreateJobSession.TOP_JOB_ID.equals(parentJobId)){
 			//セッションIDとジョブIDから、セッションジョブを取得
-			if(parentSessionJob.getStatus() == StatusConstant.TYPE_RUNNING){
-				//ジョブ終了時関連処理（再帰呼び出し）
-				endJob(sessionId, parentJobunitId, parentJobId, null, true);
-			}
+			//ジョブ終了時関連処理（再帰呼び出し）
+			endJob(sessionId, parentJobunitId, parentJobId, null, true);
 		}
 	}
 }
