@@ -16,6 +16,7 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.jobmanagement.factory;
 
 import java.sql.Timestamp;
+import java.text.SimpleDateFormat;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
@@ -23,9 +24,11 @@ import java.util.Comparator;
 import java.util.Date;
 import java.util.HashMap;
 import java.util.List;
+import java.util.Map;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
 
 import javax.persistence.EntityExistsException;
-import javax.persistence.EntityManager;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -33,11 +36,14 @@ import org.apache.commons.logging.LogFactory;
 import com.clustercontrol.bean.EndStatusConstant;
 import com.clustercontrol.bean.StatusConstant;
 import com.clustercontrol.bean.YesNoConstant;
+import com.clustercontrol.commons.util.HinemosEntityManager;
 import com.clustercontrol.commons.util.JpaTransactionManager;
 import com.clustercontrol.fault.FacilityNotFound;
 import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.fault.InvalidRole;
 import com.clustercontrol.fault.JobInfoNotFound;
+import com.clustercontrol.fault.JobMasterNotFound;
+import com.clustercontrol.hinemosagent.bean.AgentInfo;
 import com.clustercontrol.hinemosagent.util.AgentConnectUtil;
 import com.clustercontrol.jobmanagement.bean.CommandConstant;
 import com.clustercontrol.jobmanagement.bean.CommandStopTypeConstant;
@@ -47,6 +53,8 @@ import com.clustercontrol.jobmanagement.bean.ProcessingMethodConstant;
 import com.clustercontrol.jobmanagement.bean.RunInstructionInfo;
 import com.clustercontrol.jobmanagement.bean.RunResultInfo;
 import com.clustercontrol.jobmanagement.bean.RunStatusConstant;
+import com.clustercontrol.jobmanagement.bean.SystemParameterConstant;
+import com.clustercontrol.jobmanagement.model.JobEndInfoEntity;
 import com.clustercontrol.jobmanagement.model.JobInfoEntity;
 import com.clustercontrol.jobmanagement.model.JobSessionJobEntity;
 import com.clustercontrol.jobmanagement.model.JobSessionNodeEntity;
@@ -55,7 +63,11 @@ import com.clustercontrol.jobmanagement.util.JobMultiplicityCache;
 import com.clustercontrol.jobmanagement.util.ParameterUtil;
 import com.clustercontrol.jobmanagement.util.QueryUtil;
 import com.clustercontrol.jobmanagement.util.SendTopic;
+import com.clustercontrol.maintenance.util.HinemosPropertyUtil;
+import com.clustercontrol.repository.bean.NodeInfo;
 import com.clustercontrol.repository.factory.NodeProperty;
+import com.clustercontrol.repository.session.RepositoryControllerBean;
+import com.clustercontrol.repository.util.RepositoryUtil;
 import com.clustercontrol.util.Messages;
 
 public class JobSessionNodeImpl {
@@ -65,15 +77,15 @@ public class JobSessionNodeImpl {
 
 	/**
 	 * ノードへの実行指示を行います。
-	 * 
+	 *
 	 * @param sessionId セッションID
 	 * @param jobId ジョブID
 	 * @param facilityId ファシリティID
-	 * @return true：成功、false：失敗
+	 * @return true：終了していた、false：実行された
 	 * @throws JobInfoNotFound
 	 * @throws InvalidRole
 	 */
-	public void startNode(String sessionId, String jobunitId, String jobId) throws JobInfoNotFound, InvalidRole {
+	public boolean startNode(String sessionId, String jobunitId, String jobId) throws JobInfoNotFound, InvalidRole {
 		m_log.debug("startNode() : sessionId=" + sessionId + ", jobId=" + jobId);
 
 		//セッションIDとジョブIDから、セッションジョブを取得
@@ -84,14 +96,16 @@ public class JobSessionNodeImpl {
 			try {
 				new JobSessionJobImpl().endJob(sessionId, jobunitId, jobId, null, true);
 			} catch (HinemosUnknown e) {
-				m_log.warn("startNode() : no node. " + e.getMessage());
+				m_log.warn("startNode() : no node. " + e.getMessage(), e);
+			} catch (FacilityNotFound e) {
+				m_log.warn("startNode() : no node. " + e.getMessage(), e);
 			}
-			return;
+			return false;
 		}
 
 		//終了している場合はメソッドから抜ける。
 		if (checkAllNodeEnd(sessionJob)) {
-			return;
+			return true;
 		}
 
 		//コマンドの実行が正常終了するまで順次リトライの場合
@@ -101,7 +115,7 @@ public class JobSessionNodeImpl {
 			for (JobSessionNodeEntity sessionNode : jobSessionNodeList) {
 				//実行状態が実行中の場合
 				if(sessionNode.getStatus() == StatusConstant.TYPE_RUNNING){
-					return;
+					return false;
 				}
 			}
 		}
@@ -142,7 +156,7 @@ public class JobSessionNodeImpl {
 				}
 			}
 		}
-		return;
+		return false;
 	}
 
 	private boolean checkMultiplicity(JobSessionNodeEntity sessionNode) {
@@ -165,7 +179,7 @@ public class JobSessionNodeImpl {
 				m_log.info("multiplicity notify is null");
 				return false;
 			}
-			
+
 			// 上限を超えたときは通知する
 			m_log.debug("checkMultiplicity " + sessionJob.getJobInfoEntity().getMultiplicityNotify());
 			if (sessionJob.getJobInfoEntity().getMultiplicityNotify() == YesNoConstant.TYPE_YES) {
@@ -185,12 +199,15 @@ public class JobSessionNodeImpl {
 				startFlag = false;
 				sessionNode.setStatus(StatusConstant.TYPE_END);
 				sessionNode.setEndValue(sessionJob.getJobInfoEntity().getMultiplicityEndValue());
-				sessionNode.setMessage(Messages.getString("message.job.86"));
+				setMessage(sessionNode, Messages.getString("message.job.86"));
+
 				if (checkAllNodeEnd(sessionJob)) {
 					try {
 						new JobSessionJobImpl().endJob(sessionId, jobunitId, jobId, sessionNode.getResult(), true);
 					} catch (HinemosUnknown e) {
-						m_log.warn("wait2running END " + e.getMessage());
+						m_log.warn("wait2running END " + e.getMessage(), e);
+					} catch (FacilityNotFound e) {
+						m_log.warn("wait2running END " + e.getMessage(), e);
 					}
 				}
 				break;
@@ -211,7 +228,7 @@ public class JobSessionNodeImpl {
 	/**
 	 * ノード詳細の中で待機中のものを実行中に遷移させる。
 	 * JobMultiplicityCache.kick()以外から呼ばないこと。
-	 * 
+	 *
 	 * @param sessionId
 	 * @param jobunitId
 	 * @param jobId
@@ -244,7 +261,7 @@ public class JobSessionNodeImpl {
 		m_log.info("wait2running " + sessionNode.getId().getFacilityId() +
 				"," + sessionNode.getId().getSessionId());
 		sessionNode.setStatus(StatusConstant.TYPE_RUNNING);
-		sessionNode.setMessage(Messages.getString("wait.agent.response"));
+		setMessage(sessionNode, Messages.getString("wait.agent.response"));
 
 		try {
 			//Topicに送信
@@ -260,7 +277,7 @@ public class JobSessionNodeImpl {
 		return startCommand;
 	}
 
-	private void runJobSessionNode(String sessionId, String jobunitId, String jobId, String facilityId) throws JobInfoNotFound, InvalidRole, HinemosUnknown {
+	private void runJobSessionNode(String sessionId, String jobunitId, String jobId, String facilityId) throws JobInfoNotFound, InvalidRole, HinemosUnknown, JobMasterNotFound, FacilityNotFound {
 		m_log.debug("runJobSessionNode() : sessionId=" + sessionId + ", jobunitid=" + jobunitId + ", jobId=" + jobId + ", facilityId=" + facilityId);
 		JobSessionJobEntity sessionJob = QueryUtil.getJobSessionJobPK(sessionId, jobunitId, jobId);
 		JobInfoEntity job = sessionJob.getJobInfoEntity();
@@ -272,10 +289,15 @@ public class JobSessionNodeImpl {
 		instructionInfo.setJobunitId(sessionJob.getId().getJobunitId());
 		instructionInfo.setJobId(sessionJob.getId().getJobId());
 		instructionInfo.setFacilityId(sessionNode.getId().getFacilityId());
-		//コマンド内のパラメータを置き換える
-		String startCommand = ParameterUtil.replaceSessionParameterValue(
+
+		String startCommand = job.getStartCommand();
+
+		// ジョブ変数のパラメータを置き換える
+		startCommand = ParameterUtil.replaceSessionParameterValue(
 				sessionId,
+				sessionNode.getId().getFacilityId(),
 				job.getStartCommand());
+		
 		//コマンド内のパラメータを置き換える(#[RETURN:jobid:facilityId])
 		startCommand = ParameterUtil.replaceReturnCodeParameter(sessionId, jobunitId, startCommand);
 		instructionInfo.setCommand(startCommand);
@@ -324,7 +346,7 @@ public class JobSessionNodeImpl {
 					sessionId, jobunitId,
 					job.getArgumentJobId());
 			String result = argumentSessionJob.getResult();
-			
+
 			// TRIDを指定
 			instructionInfo.setCommand(instructionInfo.getCommand() + " " + result);
 		}
@@ -332,6 +354,7 @@ public class JobSessionNodeImpl {
 		try {
 			//Topicに送信
 			SendTopic.put(instructionInfo);
+
 		} catch (Exception e) {
 			m_log.warn("runJobSessionNode() : "
 					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
@@ -340,7 +363,7 @@ public class JobSessionNodeImpl {
 
 	/**
 	 * ノード終了処理を行います。
-	 * 
+	 *
 	 * @param info 実行結果情報
 	 * @return コマンドを実行してよい場合はtrue、コマンドを実行しないでほしい場合はfalse
 	 * @throws HinemosUnknown
@@ -401,7 +424,14 @@ public class JobSessionNodeImpl {
 			if(sessionNode.getStartDate() == null){
 				//開始・再実行日時を設定
 				sessionNode.setStartDate(new Timestamp(info.getTime()));
-				sessionNode.setMessage(Messages.getString("wait.command.end"));
+				setMessage(sessionNode, Messages.getString("wait.command.end"));
+				
+				AgentInfo agentInfo = AgentConnectUtil.getAgentInfo(info.getFacilityId());
+				if (agentInfo != null) {
+					sessionNode.setStartupTime(agentInfo.getStartupTime());
+				} else {
+					m_log.warn("agentInfo is null");
+				}
 
 				//チェック中の場合
 				m_log.debug("agent check OK : status=" + info.getStatus() + ", sessionId=" + info.getSessionId() + ", jobId=" + info.getJobId() + ", facilityId=" + info.getFacilityId());
@@ -415,8 +445,30 @@ public class JobSessionNodeImpl {
 				return false;
 			}
 		}else{
+			boolean retryFlag = true;
+
+			//再実行判定（正常終了時は再実行しない）
+			JobEndInfoEntity jobEndInfo = QueryUtil
+					.getJobEndInfoPK(info.getSessionId(),
+							info.getJobunitId(), info.getJobId(),
+							EndStatusConstant.TYPE_NORMAL);
+
+			if (info.getStatus() == RunStatusConstant.END &&
+					(jobEndInfo.getEndValueFrom() <= info.getEndValue() &&
+					info.getEndValue() <= jobEndInfo.getEndValueTo())) {
+				retryFlag = false;
+			} else {
+				if (job.getCommandRetryFlg() == YesNoConstant.TYPE_NO) {
+					retryFlag = false;
+				}
+			}
+
 			if(info.getStatus() == RunStatusConstant.END){
 				//終了の場合
+				if (retryFlag && retryJob(sessionNode, sessionJob, info, job.getCommandRetry())) {
+					//再実行あり
+					return false;
+				}
 
 				//開始・再実行日時が設定済みならば、終了処理を行う。
 				if(sessionJob.getStartDate() != null || sessionNode.getStartDate() != null){
@@ -441,12 +493,13 @@ public class JobSessionNodeImpl {
 								info.getStopType() == CommandStopTypeConstant.DESTROY_PROCESS) {
 							// プロセス終了の場合
 							//メッセージを設定
-							sessionNode.setMessage(Messages.getString("job.process.shutdown"));
+							setMessage(sessionNode, Messages.getString("job.process.shutdown"));
 						} else {
 							// プロセス終了以外の場合
 							//メッセージを設定
-							sessionNode.setMessage(info.getMessage() + info.getErrorMessage());
+							setMessage(sessionNode, "stdout=" + info.getMessage() + ", stderr=" + info.getErrorMessage());
 						}
+
 						//終了値を設定
 						sessionNode.setEndValue(info.getEndValue());
 
@@ -457,7 +510,7 @@ public class JobSessionNodeImpl {
 						}else if(info.getCommand().equals(CommandConstant.GET_CHECKSUM)){
 							//チェックサム取得
 							sessionNode.setResult(info.getCheckSum());
-						} else if (CreateHulftJob.isHulftMode() && info.getJobId().endsWith(CreateHulftJob.UTLSEND)) {
+						} else if (info.getJobId().endsWith(CreateHulftJob.UTLSEND) && CreateHulftJob.isHulftMode()) {
 							//TRID取得
 							sessionNode.setResult(info.getMessage());
 						}
@@ -476,18 +529,22 @@ public class JobSessionNodeImpl {
 				}
 			}else if(info.getStatus() == RunStatusConstant.ERROR){
 				//失敗の場合
+				if (retryFlag && retryJob(sessionNode, sessionJob, info, job.getCommandRetry())) {
+					//再実行あり
+					return false;
+				}
 
 				//実行状態、終了値、終了・中断日時を設定
 				if(sessionNode.getStatus() == StatusConstant.TYPE_RUNNING){
 					//エラー時に終了にする
-					if(job.getErrorEndFlg() == YesNoConstant.TYPE_YES){
+					if(job.getMessageRetryEndFlg() == YesNoConstant.TYPE_YES){
 						//実行状態が実行中の場合、実行状態バッファに終了を設定
 						sessionNode.setStatus(StatusConstant.TYPE_END);
 
 						//終了・中断日時を設定
 						sessionNode.setEndDate(new Timestamp(new Date().getTime()));
 						//終了値を設定
-						sessionNode.setEndValue(job.getErrorEndValue());
+						sessionNode.setEndValue(job.getMessageRetryEndValue());
 					}else{
 						//実行状態が実行中の場合、実行状態バッファに実行失敗を設定
 						sessionNode.setStatus(StatusConstant.TYPE_ERROR);
@@ -499,7 +556,7 @@ public class JobSessionNodeImpl {
 				}
 
 				//メッセージを設定
-				sessionNode.setMessage(info.getMessage() + info.getErrorMessage());
+				setMessage(sessionNode, info.getMessage() + info.getErrorMessage());
 			}
 
 			if (sessionNode.getStartDate() == null) {
@@ -514,7 +571,6 @@ public class JobSessionNodeImpl {
 				JobMultiplicityCache.fromRunning(sessionNode.getId());
 			}
 
-			
 		}
 		return true;
 	}
@@ -566,7 +622,7 @@ public class JobSessionNodeImpl {
 						if (node.getStatus() == StatusConstant.TYPE_WAIT) {
 							JobMultiplicityCache.removeWait(node.getId());
 							node.setStatus(StatusConstant.TYPE_END);
-							node.setMessage("didn't execute");
+							setMessage(node, "didn't execute");
 						}
 					}
 					//ジョブ終了時関連処理（再帰呼び出し）
@@ -598,7 +654,7 @@ public class JobSessionNodeImpl {
 
 	/**
 	 * 全ノードの停止チェックを行います。
-	 * 
+	 *
 	 * @param sessionJob セッションジョブ
 	 * @return true：停止、false：未停止あり
 	 */
@@ -621,7 +677,7 @@ public class JobSessionNodeImpl {
 
 	/**
 	 * 全ノードの終了チェックを行います。
-	 * 
+	 *
 	 * @param sessionJob セッションジョブ
 	 * @return true：終了、false：未終了
 	 */
@@ -665,7 +721,7 @@ public class JobSessionNodeImpl {
 	 * エージェントタイムアウトチェックを行います。
 	 */
 	public HashMap<String, List<JobSessionNodeEntityPK>> checkTimeoutAll() throws JobInfoNotFound {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		Collection<JobSessionNodeEntity> collection = null;
 		collection = em.createNamedQuery("JobSessionNodeEntity.findByStatusStartIsNull", JobSessionNodeEntity.class)
 				.setParameter("status", StatusConstant.TYPE_RUNNING)
@@ -689,7 +745,7 @@ public class JobSessionNodeImpl {
 
 	/**
 	 * エージェントタイムアウトチェックを行います。
-	 * 
+	 *
 	 * @param sessionId セッションID
 	 * @param jobId ジョブID
 	 * @throws JobInfoNotFound
@@ -736,15 +792,12 @@ public class JobSessionNodeImpl {
 			info.setErrorMessage("");
 			try {
 				endNode(info);
-			} catch (InvalidRole e) {
-				m_log.info("setting status failure. (sessionId = " + info.getSessionId() + ", facilityId = " + info.getFacilityId()
-						+ ", status = " + info.getStatus() + ", commandType = " + info.getCommandType() + ")", e);
-			} catch (JobInfoNotFound e) {
-				m_log.info("setting status failure. (sessionId = " + info.getSessionId() + ", facilityId = " + info.getFacilityId()
-						+ ", status = " + info.getStatus() + ", commandType = " + info.getCommandType() + ")", e);
+			} catch (InvalidRole | JobInfoNotFound e) {
+				m_log.warn("setting status failure. (sessionId = " + info.getSessionId() + ", facilityId = " + info.getFacilityId()
+						+ ", status = " + info.getStatus() + ", commandType = " + info.getCommandType() + ")"  + " (" + e.getClass().getName() + ")");
 			} catch (Exception e) {
 				m_log.warn("checkTimeout() RunresultInfo send error : sessionId=" + sessionId + ", jobId=" + jobId + ", facilityId=" + facilityId + ",  : "
-						+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
+						+ e.getClass().getSimpleName() + ", " + e.getMessage() + " (" + e.getClass().getName() + ")", e);
 			}
 		}else{
 			int retryCount = sessionNode.getRetryCount();
@@ -756,8 +809,11 @@ public class JobSessionNodeImpl {
 						", jobId=" + jobId + ", facilityId=" + facilityId + ", retry=" + retryCount);
 
 				runJobSessionNode(sessionId, jobunitId, jobId, facilityId);
+			} catch (InvalidRole | HinemosUnknown | JobMasterNotFound | FacilityNotFound e) {
+				m_log.warn("checkTimeout() RunInstructionInfo() send error : sessionId=" + sessionId + ", jobId=" + jobId + ", facilityId=" + facilityId + " : "
+						+ e.getClass().getSimpleName() + ", " + e.getMessage());
 			} catch (Exception e) {
-				m_log.warn("checkTimeout() RunInstructionInfo) send error : sessionId=" + sessionId + ", jobId=" + jobId + ", facilityId=" + facilityId + " : "
+				m_log.warn("checkTimeout() RunInstructionInfo() send error : sessionId=" + sessionId + ", jobId=" + jobId + ", facilityId=" + facilityId + " : "
 						+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 			}
 		}
@@ -783,4 +839,166 @@ public class JobSessionNodeImpl {
 			return 0;
 		}
 	}
+
+	/**
+	 * ノード詳細に表示するメッセージをセットします。
+	 * @param sessionNode
+	 * @param newMsg
+	 */
+	public void setMessage(JobSessionNodeEntity sessionNode, String newMsg) {
+		String msg;
+		Date date = new Date();
+		SimpleDateFormat df = new SimpleDateFormat("yyyy/MM/dd HH:mm:ss");
+		String dateStr = df.format(date);
+		String header ="["+ dateStr + "] ";
+		String oldMsg = sessionNode.getMessage();
+
+		//行末に改行が含まれている場合は除く
+		Pattern pattern = Pattern.compile("\r\n$");
+		Matcher m = pattern.matcher(newMsg);
+		if (m.find() == false) {
+			pattern = Pattern.compile("\n$");
+			m = pattern.matcher(newMsg);
+		}
+		newMsg = m.replaceAll("");
+
+		if (oldMsg == null || oldMsg.equals("")) {
+			msg = header + newMsg;
+		} else {
+			//既にメッセージがあれば追記して改行
+			msg =  header + newMsg + "\r\n" + oldMsg;
+		}
+
+		//設定された文字数で切る
+		int msgMaxLen = HinemosPropertyUtil.getHinemosPropertyNum("job.message.max.length", 2048);
+		if (msg.length() > msgMaxLen) {
+			msg = msg.substring(0, msgMaxLen);
+		}
+		sessionNode.setMessage(msg);
+	}
+
+	private boolean retryJob(JobSessionNodeEntity sessionNode, JobSessionJobEntity sessionJob, RunResultInfo info, int maxRetry) {
+
+		if (sessionNode.getStatus() != StatusConstant.TYPE_RUNNING) {
+			return false;
+		}
+
+		if (sessionJob.getStatus() == StatusConstant.TYPE_SUSPEND) {
+			setMessage(sessionNode, Messages.getString("suspend"));
+			sessionNode.setStatus(StatusConstant.TYPE_WAIT);
+			sessionNode.setStartDate(null);
+			return false;
+		} else if (sessionJob.getStatus() != StatusConstant.TYPE_RUNNING) {
+			return false;
+		}
+
+		//エージェントが終了した場合は再実行を行わない
+		if (info.getStatus().equals(RunStatusConstant.ERROR)
+				&& info.getMessage().equals(Messages.getString("message.agent.5"))) {
+			return false;
+		}
+
+		//通算回数
+		int errorCount = sessionNode.getErrorRetryCount();
+		m_log.debug("maxRetry:" + maxRetry + " errorCount:" + errorCount + " " + (maxRetry > errorCount) + ", " + sessionNode.getId());
+		if (maxRetry > errorCount) {
+			//再実行前にスリープ処理
+			int jobRetryInterval = HinemosPropertyUtil.getHinemosPropertyNum("job.retry.interval", 10 * 1000);
+			try {
+				Thread.sleep(jobRetryInterval);
+			} catch (InterruptedException e) {
+				m_log.warn("retryJob() : "
+						+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
+				return false;
+			}
+
+			//上限回数に達してない場合は再実行
+			//通算回数を加算
+			errorCount++;
+			m_log.debug("errRtryCnt++=" + errorCount);
+
+			//DB更新
+			String msg =info.getMessage() + info.getErrorMessage();
+			setMessage(sessionNode, msg);
+			setMessage(sessionNode, Messages.getString("retrying") + "(" + errorCount + ")");
+			sessionNode.setErrorRetryCount(errorCount);
+			sessionNode.setStatus(StatusConstant.TYPE_WAIT);
+			sessionNode.setStartDate(null);
+
+			//再実行
+			if(checkMultiplicity(sessionNode)) {
+				JobMultiplicityCache.fromRunning(sessionNode.getId());
+				JobMultiplicityCache.toRunning(sessionNode.getId());
+				return true;
+			}
+		}
+
+		return false;
+	}
+
+	/**
+	 * Hinemosエージェントが終了した際に実行中ノードを終了状態へ更新します。
+	 * @param facilityId ファシリティID
+	 * @param agentInfo エージェント情報
+	 * @param isNormalEnd エージェントが正常終了時に呼ばれたかどうか
+	 */
+	public void endNodeByAgent(String facilityId, AgentInfo agentInfo, boolean isNormalEnd) {
+
+		String queryName = new String();
+		if (isNormalEnd) {
+			queryName = "JobSessionNodeEntity.findByFacilityIdStatus";
+		} else {
+			queryName = "JobSessionNodeEntity.findByDifferentStartuptime";
+		}
+
+		JpaTransactionManager jtm = new JpaTransactionManager();
+		jtm.begin();
+
+		//実行中のジョブ情報を取得
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
+		List<JobSessionNodeEntity> list = null;
+		list = em.createNamedQuery(queryName, JobSessionNodeEntity.class)
+				.setParameter("status", StatusConstant.TYPE_RUNNING)
+				.setParameter("facilityId", facilityId)
+				.setParameter("startupTime", agentInfo.getStartupTime())
+				.getResultList();
+
+		for (JobSessionNodeEntity entity : list) {
+			//実行結果情報を作成
+				RunResultInfo info = new RunResultInfo();
+				info.setSessionId(entity.getId().getSessionId());
+				info.setJobunitId(entity.getId().getJobunitId());
+				info.setJobId(entity.getId().getJobId());
+				info.setFacilityId(facilityId);
+				info.setCommand("");
+				info.setCommandType(CommandTypeConstant.NORMAL);
+				info.setStatus(RunStatusConstant.ERROR);
+				info.setMessage(Messages.getString("message.agent.5"));
+				info.setErrorMessage("");
+				m_log.info("endNodeByAgent " + entity.getId().toString());
+				try {
+					endNode(info);
+				} catch (InvalidRole e) {
+					m_log.info("setting status failure. (sessionId = " + info.getSessionId() + ", facilityId = " + info.getFacilityId()
+							+ ", status = " + info.getStatus() + ", commandType = " + info.getCommandType() + ")", e);
+					jtm.rollback();
+					return;
+				} catch (JobInfoNotFound e) {
+					m_log.info("setting status failure. (sessionId = " + info.getSessionId() + ", facilityId = " + info.getFacilityId()
+							+ ", status = " + info.getStatus() + ", commandType = " + info.getCommandType() + ")", e);
+					jtm.rollback();
+					return;
+				} catch (Exception e) {
+					m_log.warn(
+							"endNodeByAgent() RunresultInfo send error : sessionId=" + info.getSessionId()
+									+ ", jobId="+ info.getJobId()
+									+ ", facilityId=" + facilityId
+									+ ",  : " + e.getClass().getSimpleName()
+									+ ", " + e.getMessage(), e);
+					jtm.rollback();
+					return;
+				}
+			}
+		jtm.commit();
+	}
 }
