@@ -16,13 +16,12 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.jobmanagement.factory;
 
 import java.sql.Timestamp;
-import java.util.ArrayList;
 import java.util.Calendar;
 import java.util.Collection;
+import java.util.HashSet;
 import java.util.List;
 
 import javax.persistence.EntityExistsException;
-import javax.persistence.EntityManager;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -32,6 +31,7 @@ import com.clustercontrol.accesscontrol.util.ObjectPrivilegeUtil;
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.commons.util.HinemosEntityManager;
 import com.clustercontrol.commons.util.JpaTransactionManager;
+import com.clustercontrol.commons.util.NotifyGroupIdGenerator;
 import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.fault.InvalidRole;
 import com.clustercontrol.fault.JobInvalid;
@@ -41,7 +41,6 @@ import com.clustercontrol.fault.ObjectPrivilege_InvalidRole;
 import com.clustercontrol.jobmanagement.bean.JobConstant;
 import com.clustercontrol.jobmanagement.bean.JobEndStatusInfo;
 import com.clustercontrol.jobmanagement.bean.JobInfo;
-import com.clustercontrol.jobmanagement.bean.JobNotificationsInfo;
 import com.clustercontrol.jobmanagement.bean.JobObjectInfo;
 import com.clustercontrol.jobmanagement.bean.JobParameterInfo;
 import com.clustercontrol.jobmanagement.bean.JobTreeItem;
@@ -49,10 +48,10 @@ import com.clustercontrol.jobmanagement.bean.JobWaitRuleInfo;
 import com.clustercontrol.jobmanagement.bean.JudgmentObjectConstant;
 import com.clustercontrol.jobmanagement.model.JobEndMstEntity;
 import com.clustercontrol.jobmanagement.model.JobMstEntity;
-import com.clustercontrol.jobmanagement.model.JobNoticeMstEntity;
 import com.clustercontrol.jobmanagement.model.JobParamMstEntity;
 import com.clustercontrol.jobmanagement.model.JobStartJobMstEntity;
 import com.clustercontrol.jobmanagement.util.QueryUtil;
+import com.clustercontrol.notify.bean.NotifyRelationInfo;
 import com.clustercontrol.notify.session.NotifyControllerBean;
 
 /**
@@ -65,31 +64,31 @@ public class ModifyJob {
 	/** ログ出力のインスタンス */
 	private static Log m_log = LogFactory.getLog( ModifyJob.class );
 
-	public void replaceJobunit(List<JobInfo> oldList, List<JobInfo> newList, String userId)
+	public Long replaceJobunit(List<JobInfo> oldList, List<JobInfo> newList, String userId)
 			throws JobInvalid, JobMasterNotFound, EntityExistsException, HinemosUnknown, JobMasterDuplicate, InvalidRole {
 		//ジョブユニットのジョブIDを取得
 		String jobunitId = newList.get(0).getJobunitId();
 
 		// ジョブマスタ変更
-		List<JobInfo> delList = new ArrayList<JobInfo> ();
-		for (JobInfo oldJob : oldList) {
-			if (!newList.contains(oldJob)){
-				m_log.debug("delJob " + oldJob.getId());
-				delList.add(oldJob);
-			}
-		}
-		List<JobInfo> addList = new ArrayList<JobInfo> ();
-		for (JobInfo newJob : newList) {
-			if (!oldList.contains(newJob)) {
-				m_log.debug("addJob " + newJob.getId());
-				addList.add(newJob);
-			}
-		}
+		long start = System.currentTimeMillis();
+
+		HashSet<JobInfo>delJobs = new HashSet<JobInfo>(oldList);
+		HashSet<JobInfo>newJobs = new HashSet<JobInfo>(newList);
+		delJobs.removeAll(newJobs);
+
+		long timeJobToDelete = System.currentTimeMillis();
+		m_log.info("Find jobs to delete " + (timeJobToDelete - start) + "ms");
+
+		HashSet<JobInfo> addJobs = newJobs;
+		addJobs.removeAll(new HashSet<JobInfo>(oldList));
+
+		long timeJobToAdd = System.currentTimeMillis();
+		m_log.info("Find jobs to add " + (timeJobToAdd - timeJobToDelete) + "ms");
 		m_log.info("oldList=" + oldList.size() + ", newList=" + newList.size() +
-				", delList=" + delList.size() + ", addList=" + addList.size());
+				", delJobs=" + delJobs.size() + ", addJobs=" + addJobs.size());
 
 		JpaTransactionManager jtm = new JpaTransactionManager();
-		for (JobInfo delJob : delList) {
+		for (JobInfo delJob : delJobs) {
 			String jobId = delJob.getId();
 			JobMstEntity entity = QueryUtil.getJobMstPK(delJob.getJobunitId(), delJob.getId());
 			deleteJob(entity);
@@ -99,7 +98,22 @@ public class ModifyJob {
 		jtm.flush();
 
 		Timestamp timestamp = new Timestamp(System.currentTimeMillis());
-		for (JobInfo addJob : addList) {
+
+		// ジョブユニットを最初に登録する必要があるため。
+		for (JobInfo addJob : addJobs) {
+			int type = addJob.getType();
+			if (type == JobConstant.TYPE_JOBUNIT) {
+				String jobId = addJob.getId();
+				String parentJobId = addJob.getParentId();
+				if (jobunitId.equals(jobId)) {
+					parentJobId = CreateJobSession.TOP_JOB_ID;
+				}
+				createJobMasterData(addJob, jobunitId, parentJobId, userId, timestamp);
+				addJobs.remove(addJob);
+				break;
+			}
+		}
+		for (JobInfo addJob : addJobs) {
 			String jobId = addJob.getId();
 			String parentJobId = addJob.getParentId();
 			if (jobunitId.equals(jobId)) {
@@ -112,6 +126,10 @@ public class ModifyJob {
 		String jobId = newList.get(0).getId();
 		JobMstEntity entity = QueryUtil.getJobMstPK(jobunitId, jobId);
 		entity.setUpdateDate(timestamp);
+		m_log.info("Left tasks in replaceJobunit " + (System.currentTimeMillis() - timeJobToAdd) + "ms");
+		
+		// ジョブユニットの最終更新日時を返す
+		return timestamp.getTime();
 	}
 
 	/**
@@ -136,7 +154,7 @@ public class ModifyJob {
 	 *   </ol>
 	 *   <li>ジョブツリー情報を基に、ジョブマスタを作成します。</li>
 	 * </ol>
-	 * 
+	 *
 	 * @param item ジョブツリー情報
 	 * @param userId ユーザID
 	 * @throws HinemosUnknown
@@ -146,7 +164,7 @@ public class ModifyJob {
 	 * @throws InvalidRole
 	 * @see com.clustercontrol.jobmanagement.factory.ModifyJob#createJobMaster(JobTreeItem, String)
 	 */
-	public void registerJobunit(JobTreeItem jobunit, String userId)
+	public Long registerJobunit(JobTreeItem jobunit, String userId)
 			throws HinemosUnknown, JobMasterNotFound, JobInvalid, JobMasterDuplicate, InvalidRole {
 
 		//ジョブユニットのジョブIDを取得
@@ -155,29 +173,34 @@ public class ModifyJob {
 		int msec = Calendar.getInstance().get(Calendar.MILLISECOND);
 		m_log.debug("registerJobunit() start : " + msec);
 
+		Timestamp timestamp = new Timestamp(System.currentTimeMillis());
+		
 		// ジョブマスタ作成
-		createJobMaster(jobunit, jobunitId, CreateJobSession.TOP_JOB_ID, userId, new Timestamp(System.currentTimeMillis()));
+		createJobMaster(jobunit, jobunitId, CreateJobSession.TOP_JOB_ID, userId, timestamp);
 
 		m_log.debug("registerJobunit() End : " + msec);
+		
+		// ジョブユニットの最終更新日時を返す
+		return timestamp.getTime();
 	}
 
 	/**
 	 * 指定されたジョブユニットを削除する
-	 * 
+	 *
 	 * @param jobunitId 削除対象ジョブユニットのジョブID
 	 * @throws HinemosUnknown
 	 * @throws JobMasterNotFound
 	 * @throws JobInvalid
-	 * 
+	 *
 	 */
 	public void deleteJobunit(String jobunitId, String userId) throws HinemosUnknown, JobMasterNotFound, JobInvalid, ObjectPrivilege_InvalidRole {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 
 		// 引数で指定されたジョブユニットIDを持つジョブユニットを取得
 		Collection<JobMstEntity> ct =
-				((HinemosEntityManager)em).createNamedQuery("JobMstEntity.findByJobunitId", JobMstEntity.class, ObjectPrivilegeMode.WRITE)
+				em.createNamedQuery("JobMstEntity.findByJobunitId", JobMstEntity.class, ObjectPrivilegeMode.MODIFY)
 				.setParameter("jobunitId", jobunitId).getResultList();
-		
+
 		// オブジェクト権限チェック(削除対象のリストが空だった場合)
 		if (ct == null || ct.size() == 0) {
 			ObjectPrivilege_InvalidRole e = new ObjectPrivilege_InvalidRole(
@@ -186,7 +209,7 @@ public class ModifyJob {
 
 			throw e;
 		}
-		
+
 		for (JobMstEntity jobMstEntity : ct) {
 			deleteJob(jobMstEntity);
 		}
@@ -196,7 +219,7 @@ public class ModifyJob {
 	}
 
 	private void deleteJob(JobMstEntity jobMstEntity) {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 
 		if (jobMstEntity != null) {
 			String jobunitId = jobMstEntity.getId().getJobunitId();
@@ -222,7 +245,7 @@ public class ModifyJob {
 	 * <li>ジョブツリー情報を基に、ジョブマスタを作成します。</li>
 	 * </ol>
 	 * </ol>
-	 * 
+	 *
 	 * @param item
 	 *            ジョブツリー情報
 	 * @param user
@@ -262,7 +285,7 @@ public class ModifyJob {
 	 * <li>ジョブツリー情報を基に、ジョブ終了状態マスタを作成します。</li>
 	 * <li>ジョブツリー情報を基に、ジョブ変数マスタを作成します。</li>
 	 * </ol>
-	 * 
+	 *
 	 * @param item ジョブツリー情報
 	 * @param user ユーザID
 	 * @throws HinemosUnknown
@@ -273,6 +296,7 @@ public class ModifyJob {
 	private void createJobMasterData(JobInfo info, String jobunitId, String parentId, String user, Timestamp updateDate)
 			throws HinemosUnknown, JobMasterDuplicate, JobMasterNotFound, InvalidRole {
 
+		m_log.debug("createJobMasterData");
 		JpaTransactionManager jtm = new JpaTransactionManager();
 
 		// ジョブユニット単位で再帰的に登録するため、親となるジョブユニットIDは変わらない
@@ -317,6 +341,7 @@ public class ModifyJob {
 
 			//待ち条件作成
 			if(info.getWaitRule() != null){
+				m_log.debug("info.getWaitRule = " + info.getWaitRule());
 				JobWaitRuleInfo waitRule = info.getWaitRule();
 				Timestamp startDelayTime = null;
 				Timestamp endDelayTime = null;
@@ -395,9 +420,14 @@ public class ModifyJob {
 								// 重複チェック
 								jtm.checkEntityExists(JobStartJobMstEntity.class, jobStartJobMstEntity.getId());
 							}
-							else{
+							else if(objectInfo.getType() == JudgmentObjectConstant.TYPE_TIME) {
 								jobMst.setStartTime(objectInfo.getTime()==null?null:new Timestamp(objectInfo.getTime()));
 							}
+							else if(objectInfo.getType() == JudgmentObjectConstant.TYPE_START_MINUTE) {
+								m_log.debug("objectInfo.getType = " + objectInfo.getType());
+								m_log.debug("objectInfo.getStartMinute = " + objectInfo.getStartMinute());
+								jobMst.setStartMinute(objectInfo.getStartMinute());
+							}
 						}
 					}
 				}
@@ -413,10 +443,12 @@ public class ModifyJob {
 				jobMst.setSpecifyUser(info.getCommand().getSpecifyUser());
 				jobMst.setEffectiveUser(info.getCommand().getUser());
 				jobMst.setMessageRetry(info.getCommand().getMessageRetry());
-				jobMst.setErrorEndFlg(info.getCommand().getErrorEndFlg());
-				jobMst.setErrorEndValue(info.getCommand().getErrorEndValue());
+				jobMst.setMessageRetryEndFlg(info.getCommand().getMessageRetryEndFlg());
+				jobMst.setMessageRetryEndValue(info.getCommand().getMessageRetryEndValue());
 				jobMst.setArgumentJobId("");
 				jobMst.setArgument("");
+				jobMst.setCommandRetryFlg(info.getCommand().getCommandRetryFlg());
+				jobMst.setCommandRetry(info.getCommand().getCommandRetry());
 			}
 
 			//ファイル転送作成
@@ -433,24 +465,28 @@ public class ModifyJob {
 				jobMst.setSpecifyUser(info.getFile().getSpecifyUser());
 				jobMst.setEffectiveUser(info.getFile().getUser());
 				jobMst.setMessageRetry(info.getFile().getMessageRetry());
+				jobMst.setMessageRetryEndFlg(info.getFile().getMessageRetryEndFlg());
+				jobMst.setMessageRetryEndValue(info.getFile().getMessageRetryEndValue());
+				jobMst.setCommandRetryFlg(info.getFile().getCommandRetryFlg());
+				jobMst.setCommandRetry(info.getFile().getCommandRetry());
 			}
 
 			//通知メッセージを取得
-			if(info.getNotifications() != null){
-				for(JobNotificationsInfo notificationsInfo : info.getNotifications()){
-					if(notificationsInfo != null){
-						// インスタンス生成
-						JobNoticeMstEntity jobNoticeMstEntity = new JobNoticeMstEntity(jobMst, notificationsInfo.getType());
-						// 重複チェック
-						jtm.checkEntityExists(JobNoticeMstEntity.class, jobNoticeMstEntity.getId());
-						jobNoticeMstEntity.setPriority(notificationsInfo.getPriority());
-						jobNoticeMstEntity.setNotifyGroupId(notificationsInfo.getNotifyGroupId());
+			jobMst.setBeginPriority(info.getBeginPriority());
+			jobMst.setNormalPriority(info.getNormalPriority());
+			jobMst.setWarnPriority(info.getWarnPriority());
+			jobMst.setAbnormalPriority(info.getAbnormalPriority());
 
-						//通知情報を投入
-						new NotifyControllerBean().addNotifyRelation(notificationsInfo.getNotifyId());
-					}
+			//notifyGroupIdを更新
+			String notifyGroupId = NotifyGroupIdGenerator.generate(info);
+			jobMst.setNotifyGroupId(notifyGroupId);
+
+			if (info.getNotifyRelationInfos() != null) {
+				for (NotifyRelationInfo notifyRelationInfo : info.getNotifyRelationInfos()) {
+					notifyRelationInfo.setNotifyGroupId(notifyGroupId);
 				}
 			}
+			new NotifyControllerBean().addNotifyRelation(info.getNotifyRelationInfos());
 
 			//終了状態を取得
 			if(info.getEndStatus() != null){
