@@ -1,8 +1,14 @@
 package com.clustercontrol.jobmanagement.model;
 
 import java.io.Serializable;
-import javax.persistence.*;
 
+import javax.persistence.Cacheable;
+import javax.persistence.Column;
+import javax.persistence.Entity;
+import javax.persistence.Id;
+import javax.persistence.Table;
+
+import com.clustercontrol.commons.util.HinemosEntityManager;
 import com.clustercontrol.commons.util.JpaTransactionManager;
 
 
@@ -12,7 +18,7 @@ import com.clustercontrol.commons.util.JpaTransactionManager;
  * 
  */
 @Entity
-@Table(name="cc_job_edit")
+@Table(name="cc_job_edit", schema="setting")
 @Cacheable(true)
 public class JobEditEntity implements Serializable {
 	private static final long serialVersionUID = 1L;
@@ -28,7 +34,7 @@ public class JobEditEntity implements Serializable {
 
 	public JobEditEntity(String jobunitId) {
 		this.setJobunitId(jobunitId);
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		em.persist(this);
 	}
 
