@@ -1,26 +1,35 @@
 package com.clustercontrol.jobmanagement.model;
 
-import javax.persistence.*;
+import java.sql.Timestamp;
+import java.util.List;
+
+import javax.persistence.AttributeOverride;
+import javax.persistence.Cacheable;
+import javax.persistence.CascadeType;
+import javax.persistence.Column;
+import javax.persistence.EmbeddedId;
+import javax.persistence.Entity;
+import javax.persistence.FetchType;
+import javax.persistence.OneToMany;
+import javax.persistence.Table;
 
 import com.clustercontrol.accesscontrol.annotation.HinemosObjectPrivilege;
-import com.clustercontrol.accesscontrol.bean.RoleIdConstant;
 import com.clustercontrol.accesscontrol.bean.PrivilegeConstant.ObjectPrivilegeMode;
+import com.clustercontrol.accesscontrol.bean.RoleIdConstant;
 import com.clustercontrol.accesscontrol.model.ObjectPrivilegeTargetEntity;
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.commons.util.HinemosEntityManager;
 import com.clustercontrol.commons.util.JpaTransactionManager;
 import com.clustercontrol.jobmanagement.bean.JobConstant;
 
-import java.sql.Timestamp;
-import java.util.List;
 
 
 /**
  * The persistent class for the cc_job_mst database table.
- * 
+ *
  */
 @Entity
-@Table(name="cc_job_mst")
+@Table(name="cc_job_mst", schema="setting")
 @Cacheable(true)
 @HinemosObjectPrivilege(
 		objectType=HinemosModuleConstant.JOB,
@@ -42,8 +51,9 @@ public class JobMstEntity extends ObjectPrivilegeTargetEntity {
 	private String argumentJobId;
 	private Integer specifyUser;
 	private String effectiveUser;
-	private Integer errorEndFlg;
-	private Integer errorEndValue;
+	private Integer messageRetryEndFlg;
+	private Integer messageRetryEndValue;
+	private Integer commandRetryFlg;
 	private String facilityId;
 	private Integer processMode;
 	private String startCommand;
@@ -72,7 +82,8 @@ public class JobMstEntity extends ObjectPrivilegeTargetEntity {
 	private Integer multiplicity_notify_priority;
 	private Integer multiplicity_operation;
 	private Integer multiplicity_end_value;
-	private Integer message_retry;
+	private Integer messageRetry;
+	private Integer commandRetry;
 	private Integer skip;
 	private Integer skipEndStatus;
 	private Integer skipEndValue;
@@ -104,9 +115,16 @@ public class JobMstEntity extends ObjectPrivilegeTargetEntity {
 	private String destFacilityId;
 	// cc_job_start_time_mst
 	private Timestamp startTime;
+	private Integer startMinute;
+
+	//ジョブ通知関連
+	private String notifyGroupId;
+	private Integer beginPriority;
+	private Integer normalPriority;
+	private Integer warnPriority;
+	private Integer abnormalPriority;
 
 	private List<JobEndMstEntity> jobEndMstEntities;
-	private List<JobNoticeMstEntity> jobNoticeMstEntities;
 	private List<JobParamMstEntity> jobParamMstEntities;
 	private List<JobStartJobMstEntity> jobStartJobMstEntities;
 	private String parentJobunitId;
@@ -121,7 +139,7 @@ public class JobMstEntity extends ObjectPrivilegeTargetEntity {
 
 	public JobMstEntity(JobMstEntityPK pk, Integer jobType) {
 		this.setId(pk);
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		em.persist(this);
 		this.jobType = jobType;
 		this.setObjectId(this.getId().getJobunitId());
@@ -129,7 +147,7 @@ public class JobMstEntity extends ObjectPrivilegeTargetEntity {
 		// JOBUNIT以外は、JOBUNITのowner_role_idを設定する
 		if (this.getJobType() != null && this.getJobType() != JobConstant.TYPE_JOBUNIT) {
 			JobMstEntity jobMstEntity
-			= ((HinemosEntityManager)em).find(JobMstEntity.class,
+			= em.find(JobMstEntity.class,
 					new JobMstEntityPK(this.getId().getJobunitId(), this.getId().getJobunitId()), ObjectPrivilegeMode.NONE);
 			if (jobMstEntity != null && jobMstEntity.getOwnerRoleId() != null) {
 				this.setOwnerRoleId(jobMstEntity.getOwnerRoleId());
@@ -263,23 +281,33 @@ public class JobMstEntity extends ObjectPrivilegeTargetEntity {
 	}
 
 
-	@Column(name="error_end_flg")
-	public Integer getErrorEndFlg() {
-		return this.errorEndFlg;
+	@Column(name="message_retry_end_flg")
+	public Integer getMessageRetryEndFlg() {
+		return this.messageRetryEndFlg;
 	}
 
-	public void setErrorEndFlg(Integer errorEndFlg) {
-		this.errorEndFlg = errorEndFlg;
+	public void setMessageRetryEndFlg(Integer messageRetryEndFlg) {
+		this.messageRetryEndFlg = messageRetryEndFlg;
 	}
 
 
-	@Column(name="error_end_value")
-	public Integer getErrorEndValue() {
-		return this.errorEndValue;
+	@Column(name="message_retry_end_value")
+	public Integer getMessageRetryEndValue() {
+		return this.messageRetryEndValue;
 	}
 
-	public void setErrorEndValue(Integer errorEndValue) {
-		this.errorEndValue = errorEndValue;
+	public void setMessageRetryEndValue(Integer messageRetryEndValue) {
+		this.messageRetryEndValue = messageRetryEndValue;
+	}
+
+
+	@Column(name="command_retry_flg")
+	public Integer getCommandRetryFlg() {
+		return this.commandRetryFlg;
+	}
+
+	public void setCommandRetryFlg(Integer commandRetryFlg) {
+		this.commandRetryFlg = commandRetryFlg;
 	}
 
 
@@ -513,11 +541,20 @@ public class JobMstEntity extends ObjectPrivilegeTargetEntity {
 
 	@Column(name="message_retry")
 	public Integer getMessageRetry() {
-		return this.message_retry;
+		return this.messageRetry;
 	}
 
-	public void setMessageRetry(Integer message_retry) {
-		this.message_retry = message_retry;
+	public void setMessageRetry(Integer messageRetry) {
+		this.messageRetry = messageRetry;
+	}
+
+	@Column(name="command_retry")
+	public Integer getCommandRetry() {
+		return this.commandRetry;
+	}
+
+	public void setCommandRetry(Integer commandRetry) {
+		this.commandRetry = commandRetry;
 	}
 
 	@Column(name="multiplicity_notify")
@@ -845,6 +882,15 @@ public class JobMstEntity extends ObjectPrivilegeTargetEntity {
 		this.startTime = startTime;
 	}
 
+	@Column(name="start_minute")
+	public Integer getStartMinute() {
+		return this.startMinute;
+	}
+
+	public void setStartMinute(Integer startMinute) {
+		this.startMinute = startMinute;
+	}
+
 	@Column(name="parent_jobunit_id")
 	public String getParentJobunitId() {
 		return parentJobunitId;
@@ -881,6 +927,51 @@ public class JobMstEntity extends ObjectPrivilegeTargetEntity {
 		this.referJobId = referJobId;
 	}
 
+	@Column(name="notify_group_id")
+	public String getNotifyGroupId() {
+		return notifyGroupId;
+	}
+
+	public void setNotifyGroupId(String notifyGroupId) {
+		this.notifyGroupId = notifyGroupId;
+	}
+
+	@Column(name="begin_priority")
+	public Integer getBeginPriority() {
+		return beginPriority;
+	}
+
+	public void setBeginPriority(Integer beginPriority) {
+		this.beginPriority = beginPriority;
+	}
+
+	@Column(name="normal_priority")
+	public Integer getNormalPriority() {
+		return normalPriority;
+	}
+
+	public void setNormalPriority(Integer normalPriority) {
+		this.normalPriority = normalPriority;
+	}
+
+	@Column(name="warn_priority")
+	public Integer getWarnPriority() {
+		return warnPriority;
+	}
+
+	public void setWarnPriority(Integer warnPriority) {
+		this.warnPriority = warnPriority;
+	}
+
+	@Column(name="abnormal_priority")
+	public Integer getAbnormalPriority() {
+		return abnormalPriority;
+	}
+
+	public void setAbnormalPriority(Integer abnormalPriority) {
+		this.abnormalPriority = abnormalPriority;
+	}
+
 	//bi-directional many-to-one association to JobEndMstEntity
 	@OneToMany(mappedBy="jobMstEntity", cascade=CascadeType.ALL, fetch=FetchType.LAZY)
 	public List<JobEndMstEntity> getJobEndMstEntities() {
@@ -891,18 +982,6 @@ public class JobMstEntity extends ObjectPrivilegeTargetEntity {
 		this.jobEndMstEntities = jobEndMstEntities;
 	}
 
-
-	//bi-directional many-to-one association to JobNoticeMstEntity
-	@OneToMany(mappedBy="jobMstEntity", cascade=CascadeType.ALL, fetch=FetchType.LAZY)
-	public List<JobNoticeMstEntity> getJobNoticeMstEntities() {
-		return this.jobNoticeMstEntities;
-	}
-
-	public void setJobNoticeMstEntities(List<JobNoticeMstEntity> jobNoticeMstEntities) {
-		this.jobNoticeMstEntities = jobNoticeMstEntities;
-	}
-
-
 	//bi-directional many-to-one association to JobParamMstEntity
 	@OneToMany(mappedBy="jobMstEntity", cascade=CascadeType.ALL, fetch=FetchType.LAZY)
 	public List<JobParamMstEntity> getJobParamMstEntities() {
