@@ -8,14 +8,15 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.util.EndpointManager;
-import com.clustercontrol.util.EndpointManager.EndpointSetting;
+import com.clustercontrol.util.EndpointUnit;
+import com.clustercontrol.util.EndpointUnit.EndpointSetting;
 import com.clustercontrol.ws.jobmanagement.FacilityNotFound_Exception;
 import com.clustercontrol.ws.jobmanagement.HinemosUnknown_Exception;
-import com.clustercontrol.ws.jobmanagement.InvalidObjectPrivilege_Exception;
 import com.clustercontrol.ws.jobmanagement.InvalidRole_Exception;
 import com.clustercontrol.ws.jobmanagement.InvalidSetting_Exception;
 import com.clustercontrol.ws.jobmanagement.InvalidUserPass_Exception;
 import com.clustercontrol.ws.jobmanagement.JobEndpoint;
+import com.clustercontrol.ws.jobmanagement.JobEndpointService;
 import com.clustercontrol.ws.jobmanagement.JobFileCheck;
 import com.clustercontrol.ws.jobmanagement.JobForwardFile;
 import com.clustercontrol.ws.jobmanagement.JobHistoryFilter;
@@ -44,7 +45,7 @@ import com.sun.xml.internal.ws.client.ClientTransportException;
 /**
  * Hinemosマネージャとの通信をするクラス。
  * HAのような複数マネージャ対応のため、このクラスを実装する。
- * 
+ *
  * Hinemosマネージャと通信できない場合は、WebServiceExceptionがthrowされる。
  * WebServiceExeptionが出力された場合は、もう一台のマネージャと通信する。
  */
@@ -53,257 +54,277 @@ public class JobEndpointWrapper {
 	// ログ
 	private static Log m_log = LogFactory.getLog( JobEndpointWrapper.class );
 
-	public static void addSchedule(JobSchedule jobSchedule)
+	private EndpointUnit endpointUnit;
+
+	public JobEndpointWrapper(EndpointUnit endpointUnit) {
+		this.endpointUnit = endpointUnit;
+	}
+
+	public static JobEndpointWrapper getWrapper(String managerName) {
+		return new JobEndpointWrapper(EndpointManager.get(managerName));
+	}
+
+	public EndpointUnit getEndpointUnit() {
+		return this.endpointUnit;
+	}
+
+	public static List<EndpointSetting<JobEndpoint>> getJobEndpoint(EndpointUnit endpointUnit) {
+		return endpointUnit.getEndpoint(JobEndpointService.class, JobEndpoint.class);
+	}
+
+	public void addSchedule(JobSchedule jobSchedule)
 			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception, JobKickDuplicate_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+		for (EndpointSetting<JobEndpoint> endpointSetting : getJobEndpoint(endpointUnit)) {
 			try {
-				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
+				JobEndpoint endpoint = endpointSetting.getEndpoint();
 				endpoint.addSchedule(jobSchedule);
 				return;
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("addSchedule(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("addSchedule(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
 	}
 
-	public static void addFileCheck(JobFileCheck jobFileCheck)
-			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception, JobKickDuplicate_Exception, InvalidObjectPrivilege_Exception {
+	public void addFileCheck(JobFileCheck jobFileCheck)
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception, JobKickDuplicate_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+		for (EndpointSetting<JobEndpoint> endpointSetting : getJobEndpoint(endpointUnit)) {
 			try {
-				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
+				JobEndpoint endpoint = endpointSetting.getEndpoint();
 				endpoint.addFileCheck(jobFileCheck);
 				return;
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("addFileCheck(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("addFileCheck(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
 	}
-	public static void modifySchedule(JobSchedule jobSchedule)
-			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception, JobInfoNotFound_Exception, InvalidObjectPrivilege_Exception {
+
+	public void modifySchedule(JobSchedule jobSchedule)
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception, JobInfoNotFound_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+		for (EndpointSetting<JobEndpoint> endpointSetting : getJobEndpoint(endpointUnit)) {
 			try {
-				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
+				JobEndpoint endpoint = endpointSetting.getEndpoint();
 				endpoint.modifySchedule(jobSchedule);
 				return;
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("modifySchedule(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("modifySchedule(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
 	}
 
-	public static void modifyFileCheck(JobFileCheck jobFileCheck)
-			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception, JobInfoNotFound_Exception, InvalidObjectPrivilege_Exception {
+	public void modifyFileCheck(JobFileCheck jobFileCheck)
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception, JobInfoNotFound_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+		for (EndpointSetting<JobEndpoint> endpointSetting : getJobEndpoint(endpointUnit)) {
 			try {
-				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
+				JobEndpoint endpoint = endpointSetting.getEndpoint();
 				endpoint.modifyFileCheck(jobFileCheck);
 				return;
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("modifyFileCheck(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("modifyFileCheck(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
 	}
 
-	public static void deleteSchedule(String scheduleId)
-			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInfoNotFound_Exception, InvalidObjectPrivilege_Exception {
-		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
-			try {
-				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
-				endpoint.deleteSchedule(scheduleId);
-				return;
-			} catch (WebServiceException e) {
-				wse = e;
-				m_log.warn("deleteSchedule(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
-			}
-		}
-		throw wse;
-	}
-
-	public static void deleteFileCheck(String scheduleId)
+	public void deleteSchedule(List<String> scheduleIdList)
 			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInfoNotFound_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+		for (EndpointSetting<JobEndpoint> endpointSetting : getJobEndpoint(endpointUnit)) {
 			try {
-				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
-				endpoint.deleteFileCheck(scheduleId);
+				JobEndpoint endpoint = endpointSetting.getEndpoint();
+				endpoint.deleteSchedule(scheduleIdList);
 				return;
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("deleteFileCheck(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("deleteSchedule(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
 	}
 
-	public static JobSchedule getJobSchedule(String jobKickId)
+	public void deleteFileCheck(List<String> scheduleIdList)
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInfoNotFound_Exception {
+		WebServiceException wse = null;
+		for (EndpointSetting<JobEndpoint> endpointSetting : getJobEndpoint(endpointUnit)) {
+			try {
+				JobEndpoint endpoint = endpointSetting.getEndpoint();
+				endpoint.deleteFileCheck(scheduleIdList);
+				return;
+			} catch (WebServiceException e) {
+				wse = e;
+				m_log.warn("deleteFileCheck(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
+			}
+		}
+		throw wse;
+	}
+
+	public JobSchedule getJobSchedule(String jobKickId)
 			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobMasterNotFound_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+		for (EndpointSetting<JobEndpoint> endpointSetting : getJobEndpoint(endpointUnit)) {
 			try {
-				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
+				JobEndpoint endpoint = endpointSetting.getEndpoint();
 				return endpoint.getJobSchedule(jobKickId);
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("getJobSchedule(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("getJobSchedule(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
 	}
 
-	public static JobFileCheck getJobFileCheck(String jobKickId)
+	public JobFileCheck getJobFileCheck(String jobKickId)
 			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobMasterNotFound_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+		for (EndpointSetting<JobEndpoint> endpointSetting : getJobEndpoint(endpointUnit)) {
 			try {
-				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
+				JobEndpoint endpoint = endpointSetting.getEndpoint();
 				return endpoint.getJobFileCheck(jobKickId);
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("getJobFileCheck(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("getJobFileCheck(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
 	}
 
-	public static List<JobKick> getJobKickList()
+	public List<JobKick> getJobKickList()
 			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobMasterNotFound_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+		for (EndpointSetting<JobEndpoint> endpointSetting : getJobEndpoint(endpointUnit)) {
 			try {
-				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
+				JobEndpoint endpoint = endpointSetting.getEndpoint();
 				return endpoint.getJobKickList();
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("getScheduleList(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("getScheduleList(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
 	}
-	public static void setJobKickStatus(String scheduleId, boolean validFlag)
+	public void setJobKickStatus(String scheduleId, boolean validFlag)
 			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception, JobInfoNotFound_Exception, JobMasterNotFound_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+		for (EndpointSetting<JobEndpoint> endpointSetting : getJobEndpoint(endpointUnit)) {
 			try {
-				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
+				JobEndpoint endpoint = endpointSetting.getEndpoint();
 				endpoint.setJobKickStatus(scheduleId, validFlag);
 				return;
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("setJobKickStatus(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("setJobKickStatus(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
 	}
 
-	public static List<JobForwardFile> getForwardFileList(String sessionId, String jobunitId, String jobId)
-			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInfoNotFound_Exception, InvalidObjectPrivilege_Exception {
+	public List<JobForwardFile> getForwardFileList(String sessionId, String jobunitId, String jobId)
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInfoNotFound_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+		for (EndpointSetting<JobEndpoint> endpointSetting : getJobEndpoint(endpointUnit)) {
 			try {
-				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
+				JobEndpoint endpoint = endpointSetting.getEndpoint();
 				return endpoint.getForwardFileList(sessionId, jobunitId, jobId);
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("getForwardFileList(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("getForwardFileList(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
 	}
 
-	public static JobTreeItem getJobDetailList(String sessionId)
-			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInfoNotFound_Exception, JobMasterNotFound_Exception, InvalidObjectPrivilege_Exception {
+	public JobTreeItem getJobDetailList(String sessionId)
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInfoNotFound_Exception, JobMasterNotFound_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+		for (EndpointSetting<JobEndpoint> endpointSetting : getJobEndpoint(endpointUnit)) {
 			try {
-				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
+				JobEndpoint endpoint = endpointSetting.getEndpoint();
 				JobTreeItem item = endpoint.getJobDetailList(sessionId);
 				setTreeParent(item);
 				return item;
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("getJobDetailList(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("getJobDetailList(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
 	}
 
-	public static List<String> getAvailableStartOperation(String sessionId, String jobunitId, String jobId, String facilityId)
-			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidObjectPrivilege_Exception {
+	public List<String> getAvailableStartOperation(String sessionId, String jobunitId, String jobId, String facilityId)
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+		for (EndpointSetting<JobEndpoint> endpointSetting : getJobEndpoint(endpointUnit)) {
 			try {
 				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
 				return endpoint.getAvailableStartOperation(sessionId, jobunitId, jobId, facilityId);
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("getAvailableStartOperation(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("getAvailableStartOperation(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
 	}
 
-	public static List<String> getAvailableStopOperation(String sessionId, String jobunitId, String jobId, String facilityId)
-			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidObjectPrivilege_Exception {
+	public List<String> getAvailableStopOperation(String sessionId, String jobunitId, String jobId, String facilityId)
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+		for (EndpointSetting<JobEndpoint> endpointSetting : getJobEndpoint(endpointUnit)) {
 			try {
 				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
 				return endpoint.getAvailableStopOperation(sessionId, jobunitId, jobId, facilityId);
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("getAvailableStopOperation(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("getAvailableStopOperation(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
 	}
 
-	public static JobTreeItem getJobTree(String ownerRoleId, boolean treeOnly)
+	public JobTreeItem getJobTree(String ownerRoleId, boolean treeOnly)
 			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobMasterNotFound_Exception, NotifyNotFound_Exception, UserNotFound_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+		for (EndpointSetting<JobEndpoint> endpointSetting : getJobEndpoint(endpointUnit)) {
 			try {
-				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
+				JobEndpoint endpoint = endpointSetting.getEndpoint();
 				JobTreeItem item = endpoint.getJobTree(ownerRoleId, treeOnly);
 				setTreeParent(item);
+				m_log.info("getJobTree role=" + ownerRoleId);
 				return item;
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("getJobTree(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("getJobTree(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
 	}
 
 	// ジョブマップからも利用します。
-	public static void setTreeParent(JobTreeItem item) {
+	public void setTreeParent(JobTreeItem item) {
 		List<JobTreeItem> children = item.getChildren();
 		for (JobTreeItem child : children) {
 			child.setParent(item);
@@ -311,17 +332,17 @@ public class JobEndpointWrapper {
 		}
 	}
 
-	public static List<JobNodeDetail> getNodeDetailList(String sessionId, String jobunitId, String jobId)
+	public List<JobNodeDetail> getNodeDetailList(String sessionId, String jobunitId, String jobId)
 			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInfoNotFound_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+		for (EndpointSetting<JobEndpoint> endpointSetting : getJobEndpoint(endpointUnit)) {
 			try {
-				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
+				JobEndpoint endpoint = endpointSetting.getEndpoint();
 				return endpoint.getNodeDetailList(sessionId, jobunitId, jobId);
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("getNodeDetailList(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("getNodeDetailList(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
@@ -329,91 +350,91 @@ public class JobEndpointWrapper {
 
 
 
-	public static JobTreeItem getSessionJobInfo(String sessionId, String jobunitId, String jobId)
+	public JobTreeItem getSessionJobInfo(String sessionId, String jobunitId, String jobId)
 			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInfoNotFound_Exception, NotifyNotFound_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+		for (EndpointSetting<JobEndpoint> endpointSetting : getJobEndpoint(endpointUnit)) {
 			try {
-				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
+				JobEndpoint endpoint = endpointSetting.getEndpoint();
 				return endpoint.getSessionJobInfo(sessionId, jobunitId, jobId);
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("getSessionJobInfo(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("getSessionJobInfo(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
 	}
 
-	public static JobHistoryList getJobHistoryList(JobHistoryFilter filter, int histories)
+	public JobHistoryList getJobHistoryList(JobHistoryFilter filter, int histories)
 			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInfoNotFound_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+		for (EndpointSetting<JobEndpoint> endpointSetting : getJobEndpoint(endpointUnit)) {
 			try {
-				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
+				JobEndpoint endpoint = endpointSetting.getEndpoint();
 				return endpoint.getJobHistoryList(filter, histories);
 			} catch (WebServiceException e) {
 				wse = e;
 				if (e instanceof ClientTransportException) {
 					m_log.warn("getJobHistoryList(), " + e.getMessage());
 				} else {
-					m_log.warn("getJobHistoryList(), " + e.getMessage(), e);
+					m_log.warn("getJobHistoryList(), " + e.getMessage());
 				}
-				EndpointManager.changeEndpoint();
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
 	}
 
-	public static List<JobPlan> getPlanList(JobPlanFilter filter, int plans)
+	public List<JobPlan> getPlanList(JobPlanFilter filter, int plans)
 			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobMasterNotFound_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+		for (EndpointSetting<JobEndpoint> endpointSetting : getJobEndpoint(endpointUnit)) {
 			try {
-				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
+				JobEndpoint endpoint = endpointSetting.getEndpoint();
 				return endpoint.getPlanList(filter, plans);
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("getPlanList(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("getPlanList(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
 	}
 
-	public static void operationJob(JobOperationInfo info)
+	public void operationJob(JobOperationInfo info)
 			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInfoNotFound_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+		for (EndpointSetting<JobEndpoint> endpointSetting : getJobEndpoint(endpointUnit)) {
 			try {
 				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
 				endpoint.operationJob(info);
 				return;
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("operationJob(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("operationJob(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
 	}
 
-	public static void registerJobunit(JobTreeItem jobunit)
-			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInvalid_Exception, JobMasterNotFound_Exception, InvalidSetting_Exception, InvalidObjectPrivilege_Exception {
+	public Long registerJobunit(JobTreeItem jobunit)
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInvalid_Exception, JobMasterNotFound_Exception, InvalidSetting_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+		for (EndpointSetting<JobEndpoint> endpointSetting : getJobEndpoint(endpointUnit)) {
 			JobTreeItem top = null; // TOPを保存しておく
 			try {
-				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
+				JobEndpoint endpoint = endpointSetting.getEndpoint();
 				removeTreeParent(jobunit);
 				top = jobunit.getParent();
 				jobunit.setParent(null);
-				endpoint.registerJobunit(jobunit);
-				return;
+				Long lastUpdateTime = endpoint.registerJobunit(jobunit);
+				return lastUpdateTime;
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("registerJob(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("registerJob(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			} finally {
 				jobunit.setParent(top);
 				setTreeParent(jobunit);
@@ -422,18 +443,18 @@ public class JobEndpointWrapper {
 		throw wse;
 	}
 
-	public static void deleteJobunit(String jobunitId)
-			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInvalid_Exception, JobMasterNotFound_Exception, InvalidSetting_Exception, NotifyNotFound_Exception, InvalidObjectPrivilege_Exception {
+	public void deleteJobunit(String jobunitId)
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInvalid_Exception, JobMasterNotFound_Exception, InvalidSetting_Exception, NotifyNotFound_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+		for (EndpointSetting<JobEndpoint> endpointSetting : getJobEndpoint(endpointUnit)) {
 			try {
-				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
+				JobEndpoint endpoint = endpointSetting.getEndpoint();
 				endpoint.deleteJobunit(jobunitId);
 				return;
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("registerJobunit(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("registerJobunit(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
@@ -447,102 +468,117 @@ public class JobEndpointWrapper {
 		}
 	}
 
-	public static void runJob(String jobunitId, String jobId, OutputBasicInfo info, JobTriggerInfo triggerInfo)
-			throws FacilityNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInfoNotFound_Exception, JobMasterNotFound_Exception, JobSessionDuplicate_Exception {
+	public void runJob(String jobunitId, String jobId, OutputBasicInfo info, JobTriggerInfo triggerInfo)
+			throws FacilityNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobInfoNotFound_Exception, JobMasterNotFound_Exception, JobSessionDuplicate_Exception, InvalidSetting_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+		for (EndpointSetting<JobEndpoint> endpointSetting : getJobEndpoint(endpointUnit)) {
 			try {
 				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
 				endpoint.runJob(jobunitId, jobId, info, triggerInfo);
 				return;
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("runJob(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("runJob(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
 	}
 
-	public static JobInfo getJobFull(JobInfo jobInfo)
+	public JobInfo getJobFull(JobInfo jobInfo)
 			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, JobMasterNotFound_Exception, NotifyNotFound_Exception, UserNotFound_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+		for (EndpointSetting<JobEndpoint> endpointSetting : getJobEndpoint(endpointUnit)) {
 			try {
-				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
+				JobEndpoint endpoint = endpointSetting.getEndpoint();
 				return endpoint.getJobFull(jobInfo);
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("getJobFull(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("getJobFull(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
 	}
-
-
-	public static Long getUpdateTime(String jobunitId) throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+	
+	
+	public List<JobInfo> getJobFullList(List<JobInfo> jobList)
+			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, NotifyNotFound_Exception, UserNotFound_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+		for (EndpointSetting<JobEndpoint> endpointSetting : getJobEndpoint(endpointUnit)) {
 			try {
-				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
-				Long updateTime = endpoint.getUpdateTime(jobunitId);
-				m_log.debug("getUpdateTime() : jobunit=" + jobunitId + ", update=" + updateTime);
-				return updateTime;
+				JobEndpoint endpoint = endpointSetting.getEndpoint();
+				return endpoint.getJobFullList(jobList);
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("getJobunitUpdateTime(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("getJobFull(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
+			}
+		}
+		throw wse;
+	}
+	
+	public List<Long> getUpdateTimeList(List<String> jobunitIdList) throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+		WebServiceException wse = null;
+		for (EndpointSetting<JobEndpoint> endpointSetting : getJobEndpoint(endpointUnit)) {
+			try {
+				JobEndpoint endpoint = endpointSetting.getEndpoint();
+				List<Long> updateTimeList = endpoint.getUpdateTimeList(jobunitIdList);
+				return updateTimeList;
+			} catch (WebServiceException e) {
+				wse = e;
+				m_log.warn("getJobunitUpdateTime(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
 	}
 
-	public static Integer getEditLock(String jobunitId, Long updateTime, boolean forceFlag)
+	public Integer getEditLock(String jobunitId, Long updateTime, boolean forceFlag)
 			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, OtherUserGetLock_Exception, UpdateTimeNotLatest_Exception, JobInvalid_Exception, JobMasterNotFound_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+		for (EndpointSetting<JobEndpoint> endpointSetting : getJobEndpoint(endpointUnit)) {
 			try {
-				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
+				JobEndpoint endpoint = endpointSetting.getEndpoint();
 				return endpoint.getEditLock(jobunitId, updateTime, forceFlag);
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("getEditLock(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("getEditLock(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
 	}
 
-	public static void checkEditLock(String jobunitId, Integer editSession)
+	public void checkEditLock(String jobunitId, Integer editSession)
 			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, OtherUserGetLock_Exception, UpdateTimeNotLatest_Exception, JobInvalid_Exception, JobMasterNotFound_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+		for (EndpointSetting<JobEndpoint> endpointSetting : getJobEndpoint(endpointUnit)) {
 			try {
-				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
+				JobEndpoint endpoint = endpointSetting.getEndpoint();
 				endpoint.checkEditLock(jobunitId, editSession);
 				return;
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("checkEditLock(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("checkEditLock(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
 	}
 
-	public static void releaseEditLock(Integer editSession)
+	public void releaseEditLock(Integer editSession)
 			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getJobEndpoint()) {
+		for (EndpointSetting<JobEndpoint> endpointSetting : getJobEndpoint(endpointUnit)) {
 			try {
-				JobEndpoint endpoint = (JobEndpoint) endpointSetting.getEndpoint();
+				JobEndpoint endpoint = endpointSetting.getEndpoint();
 				endpoint.releaseEditLock(editSession);
 				return;
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("releaseEditLock(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("releaseEditLock(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
