@@ -22,7 +22,6 @@ import com.clustercontrol.ws.jobmanagement.JobEndStatusInfo;
 import com.clustercontrol.ws.jobmanagement.JobHistoryFilter;
 import com.clustercontrol.ws.jobmanagement.JobInfo;
 import com.clustercontrol.ws.jobmanagement.JobMasterNotFound_Exception;
-import com.clustercontrol.ws.jobmanagement.JobNotificationsInfo;
 import com.clustercontrol.ws.jobmanagement.JobOperationInfo;
 import com.clustercontrol.ws.jobmanagement.JobParameterInfo;
 import com.clustercontrol.ws.jobmanagement.JobPlanFilter;
@@ -38,7 +37,7 @@ public class JobPropertyUtil {
 		JobOperationInfo info = new JobOperationInfo();
 
 		//セッションID取得
-		ArrayList values = PropertyUtil.getPropertyValue(property, JobOperationConstant.SESSION);
+		ArrayList<?> values = PropertyUtil.getPropertyValue(property, JobOperationConstant.SESSION);
 		if(values.get(0) instanceof String && ((String)values.get(0)).length() > 0)
 			info.setSessionId((String)values.get(0));
 
@@ -88,7 +87,7 @@ public class JobPropertyUtil {
 
 	public static JobHistoryFilter property2jobHistoryFilter (Property property) {
 		JobHistoryFilter filter = new JobHistoryFilter();
-		ArrayList values = null;
+		ArrayList<?> values = null;
 
 		//開始・再実行日時（自）取得
 		values = PropertyUtil.getPropertyValue(property, HistoryFilterPropertyConstant.START_FROM_DATE);
@@ -145,7 +144,7 @@ public class JobPropertyUtil {
 			triggerInfo = (String) values.get(0);
 			filter.setTriggerInfo(triggerInfo);
 		}
-		
+
 		//オーナーロールID
 		values = PropertyUtil.getPropertyValue(property, HistoryFilterPropertyConstant.OWNER_ROLE_ID);
 		String ownerRoleId = null;
@@ -157,26 +156,25 @@ public class JobPropertyUtil {
 	}
 	public static JobPlanFilter property2jobPlanFilter (Property property) {
 		JobPlanFilter filter = new JobPlanFilter();
-		ArrayList values = null;
+		ArrayList<?> values = null;
 
 		//開始取得
 		values = PropertyUtil.getPropertyValue(property, PlanFilterPropertyConstant.FROM_DATE);
-		m_log.trace("JobPlanFilter fromDate :");
-		if(values.get(0) != null && values.get(0) instanceof Date){
-			m_log.trace(" " + ((Date)values.get(0)).getTime());
+		m_log.debug("JobPlanFilter property2JobPlanFilter");
+		if (values.get(0) instanceof Date){
+			m_log.debug("property2jobPlanFilter : fromDate=" + ((Date)values.get(0)).getTime());
 			filter.setFromDate(((Date)values.get(0)).getTime());
 		}
 		//終了取得
 		values = PropertyUtil.getPropertyValue(property, PlanFilterPropertyConstant.TO_DATE);
-		m_log.trace("JobPlanFilter toDate :");
-		if(values.get(0) != null && values.get(0) instanceof Date){
-			m_log.trace(" " + ((Date)values.get(0)).getTime());
+		if (values.get(0) instanceof Date){
+			m_log.debug("property2jobPlanFilter : toDate=" + ((Date)values.get(0)).getTime());
 			filter.setToDate(((Date)values.get(0)).getTime());
 		}
 		//実行契機ID
 		values = PropertyUtil.getPropertyValue(property, PlanFilterPropertyConstant.SCHEDULE_ID);
 		if(values.get(0) != null){
-			m_log.trace(" " + ((String)values.get(0)));
+			m_log.debug("property2jobPlanFilter : id=" + ((String)values.get(0)));
 			filter.setJobKickId((String)values.get(0));
 		}
 		return filter;
@@ -187,22 +185,75 @@ public class JobPropertyUtil {
 	 * 負荷が高いので取り扱い注意。
 	 * @param jobTreeItem
 	 */
-	public static void setJobFullTree (JobTreeItem jobTreeItem) {
-		setJobFull(jobTreeItem.getData());
+	public static void setJobFullTree (String managerName, JobTreeItem jobTreeItem) {
 		List<JobTreeItem> children = jobTreeItem.getChildren();
 		if (children == null) {
 			return;
 		}
+		
+		// FullJob
+		List<JobInfo> list = new ArrayList<JobInfo>();
+		for (JobTreeItem info : children) {
+			list.add(info.getData());
+		}
+		JobPropertyUtil.setJobFullList(managerName, list);
+
 		for (JobTreeItem child : children) {
-			setJobFullTree(child);
+			setJobFullTree(managerName, child);
 		}
 	}
 
+	public static void setJobFullList (String managerName, List<JobInfo> jobList) {
+		List<JobInfo> notFullList = new ArrayList<JobInfo>();
+		List<JobInfo> fullList = null;
+		
+		for (JobInfo jobInfo : jobList) {
+			if (jobInfo.isPropertyFull()) {
+				continue;
+			}
+			if (jobInfo.getId() == null || "".equals(jobInfo.getId())) {
+				return;
+			}
+			notFullList.add(jobInfo);
+		}
+		
+		if (notFullList.size() == 0) {
+			return;
+		}
+		
+		try {
+			JobEndpointWrapper wrapper = JobEndpointWrapper.getWrapper(managerName);
+			fullList = wrapper.getJobFullList(notFullList);
+		} catch (NotifyNotFound_Exception e) {
+			m_log.warn("setJobFull() getJobFull, " + e.getMessage(), e);
+			return;
+		} catch (UserNotFound_Exception e) {
+			m_log.warn("setJobFull() getJobFull, " + e.getMessage(), e);
+			return;
+		} catch (HinemosUnknown_Exception e) {
+			m_log.warn("setJobFull() getJobFull, " + e.getMessage(), e);
+			return;
+		} catch (InvalidRole_Exception e) {
+			m_log.warn("setJobFull() getJobFull, " + e.getMessage(), e);
+			return;
+		} catch (Exception e) {
+			m_log.warn("setJobFull() getJobFull, " + e.getMessage(), e);
+			return;
+		}
+		
+		for (JobInfo fullInfo : fullList) {
+			for (JobInfo notFullInfo : notFullList) {
+				if (notFullInfo.getId().equals(fullInfo.getId())) {
+					copy(fullInfo, notFullInfo);
+				}
+			}
+		}
+	}
+	
 	/**
-	 * マネージャへアクセスするため、むやみに呼ばないこと。
 	 * @param jobInfo
 	 */
-	public static void setJobFull (JobInfo jobInfo) {
+	public static void setJobFull (String managerName, JobInfo jobInfo) {
 		if (jobInfo.isPropertyFull()) {
 			return;
 		}
@@ -212,7 +263,8 @@ public class JobPropertyUtil {
 
 		JobInfo ret = null;
 		try {
-			ret = JobEndpointWrapper.getJobFull(jobInfo);
+			JobEndpointWrapper wrapper = JobEndpointWrapper.getWrapper(managerName);
+			ret = wrapper.getJobFull(jobInfo);
 		} catch (JobMasterNotFound_Exception e) {
 			m_log.warn("setJobFull(), " + e.getMessage(), e);
 			// 新ジョブの場合は、必ず通る。
@@ -230,47 +282,91 @@ public class JobPropertyUtil {
 			m_log.warn("setJobFull() getJobFull, " + e.getMessage(), e);
 			return;
 		} catch (Exception e) {
-			//TODO:メッセージを入れる必要があるか検討
 			m_log.warn("setJobFull() getJobFull, " + e.getMessage(), e);
+			return;
 		}
 
-		jobInfo.setCommand(ret.getCommand());
+		copy(ret, jobInfo);
+	}
+	
+	private static void copy(JobInfo srcInfo, JobInfo dstInfo) {
+		dstInfo.setCommand(srcInfo.getCommand());
 		//		jobInfo.seto
-		jobInfo.setCreateTime(ret.getCreateTime());
-		jobInfo.setCreateUser(ret.getCreateUser());
-		jobInfo.setDescription(ret.getDescription());
-		jobInfo.setOwnerRoleId(ret.getOwnerRoleId());
-		List<JobEndStatusInfo> jobEndStatusInfoList = jobInfo.getEndStatus();
+		dstInfo.setCreateTime(srcInfo.getCreateTime());
+		dstInfo.setCreateUser(srcInfo.getCreateUser());
+		dstInfo.setDescription(srcInfo.getDescription());
+		dstInfo.setOwnerRoleId(srcInfo.getOwnerRoleId());
+		List<JobEndStatusInfo> jobEndStatusInfoList = dstInfo.getEndStatus();
 		jobEndStatusInfoList.clear();
-		if (ret.getEndStatus() != null) {
-			jobEndStatusInfoList.addAll(ret.getEndStatus());
+		if (srcInfo.getEndStatus() != null) {
+			jobEndStatusInfoList.addAll(srcInfo.getEndStatus());
 		}
-		jobInfo.setFile(ret.getFile());
+		dstInfo.setFile(srcInfo.getFile());
 		// jobInfo.setId(ret.getId());
 		// jobInfo.setJobunitId(ret.getJobunitId());
 		// jobInfo.setName(ret.getName());
-		List<JobNotificationsInfo> jobNotificationsInfoList = jobInfo.getNotifications();
-		jobNotificationsInfoList.clear();
-		if (ret.getNotifications() != null) {
-			jobNotificationsInfoList.addAll(ret.getNotifications());
-		}
-		List<JobParameterInfo> jobParameterInfoList = jobInfo.getParam();
+		dstInfo.setBeginPriority(srcInfo.getBeginPriority());
+		dstInfo.setNormalPriority(srcInfo.getNormalPriority());
+		dstInfo.setWarnPriority(srcInfo.getWarnPriority());
+		dstInfo.setAbnormalPriority(srcInfo.getAbnormalPriority());
+		dstInfo.getNotifyRelationInfos().clear();
+		dstInfo.getNotifyRelationInfos().addAll(srcInfo.getNotifyRelationInfos());
+
+		List<JobParameterInfo> jobParameterInfoList = dstInfo.getParam();
 		jobParameterInfoList.clear();
-		if (ret.getParam() != null) {
-			jobParameterInfoList.addAll(ret.getParam());
+		if (srcInfo.getParam() != null) {
+			jobParameterInfoList.addAll(srcInfo.getParam());
 		}
-		jobInfo.setPropertyFull(true);
-		jobInfo.setType(ret.getType());
-		jobInfo.setUpdateTime(ret.getUpdateTime());
-		jobInfo.setUpdateUser(ret.getUpdateUser());
-		jobInfo.setWaitRule(ret.getWaitRule());
+		dstInfo.setPropertyFull(true);
+		dstInfo.setType(srcInfo.getType());
+		dstInfo.setUpdateTime(srcInfo.getUpdateTime());
+		dstInfo.setUpdateUser(srcInfo.getUpdateUser());
+		dstInfo.setWaitRule(srcInfo.getWaitRule());
 
 		//参照ジョブ
-		if(ret.getReferJobUnitId() != null){
-			jobInfo.setReferJobUnitId(ret.getReferJobUnitId());
+		if(srcInfo.getReferJobUnitId() != null){
+			dstInfo.setReferJobUnitId(srcInfo.getReferJobUnitId());
 		}
-		if(ret.getReferJobId() != null){
-			jobInfo.setReferJobId(ret.getReferJobId());
+		if(srcInfo.getReferJobId() != null){
+			dstInfo.setReferJobId(srcInfo.getReferJobId());
+		}
+		
+	}
+
+	public static String getManagerName (Property property) {
+		ArrayList<?> values = null;
+
+		String managerName = null;
+		//開始・再実行日時（自）取得
+		values = PropertyUtil.getPropertyValue(property, HistoryFilterPropertyConstant.MANAGER);
+		if(values.get(0) instanceof String && ((String)values.get(0)).length() > 0){
+			managerName = (String)values.get(0);
+		}
+
+		return managerName;
+	}
+	
+	/**
+	 * 特定のジョブユニット配下に関して、JobTreeItemキャッシュ中のpropertyFullをクリアする
+	 */
+	public static void clearPropertyFull( JobTreeItem item, String jobunitId ){
+		for( JobTreeItem jobunitItem : item.getChildren() ){
+			if( jobunitItem.getData().getJobunitId().equals(jobunitId) ){
+				jobunitItem.getData().setPropertyFull(false);
+				for( JobTreeItem child : jobunitItem.getChildren() ){
+					child.getData().setPropertyFull(false);
+					clearPropertyFullRecursive(child);
+				}
+			}
 		}
 	}
+
+	private static void clearPropertyFullRecursive( JobTreeItem parentItem ){
+		for( JobTreeItem item : parentItem.getChildren() ){
+			item.getData().setPropertyFull(false);
+			clearPropertyFullRecursive(item);
+
+		}
+	}
+
 }
