@@ -22,19 +22,22 @@ import org.eclipse.swt.widgets.Composite;
 
 import com.clustercontrol.jobmanagement.composite.ForwardFileComposite;
 import com.clustercontrol.view.CommonViewPart;
+import com.clustercontrol.util.WidgetTestUtil;
 
 /**
  * ジョブ[ファイル転送]ビュークラスです。
- * 
+ *
  * @version 2.0.0
  * @since 2.0.0
  */
 public class ForwardFileView extends CommonViewPart {
 	/** ビューID */
-	public static final String ID = "com.clustercontrol.jobmanagement.view.ForwardFileView";
+	public static final String ID = ForwardFileView.class.getName();
 	/** ジョブ[ファイル転送]ビュー用のコンポジット */
 	private ForwardFileComposite m_composite = null;
 
+	private String orgViewName = null;
+
 	/**
 	 * コンストラクタ
 	 */
@@ -44,9 +47,9 @@ public class ForwardFileView extends CommonViewPart {
 
 	/**
 	 * ビューを構築します。
-	 * 
+	 *
 	 * @param parent 親コンポジット
-	 * 
+	 *
 	 * @see org.eclipse.ui.IWorkbenchPart#createPartControl(org.eclipse.swt.widgets.Composite)
 	 * @see #update(String, String)
 	 */
@@ -58,6 +61,7 @@ public class ForwardFileView extends CommonViewPart {
 		layout.marginWidth = 0;
 
 		m_composite = new ForwardFileComposite(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, null, m_composite);
 		GridData gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
@@ -66,28 +70,36 @@ public class ForwardFileView extends CommonViewPart {
 		m_composite.setLayoutData(gridData);
 
 		//ビューの更新
-		this.update(null, null, null);
+		this.update(null, null, null, null);
+		orgViewName = this.getPartName();
 	}
 
 	/**
 	 * ビューを更新します。
-	 * 
+	 *
+	 * @param managerName マネージャ名
 	 * @param sessionId セッションID
 	 * @param jobunitId 所属ジョブユニットのジョブID
 	 * @param jobId ジョブID
-	 * 
+	 *
 	 * @see com.clustercontrol.jobmanagement.composite.ForwardFileComposite#update(String, String, String)
 	 */
-	public void update(String sessionId, String jobunitId, String jobId) {
-		m_composite.update(sessionId, jobunitId, jobId);
+	public void update(String managerName, String sessionId, String jobunitId, String jobId) {
+		m_composite.update(managerName, sessionId, jobunitId, jobId);
+
+		if(managerName == null || managerName.equals("")) {
+			return;
+		}
+		String viewName = orgViewName + "(" + managerName + ")";
+		setPartName(viewName);
 	}
 
 	/**
 	 * ジョブ[ファイル転送]ビュー用のコンポジットを返します。
-	 * 
+	 *
 	 * @return ジョブ[ファイル転送]ビュー用のコンポジット
 	 */
 	public ForwardFileComposite getComposite() {
 		return m_composite;
 	}
-}
\ No newline at end of file
+}
