@@ -19,7 +19,6 @@ package com.clustercontrol.logfile.util;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import com.clustercontrol.commons.bean.SettingUpdateInfo;
 import com.clustercontrol.hinemosagent.bean.TopicInfo;
 import com.clustercontrol.hinemosagent.util.AgentConnectUtil;
 
@@ -43,8 +42,6 @@ public class LogfileManagerUtil{
 		// MAIN
 		m_log.info("broadcasting logfile monitor configuration modified.");
 
-		SettingUpdateInfo.getInstance().setLogFileMonitorUpdateTime(System.currentTimeMillis());
-
 		TopicInfo topicInfo = new TopicInfo();
 		topicInfo.setLogfileMonitorChanged(true);
 
