@@ -26,7 +26,7 @@ import com.clustercontrol.ws.maintenance.MaintenanceInfo;
 
 /**
  * メンテナンス情報を取得するクライアント側アクションクラス<BR>
- * 
+ *
  * @version 4.0.0
  * @since 2.2.0
  */
@@ -38,15 +38,16 @@ public class GetMaintenance {
 
 	/**
 	 * メンテナンス情報を返します。
-	 * 
+	 *
 	 * @param maintenanceId
 	 * @return
 	 */
-	public MaintenanceInfo getMaintenanceInfo(String maintenanceId) {
+	public MaintenanceInfo getMaintenanceInfo(String managerName, String maintenanceId) {
 
 		MaintenanceInfo info = null;
 		try {
-			info = MaintenanceEndpointWrapper.getMaintenanceInfo(maintenanceId);
+			MaintenanceEndpointWrapper wrapper = MaintenanceEndpointWrapper.getWrapper(managerName);
+			info = wrapper.getMaintenanceInfo(maintenanceId);
 		} catch (InvalidRole_Exception e) {
 			MessageDialog.openInformation(null, Messages.getString("message"),
 					Messages.getString("message.accesscontrol.16"));
@@ -59,4 +60,4 @@ public class GetMaintenance {
 		}
 		return info;
 	}
-}
\ No newline at end of file
+}
