@@ -16,10 +16,11 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.maintenance.composite;
 
 import java.util.List;
+import java.util.Map;
+import java.util.concurrent.ConcurrentHashMap;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.ModifyListener;
 import org.eclipse.swt.graphics.Color;
@@ -31,13 +32,15 @@ import org.eclipse.swt.widgets.Label;
 
 import com.clustercontrol.maintenance.util.MaintenanceEndpointWrapper;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.util.UIManager;
 import com.clustercontrol.ws.maintenance.InvalidRole_Exception;
 import com.clustercontrol.ws.maintenance.MaintenanceTypeMst;
+import com.clustercontrol.util.WidgetTestUtil;
 
 
 /**
  * メンテナンス種別コンポジットクラスです。
- * 
+ *
  * @version 2.2.0
  * @since 2.2.0
  */
@@ -58,20 +61,25 @@ public class MaintenanceTypeListComposite extends Composite {
 	private Combo comboMaintenanceType = null;
 
 	/** メンテナンス種別一覧リスト */
-	List<MaintenanceTypeMst> maintenanceTypeList = null;
+	ConcurrentHashMap<String, List<MaintenanceTypeMst>> dispDataMap= new ConcurrentHashMap<String, List<MaintenanceTypeMst>>();
+
+	/** マネージャ名 */
+	private String managerName = null;
 
 	// ----- コンストラクタ ----- //
 
 	/**
 	 * インスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @param style スタイル
+	 * @param managerName マネージャ名
 	 * @param labelFlg メンテナンス種別ラベル表示フラグ
 	 */
-	public MaintenanceTypeListComposite(Composite parent, int style, boolean labelFlg) {
+	public MaintenanceTypeListComposite(Composite parent, int style, String managerName, boolean labelFlg) {
 		super(parent, style);
 
+		this.managerName = managerName;
 		this.initialize(parent, labelFlg);
 	}
 
@@ -103,6 +111,7 @@ public class MaintenanceTypeListComposite extends Composite {
 		if(labelFlg){
 			// ラベル
 			this.labelMaintenanceType = new Label(this, SWT.NONE);
+			WidgetTestUtil.setTestId(this, "maintenancetype", labelMaintenanceType);
 			gridData = new GridData();
 			gridData.horizontalSpan = WIDTH_TITLE;
 			gridData.horizontalAlignment = GridData.FILL;
@@ -113,6 +122,7 @@ public class MaintenanceTypeListComposite extends Composite {
 
 		// コンボボックス
 		this.comboMaintenanceType = new Combo(this, SWT.DROP_DOWN | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, null, comboMaintenanceType);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_TEXT;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -125,19 +135,22 @@ public class MaintenanceTypeListComposite extends Composite {
 	/**
 	 * コンポジットを更新します。
 	 * <p>
-	 * 
+	 *
 	 */
 	@Override
 	public void update() {
 
 		// データ取得
-		if(maintenanceTypeList == null){
-			getMaintenanceTypeList();
+		if(dispDataMap.get(managerName) == null || dispDataMap.get(managerName).isEmpty()){
+			getMaintenanceTypeList(getManagerName());
 		}
 
+		this.comboMaintenanceType.removeAll();
 		// メンテナンス種別プルダウンメニューの作成
-		for(MaintenanceTypeMst type : maintenanceTypeList){
-			this.comboMaintenanceType.add(Messages.getString(type.getNameId()));
+		for(Map.Entry<String, List<MaintenanceTypeMst>> map : dispDataMap.entrySet()) {
+			for(MaintenanceTypeMst type : map.getValue()){
+				this.comboMaintenanceType.add(Messages.getString(type.getNameId()));
+			}
 		}
 	}
 
@@ -151,18 +164,18 @@ public class MaintenanceTypeListComposite extends Composite {
 
 	/**
 	 * メンテナンス種別のプルダウンメニューより選択された種別の取得
-	 * @param index
+	 * @param managerName
 	 * @return
 	 */
-	public String getSelectionTypeId(){
+	public String getSelectionTypeId(String managerName){
 		String typeId = null;
 		// データ取得
-		if(maintenanceTypeList == null){
-			getMaintenanceTypeList();
+		if(dispDataMap.get(managerName) == null || dispDataMap.get(managerName).isEmpty()){
+			getMaintenanceTypeList(managerName);
 		}
 		int index = getSelectionIndex();
 		if(index >= 0){
-			MaintenanceTypeMst maintenanceType = maintenanceTypeList.get(index);
+			MaintenanceTypeMst maintenanceType = dispDataMap.get(managerName).get(index);
 			typeId = maintenanceType.getTypeId();
 		}else{
 			typeId = "";
@@ -173,18 +186,20 @@ public class MaintenanceTypeListComposite extends Composite {
 
 	/**
 	 * メンテナンス種別IDよりメンテナンス種別名の取得
+	 * @param managerName
 	 * @param type_id
 	 * @return
 	 */
-	public String getMaintenanceTypeName(String type_id){
+	public String getMaintenanceTypeName(String managerName, String type_id){
 		String name = null;
 		// データ取得
-		if(maintenanceTypeList == null){
-			getMaintenanceTypeList();
+		if(dispDataMap.isEmpty()){
+			getMaintenanceTypeList(managerName);
 		}
 
 		// メンテナンス種別IDよりメンテナンス種別名を取得
-		for(MaintenanceTypeMst type : maintenanceTypeList){
+		List<MaintenanceTypeMst> list = dispDataMap.get(managerName);
+		for(MaintenanceTypeMst type : list){
 			if((type.getTypeId()).equals(type_id)){
 				name = Messages.getString(type.getNameId());
 				break;
@@ -195,19 +210,26 @@ public class MaintenanceTypeListComposite extends Composite {
 
 	/**
 	 * メンテナンス種別一覧の取得
+	 * @param managerName マネージャ名
 	 */
-	private void getMaintenanceTypeList(){
+	private void getMaintenanceTypeList(String managerName){
+		Map<String, String> errorMsgs = new ConcurrentHashMap<>();
+
+		List<MaintenanceTypeMst> mst = null;
 		try {
-			maintenanceTypeList = MaintenanceEndpointWrapper.getMaintenanceTypeList();
+			MaintenanceEndpointWrapper wrapper = MaintenanceEndpointWrapper.getWrapper(managerName);
+			mst = wrapper.getMaintenanceTypeList();
+			dispDataMap.put(managerName, mst);
 		} catch (InvalidRole_Exception e) {
-			MessageDialog.openInformation(null, Messages.getString("message"),
-					Messages.getString("message.accesscontrol.16"));
+			errorMsgs.put( managerName, Messages.getString("message.accesscontrol.16") );
 		} catch (Exception e) {
 			m_log.warn("getMaintenanceTypeList(), " + e.getMessage(), e);
-			MessageDialog.openError(
-					null,
-					Messages.getString("failed"),
-					Messages.getString("message.hinemos.failure.unexpected") + ", " + e.getMessage());
+			errorMsgs.put( managerName, Messages.getString("message.hinemos.failure.unexpected") + ", " + e.getMessage());
+		}
+
+		//メッセージ表示
+		if( 0 < errorMsgs.size() ){
+			UIManager.showMessageBox(errorMsgs, true);
 		}
 	}
 
@@ -248,4 +270,12 @@ public class MaintenanceTypeListComposite extends Composite {
 		this.comboMaintenanceType.addModifyListener(listener);
 	}
 
-}
\ No newline at end of file
+	public String getManagerName() {
+		return managerName;
+	}
+
+	public void setManagerName(String managerName) {
+		this.managerName = managerName;
+	}
+
+}
