@@ -16,16 +16,21 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.maintenance.factory;
 
 import java.sql.Timestamp;
+import java.util.ArrayList;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import com.clustercontrol.accesscontrol.bean.RoleIdConstant;
+import com.clustercontrol.commons.util.ILockManager;
+import com.clustercontrol.commons.util.LockManagerFactory;
+import com.clustercontrol.jobmanagement.factory.JobSessionImpl;
 import com.clustercontrol.jobmanagement.util.JobMultiplicityCache;
 import com.clustercontrol.maintenance.util.QueryUtil;
 
 /**
  * ジョブ履歴の削除処理
- * 
+ *
  * @version 4.0.0
  * @since 3.1.0
  *
@@ -38,7 +43,7 @@ public class MaintenanceJob extends MaintenanceObject{
 	 * 削除処理
 	 */
 	@Override
-	protected int _delete(Timestamp keep, boolean status) {
+	protected int _delete(Timestamp keep, boolean status, String ownerRoleId) {
 		m_log.debug("_delete() start : keep = " + keep.toString() + ", status = " + status);
 
 		int ret = 0;	// target job_session_id count
@@ -56,12 +61,32 @@ public class MaintenanceJob extends MaintenanceObject{
 		ret = QueryUtil.createJobCompletedSessionsTable();
 
 		// 削除対象となるsession_idの検索と挿入
-		if(status){
-			ret = QueryUtil.insertJobCompletedSessionsJobSessionJob(keep);
-		} else {
-			ret = QueryUtil.insertJobCompletedSessionsJobSessionJobByStatus(keep);
+		//オーナーロールIDがADMINISTRATORSの場合
+		if(RoleIdConstant.isAdministratorRole(ownerRoleId)) {
+			if(status){
+				ret = QueryUtil.insertJobCompletedSessionsJobSessionJob(keep);
+			} else {
+				ret = QueryUtil.insertJobCompletedSessionsJobSessionJobByStatus(keep);
+			}
+		}
+		//オーナーロールが一般ロールの場合
+		else {
+			if(status){
+				ret = QueryUtil.insertJobCompletedSessionsJobSessionJobByOwnerRoleId(keep, ownerRoleId);
+			} else {
+				ret = QueryUtil.insertJobCompletedSessionsJobSessionJobByStatusAndOwnerRoleId(keep, ownerRoleId);
+			}
 		}
 
+		//ロックオブジェクトの削除
+		ArrayList<String> sessionIdList = QueryUtil.selectCompletedSession();
+		ILockManager lm = LockManagerFactory.instance().create();
+		for (String sessionId : sessionIdList) {
+			lm.delete(JobSessionImpl.class.getName() + "-" + sessionId);
+		}
+
+		m_log.info("_delete() : completed session list size = " + sessionIdList.size()); 
+		
 		// 削除:cc_job_sessionと関連テーブル(CASCADE)
 		m_log.debug("_delete() : DELETE cc_job_session");
 		m_log.debug("_delete() : sql = JobCompletedSessionsEntity.deleteByJobCompletedSessions");
