@@ -16,17 +16,24 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.maintenance.view.action;
 
 import java.util.List;
+import java.util.Map;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.eclipse.jface.action.IAction;
+import org.eclipse.core.commands.AbstractHandler;
+import org.eclipse.core.commands.ExecutionEvent;
+import org.eclipse.core.commands.ExecutionException;
 import org.eclipse.jface.dialogs.IDialogConstants;
 import org.eclipse.jface.dialogs.MessageDialog;
-import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.jface.viewers.StructuredSelection;
 import org.eclipse.swt.widgets.Table;
-import org.eclipse.ui.IViewActionDelegate;
-import org.eclipse.ui.IViewPart;
+import org.eclipse.ui.IWorkbenchPage;
+import org.eclipse.ui.IWorkbenchPart;
+import org.eclipse.ui.IWorkbenchWindow;
+import org.eclipse.ui.PlatformUI;
+import org.eclipse.ui.commands.IElementUpdater;
+import org.eclipse.ui.handlers.HandlerUtil;
+import org.eclipse.ui.menus.UIElement;
 
 import com.clustercontrol.bean.PropertyDefineConstant;
 import com.clustercontrol.maintenance.action.GetMaintenanceListTableDefine;
@@ -34,46 +41,59 @@ import com.clustercontrol.maintenance.composite.MaintenanceListComposite;
 import com.clustercontrol.maintenance.dialog.MaintenanceDialog;
 import com.clustercontrol.maintenance.view.MaintenanceListView;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.util.WidgetTestUtil;
 
 /**
  * メンテナンス[一覧]ビューの編集アクションクラス<BR>
- * 
+ *
  * @version 4.0.0
  * @since 4.0.0
  */
-public class MaintenanceModifyAction implements IViewActionDelegate {
+public class MaintenanceModifyAction extends AbstractHandler implements IElementUpdater {
 
 	// ログ
 	private static Log m_log = LogFactory.getLog( MaintenanceModifyAction.class );
 
 	/** アクションID */
-	public static final String ID = "com.clustercontrol.maintenance.view.action.MaintenanceModifyAction";
+	public static final String ID = MaintenanceModifyAction.class.getName();
 
 	/** ビュー */
-	private IViewPart viewPart;
+	private IWorkbenchPart viewPart;
+
+	/**
+	 * Dispose
+	 */
+	@Override
+	public void dispose() {
+		this.viewPart = null;
+	}
 
 	@Override
-	public void run(IAction action) {
+	public Object execute(ExecutionEvent event) throws ExecutionException {
 		// 選択アイテムの取得
-
+		this.viewPart = HandlerUtil.getActivePart(event);
 		MaintenanceListView view = (MaintenanceListView)this.viewPart.getAdapter(MaintenanceListView.class);
 		MaintenanceListComposite composite = (MaintenanceListComposite) view.getListComposite();
 		StructuredSelection selection = (StructuredSelection) composite.getTableViewer().getSelection();
 
-		List list = (List) selection.getFirstElement();
+		List<?> list = (List<?>) selection.getFirstElement();
+		String managerName = null;
 		String maintenanceId = null;
-		String typeId = null;
 		if(list != null && list.size() > 0){
+			managerName = (String) list.get(GetMaintenanceListTableDefine.MANAGER_NAME);
 			maintenanceId = (String) list.get(GetMaintenanceListTableDefine.MAINTENANCE_ID);
 		}
 		Table table = composite.getTableViewer().getTable();
+		WidgetTestUtil.setTestId(this, null, table);
 
 		//選択アイテムがある場合に、編集ダイアログを表示する
 		if(maintenanceId != null){
 
 			try{
 				// ダイアログを生成
-				MaintenanceDialog dialog = new MaintenanceDialog(this.viewPart.getSite().getShell(), maintenanceId, PropertyDefineConstant.MODE_MODIFY);
+				MaintenanceDialog dialog = new MaintenanceDialog(this.viewPart
+						.getSite().getShell(), managerName, maintenanceId,
+						PropertyDefineConstant.MODE_MODIFY);
 				// MaintenanceSchedule scheduleList = new GetSchedule().getSchedule(maintenanceId);
 				// dialog.setSchedule(scheduleList);
 				// ダイアログにて変更が選択された場合、入力内容をもって更新を行う。
@@ -93,18 +113,31 @@ public class MaintenanceModifyAction implements IViewActionDelegate {
 					Messages.getString("warning"),
 					Messages.getString("message.maintenance.8"));
 		}
+		return null;
 	}
 
 	@Override
-	public void selectionChanged(IAction action, ISelection selection) {
-		// TODO Auto-generated method stub
+	public void updateElement(UIElement element, @SuppressWarnings("rawtypes") Map parameters) {
+		IWorkbenchWindow window = PlatformUI.getWorkbench().getActiveWorkbenchWindow();
+		// page may not start at state restoring
+		if( null != window ){
+			IWorkbenchPage page = window.getActivePage();
+			if( null != page ){
+				IWorkbenchPart part = page.getActivePart();
 
-	}
-	/**
-	 * ビューを保持します。ワークベンチにロードされた際に呼ばれます。
-	 */
-	@Override
-	public void init(IViewPart viewPart) {
-		this.viewPart = viewPart;
+				boolean editEnable = false;
+				if(part instanceof MaintenanceListView){
+					// Enable button when 1 item is selected
+					MaintenanceListView view = (MaintenanceListView)part;
+
+					if(view.getSelectedNum() == 1) {
+						editEnable = true;
+					}
+				}
+				this.setBaseEnabled(editEnable);
+			} else {
+				this.setBaseEnabled(false);
+			}
+		}
 	}
 }
