@@ -25,34 +25,43 @@ import com.clustercontrol.util.Messages;
 
 /**
  * 監視[スコープ]ビューのテーブル定義を取得するクライアント側アクションクラス<BR>
- * 
+ *
  * マネージャにSessionBean経由でアクセスし、テーブル定義を取得します。
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  */
 public class GetScopeListTableDefine {
 
+	/** マネージャ名 */
+	public static final int MANAGER_NAME = 0;
+
 	/** 重要度。 */
-	public static final int PRIORITY = 0;
+	public static final int PRIORITY = 1;
 
 	/** ファシリティID。 */
-	public static final int FACILITY_ID = 1;
+	public static final int FACILITY_ID = 2;
 
 	/** スコープ。 */
-	public static final int SCOPE = 2;
+	public static final int SCOPE = 3;
+
+	/** ダミー**/
+	public static final int DUMMY=4;
 
 	/** 更新日時。 */
-	public static final int UPDATE_TIME = 3;
+	public static final int UPDATE_TIME = 5;
 
 	/** ソート用データ**/
-	public static final int SORT_VALUE=4;
+	public static final int SORT_VALUE=6;
 
 	/** 初期表示時ソートカラム。 */
-	public static final int SORT_COLUMN_INDEX = SORT_VALUE;
+	public static final int SORT_COLUMN_INDEX1 = SORT_VALUE;
 
 	/** 初期表示時ソートカラム。 */
-	public static final int SORT_COLUMN_INDEX_SECOND = FACILITY_ID;
+	public static final int SORT_COLUMN_INDEX2 = MANAGER_NAME;
+
+	/** 初期表示時ソートカラム。 */
+	public static final int SORT_COLUMN_INDEX3 = FACILITY_ID;
 
 	/** 初期表示時ソートオーダー。 */
 	public static final int SORT_ORDER = 1;
@@ -60,9 +69,9 @@ public class GetScopeListTableDefine {
 	/**
 	 * 監視[スコープ]ビューのテーブル定義情報を取得します。<BR><BR>
 	 * リストに、カラム毎にテーブルカラム情報をセットします。
-	 * 
+	 *
 	 * @return テーブル定義情報（{@link com.clustercontrol.bean.TableColumnInfo}のリスト）
-	 * 
+	 *
 	 * @see com.clustercontrol.bean.TableColumnInfo#TableColumnInfo(java.lang.String, int, int, int)
 	 * @see com.clustercontrol.monitor.action.GetScopeListTableDefine
 	 */
@@ -72,13 +81,17 @@ public class GetScopeListTableDefine {
 		Locale locale = Locale.getDefault();
 
 		/** メイン処理 */
+		tableDefine.add(MANAGER_NAME,
+				new TableColumnInfo(Messages.getString("facility.manager", locale), TableColumnInfo.NONE, 100, SWT.LEFT));
 		tableDefine.add(PRIORITY,
 				new TableColumnInfo(Messages.getString("priority", locale), TableColumnInfo.PRIORITY, 55, SWT.LEFT));
 		tableDefine.add(FACILITY_ID,
 				new TableColumnInfo(Messages.getString("facility.id", locale), TableColumnInfo.NONE, 100, SWT.LEFT));
 		tableDefine.add(SCOPE,
 				new TableColumnInfo(Messages.getString("scope", locale), TableColumnInfo.FACILITY, 150, SWT.LEFT));
+		tableDefine.add(DUMMY,
+				new TableColumnInfo("", TableColumnInfo.DUMMY, 200, SWT.LEFT));
 
 		return tableDefine;
 	}
-}
\ No newline at end of file
+}
