@@ -15,35 +15,37 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.monitor.etc.action;
 
+import org.eclipse.core.commands.AbstractHandler;
+import org.eclipse.core.commands.ExecutionEvent;
+import org.eclipse.core.commands.ExecutionException;
 import org.eclipse.jface.action.IAction;
-import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.ui.IWorkbenchPage;
-import org.eclipse.ui.IWorkbenchWindow;
-import org.eclipse.ui.IWorkbenchWindowActionDelegate;
 import org.eclipse.ui.PartInitException;
-import org.eclipse.ui.PlatformUI;
+import org.eclipse.ui.handlers.HandlerUtil;
 
 import com.clustercontrol.monitor.view.ScopeView;
 
 /**
  * 監視[スコープ]ビューを表示するクライアント側アクションクラス<BR>
- * 
- * @version 1.0.0
+ *
+ * @version 5.0.0
  * @since 1.0.0
  */
-public class OpenScopeViewAction implements IWorkbenchWindowActionDelegate {
+public class OpenScopeViewAction extends AbstractHandler {
+
+	public void run(IAction action) {
+	}
 
 	/**
 	 * 監視[スコープ]ビューを表示します。
-	 * 
-	 * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
+	 *
+	 * @see org.eclipse.core.commands.IHandler#execute
 	 * @see com.clustercontrol.monitor.view.ScopeView
 	 */
 	@Override
-	public void run(IAction action) {
+	public Object execute(ExecutionEvent event) throws ExecutionException {
 		//アクティブページを手に入れる
-		IWorkbenchPage page = PlatformUI.getWorkbench()
-				.getActiveWorkbenchWindow().getActivePage();
+		IWorkbenchPage page = HandlerUtil.getActiveWorkbenchWindow( event ).getActivePage();
 
 		//ビューを表示する
 		try {
@@ -52,33 +54,6 @@ public class OpenScopeViewAction implements IWorkbenchWindowActionDelegate {
 			view.setFocus();
 		} catch (PartInitException e) {
 		}
+		return null;
 	}
-
-	/**
-	 * 終了する際に呼ばれます。
-	 * 
-	 * @see org.eclipse.ui.IWorkbenchWindowActionDelegate#dispose()
-	 */
-	@Override
-	public void dispose() {
-	}
-
-	/**
-	 * ワークベンチにロードされた際に呼ばれます。
-	 * 
-	 * @see org.eclipse.ui.IWorkbenchWindowActionDelegate#init(org.eclipse.ui.IWorkbenchWindow)
-	 */
-	@Override
-	public void init(IWorkbenchWindow window) {
-	}
-
-	/**
-	 * 選択を変更した際に呼ばれます。
-	 * 
-	 * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction,
-	 *      org.eclipse.jface.viewers.ISelection)
-	 */
-	@Override
-	public void selectionChanged(IAction action, ISelection selection) {
-	}
-}
\ No newline at end of file
+}
