@@ -30,8 +30,8 @@ import com.clustercontrol.fault.MonitorNotFound;
 import com.clustercontrol.monitor.bean.ConfirmConstant;
 import com.clustercontrol.monitor.bean.EventBatchConfirmInfo;
 import com.clustercontrol.monitor.bean.EventDataInfo;
-import com.clustercontrol.notify.monitor.util.QueryUtil;
 import com.clustercontrol.notify.monitor.model.EventLogEntity;
+import com.clustercontrol.notify.monitor.util.QueryUtil;
 import com.clustercontrol.repository.bean.FacilityTargetConstant;
 import com.clustercontrol.repository.session.RepositoryControllerBean;
 
@@ -44,8 +44,8 @@ import com.clustercontrol.repository.session.RepositoryControllerBean;
  */
 public class ModifyEventConfirm {
 
-	/** ログ出力のインスタンス。 */
-	private static Log m_log = LogFactory.getLog( ModifyEventConfirm.class );
+	/** ログ出力のインスタンス */
+	private static Log m_log = LogFactory.getLog(ModifyEventConfirm.class);
 
 	/**
 	 * 引数で指定されたイベント情報一覧の確認を更新します。<BR>
@@ -131,7 +131,7 @@ public class ModifyEventConfirm {
 		// イベントログ情報を取得
 		EventLogEntity event = null;
 		try {
-			event = QueryUtil.getEventLogPK(monitorId, monitorDetailId, pluginId, new Timestamp(outputDate), facilityId, ObjectPrivilegeMode.WRITE);
+			event = QueryUtil.getEventLogPK(monitorId, monitorDetailId, pluginId, new Timestamp(outputDate), facilityId, ObjectPrivilegeMode.MODIFY);
 		} catch (EventLogNotFound e) {
 			throw new MonitorNotFound(e.getMessage(), e);
 		} catch (InvalidRole e) {
@@ -175,11 +175,13 @@ public class ModifyEventConfirm {
 	 */
 	public void modifyBatchConfirm(int confirmType, String facilityId, EventBatchConfirmInfo info, String confirmUser) throws HinemosUnknown {
 
-		Integer priority = null;
+		Integer[] priorityList = null;
 		Timestamp outputFromDate = null;
 		Timestamp outputToDate = null;
 		Timestamp generationFromDate = null;
 		Timestamp generationToDate = null;
+		String monitorId = null;
+		String monitorDetailId = null;
 		String facilityType = null;
 		String application = null;
 		String message = null;
@@ -187,11 +189,8 @@ public class ModifyEventConfirm {
 		String commentUser = null;
 
 		//重要度取得
-		if(info.getPriority() != null && !"".equals(info.getPriority())){
-			int priorityType = info.getPriority().intValue();
-			if(priorityType != -1){
-				priority = new Integer(priorityType);
-			}
+		if(info.getPriorityList() != null && info.getPriorityList().length>0){
+			priorityList = info.getPriorityList();
 		}
 
 		//更新日時（自）取得
@@ -218,6 +217,16 @@ public class ModifyEventConfirm {
 			generationToDate.setNanos(999999999);
 		}
 
+		//監視項目ID取得
+		if(!"".equals(info.getMonitorId())){
+			monitorId = info.getMonitorId();
+		}
+
+		//監視詳細取得
+		if(!"".equals(info.getMonitorDetailId())){
+			monitorDetailId = info.getMonitorDetailId();
+		}
+
 		//対象ファシリティ種別取得
 		if(!"".equals(info.getFacilityType())){
 			facilityType = info.getFacilityType();
@@ -269,11 +278,13 @@ public class ModifyEventConfirm {
 		// アップデートする設定フラグ
 		Integer confirmFlg = new Integer(confirmType);
 		int rtn = QueryUtil.updateEventLogFlgByFilter(facilityIds,
-				priority,
+				priorityList,
 				outputFromDate,
 				outputToDate,
 				generationFromDate,
 				generationToDate,
+				monitorId,
+				monitorDetailId,
 				application,
 				message,
 				comment,
@@ -281,7 +292,7 @@ public class ModifyEventConfirm {
 				confirmFlg,
 				confirmType,
 				confirmUser);
-
+		m_log.debug("The result of updateEventLogFlgByFilter is: " + rtn);
 	}
 
 }
