@@ -25,14 +25,12 @@ import org.eclipse.swt.widgets.Button;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Group;
-import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.bean.RunIntervalConstant;
 import com.clustercontrol.bean.ValidConstant;
-import com.clustercontrol.composite.RoleIdListComposite;
-import com.clustercontrol.composite.RoleIdListComposite.Mode;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.monitor.run.bean.MonitorTypeConstant;
@@ -44,14 +42,28 @@ import com.clustercontrol.ws.monitor.MonitorInfo;
 
 /**
  * 監視設定共通ダイアログクラス
- * 
+ *
  */
 public class CommonMonitorDialog extends CommonDialog {
 
 	public static final int WIDTH_TITLE = 4;
+	public static final int WIDTH_TITLE_LONG = 8;
 	public static final int WIDTH_VALUE = 2;
+	public static final int WIDTH_VALUE_LONG = 4;
+	public static final int WIDTH_TEXT_SHORT = 4;
 	public static final int WIDTH_TEXT = 8;
+	public static final int WIDTH_TEXT_LONG = 16;
+	public static final int BASIC_UNIT = 30;
+	public static final int LONG_UNIT = 20;
+	public static final int HALF_UNIT = 15;
+	public static final int SHORT_UNIT = 10;
+	public static final int SMALL_UNIT = 5;
+	public static final int MIN_UNIT = 1;
+	public static final int BASIC_MARGIN = 5;
+	public static final int HALF_MARGIN = 1;
 
+	// 初期値
+	public static final int RUNCOUNT_COUNT = 1;
 	public static final int TIMEOUT_SEC = 5000;
 
 	// ----- instance フィールド ----- //
@@ -89,6 +101,9 @@ public class CommonMonitorDialog extends CommonDialog {
 	/** 未登録ノード スコープを表示するかフラグ*/
 	protected boolean m_unregistered = false;
 
+	/** マネージャ名 */
+	protected String managerName = null;
+
 	// ----- 共通メンバ変数 ----- //
 	protected Shell shell = null;
 	protected Group groupRule = null;				// 条件グループ
@@ -100,64 +115,71 @@ public class CommonMonitorDialog extends CommonDialog {
 
 	/**
 	 * 作成用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のシェルオブジェクト
+	 * @param managerName
+	 *            マネージャ名
 	 */
-	public CommonMonitorDialog(Shell parent) {
+	public CommonMonitorDialog(Shell parent, String managerName) {
 		super(parent);
+		this.managerName = managerName;
 	}
 
 	// ----- instance メソッド ----- //
 
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent 親のインスタンス
 	 */
 	@Override
 	protected void customizeDialog(Composite parent) {
 		shell = this.getShell();
 
-		// 変数として利用されるラベル
-		Label label = null;
 		// 変数として利用されるグリッドデータ
 		GridData gridData = null;
 
 		// レイアウト
 		GridLayout layout = new GridLayout(1, true);
-		layout.marginWidth = 10;
-		layout.marginHeight = 10;
-		layout.numColumns = 15;
+		layout.marginWidth = BASIC_MARGIN;
+		layout.marginHeight = BASIC_MARGIN;
+		layout.numColumns = BASIC_UNIT;
 		parent.setLayout(layout);
 
 		// 監視基本情報
 		m_monitorBasic = new MonitorBasicScopeComposite(parent, SWT.NONE, m_unregistered, this);
+		WidgetTestUtil.setTestId(this, null, m_monitorBasic);
 		gridData = new GridData();
-		gridData.horizontalSpan = 15;
+		gridData.horizontalSpan = BASIC_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		m_monitorBasic.setLayoutData(gridData);
+		if(this.managerName != null) {
+			m_monitorBasic.getManagerListComposite().setText(this.managerName);
+		}
 
 		/*
 		 * 条件グループ
 		 */
 		groupRule = new Group(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "rule", groupRule);
 		layout = new GridLayout(1, true);
-		layout.marginWidth = 5;
-		layout.marginHeight = 5;
-		layout.numColumns = 15;
+		layout.marginWidth = HALF_MARGIN;
+		layout.marginHeight = HALF_MARGIN;
+		layout.numColumns = BASIC_UNIT;
 		groupRule.setLayout(layout);
 		gridData = new GridData();
-		gridData.horizontalSpan = 15;
+		gridData.horizontalSpan = BASIC_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		groupRule.setLayoutData(gridData);
 		groupRule.setText(Messages.getString("monitor.rule"));
 
 		m_monitorRule = new MonitorRuleComposite(groupRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "rule", m_monitorRule);
 		gridData = new GridData();
-		gridData.horizontalSpan = 15;
+		gridData.horizontalSpan = BASIC_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		m_monitorRule.setLayoutData(gridData);
@@ -166,13 +188,14 @@ public class CommonMonitorDialog extends CommonDialog {
 		 * 監視グループ
 		 */
 		groupMonitor = new Group(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, null, groupMonitor);
 		layout = new GridLayout(1, true);
-		layout.marginWidth = 5;
-		layout.marginHeight = 5;
-		layout.numColumns = 15;
+		layout.marginWidth = HALF_MARGIN;
+		layout.marginHeight = HALF_MARGIN;
+		layout.numColumns = BASIC_UNIT;
 		groupMonitor.setLayout(layout);
 		gridData = new GridData();
-		gridData.horizontalSpan = 15;
+		gridData.horizontalSpan = BASIC_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		groupMonitor.setLayoutData(gridData);
@@ -180,8 +203,9 @@ public class CommonMonitorDialog extends CommonDialog {
 
 		// 監視（有効／無効）
 		this.confirmMonitorValid = new Button(groupMonitor, SWT.CHECK);
+		WidgetTestUtil.setTestId(this, "confirmvalidcheck", confirmMonitorValid);
 		gridData = new GridData();
-		gridData.horizontalSpan = 15;
+		gridData.horizontalSpan = WIDTH_TEXT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.confirmMonitorValid.setLayoutData(gridData);
@@ -203,13 +227,14 @@ public class CommonMonitorDialog extends CommonDialog {
 		 * なお、判定内容は継承先のクラスにて実装する。
 		 */
 		groupDetermine = new Group(groupMonitor, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "determine", groupDetermine);
 		layout = new GridLayout(1, true);
-		layout.marginWidth = 5;
-		layout.marginHeight = 5;
-		layout.numColumns = 1;
+		layout.marginWidth = HALF_MARGIN;
+		layout.marginHeight = HALF_MARGIN;
+		layout.numColumns = MIN_UNIT;
 		groupDetermine.setLayout(layout);
 		gridData = new GridData();
-		gridData.horizontalSpan = 15;
+		gridData.horizontalSpan = BASIC_UNIT - WIDTH_TEXT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		groupDetermine.setLayoutData(gridData);
@@ -219,37 +244,31 @@ public class CommonMonitorDialog extends CommonDialog {
 		 * 通知グループ（監視グループの子グループ）
 		 */
 		groupNotifyAttribute = new Group(groupMonitor, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "notifyattribute", groupNotifyAttribute);
 		layout = new GridLayout(1, true);
-		layout.marginWidth = 5;
-		layout.marginHeight = 5;
-		layout.numColumns = 1;
+		layout.marginWidth = HALF_MARGIN;
+		layout.marginHeight = HALF_MARGIN;
+		layout.numColumns = MIN_UNIT;
 		groupNotifyAttribute.setLayout(layout);
 		gridData = new GridData();
-		gridData.horizontalSpan = 15;
+		gridData.horizontalSpan = BASIC_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		groupNotifyAttribute.setLayoutData(gridData);
 		groupNotifyAttribute.setText(Messages.getString("notify.attribute"));
 		this.m_notifyInfo = new NotifyInfoComposite(groupNotifyAttribute, SWT.NONE);
+		this.m_notifyInfo.setManagerName(getManagerName());
+		WidgetTestUtil.setTestId(this, "notifyinfo", m_notifyInfo);
 		gridData = new GridData();
-		gridData.horizontalSpan = 1;
+		gridData.horizontalSpan = MIN_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.m_notifyInfo.setLayoutData(gridData);
-
-		// ラインを引く
-		Label line = new Label(parent, SWT.SEPARATOR | SWT.HORIZONTAL);
-		gridData = new GridData();
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		gridData.horizontalSpan = 15;
-		line.setLayoutData(gridData);
-
 	}
 
 	/**
 	 * 監視エリアを有効/無効化します。
-	 * 
+	 *
 	 */
 	protected void setMonitorEnabled(boolean enabled){
 		m_notifyInfo.setEnabled(enabled);
@@ -258,13 +277,13 @@ public class CommonMonitorDialog extends CommonDialog {
 
 	/**
 	 * ダイアログエリアを調整します。
-	 * 
+	 *
 	 */
 	protected void adjustDialog(){
 		// サイズを最適化
 		// グリッドレイアウトを用いた場合、こうしないと横幅が画面いっぱいになります。
 		shell.pack();
-		shell.setSize(new Point(600, shell.getSize().y));
+		shell.setSize(new Point(700, shell.getSize().y));
 
 		// 画面中央に配置
 		Display display = shell.getDisplay();
@@ -275,13 +294,13 @@ public class CommonMonitorDialog extends CommonDialog {
 
 	/**
 	 * 入力内容を返します。
-	 * 
+	 *
 	 * @return 入力内容を保持した通知情報
 	 */
 	public MonitorInfo getInputData() {
 		return this.inputData;
 	}
-	
+
 	public boolean getUpdateFlg(){
 		return this.updateFlg;
 	}
@@ -289,18 +308,18 @@ public class CommonMonitorDialog extends CommonDialog {
 	public MonitorRuleComposite getMonitorRule(){
 		return this.m_monitorRule;
 	}
-	
+
 	public MonitorBasicScopeComposite getMonitorBasicScope(){
 		return this.m_monitorBasic;
 	}
-	
+
 	public NotifyInfoComposite getNotifyInfo(){
 		return this.m_notifyInfo;
 	}
-	
+
 	/**
 	 * 各項目に入力値を設定します。
-	 * 
+	 *
 	 * @param monitor 設定値として用いる監視情報
 	 */
 	protected void setInputData(MonitorInfo monitor) {
@@ -333,7 +352,7 @@ public class CommonMonitorDialog extends CommonDialog {
 
 	/**
 	 * 入力値を用いて通知情報を生成します。
-	 * 
+	 *
 	 * @return 入力値を保持した通知情報
 	 */
 	protected MonitorInfo createInputData() {
@@ -364,9 +383,9 @@ public class CommonMonitorDialog extends CommonDialog {
 
 	/**
 	 * 入力値チェックをします。
-	 * 
+	 *
 	 * @return 検証結果
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#validate()
 	 */
 	@Override
@@ -384,7 +403,7 @@ public class CommonMonitorDialog extends CommonDialog {
 
 	/**
 	 * ＯＫボタンのテキストを返します。
-	 * 
+	 *
 	 * @return ＯＫボタンのテキスト
 	 */
 	@Override
@@ -394,7 +413,7 @@ public class CommonMonitorDialog extends CommonDialog {
 
 	/**
 	 * キャンセルボタンのテキストを返します。
-	 * 
+	 *
 	 * @return キャンセルボタンのテキスト
 	 */
 	@Override
@@ -404,10 +423,9 @@ public class CommonMonitorDialog extends CommonDialog {
 
 	/**
 	 * 無効な入力値の情報を設定します
-	 * 
+	 *
 	 */
-	protected void setValidateResult(String id, String message) {
-
+	protected void setValidateResult(String id, String message){
 		this.validateResult = new ValidateResult();
 		this.validateResult.setValid(false);
 		this.validateResult.setID(id);
@@ -416,7 +434,7 @@ public class CommonMonitorDialog extends CommonDialog {
 
 	/**
 	 * MonitorInfoに初期値を設定します
-	 * 
+	 *
 	 */
 	protected void setInfoInitialValue(MonitorInfo monitor) {
 
@@ -437,4 +455,12 @@ public class CommonMonitorDialog extends CommonDialog {
 	 */
 	protected void update(){
 	}
-}
\ No newline at end of file
+
+	/**
+	 * 入力されたマネージャ名を返します。
+	 * @return
+	 */
+	public String getManagerName() {
+		return this.getMonitorBasicScope().getManagerListComposite().getText();
+	}
+}
