@@ -17,12 +17,12 @@ package com.clustercontrol.monitor.run.factory;
 
 import java.util.ArrayList;
 
-import javax.ejb.CreateException;
-import javax.naming.NamingException;
-
+import com.clustercontrol.fault.InvalidRole;
+import com.clustercontrol.fault.MonitorNotFound;
 import com.clustercontrol.monitor.run.bean.MonitorNumericValueInfo;
-import com.clustercontrol.monitor.run.ejb.entity.MonitorNumericValueInfoLocal;
-import com.clustercontrol.monitor.run.ejb.entity.MonitorNumericValueInfoUtil;
+import com.clustercontrol.monitor.run.model.MonitorInfoEntity;
+import com.clustercontrol.monitor.run.model.MonitorNumericValueInfoEntity;
+import com.clustercontrol.monitor.run.util.QueryUtil;
 
 /**
  * 数値監視の判定情報を作成する抽象クラス<BR>
@@ -41,25 +41,23 @@ abstract public class AddMonitorNumericValueType extends AddMonitor{
 	 * @see com.clustercontrol.monitor.run.ejb.entity.MonitorNumericValueInfoBean
 	 */
 	@Override
-	@SuppressWarnings("unchecked")
-	protected boolean addJudgementInfo() throws CreateException, NamingException {
+	protected boolean addJudgementInfo() throws MonitorNotFound, InvalidRole {
 
-		ArrayList valueList = m_monitorInfo.getNumericValueInfo();
-		ArrayList<MonitorNumericValueInfoLocal> valueLocalList = new ArrayList<MonitorNumericValueInfoLocal>();
+		MonitorInfoEntity monitorEntity = QueryUtil.getMonitorInfoPK(m_monitorInfo.getMonitorId());
 
+		ArrayList<MonitorNumericValueInfo> valueList = m_monitorInfo.getNumericValueInfo();
 		// 数値監視判定情報を設定
 		MonitorNumericValueInfo value = null;
 		for(int index=0; index<valueList.size(); index++){
-			value = (MonitorNumericValueInfo)valueList.get(index);
+			value = valueList.get(index);
 			if(value != null){
-				MonitorNumericValueInfoLocal local = MonitorNumericValueInfoUtil.getLocalHome().create(
-						m_monitorInfo.getMonitorId(),
-						Integer.valueOf(value.getPriority()),
-						Double.valueOf(value.getThresholdUpperLimit()),
-						Double.valueOf(value.getThresholdLowerLimit()),
-						value.getMessageId(),
-						value.getMessage());
-				valueLocalList.add(local);
+				MonitorNumericValueInfoEntity entity = new MonitorNumericValueInfoEntity(
+						monitorEntity,
+						Integer.valueOf(value.getPriority()));
+				entity.setMessage(value.getMessage());
+				entity.setMessageId(value.getMessageId());
+				entity.setThresholdLowerLimit(Double.valueOf(value.getThresholdLowerLimit()));
+				entity.setThresholdUpperLimit(Double.valueOf(value.getThresholdUpperLimit()));
 			}
 		}
 
