@@ -15,17 +15,15 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.monitor.run.factory;
 
-import java.io.File;
-import java.io.FileInputStream;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.HashMap;
 import java.util.Iterator;
 import java.util.Map;
-import java.util.Properties;
 import java.util.Set;
 import java.util.TreeMap;
 import java.util.concurrent.ExecutionException;
+import java.util.concurrent.ExecutorCompletionService;
 import java.util.concurrent.Future;
 
 import javax.persistence.EntityExistsException;
@@ -33,15 +31,15 @@ import javax.persistence.EntityExistsException;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import com.clustercontrol.bean.PriorityConstant;
+import com.clustercontrol.bean.ProcessConstant;
+import com.clustercontrol.bean.ValidConstant;
+import com.clustercontrol.calendar.session.CalendarControllerBean;
 import com.clustercontrol.fault.CalendarNotFound;
 import com.clustercontrol.fault.FacilityNotFound;
 import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.fault.InvalidRole;
 import com.clustercontrol.fault.MonitorNotFound;
-import com.clustercontrol.bean.PriorityConstant;
-import com.clustercontrol.bean.ProcessConstant;
-import com.clustercontrol.bean.ValidConstant;
-import com.clustercontrol.calendar.session.CalendarControllerBean;
 import com.clustercontrol.monitor.run.bean.MonitorJudgementInfo;
 import com.clustercontrol.monitor.run.bean.MonitorRunResultInfo;
 import com.clustercontrol.monitor.run.bean.MonitorTypeConstant;
@@ -81,9 +79,6 @@ abstract public class RunMonitor {
 	/** 不明のメッセージ。 */
 	private static final String MESSAGE_UNKNOWN = Messages.getString("message.unknown");
 
-	/** 監視結果の確認間隔 */
-	protected static int RETRY_INTERVAL = 1000;
-
 	/** 監視情報のローカルコンポーネント。 */
 	protected MonitorInfoEntity m_monitor;
 
@@ -103,7 +98,7 @@ abstract public class RunMonitor {
 	 * 値取得の失敗時の重要度。
 	 * 初期値は値取得失敗を示す値(-1)として、
 	 * setMonitorInfoがコールされた際に、値取得失敗時の重要度がセットされる。
-	 * 
+	 *
 	 * @see #setMonitorInfo(String, String)
 	 */
 	protected int m_failurePriority = PriorityConstant.TYPE_FAILURE;
@@ -155,55 +150,19 @@ abstract public class RunMonitor {
 	/** 監視取得値 */
 	protected double m_value;
 
-
-	// プロパティファイルの読み込み
-	static{
-		Properties properties = new Properties();
-		String etcdir = System.getProperty("hinemos.manager.etc.dir");
-		String propertyFile = etcdir + File.separator + "hinemos.properties";
-
-		try {
-			properties.load(new FileInputStream(propertyFile));
-
-			String retryInterval = properties.getProperty("monitor.common.retry.interval");
-
-			RETRY_INTERVAL = Integer.parseInt(retryInterval);
-
-			new ParallelExecution(properties);	// スレッド数の設定
-
-		} catch (Exception e) {
-			m_log.warn("static() : "
-					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
-		}
-	}
-
-
-	/**
-	 * コンストラクタ。<BR>
-	 * 初期処理を呼び出します。
-	 * 
-	 * @see #initialize()
-	 */
-	protected RunMonitor() {
-
-		// 初期化処理
-		//		this.initialize();
-	}
-
 	/**
 	 * トランザクションを開始し、引数で指定された監視情報の監視を実行します。
-	 * 
+	 *
 	 * @param monitorTypeId 監視対象ID
 	 * @param monitorId 監視項目ID
 	 * @throws FacilityNotFound
 	 * @throws MonitorNotFound
 	 * @throws InvalidRole
-	 * @throws EntityExistsException
 	 * @throws HinemosUnknown
-	 * 
+	 *
 	 * @see #runMonitorInfo()
 	 */
-	public void run(String monitorTypeId, String monitorId) throws FacilityNotFound, MonitorNotFound, InvalidRole, EntityExistsException, HinemosUnknown {
+	public void run(String monitorTypeId, String monitorId) throws FacilityNotFound, MonitorNotFound, InvalidRole, HinemosUnknown {
 
 		this.initialize(monitorTypeId);
 
@@ -239,14 +198,14 @@ abstract public class RunMonitor {
 	 * <li>監視結果から、重要度を取得します（{@link #getPriority(int)}）。</li>
 	 * <li>監視結果を通知します（{@link #notify(boolean, String, int, Date)}）。</li>
 	 * </ol>
-	 * 
+	 *
 	 * @return 実行に成功した場合、</code> true </code>
 	 * @throws FacilityNotFound
 	 * @throws MonitorNotFound
 	 * @throws InvalidRole
 	 * @throws EntityExistsException
 	 * @throws HinemosUnknown
-	 * 
+	 *
 	 * @see #setMonitorInfo(String, String)
 	 * @see #setJudgementInfo()
 	 * @see #setCheckInfo()
@@ -304,15 +263,16 @@ abstract public class RunMonitor {
 			m_log.debug("monitor start : monitorTypeId : " + m_monitorTypeId + ", monitorId : " + m_monitorId);
 
 			String facilityId = null;
-			// ファシリティIDをキーとしたハッシュマップを作成
-			HashMap<String,Future<MonitorRunResultInfo>> futuresMap = new HashMap<String,Future<MonitorRunResultInfo>>(facilityList.size());
 
 			/**
 			 * 監視の実行
 			 */
 			// ファシリティIDの数だけ、各監視処理を実行する
 			Iterator<String> itr = facilityList.iterator();
-
+			
+			ExecutorCompletionService<MonitorRunResultInfo> ecs = new ExecutorCompletionService<MonitorRunResultInfo>(ParallelExecution.instance().getExecutorService());
+			int taskCount = 0;
+			
 			while(itr.hasNext()){
 				facilityId = itr.next();
 				if(facilityId != null && !"".equals(facilityId)){
@@ -330,10 +290,13 @@ abstract public class RunMonitor {
 					runMonitor.setJudgementInfo();
 					runMonitor.nodeInfo = this.nodeInfo;
 					runMonitor.setCheckInfo();
-
-					Future<MonitorRunResultInfo> future = ParallelExecution.submit(new CallableTask(runMonitor, facilityId));
-
-					futuresMap.put(facilityId, future);
+					
+					ecs.submit(new CallableTask(runMonitor, facilityId));
+					taskCount++;
+					
+					if (m_log.isDebugEnabled()) {
+						m_log.debug("starting monitor result : monitorId = " + m_monitorId + ", facilityId = " + facilityId);
+					}
 				}
 				else {
 					facilityList.remove(facilityId);
@@ -342,80 +305,41 @@ abstract public class RunMonitor {
 			/**
 			 * 監視結果の集計
 			 */
-			ArrayList<String> facilityListCopy = null;	// ファシリティリストのコピーを格納（監視を完了したものから削除するためコピーを作成）
-			ArrayList<String> facilityListComplete = null;	// 監視を完了したファシリティIDを格納
-			boolean isGet = false;	// 監視が完了したかを判定
 			MonitorRunResultInfo result = new MonitorRunResultInfo();	// 監視結果を格納
 
 			m_log.debug("total start : monitorTypeId : " + m_monitorTypeId + ", monitorId : " + m_monitorId);
 
-			// ログ出力情報を送信
-			facilityListCopy = new ArrayList<String>(facilityList);
-			facilityListComplete = new ArrayList<String>();
-
 			// 収集値の入れ物を作成
 			Sample sample = null;
 			if(m_monitor.getCollectorFlg() == ValidConstant.TYPE_VALID){
 				sample = new Sample(m_monitorId, new Date());
 			}
-
-			while(true) {
-
-				facilityListComplete.clear();	// 収集したファシリティID情報を削除する
-				itr = facilityListCopy.iterator();	// 収集が完了していない情報のみを確認するためIteratorを取得しなおす
-
-				while(itr.hasNext()) {
-					facilityId = itr.next();
-					isGet = futuresMap.get(facilityId).isDone();	//監視完了の有無を取得
-
-					// 監視が終了していた場合
-					if(isGet){
-						m_log.debug("output result : monitorTypeId : " + m_monitorTypeId + ", m_monitorId : " + m_monitorId + ", m_facilityId : " + facilityId);
-
-						result = futuresMap.get(facilityId).get();	// 監視結果を取得
-						m_nodeDate = result.getNodeDate();
-
-
-						// 処理する場合
-						if(result.getProcessType() == ProcessConstant.TYPE_YES){
-
-							// 監視結果を通知
-							notify(true, facilityId, result.getCheckResult(), new Date(m_nodeDate), result);
-
-							// 個々の収集値の登録
-							if(sample != null){
-								if(result.isCollectorResult()){
-									sample.set(facilityId, m_monitorId, DISPLAY_NAME_STRING, result.getValue(), CollectedDataErrorTypeConstant.NOT_ERROR);
-								}else{
-									sample.set(facilityId, m_monitorId, DISPLAY_NAME_STRING, result.getValue(), CollectedDataErrorTypeConstant.UNKNOWN);
-								}
-							}
-						}
-
-						// 監視が完了したファシリティIDをfacilityListCompleteに追加する
-						facilityListComplete.add(facilityId);
-					}
+			
+			for (int i = 0; i < taskCount; i++) {
+				Future<MonitorRunResultInfo> future = ecs.take();
+				result = future.get();	// 監視結果を取得
+				
+				facilityId = result.getFacilityId();
+				m_nodeDate = result.getNodeDate();
+				
+				if (m_log.isDebugEnabled()) {
+					m_log.debug("finished monitor : monitorId = " + m_monitorId + ", facilityId = " + facilityId);
 				}
+				
+				// 処理する場合
+				if(result.getProcessType() == ProcessConstant.TYPE_YES){
 
-				// 監視が完了したファシリティIDをfacilityListCopyから削除する
-				itr = facilityListComplete.iterator();
-				while(itr.hasNext()){
-					facilityListCopy.remove(itr.next());
-				}
+					// 監視結果を通知
+					notify(true, facilityId, result.getCheckResult(), new Date(m_nodeDate), result);
 
-				// すべてのファシリティIDの監視が完了したかの確認
-				if(facilityListCopy.size() == 0) {
-					m_log.debug("end collect (node) : monitorTypeId : " + m_monitorTypeId + ", m_monitorId : " + m_monitorId);
-					break;
-				}
-				else {
-					m_log.debug("collect (node) : monitorTypeId : " + m_monitorTypeId + ", m_monitorId : " + m_monitorId);
-					if(m_log.isDebugEnabled()){
-						for(String facility : facilityListCopy){
-							m_log.debug("collect (node) : remain node = " + facility);
+					// 個々の収集値の登録
+					if(sample != null){
+						if(result.isCollectorResult()){
+							sample.set(facilityId, m_monitorId, DISPLAY_NAME_STRING, result.getValue(), CollectedDataErrorTypeConstant.NOT_ERROR);
+						}else{
+							sample.set(facilityId, m_monitorId, DISPLAY_NAME_STRING, result.getValue(), CollectedDataErrorTypeConstant.UNKNOWN);
 						}
 					}
-					Thread.sleep(RETRY_INTERVAL);	// まだ結果が出揃っていない場合は「RETRY_INTERVAL」秒sleepする
 				}
 			}
 
@@ -454,7 +378,7 @@ abstract public class RunMonitor {
 	 * <p>
 	 * 各監視管理のサブクラスで実装します。
 	 * 監視情報よりチェック条件情報を取得し、保持します。
-	 * 
+	 *
 	 * @throws MonitorNotFound
 	 */
 	protected abstract void setCheckInfo() throws MonitorNotFound ;
@@ -465,7 +389,7 @@ abstract public class RunMonitor {
 	 * 各監視管理のサブクラスで実装します。
 	 * 引数で指定されたファシリティIDの監視を実行して値を収集し、
 	 * 各監視種別（真偽値，数値，文字列）のサブクラスの監視取得値にセットします。
-	 * 
+	 *
 	 * @param facilityId 監視対象のファシリティID
 	 * @return 値取得に成功した場合、</code> true </code>
 	 * @throws FacilityNotFound
@@ -478,19 +402,19 @@ abstract public class RunMonitor {
 	 * 監視を実装するクラスでは、RunMonitorクラス（すべての監視実装クラスの親クラス）のインスタンスを返すために、
 	 * このメソッドを実装してください。
 	 * このメソッドで生成されたインスタンスは、監視実行スレッドごとの監視結果を保持するために利用されます。
-	 * 
+	 *
 	 * すべての監視はマルチスレッドで動作しており、監視設定単位でRunMonitorクラスのインスタンスを共有しています。
 	 * 監視結果（収集値）は、数値監視、文字列監視、真偽値監視のレベルで共有される変数に格納されるため、
 	 * 同一監視設定で複数ノードに対して監視を実行する場合、監視結果に不整合が生じる可能性があります。
-	 * 
+	 *
 	 * したがって、本メソッドによって新たにインスタンスを生成し、マルチスレッドを実現するCallableTaskに渡す必要があります。
-	 * 
+	 *
 	 * @see com.clustercontrol.monitor.run.factory.RunMonitor#runMonitorInfo()
 	 * @see com.clustercontrol.monitor.run.factory.RunMonitorNumericValueType
 	 * @see com.clustercontrol.monitor.run.factory.RunMonitorStringValueType
 	 * @see com.clustercontrol.monitor.run.factory.RunMonitorTruthValueType
 	 * @see com.clustercontrol.monitor.run.util.CallableTask
-	 * 
+	 *
 	 * @return
 	 * @throws HinemosUnknown
 	 */
@@ -509,7 +433,7 @@ abstract public class RunMonitor {
 	 *  <dd>数値監視：重要度定数（{@link com.clustercontrol.bean.PriorityConstant}）</dd>
 	 *  <dd>文字列監視：順序（{@link com.clustercontrol.monitor.run.ejb.entity.MonitorStringValueInfoBean#getOrderNo()}）</dd>
 	 * </dl>
-	 * 
+	 *
 	 * @param ret 監視の実行が成功した場合、</code> true </code>
 	 * @return 判定結果
 	 */
@@ -519,7 +443,7 @@ abstract public class RunMonitor {
 	 * 重要度を返します。
 	 * <p>
 	 * 引数で指定された判定結果のキーに対応する重要度を、判定情報マップから取得します。
-	 * 
+	 *
 	 * @param key 各監視種別（真偽値，数値，文字列）の判定結果のキー
 	 * @return 重要度
 	 * @since 2.0.0
@@ -537,7 +461,7 @@ abstract public class RunMonitor {
 
 	/**
 	 * 通知グループIDを返します。
-	 * 
+	 *
 	 * @return 通知グループID
 	 * @since 2.1.0
 	 */
@@ -549,7 +473,7 @@ abstract public class RunMonitor {
 	 * ノード用メッセージIDを返します。
 	 * <p>
 	 * 引数で指定された判定結果のキーに対応するメッセージIDを、判定情報マップから取得します。
-	 * 
+	 *
 	 * @param key 各監視種別（真偽値，数値，文字列）の判定結果のキー
 	 * @return メッセージID
 	 * @since 2.0.0
@@ -569,7 +493,7 @@ abstract public class RunMonitor {
 	 * ノード用メッセージを返します。
 	 * <p>
 	 * 引数で指定された判定結果のキーに対応するメッセージを、判定情報マップから取得します。
-	 * 
+	 *
 	 * @param key 各監視種別（真偽値，数値，文字列）の判定結果のキー
 	 * @return メッセージ
 	 * @since 2.0.0
@@ -589,7 +513,7 @@ abstract public class RunMonitor {
 	 * ノード用オリジナルメッセージを返します。
 	 * <p>
 	 * 各監視管理のサブクラスで実装します。
-	 * 
+	 *
 	 * @param key 各監視種別（真偽値，数値，文字列）の判定結果のキー
 	 * @return オリジナルメッセージ
 	 * @since 2.0.0
@@ -600,7 +524,7 @@ abstract public class RunMonitor {
 	 * スコープ用メッセージIDを返します。
 	 * <p>
 	 * 引数で指定された重要度に対応するメッセージIDを、判定情報マップから取得します。
-	 * 
+	 *
 	 * @param priority 重要度
 	 * @return メッセージ
 	 * @since 2.1.0
@@ -624,7 +548,7 @@ abstract public class RunMonitor {
 	 * スコープ用メッセージを返します。
 	 * <p>
 	 * 引数で指定された重要度に対応するメッセージを返します。
-	 * 
+	 *
 	 * @param priority 重要度
 	 * @return メッセージ
 	 */
@@ -648,7 +572,7 @@ abstract public class RunMonitor {
 	 * スコープ用オリジナルメッセージを返します。
 	 * <p>
 	 * 重要度別の件数，ファシリティ名を表示する文字列を作成し、返します。
-	 * 
+	 *
 	 * <dl>
 	 *  <dt>通知:X件, 警告:X件, 危険:X件, 不明:X件</dt>
 	 *  <dt>通知:</dt>
@@ -661,7 +585,7 @@ abstract public class RunMonitor {
 	 *  <dt>不明:</dt>
 	 *   <dd>NODE5</dd>
 	 * </dl>
-	 * 
+	 *
 	 * @param priority 重要度
 	 * @return オリジナルメッセージ
 	 */
@@ -691,7 +615,7 @@ abstract public class RunMonitor {
 
 	/**
 	 * ノードの監視結果取得時刻を返します。
-	 * 
+	 *
 	 * @return ノードの監視結果取得時刻
 	 * @since 3.0.0
 	 */
@@ -702,7 +626,7 @@ abstract public class RunMonitor {
 
 	/**
 	 * 監視値を返します。
-	 * 
+	 *
 	 * @return 監視値
 	 * @since 4.0.0
 	 */
@@ -716,15 +640,15 @@ abstract public class RunMonitor {
 	 * 引数で指定された監視対象と監視項目の監視情報を取得し、保持します。<BR>
 	 * 通知IDが指定されていない場合は、処理を終了します。<BR>
 	 * カレンダIDが指定されていた場合は、稼動日か否かチェックします（{@link com.clustercontrol.calendar.session.CalendarControllerBean#isRun(java.lang.String, java.util.Date)}）。非稼動日の場合は、処理を終了します。
-	 * 
+	 *
 	 * @param monitorTypeId 監視対象ID
 	 * @param monitorId 監視項目ID
 	 * @return 監視を実行する場合、</code> true </code>
 	 * @throws MonitorNotFound
 	 * @throws HinemosUnknown
-	 * 
+	 *
 	 * @since 2.0.0
-	 * 
+	 *
 	 * @see com.clustercontrol.calendar.session.CalendarControllerBean#isRun(java.lang.String, java.util.Date)
 	 */
 	protected boolean setMonitorInfo(String monitorTypeId, String monitorId) throws MonitorNotFound, HinemosUnknown {
@@ -795,17 +719,17 @@ abstract public class RunMonitor {
 	 * </li>
 	 * <li>ログ出力情報を、ログ出力キューへ送信します。</li>
 	 * </ol>
-	 * 
+	 *
 	 * @param isNode ノードの場合、</code> true </code>
 	 * @param facilityId 通知対象のファシリティID
 	 * @param result 判定結果
 	 * @param generationDate ログ出力日時（監視を実行した日時）
 	 * @throws HinemosUnknown
 	 * @since 2.0.0
-	 * 
+	 *
 	 * @see com.clustercontrol.monitor.message.LogOutputNotifyInfo
 	 * @see com.clustercontrol.repository.session.RepositoryControllerBean#getFacilityPath(java.lang.String, java.lang.String)
-	 * @see #getNotifyId()
+	 * @see #getNotifyRelationInfos()
 	 * @see #getPriority(int)
 	 * @see #getMessageId(int)
 	 * @see #getMessage(int)
@@ -910,7 +834,7 @@ abstract public class RunMonitor {
 	 * </li>
 	 * <li>ログ出力情報を、ログ出力キューへ送信します。</li>
 	 * </ol>
-	 * 
+	 *
 	 * @param isNode ノードの場合、</code> true </code>
 	 * @param facilityId 通知対象のファシリティID
 	 * @param result 判定結果
@@ -918,10 +842,10 @@ abstract public class RunMonitor {
 	 * @param resultList 並列実行時の情報
 	 * @throws HinemosUnknown
 	 * @since 2.0.0
-	 * 
+	 *
 	 * @see com.clustercontrol.monitor.message.LogOutputNotifyInfo
 	 * @see com.clustercontrol.repository.session.RepositoryControllerBean#getFacilityPath(java.lang.String, java.lang.String)
-	 * @see #getNotifyId()
+	 * @see #getNotifyRelationInfos()
 	 * @see #getPriority(int)
 	 * @see #getMessageId(int)
 	 * @see #getMessage(int)
@@ -1035,7 +959,7 @@ abstract public class RunMonitor {
 	 * <ol>
 	 * <li>引数で指定されたファシリティIDのファシリティ名を取得します。</li>
 	 * <li>重要度別のファシリティマップの引数で指定された重要度に、ファシリティ名を追加します。</li>
-	 * 
+	 *
 	 * @param priority 重要度
 	 * @param facilityId ファシリティ名
 	 * @throws HinemosUnknown
@@ -1055,7 +979,7 @@ abstract public class RunMonitor {
 
 	/**
 	 * 項目一覧の文字列を返します。
-	 * 
+	 *
 	 * <dl>
 	 *  <dt>項目名:</dt>
 	 * 	 <dd>リスト[0]</dd>
@@ -1063,7 +987,7 @@ abstract public class RunMonitor {
 	 *   <dd>リスト[2]</dd>
 	 *   <dd>　 ：　</dd>
 	 * </dl>
-	 * 
+	 *
 	 * @param item 項目名
 	 * @param list リスト
 	 * @return 項目一覧の文字列
@@ -1089,17 +1013,17 @@ abstract public class RunMonitor {
 
 	/**
 	 * 監視実行の初期処理を行います。
-	 * 
+	 *
 	 * 監視を実行するrunメソッドの最初の部分でcallしてください。
 	 * runメソッド終了部分で、terminatteメソッドをcallし、キューのコネクションをクローズする必要があります。
-	 * 
+	 *
 	 */
 	private void initialize(String monitorTypeId) {
 	}
 
 	/**
 	 * 監視実行の終了処理を行います。
-	 * 
+	 *
 	 */
 	private void terminate() {
 	}
