@@ -87,16 +87,18 @@ abstract public class RunMonitorStringValueType extends RunMonitor{
 		Pattern pattern = null;
 		Matcher matcher = null;
 
+		int orderNo = 0;
 		// 文字列監視判定情報で順番にフィルタリング
 		Set<Integer> set = m_judgementInfoList.keySet();
 		for (Iterator<Integer> iter = set.iterator(); iter.hasNext();) {
 			Integer key = iter.next();
 			info = (MonitorStringValueInfo) m_judgementInfoList.get(key);
 
+			++orderNo;
 			if(m_log.isDebugEnabled()){
 				m_log.debug("getCheckResult() value = " + m_value
 						+ ", monitorId = " + info.getMonitorId()
-						+ ", orderNo = " + info.getOrderNo()
+						+ ", orderNo = " + orderNo
 						+ ", pattern = " + info.getPattern());
 			}
 
@@ -113,11 +115,18 @@ abstract public class RunMonitorStringValueType extends RunMonitor{
 					else{
 						pattern = Pattern.compile(patternText, Pattern.DOTALL);
 					}
+					if (m_value == null) {
+						m_log.warn("getCheckResult(): PatternSyntax is not valid." +
+								" description="+info.getDescription() +
+								", patternSyntax="+info.getPattern() + ", value=" + m_value);
+						result = -1;
+						return result;
+					}
 					matcher = pattern.matcher(m_value);
 
 					// パターンマッチ表現でマッチング
 					if (matcher.matches()) {
-						result = info.getOrderNo();
+						result = orderNo;
 
 						m_log.debug("getCheckResult() true : description=" + info.getDescription() + ", value=" + m_value);
 						m_log.debug("getCheckResult() true : messageId=" + info.getMessageId() + ", message=" + info.getMessage());
@@ -170,7 +179,6 @@ abstract public class RunMonitorStringValueType extends RunMonitor{
 			Integer order = entity.getId().getOrderNo().intValue();
 
 			MonitorStringValueInfo info = new MonitorStringValueInfo();
-			info.setOrderNo(order.intValue());
 			info.setDescription(entity.getDescription());
 			info.setPattern(entity.getPattern());
 			info.setProcessType(entity.getProcessType().intValue());
