@@ -49,6 +49,7 @@ public class CallableTask implements Callable<MonitorRunResultInfo>{
 
 		// 結果を格納
 		MonitorRunResultInfo info = new MonitorRunResultInfo();
+		info.setFacilityId(m_facilityId);
 
 		try {
 			jtm = new JpaTransactionManager();
@@ -100,7 +101,8 @@ public class CallableTask implements Callable<MonitorRunResultInfo>{
 			jtm.commit();
 		} catch (Exception e) {
 			m_log.warn("call() : "
-					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
+					+ "facilityId=" + m_facilityId + ", notifyGroupId=" + m_runMonitor.getNotifyGroupId()
+					+ ", Exception=" + e.getClass().getSimpleName() + ", message=" + e.getMessage(), e);
 			jtm.rollback();
 			throw e;
 		} finally {
