@@ -15,13 +15,19 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.monitor.view.action;
 
-import org.eclipse.jface.action.IAction;
+import org.eclipse.core.commands.AbstractHandler;
+import org.eclipse.core.commands.Command;
+import org.eclipse.core.commands.ExecutionEvent;
+import org.eclipse.core.commands.ExecutionException;
+import org.eclipse.core.commands.State;
 import org.eclipse.jface.dialogs.IDialogConstants;
-import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.jface.viewers.StructuredSelection;
 import org.eclipse.jface.viewers.TreeViewer;
-import org.eclipse.ui.IViewActionDelegate;
-import org.eclipse.ui.IViewPart;
+import org.eclipse.ui.IWorkbenchPart;
+import org.eclipse.ui.IWorkbenchWindow;
+import org.eclipse.ui.commands.ICommandService;
+import org.eclipse.ui.handlers.HandlerUtil;
+import org.eclipse.ui.handlers.RegistryToggleState;
 
 import com.clustercontrol.bean.Property;
 import com.clustercontrol.monitor.dialog.StatusFilterDialog;
@@ -29,24 +35,26 @@ import com.clustercontrol.monitor.view.StatusView;
 
 /**
  * 監視[ステータスのフィルタ処理]ダイアログによるステータスの取得処理を行うクライアント側アクションクラス<BR>
- * 
- * @version 1.0.0
+ *
+ * @version 5.0.0
  * @since 1.0.0
  */
-public class StatusFilterAction implements IViewActionDelegate {
+public class StatusFilterAction extends AbstractHandler {
 
+	/** アクションID */
+	public static final String ID = StatusFilterAction.class.getName();
+
+	private IWorkbenchWindow window;
 	/** ビュー */
-	private IViewPart viewPart;
-
+	private IWorkbenchPart viewPart;
 
 	/**
-	 * ビューを保持します。ワークベンチにロードされた際に呼ばれます。
-	 * 
-	 * @see org.eclipse.ui.IViewActionDelegate#init(org.eclipse.ui.IViewPart)
+	 * Dispose
 	 */
 	@Override
-	public void init(IViewPart viewPart) {
-		this.viewPart = viewPart;
+	public void dispose() {
+		this.viewPart = null;
+		this.window = null;
 	}
 
 	/**
@@ -59,18 +67,31 @@ public class StatusFilterAction implements IViewActionDelegate {
 	 * <li>監視[ステータス]ビューの検索条件に設定します。</li>
 	 * <li>監視[ステータス]ビューを更新します。</li>
 	 * </ol>
-	 * 
-	 * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
+	 *
+	 * @see org.eclipse.core.commands.IHandler#execute
 	 * @see com.clustercontrol.monitor.dialog.StatusFilterDialog
 	 * @see com.clustercontrol.monitor.view.StatusView#setCondition(Property)
 	 * @see com.clustercontrol.monitor.view.StatusView#update()
 	 */
 	@Override
-	public void run(IAction action) {
+	public Object execute(ExecutionEvent event) throws ExecutionException {
+		this.window = HandlerUtil.getActiveWorkbenchWindow(event);
+		// In case this action has been disposed
+		if( null == this.window || !isEnabled() ){
+			return null;
+		}
+
+		// 選択アイテムの取得
+		this.viewPart = HandlerUtil.getActivePart(event);
+
 		StatusView view = (StatusView) this.viewPart
 				.getAdapter(StatusView.class);
 
-		if (action.isChecked()) {
+		ICommandService commandService = (ICommandService)window.getService(ICommandService.class);
+		Command command = commandService.getCommand(ID);
+		boolean isChecked = !HandlerUtil.toggleCommandState(command);
+
+		if (isChecked) {
 			// ダイアログを生成
 			StatusFilterDialog dialog = new StatusFilterDialog(this.viewPart
 					.getSite().getShell());
@@ -82,7 +103,8 @@ public class StatusFilterAction implements IViewActionDelegate {
 				view.setCondition(condition);
 				view.update();
 			} else {
-				action.setChecked(false);
+				State state = command.getState(RegistryToggleState.STATE_ID);
+				state.setValue(false);
 			}
 		} else {
 			// 検索条件クリア
@@ -100,15 +122,6 @@ public class StatusFilterAction implements IViewActionDelegate {
 				view.update();
 			}
 		}
+		return null;
 	}
-
-	/**
-	 * 選択を変更した際に呼ばれます。
-	 * 
-	 * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction,
-	 *      org.eclipse.jface.viewers.ISelection)
-	 */
-	@Override
-	public void selectionChanged(IAction action, ISelection selection) {
-	}
-}
\ No newline at end of file
+}
