@@ -24,7 +24,7 @@ import com.clustercontrol.ws.notify.NotifyInfo;
 
 /**
  * 通知情報を変更するクライアント側アクションクラス<BR>
- * 
+ *
  * @version 2.2.0
  * @since 1.0.0
  */
@@ -33,16 +33,18 @@ public class ModifyNotify {
 	/**
 	 * 通知情報を変更します。<BR>
 	 * マネージャにSessionBean経由でアクセスします。
-	 * 
+	 *
+	 * @param managerName マネージャ名
 	 * @param info 変更対象の通知情報
 	 * @return 変更に成功した場合、<code> true </code>
 	 */
-	public boolean modify(NotifyInfo info){
+	public boolean modify(String managerName, NotifyInfo info){
 
 		boolean result = false;
-		String[] args = { info.getNotifyId() };
+		String[] args = { info.getNotifyId(), managerName };
 		try {
-			result = NotifyEndpointWrapper.modifyNotify(info);
+			NotifyEndpointWrapper wrapper = NotifyEndpointWrapper.getWrapper(managerName);
+			result = wrapper.modifyNotify(info);
 
 			MessageDialog.openInformation(
 					null,
@@ -67,4 +69,4 @@ public class ModifyNotify {
 
 		return result;
 	}
-}
\ No newline at end of file
+}
