@@ -16,7 +16,6 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.notify.dialog;
 
 import java.util.ArrayList;
-import java.util.List;
 
 import org.eclipse.jface.dialogs.IDialogConstants;
 import org.eclipse.swt.SWT;
@@ -24,7 +23,6 @@ import org.eclipse.swt.events.ModifyEvent;
 import org.eclipse.swt.events.ModifyListener;
 import org.eclipse.swt.events.SelectionAdapter;
 import org.eclipse.swt.events.SelectionEvent;
-import org.eclipse.swt.events.SelectionListener;
 import org.eclipse.swt.graphics.Color;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
@@ -37,6 +35,7 @@ import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
 import com.clustercontrol.ClusterControlPlugin;
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.bean.PriorityColorConstant;
 import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
@@ -57,7 +56,7 @@ import com.clustercontrol.ws.repository.FacilityTreeItem;
 
 /**
  * 通知（ジョブ実行）作成・変更ダイアログクラス<BR>
- * 
+ *
  * @version 4.0.0
  * @since 3.0.0
  */
@@ -89,9 +88,6 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 	 */
 	private final int TYPE_JOB = 3;
 
-	/** 入力値を保持するオブジェクト。 */
-	private NotifyInfo inputData = null;
-
 	/** 入力値の正当性を保持するオブジェクト。 */
 	protected ValidateResult validateResult = null;
 
@@ -162,35 +158,32 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 作成用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
 	 */
 	public NotifyJobCreateDialog(Shell parent) {
 		super(parent);
 	}
 
-	public NotifyJobCreateDialog(Shell parent, int notifyIdType) {
-		super(parent, notifyIdType);
-	}
-
 	/**
 	 * 変更用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
+	 * @param managerName マネージャ名
 	 * @param notifyId 変更する通知情報の通知ID
 	 * @param updateFlg 更新フラグ（true:更新する）
 	 */
-	public NotifyJobCreateDialog(Shell parent, String notifyId, boolean updateFlg) {
-		super(parent, notifyId, updateFlg);
+	public NotifyJobCreateDialog(Shell parent, String managerName, String notifyId, boolean updateFlg) {
+		super(parent, managerName, notifyId, updateFlg);
 	}
 
 	// ----- instance メソッド ----- //
 
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
-	 * 
+	 *
 	 * @see com.clustercontrol.notify.dialog.NotifyBasicCreateDialog#customizeDialog(Composite)
 	 * @see com.clustercontrol.notify.action.GetNotify#getNotify(String)
 	 * @see #setInputData(NotifyInfo)
@@ -203,7 +196,7 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 		// 通知IDが指定されている場合、その情報を初期表示する。
 		NotifyInfo info = null;
 		if(this.notifyId != null){
-			info = new GetNotify().getNotify(this.notifyId);
+			info = new GetNotify().getNotify(this.managerName, this.notifyId);
 		}
 		else{
 			info = new NotifyInfo();
@@ -213,9 +206,9 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 親のクラスから呼ばれ、各通知用のダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
-	 * 
+	 *
 	 * @see com.clustercontrol.notify.dialog.NotifyBasicCreateDialog#customizeDialog(Composite)
 	 */
 	@Override
@@ -242,6 +235,7 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 		 */
 		// ジョブグループ
 		Group groupJob = new Group(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "job", groupJob);
 		layout = new GridLayout(1, true);
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
@@ -258,6 +252,7 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 		 * スコープグループ
 		 */
 		Group groupScope = new Group(groupJob, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "scope", groupScope);
 		groupScope.setText(Messages.getString("notify.job.scope"));
 		layout = new GridLayout(1, true);
 		layout.marginWidth = 5;
@@ -272,54 +267,49 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 
 		// ジョブ変数 ラジオボタン
 		this.m_radioGenerationNodeValue = new Button(groupScope, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "generationnodevalue", m_radioGenerationNodeValue);
 		gridData = new GridData();
 		gridData.horizontalSpan = 15;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.m_radioGenerationNodeValue.setLayoutData(gridData);
 		this.m_radioGenerationNodeValue.setText(Messages.getString("notify.node.generation") + " : ");
-		this.m_radioGenerationNodeValue.addSelectionListener(new SelectionListener() {
+		this.m_radioGenerationNodeValue.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
+				WidgetTestUtil.setTestId(this, null, check);
 				if (check.getSelection()) {
 					m_radioFixedValue.setSelection(false);
 					m_scopeSelect.setEnabled(false);
 				}
 			}
-
-			@Override
-			public void widgetDefaultSelected(SelectionEvent e) {
-
-			}
 		});
 
 		// 固定値 ラジオボタン
 		this.m_radioFixedValue = new Button(groupScope, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "fixedvalue", m_radioFixedValue);
 		gridData = new GridData();
 		gridData.horizontalSpan = 3;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.m_radioFixedValue.setLayoutData(gridData);
 		this.m_radioFixedValue.setText(Messages.getString("notify.node.fix") + " : ");
-		this.m_radioFixedValue.addSelectionListener(new SelectionListener() {
+		this.m_radioFixedValue.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
+				WidgetTestUtil.setTestId(this, null, check);
 				if (check.getSelection()) {
 					m_radioGenerationNodeValue.setSelection(false);
 					m_scopeSelect.setEnabled(true);
 				}
 				update();
 			}
-
-			@Override
-			public void widgetDefaultSelected(SelectionEvent e) {
-
-			}
 		});
 
 		this.m_textScope = new Text(groupScope, SWT.BORDER | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, "scope", m_textScope);
 		gridData = new GridData();
 		gridData.horizontalSpan = 5;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -328,6 +318,7 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 		this.m_textScope.setText("");
 
 		this.m_scopeSelect = new Button(groupScope, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "scopeselect", m_scopeSelect);
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -337,7 +328,9 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 		this.m_scopeSelect.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
-				ScopeTreeDialog dialog = new ScopeTreeDialog(shell, m_notifyBasic.getRoleIdList().getText());
+				ScopeTreeDialog dialog = new ScopeTreeDialog(shell,
+						m_notifyBasic.getManagerListComposite().getText(),
+						m_notifyBasic.getRoleIdList().getText());
 				if (dialog.open() == IDialogConstants.OK_ID) {
 					FacilityTreeItem selectItem = dialog.getSelectItem();
 					FacilityInfo info = selectItem.getData();
@@ -353,16 +346,16 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 		});
 
 		label = new Label(groupScope, SWT.NONE);
+		WidgetTestUtil.setTestId(this, null, label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 5;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 
-
-
 		// 空行
 		label = new Label(groupJob, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space1", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 15;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -374,6 +367,7 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 		 */
 		// ラベル（重要度）
 		label = new Label(groupJob, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "priority", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_PRIORITY;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -383,6 +377,7 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 
 		// ラベル（実行する）
 		label = new Label(groupJob, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "run", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_JOB_RUN;
 		gridData.horizontalAlignment = GridData.CENTER;
@@ -392,6 +387,7 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 
 		// ラベル（ジョブユニットID）
 		label = new Label(groupJob, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "jobunitid", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_JOBUNIT_ID;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -401,6 +397,7 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 
 		// ラベル（ジョブID）
 		label = new Label(groupJob, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "jobid", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_JOB_ID;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -410,6 +407,7 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 
 		// ラベル（参照）
 		label = new Label(groupJob, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "refer", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_REF_BTN;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -418,6 +416,7 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 
 		// ラベル（呼出失敗時）
 		label = new Label(groupJob, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "failurecallvalue", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_FAILURE_PRIORITY;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -428,44 +427,63 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 		// ジョブ 重要度：情報
 		label = this.getLabelPriority(groupJob, Messages.getString("info"),PriorityColorConstant.COLOR_INFO);
 		this.m_checkJobRunInfo = this.getCheckJobRun(groupJob);
+		WidgetTestUtil.setTestId(this, "jobruninfo", m_checkJobRunInfo);
 		this.m_textJobunitIdInfo = this.getTextJobunitId(groupJob);
+		WidgetTestUtil.setTestId(this, "jobunitidinfo", m_textJobunitIdInfo);
 		this.m_textJobIdInfo = this.getTextJobId(groupJob);
+		WidgetTestUtil.setTestId(this, "jobidinfo", m_textJobIdInfo);
 		this.m_buttonReferInfo = this.getButtonJobRefer(groupJob);
+		WidgetTestUtil.setTestId(this, "referinfo", m_buttonReferInfo);
 		this.m_comboFailurePriorityInfo = this.getComboPriority(groupJob);
-		this.m_buttonReferInfo.addSelectionListener(new JobIdSelectionListener(m_textJobunitIdInfo, m_textJobIdInfo, m_notifyBasic.getRoleIdList()));
+		WidgetTestUtil.setTestId(this, "failurepriority", m_comboFailurePriorityInfo);
+		this.m_buttonReferInfo.addSelectionListener(new JobIdSelectionListener(shell, m_notifyBasic.getManagerListComposite(), m_textJobunitIdInfo, m_textJobIdInfo, m_notifyBasic.getRoleIdList()));
 
 		// ジョブ 重要度：警告
 		label = this.getLabelPriority(groupJob, Messages.getString("warning"),PriorityColorConstant.COLOR_WARNING);
 		this.m_checkJobRunWarning = this.getCheckJobRun(groupJob);
+		WidgetTestUtil.setTestId(this, "jobrunwarning", m_checkJobRunWarning);
 		this.m_textJobunitIdWarning = this.getTextJobunitId(groupJob);
+		WidgetTestUtil.setTestId(this, "jobunitidwarning", m_textJobunitIdWarning);
 		this.m_textJobIdWarning = this.getTextJobId(groupJob);
+		WidgetTestUtil.setTestId(this, "jobidwarnitng", m_textJobIdWarning);
 		this.m_buttonReferWarning = this.getButtonJobRefer(groupJob);
+		WidgetTestUtil.setTestId(this, "referwarning", m_buttonReferWarning);
 		this.m_comboFailurePriorityWarning = this.getComboPriority(groupJob);
-		this.m_buttonReferWarning.addSelectionListener(new JobIdSelectionListener(m_textJobunitIdWarning, m_textJobIdWarning, m_notifyBasic.getRoleIdList()));
+		WidgetTestUtil.setTestId(this, "failureprioritywarning", m_comboFailurePriorityWarning);
+		this.m_buttonReferWarning.addSelectionListener(new JobIdSelectionListener(shell, m_notifyBasic.getManagerListComposite(), m_textJobunitIdWarning, m_textJobIdWarning, m_notifyBasic.getRoleIdList()));
 
 		// ジョブ 重要度：危険
 		label = this.getLabelPriority(groupJob, Messages.getString("critical"),PriorityColorConstant.COLOR_CRITICAL);
 		this.m_checkJobRunCritical = this.getCheckJobRun(groupJob);
+		WidgetTestUtil.setTestId(this, "criticalcheck", m_checkJobRunCritical);
 		this.m_textJobunitIdCritical = this.getTextJobunitId(groupJob);
+		WidgetTestUtil.setTestId(this, "jobunitidcritical", m_textJobunitIdCritical);
 		this.m_textJobIdCritical = this.getTextJobId(groupJob);
+		WidgetTestUtil.setTestId(this, "jobidcritical", m_textJobIdCritical);
 		this.m_buttonReferCritical = this.getButtonJobRefer(groupJob);
+		WidgetTestUtil.setTestId(this, "refercritical", m_buttonReferCritical);
 		this.m_comboFailurePriorityCritical = this.getComboPriority(groupJob);
-		this.m_buttonReferCritical.addSelectionListener(new JobIdSelectionListener(m_textJobunitIdCritical, m_textJobIdCritical, m_notifyBasic.getRoleIdList()));
+		WidgetTestUtil.setTestId(this, "failureprioritycritical", m_comboFailurePriorityCritical);
+		this.m_buttonReferCritical.addSelectionListener(new JobIdSelectionListener(shell, m_notifyBasic.getManagerListComposite(), m_textJobunitIdCritical, m_textJobIdCritical, m_notifyBasic.getRoleIdList()));
 
 		// ジョブ 重要度：不明
 		label = this.getLabelPriority(groupJob, Messages.getString("unknown"),PriorityColorConstant.COLOR_UNKNOWN);
 		this.m_checkJobRunUnknown = this.getCheckJobRun(groupJob);
+		WidgetTestUtil.setTestId(this, "jobrununknown", m_checkJobRunUnknown);
 		this.m_textJobunitIdUnknown = this.getTextJobunitId(groupJob);
+		WidgetTestUtil.setTestId(this, "jobunitidunknown", m_textJobunitIdUnknown);
 		this.m_textJobIdUnknown = this.getTextJobId(groupJob);
+		WidgetTestUtil.setTestId(this, "jobidunknown", m_textJobIdUnknown);
 		this.m_buttonReferUnknown = this.getButtonJobRefer(groupJob);
+		WidgetTestUtil.setTestId(this, "referunknown", m_buttonReferUnknown);
 		this.m_comboFailurePriorityUnknown = this.getComboPriority(groupJob);
-		this.m_buttonReferUnknown.addSelectionListener(new JobIdSelectionListener(m_textJobunitIdUnknown, m_textJobIdUnknown, m_notifyBasic.getRoleIdList()));
-
+		WidgetTestUtil.setTestId(this, "failurepriorityunknown", m_comboFailurePriorityUnknown);
+		this.m_buttonReferUnknown.addSelectionListener(new JobIdSelectionListener(shell, m_notifyBasic.getManagerListComposite(), m_textJobunitIdUnknown, m_textJobIdUnknown, m_notifyBasic.getRoleIdList()));
 	}
 
 	/**
 	 * 更新処理
-	 * 
+	 *
 	 */
 	public void update(){
 		// 必須項目を明示
@@ -512,7 +530,7 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 	}
 	/**
 	 * 入力値を保持した通知情報を返します。
-	 * 
+	 *
 	 * @return 通知情報
 	 */
 	@Override
@@ -522,78 +540,111 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 引数で指定された通知情報の値を、各項目に設定します。
-	 * 
+	 *
 	 * @param notify 設定値として用いる通知情報
 	 */
 	@Override
 	protected void setInputData(NotifyInfo notify) {
+		super.setInputData(notify);
 
-		this.inputData = notify;
-
-		// 通知基本情報
-		super.m_notifyBasic.setInputData(notify, this.updateFlg);
-
-		// 初回通知情報
-		super.m_notifyInitial.setInputData(notify);
-
-		// 抑制情報
-		super.m_notifyInhibition.setInputData(notify);
-
-		// ジョブ実行情報
-		List<NotifyJobInfo> list = notify.getNotifyJobInfo();
-		if (list != null && list.size() > 0) {
-			for (int index=0; index<list.size(); index++){
-				NotifyJobInfo job = list.get(index);
-				if(job != null){
-					// 通知の場合
-					if(PriorityConstant.TYPE_INFO == job.getPriority()){
-						this.setInputDataForJob(job, m_checkJobRunInfo, m_textJobunitIdInfo, m_textJobIdInfo, m_comboFailurePriorityInfo);
-						// 通知のみジョブ通知の共通部分の設定を行う
-						if (job.getJobExecFacility() != null) {
-							this.m_facilityId = job.getJobExecFacility();
-							this.m_textScope.setText(job.getJobExecScope());
-						}
-						if (job.getJobExecFacilityFlg() != null && job.getJobExecFacilityFlg() == ExecFacilityConstant.TYPE_GENERATION) {
-							this.m_radioGenerationNodeValue.setSelection(true);
-							this.m_scopeSelect.setEnabled(false);
-						}
-						else {
-							this.m_radioFixedValue.setSelection(true);
-							this.m_scopeSelect.setEnabled(true);
-						}
-					}
-					// 警告の場合
-					else if(PriorityConstant.TYPE_WARNING == job.getPriority()){
-						this.setInputDataForJob(job, m_checkJobRunWarning, m_textJobunitIdWarning, m_textJobIdWarning, m_comboFailurePriorityWarning);
-					}
-					// 危険の場合
-					else if(PriorityConstant.TYPE_CRITICAL == job.getPriority()){
-						this.setInputDataForJob(job, m_checkJobRunCritical, m_textJobunitIdCritical, m_textJobIdCritical, m_comboFailurePriorityCritical);
-					}
-					// 不明の場合
-					else if(PriorityConstant.TYPE_UNKNOWN == job.getPriority()){
-						this.setInputDataForJob(job, m_checkJobRunUnknown, m_textJobunitIdUnknown, m_textJobIdUnknown, m_comboFailurePriorityUnknown);
-					}
-				}
-			}
+		// コマンド情報
+		NotifyJobInfo info = notify.getNotifyJobInfo();
+		if (info != null) {
+			this.setInputDatal(info);
 		} else {
 			// 新規追加の場合
 			this.m_radioGenerationNodeValue.setSelection(true);
 			this.m_scopeSelect.setEnabled(false);
 		}
+	}
 
-		// 有効／無効
-		if (notify.getValidFlg() != null && notify.getValidFlg() == ValidConstant.TYPE_INVALID) {
-			this.m_confirmValid.setSelection(false);
+	private void setInputDatal(NotifyJobInfo job) {
+		if (job.getJobExecFacility() != null) {
+			this.m_facilityId = job.getJobExecFacility();
+			this.m_textScope.setText(job.getJobExecScope());
+		}
+		if (job.getJobExecFacilityFlg() != null && job.getJobExecFacilityFlg() == ExecFacilityConstant.TYPE_GENERATION) {
+			this.m_radioGenerationNodeValue.setSelection(true);
+			this.m_scopeSelect.setEnabled(false);
 		}
 		else {
-			this.m_confirmValid.setSelection(true);
+			this.m_radioFixedValue.setSelection(true);
+			this.m_scopeSelect.setEnabled(true);
+		}
+
+		Integer[] validFlgs = getValidFlgs(job);
+		Button[] checkJobRuns = new Button[] {
+				this.m_checkJobRunInfo,
+				this.m_checkJobRunWarning,
+				this.m_checkJobRunCritical,
+				this.m_checkJobRunUnknown
+		};
+		String[] jobunitIds = new String[] {
+				job.getInfoJobunitId(),
+				job.getWarnJobunitId(),
+				job.getCriticalJobunitId(),
+				job.getUnknownJobunitId()
+		};
+		Text[] textJobunitIds = new Text[] {
+				this.m_textJobunitIdInfo,
+				this.m_textJobunitIdWarning,
+				this.m_textJobunitIdCritical,
+				this.m_textJobunitIdUnknown
+		};
+		String[] jobIds = new String[] {
+				job.getInfoJobId(),
+				job.getWarnJobId(),
+				job.getCriticalJobId(),
+				job.getUnknownJobId()
+		};
+		Text[] textJobIds = new Text[] {
+				this.m_textJobIdInfo,
+				this.m_textJobIdWarning,
+				this.m_textJobIdCritical,
+				this.m_textJobIdUnknown
+		};
+		Integer[] jobFailurePriorities = new Integer[] {
+				job.getInfoJobFailurePriority(),
+				job.getWarnJobFailurePriority(),
+				job.getCriticalJobFailurePriority(),
+				job.getUnknownJobFailurePriority()
+		};
+		Combo[] comboFailurePriorities = new Combo[] {
+				this.m_comboFailurePriorityInfo,
+				this.m_comboFailurePriorityWarning,
+				this.m_comboFailurePriorityCritical,
+				this.m_comboFailurePriorityUnknown
+		};
+
+
+		for (int i = 0; i < validFlgs.length; i++) {
+			boolean valid = validFlgs[i] == ValidConstant.TYPE_VALID;
+			checkJobRuns[i].setSelection(valid);
+			WidgetTestUtil.setTestId(this, "checkJobRuns" + i, checkJobRuns[i]);
+
+			//ジョブユニットID
+			if (jobunitIds[i] != null){
+				textJobunitIds[i].setText(jobunitIds[i]);
+				WidgetTestUtil.setTestId(this, "textJobunitIds" + i, textJobunitIds[i]);
+			}
+
+			// ジョブID
+			if (jobIds[i] != null) {
+				textJobIds[i].setText(jobIds[i]);
+				WidgetTestUtil.setTestId(this, "textJobIds" + i, textJobIds[i]);
+			}
+
+			// ジョブ失敗時の重要度
+			if (jobFailurePriorities[i] != null) {
+				comboFailurePriorities[i].setText(PriorityConstant.typeToString(jobFailurePriorities[i]));
+				WidgetTestUtil.setTestId(this, "comboFailurePriorities" + i, comboFailurePriorities[i]);
+			}
 		}
 	}
 
 	/**
 	 * 引数で指定された通知ジョブ情報の値を、各項目に設定します。
-	 * 
+	 *
 	 * @param info 設定値として用いる通知ジョブ情報
 	 * @param checkJobRun 通知チェックボックス
 	 * @param textJobId ジョブIDテキストボックス
@@ -606,135 +657,90 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 			Text textJobId,
 			Combo comboFailurePriority
 			) {
-		// ジョブ実行
-		if (info.getValidFlg() != null && info.getValidFlg().intValue() == ValidConstant.TYPE_VALID) {
-			checkJobRun.setSelection(true);
-		}
-
-		//ジョブユニットID
-		if (info.getJobunitId() != null){
-			textJobunitId.setText(info.getJobunitId());
-		}
-
-		// ジョブID
-		if (info.getJobId() != null) {
-			textJobId.setText(info.getJobId());
-		}
-		// ジョブ失敗時の重要度
-		if (info.getJobFailurePriority() != null) {
-			comboFailurePriority.setText(PriorityConstant.typeToString(info.getJobFailurePriority()));
-		}
 	}
 
 	/**
 	 * 入力値を設定した通知情報を返します。<BR>
 	 * 入力値チェックを行い、不正な場合は<code>null</code>を返します。
-	 * 
+	 *
 	 * @return 通知情報
-	 * 
+	 *
 	 * @see #createInputDataForJob(ArrayList, int, Button, Text, Button, Combo)
 	 */
 	@Override
 	protected NotifyInfo createInputData() {
-		NotifyInfo info = new NotifyInfo();
+		NotifyInfo info = super.createInputData();
+		if (info == null) {
+			return null;
+		}
 
 		// 通知タイプの設定
 		info.setNotifyType(TYPE_JOB);
 
-		// 通知基本情報
-		validateResult = super.m_notifyBasic.createInputData(info, this.notifyId);
-		if(validateResult != null){
-			return null;
-		}
-
-		// 初回通知情報
-		validateResult = super.m_notifyInitial.createInputData(info);
-		if(validateResult != null){
-			return null;
-		}
-
-		// 抑制情報
-		validateResult = super.m_notifyInhibition.createInputData(info);
-		if(validateResult != null){
-			return null;
-		}
-
-		// ジョブ情報
-		ArrayList<NotifyJobInfo> list = new ArrayList<NotifyJobInfo>();
-		list = this.createInputDataForJob(list, PriorityConstant.TYPE_INFO,			this.m_checkJobRunInfo,			this.m_textJobunitIdInfo,			this.m_textJobIdInfo,			this.m_comboFailurePriorityInfo);
-		list = this.createInputDataForJob(list, PriorityConstant.TYPE_WARNING,		this.m_checkJobRunWarning,		this.m_textJobunitIdWarning,		this.m_textJobIdWarning,		this.m_comboFailurePriorityWarning);
-		list = this.createInputDataForJob(list, PriorityConstant.TYPE_CRITICAL,		this.m_checkJobRunCritical,		this.m_textJobunitIdCritical,		this.m_textJobIdCritical,		this.m_comboFailurePriorityCritical);
-		list = this.createInputDataForJob(list, PriorityConstant.TYPE_UNKNOWN,		this.m_checkJobRunUnknown,		this.m_textJobunitIdUnknown,		this.m_textJobIdUnknown,		this.m_comboFailurePriorityUnknown);
-
-		if(list == null){
-			return null;
-		}
-
-		List<NotifyJobInfo> notifyJobInfo = info.getNotifyJobInfo();
-		notifyJobInfo.clear();
-		notifyJobInfo.addAll(list);
-
-		// 有効/無効
-		if (this.m_confirmValid.getSelection()) {
-			info.setValidFlg(ValidConstant.TYPE_VALID);
-		} else {
-			info.setValidFlg(ValidConstant.TYPE_INVALID);
-		}
-
+		// コマンド情報
+		NotifyJobInfo notifyJobInfo = this.createInputData(info.getNotifyId());
+		info.setNotifyJobInfo(notifyJobInfo);
 		return info;
 	}
 
-	/**
-	 * 入力値を設定した通知ジョブ情報を返します。<BR>
-	 * 入力値チェックを行い、不正な場合は<code>null</code>を返します。
-	 * 
-	 * @return 通知ジョブ情報
-	 * 
-	 */
-	private ArrayList<NotifyJobInfo> createInputDataForJob(ArrayList<NotifyJobInfo> list,
-			int priority,
-			Button checkJobRun,
-			Text textJobunitId,
-			Text textJobId,
-			Combo comboFailurePriority
-			) {
-
-		if(list == null)
-			return null;
-
+	private NotifyJobInfo createInputData(String notifyId) {
+		// ジョブ情報
 		NotifyJobInfo job = new NotifyJobInfo();
 
-		// 重要度
-		job.setPriority(priority);
+		job.setNotifyId(notifyId);
 
 		//　実行
-		if (checkJobRun.getSelection()) {
-			job.setValidFlg(new Integer(ValidConstant.TYPE_VALID));
-		} else {
-			job.setValidFlg(new Integer(ValidConstant.TYPE_INVALID));
-		}
+		job.setInfoValidFlg(ValidConstant.booleanToType(m_checkJobRunInfo.getSelection()));
+		job.setWarnValidFlg(ValidConstant.booleanToType(m_checkJobRunWarning.getSelection()));
+		job.setCriticalValidFlg(ValidConstant.booleanToType(m_checkJobRunCritical.getSelection()));
+		job.setUnknownValidFlg(ValidConstant.booleanToType(m_checkJobRunUnknown.getSelection()));
+
+
 		// jobunitId
-		if (textJobunitId.getText() != null
-				&& !"".equals(textJobunitId.getText().trim())) {
-			job.setJobunitId(textJobunitId.getText());
+		if (isNotNullAndBlank(m_textJobunitIdInfo.getText())) {
+			job.setInfoJobunitId(m_textJobunitIdInfo.getText());
+		}
+		if (isNotNullAndBlank(m_textJobunitIdWarning.getText())) {
+			job.setWarnJobunitId(m_textJobunitIdWarning.getText());
+		}
+		if (isNotNullAndBlank(m_textJobunitIdCritical.getText())) {
+			job.setCriticalJobunitId(m_textJobunitIdCritical.getText());
+		}
+		if (isNotNullAndBlank(m_textJobunitIdUnknown.getText())) {
+			job.setUnknownJobunitId(m_textJobunitIdUnknown.getText());
 		}
 
 		// jobId
-		if (textJobId.getText() != null
-				&& !"".equals(textJobId.getText().trim())) {
-			job.setJobId(textJobId.getText());
+		if (isNotNullAndBlank(m_textJobIdInfo.getText())) {
+			job.setInfoJobId(m_textJobIdInfo.getText());
+		}
+		if (isNotNullAndBlank(m_textJobIdWarning.getText())) {
+			job.setWarnJobId(m_textJobIdWarning.getText());
+		}
+		if (isNotNullAndBlank(m_textJobIdCritical.getText())) {
+			job.setCriticalJobId(m_textJobIdCritical.getText());
+		}
+		if (isNotNullAndBlank(m_textJobIdUnknown.getText())) {
+			job.setUnknownJobId(m_textJobIdUnknown.getText());
 		}
 
 		// 呼出失敗時
-		if (comboFailurePriority.getText() != null
-				&& !"".equals(comboFailurePriority.getText())) {
-			job.setJobFailurePriority(PriorityConstant.stringToType(comboFailurePriority.getText()));
+		if (isNotNullAndBlank(m_comboFailurePriorityInfo.getText())) {
+			job.setInfoJobFailurePriority(PriorityConstant.stringToType(m_comboFailurePriorityInfo.getText()));
+		}
+		if (isNotNullAndBlank(m_comboFailurePriorityWarning.getText())) {
+			job.setWarnJobFailurePriority(PriorityConstant.stringToType(m_comboFailurePriorityWarning.getText()));
+		}
+		if (isNotNullAndBlank(m_comboFailurePriorityCritical.getText())) {
+			job.setCriticalJobFailurePriority(PriorityConstant.stringToType(m_comboFailurePriorityCritical.getText()));
+		}
+		if (isNotNullAndBlank(m_comboFailurePriorityUnknown.getText())) {
+			job.setUnknownJobFailurePriority(PriorityConstant.stringToType(m_comboFailurePriorityUnknown.getText()));
 		}
 
 		// 共通部分登録
 		// 実行ファシリティID
-		if (this.m_textScope.getText() != null
-				&& !"".equals(this.m_textScope.getText())) {
+		if (isNotNullAndBlank(this.m_textScope.getText())) {
 			job.setJobExecFacility(this.m_facilityId);
 			job.setJobExecScope(this.m_textScope.getText());
 		}
@@ -746,13 +752,12 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 			job.setJobExecFacilityFlg(ExecFacilityConstant.TYPE_FIX);
 		}
 
-		list.add(job);
-		return list;
+		return job;
 	}
 
 	/**
 	 * 入力値チェックをします。
-	 * 
+	 *
 	 * @return 検証結果
 	 */
 	@Override
@@ -769,9 +774,9 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 入力値をマネージャに登録します。
-	 * 
+	 *
 	 * @return true：正常、false：異常
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#action()
 	 */
 	@Override
@@ -782,11 +787,11 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 		if(info != null){
 			if (!this.updateFlg) {
 				// 作成の場合
-				result = new AddNotify().add(info);
+				result = new AddNotify().add(this.getInputManagerName(), info);
 			}
 			else{
 				// 変更の場合
-				result = new ModifyNotify().modify(info);
+				result = new ModifyNotify().modify(this.getInputManagerName(), info);
 			}
 		}
 
@@ -795,7 +800,7 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * ＯＫボタンのテキストを返します。
-	 * 
+	 *
 	 * @return ＯＫボタンのテキスト
 	 */
 	@Override
@@ -805,7 +810,7 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * キャンセルボタンのテキストを返します。
-	 * 
+	 *
 	 * @return キャンセルボタンのテキスト
 	 */
 	@Override
@@ -815,7 +820,7 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 無効な入力値の情報を設定します。
-	 * 
+	 *
 	 * @param id ID
 	 * @param message メッセージ
 	 */
@@ -831,9 +836,9 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 	/**
 	 * ボタンを生成します。<BR>
 	 * 参照フラグが<code> true </code>の場合は閉じるボタンを生成し、<code> false </code>の場合は、デフォルトのボタンを生成します。
-	 * 
+	 *
 	 * @param parent ボタンバーコンポジット
-	 * 
+	 *
 	 * @see #createButtonsForButtonBar(Composite)
 	 */
 	@Override
@@ -844,13 +849,14 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 		}
 		else{
 			// 閉じるボタン
-			this.createButton(parent, IDialogConstants.CANCEL_ID, IDialogConstants.CLOSE_LABEL, false);
+			// TODO Remove the following hard-code. IDialogConstants.*_LABEL will causes IncompatibleClassChangeError on RAP
+			this.createButton(parent, IDialogConstants.CANCEL_ID, "Close", false);
 		}
 	}
 
 	/**
 	 * コンポジットの選択可/不可を設定します。
-	 * 
+	 *
 	 * @param enable 選択可の場合、<code> true </code>
 	 */
 	@Override
@@ -861,7 +867,7 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 重要度のラベルを返します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @param text ラベルに表示するテキスト
 	 * @param background ラベルの背景色
@@ -874,6 +880,7 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 
 		// ラベル（重要度）
 		Label label = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "labelpriority", label);
 		GridData gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_PRIORITY;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -887,7 +894,7 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * ジョブの実行チェックボックスを返します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @return 生成されたチェックボックス
 	 */
@@ -895,21 +902,17 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 
 		// チェックボックス（実行）
 		Button button = new Button(parent, SWT.CHECK);
+		WidgetTestUtil.setTestId(this, null, button);
 		GridData gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_JOB_RUN;
 		gridData.horizontalAlignment = GridData.CENTER;
 		gridData.grabExcessHorizontalSpace = true;
 		button.setLayoutData(gridData);
-		button.addSelectionListener(new SelectionListener() {
+		button.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				update();
 			}
-
-			@Override
-			public void widgetDefaultSelected(SelectionEvent e) {
-
-			}
 		});
 
 		return button;
@@ -917,58 +920,58 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * ジョブユニットIDテキストボックスを返します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @return 生成されたチェックボックス
 	 */
 	private Text getTextJobunitId(Composite parent) {
-
 		// テキストボックス（ジョブユニットID）
-		Text text = new Text(parent, SWT.BORDER | SWT.READ_ONLY);
+		Text notifyJobCreateJobUnitIdText = new Text(parent, SWT.BORDER | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, "jobunitid", notifyJobCreateJobUnitIdText);
 		GridData gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_JOBUNIT_ID;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
-		text.setLayoutData(gridData);
-		text.addModifyListener(new ModifyListener(){
+		notifyJobCreateJobUnitIdText.setLayoutData(gridData);
+		notifyJobCreateJobUnitIdText.addModifyListener(new ModifyListener(){
 			@Override
 			public void modifyText(ModifyEvent arg0) {
 				update();
 			}
 		});
 
-		return text;
+		return notifyJobCreateJobUnitIdText;
 	}
 
 	/**
 	 * ジョブジョブIDテキストボックスを返します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @return 生成されたチェックボックス
 	 */
 	private Text getTextJobId(Composite parent) {
-
 		// テキストボックス（ジョブID）
-		Text text = new Text(parent, SWT.BORDER | SWT.READ_ONLY);
+		Text notifyJobCreateJobIdText = new Text(parent, SWT.BORDER | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, "job", notifyJobCreateJobIdText);
 		GridData gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_JOB_ID;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
-		text.setLayoutData(gridData);
+		notifyJobCreateJobIdText.setLayoutData(gridData);
 
-		return text;
+		return notifyJobCreateJobIdText;
 	}
 
 	/**
 	 * ジョブの参照ボタンを返します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @return 生成されたチェックボックス
 	 */
 	private Button getButtonJobRefer(Composite parent) {
-
 		// チェックボックス（参照）
 		Button button = new Button(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, null, button);
 		GridData gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_REF_BTN;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -981,14 +984,14 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * ジョブの重要度のコンボボックスを返します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @param horizontalSpan コンボボックスのカラム数
 	 * @return コンボボックス
 	 */
 	private Combo getComboPriority(Composite parent) {
-
 		Combo combo = new Combo(parent, SWT.DROP_DOWN | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, null, combo);
 		GridData gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_FAILURE_PRIORITY;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -1020,4 +1023,4 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
 		this.m_textJobIdUnknown.setText("");
 	}
 
-}
\ No newline at end of file
+}
