@@ -46,6 +46,7 @@ import com.clustercontrol.notify.model.NotifyJobInfoEntity;
 import com.clustercontrol.notify.model.NotifyLogEscalateInfoEntity;
 import com.clustercontrol.notify.model.NotifyMailInfoEntity;
 import com.clustercontrol.notify.model.NotifyStatusInfoEntity;
+import com.clustercontrol.notify.util.NotifyUtil;
 
 /**
  * 通知情報を作成するクラスです。
@@ -94,6 +95,7 @@ public class AddNotify {
 			notify.setNotifyType(info.getNotifyType());
 			notify.setRenotifyPeriod(info.getRenotifyPeriod());
 			notify.setRenotifyType(info.getRenotifyType());
+			notify.setNotFirstNotify(info.getNotFirstNotify());
 			notify.setValidFlg(info.getValidFlg());
 			notify.setOwnerRoleId(info.getOwnerRoleId());
 			notify.setRegDate(now);
@@ -142,19 +144,15 @@ public class AddNotify {
 	 * @return
 	 */
 	private boolean addNotifyCommand(NotifyInfo info, NotifyInfoEntity notify) {
-
-		// 通知コマンド情報を挿入
-		for (NotifyCommandInfo command : info.getNotifyCommandInfo()) {
-			if (command != null) {
-				NotifyCommandInfoEntity entity = new NotifyCommandInfoEntity(command.getNotifyId(), command.getPriority(),
-						notify);
-				entity.setCommand(command.getCommand());
-				entity.setCommandTimeout(command.getTimeout());
-				entity.setEffectiveUser(command.getEffectiveUser());
-				entity.setSetEnvironment(command.getSetEnvironment());
-				entity.setValidFlg(command.getValidFlg());
-			}
+		NotifyCommandInfo command = info.getNotifyCommandInfo();
+		if (command == null) {
+			return true;
 		}
+
+		NotifyCommandInfoEntity entity = new NotifyCommandInfoEntity(
+				command.getNotifyId(), notify);
+		NotifyUtil.copyProperties(command, entity);
+
 		return true;
 	}
 
@@ -165,15 +163,12 @@ public class AddNotify {
 	 * @return
 	 */
 	private boolean addNotifyEvent(NotifyInfo info, NotifyInfoEntity notify) {
-
 		// 通知イベント情報を挿入
-		for (NotifyEventInfo event : info.getNotifyEventInfo()) {
-			if (event != null) {
-				NotifyEventInfoEntity entity = new NotifyEventInfoEntity(info.getNotifyId(), event.getPriority(),
-						notify);
-				entity.setEventNormalFlg(event.getValidFlg());
-				entity.setEventNormalState(event.getEventNormalState());
-			}
+		NotifyEventInfo event = info.getNotifyEventInfo();
+		if (event != null) {
+			NotifyEventInfoEntity entity = new NotifyEventInfoEntity(info.getNotifyId(),
+					notify);
+			NotifyUtil.copyProperties(event, entity);
 		}
 		return true;
 	}
@@ -187,19 +182,11 @@ public class AddNotify {
 	 * @throws FacilityNotFound
 	 */
 	private boolean addNotifyJob(NotifyInfo info, NotifyInfoEntity notify) throws HinemosUnknown, FacilityNotFound {
-
-		// 通知ジョブ情報を挿入
-		for (NotifyJobInfo job : info.getNotifyJobInfo()) {
-			if (job != null) {
-				NotifyJobInfoEntity entity = new NotifyJobInfoEntity(info.getNotifyId(), job.getPriority(),
-						notify);
-				entity.setJobExecFacilityFlg(job.getJobExecFacilityFlg());
-				entity.setJobFailurePriority(job.getJobFailurePriority());
-				entity.setJobId(job.getJobId());
-				entity.setJobRun(job.getValidFlg());
-				entity.setJobunitId(job.getJobunitId());
-				entity.setJobExecFacilityId(job.getJobExecFacility());
-			}
+		NotifyJobInfo job = info.getNotifyJobInfo();
+		if (job != null) {
+			NotifyJobInfoEntity entity = new NotifyJobInfoEntity(info.getNotifyId(),
+					notify);
+			NotifyUtil.copyProperties(job, entity);
 		}
 		return true;
 	}
@@ -213,20 +200,11 @@ public class AddNotify {
 	 * @throws FacilityNotFound
 	 */
 	private boolean addNotifyLogEscalate(NotifyInfo info, NotifyInfoEntity notify) throws HinemosUnknown, FacilityNotFound {
-
-		// 通知ログエスカレーション情報を挿入
-		for (NotifyLogEscalateInfo log : info.getNotifyLogEscalateInfo()) {
-			if (log != null) {
-				NotifyLogEscalateInfoEntity entity = new NotifyLogEscalateInfoEntity(info.getNotifyId(), log.getPriority(),
-						notify);
-				entity.setEscalateFacilityFlg(log.getEscalateFacilityFlg());
-				entity.setEscalateFlg(log.getValidFlg());
-				entity.setEscalateMessage(log.getEscalateMessage());
-				entity.setEscalatePort(log.getEscalatePort());
-				entity.setSyslogFacility(log.getSyslogFacility());
-				entity.setSyslogPriority(log.getSyslogPriority());
-				entity.setEscalateFacilityId(log.getEscalateFacility());
-			}
+		NotifyLogEscalateInfo log = info.getNotifyLogEscalateInfo();
+		if (log != null) {
+			NotifyLogEscalateInfoEntity entity = new NotifyLogEscalateInfoEntity(info.getNotifyId(),
+					notify);
+			NotifyUtil.copyProperties(log, entity);
 		}
 		return true;
 	}
@@ -238,25 +216,21 @@ public class AddNotify {
 	 * @return
 	 */
 	private boolean addNotifyMail(NotifyInfo info, NotifyInfoEntity notify) {
-
-		// 通知メール情報を挿入
-		for (NotifyMailInfo mail : info.getNotifyMailInfo()) {
-			if (mail != null) {
-				MailTemplateInfoEntity mailTemplateInfoEntity = null;
-				if (mail.getMailTemplateId() != null
-						&& !"".equals(mail.getMailTemplateId())) {
-					try {
-						mailTemplateInfoEntity
-						= QueryUtil.getMailTemplateInfoPK(mail.getMailTemplateId());
-					} catch (MailTemplateNotFound e) {
-					} catch (InvalidRole e) {
-					}
+		NotifyMailInfo mail = info.getNotifyMailInfo();
+		if (mail != null) {
+			MailTemplateInfoEntity mailTemplateInfoEntity = null;
+			if (mail.getMailTemplateId() != null
+					&& !"".equals(mail.getMailTemplateId())) {
+				try {
+					mailTemplateInfoEntity
+					= QueryUtil.getMailTemplateInfoPK(mail.getMailTemplateId());
+				} catch (MailTemplateNotFound e) {
+				} catch (InvalidRole e) {
 				}
-				NotifyMailInfoEntity entity = new NotifyMailInfoEntity(info.getNotifyId(), mail.getPriority(),
-						mailTemplateInfoEntity, notify);
-				entity.setMailAddress(mail.getMailAddress());
-				entity.setMailFlg(mail.getValidFlg());
 			}
+			NotifyMailInfoEntity entity = new NotifyMailInfoEntity(info.getNotifyId(),
+					mailTemplateInfoEntity, notify);
+			NotifyUtil.copyProperties(mail, entity);
 		}
 		return true;
 	}
@@ -268,17 +242,11 @@ public class AddNotify {
 	 * @return
 	 */
 	private boolean addNotifyStatus(NotifyInfo info, NotifyInfoEntity notify) {
-
-		// 通知ステータス情報を挿入
-		for (NotifyStatusInfo status : info.getNotifyStatusInfo()) {
-			if (status != null) {
-				NotifyStatusInfoEntity entity = new NotifyStatusInfoEntity(info.getNotifyId(), status.getPriority(),
-						notify);
-				entity.setStatusFlg(status.getValidFlg());
-				entity.setStatusInvalidFlg(status.getStatusInvalidFlg());
-				entity.setStatusUpdatePriority(status.getStatusUpdatePriority());
-				entity.setStatusValidPeriod(status.getStatusValidPeriod());
-			}
+		NotifyStatusInfo status = info.getNotifyStatusInfo();
+		if (status != null) {
+			NotifyStatusInfoEntity entity = new NotifyStatusInfoEntity(info.getNotifyId(),
+					notify);
+			NotifyUtil.copyProperties(status, entity);
 		}
 		return true;
 	}
