@@ -18,11 +18,11 @@ package com.clustercontrol.notify.factory;
 import java.util.Collection;
 import java.util.List;
 
-import javax.persistence.EntityManager;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import com.clustercontrol.accesscontrol.bean.PrivilegeConstant.ObjectPrivilegeMode;
+import com.clustercontrol.commons.util.HinemosEntityManager;
 import com.clustercontrol.commons.util.JpaTransactionManager;
 import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.fault.InvalidRole;
@@ -66,19 +66,18 @@ public class DeleteNotify {
 	 */
 	public boolean delete(String notifyId) throws NotifyNotFound, InvalidRole, HinemosUnknown {
 
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 
 		NotifyInfoEntity notify = null;
 		try
 		{
 			// 通知設定を取得
-			notify = QueryUtil.getNotifyInfoPK(notifyId);
+			notify = QueryUtil.getNotifyInfoPK(notifyId, ObjectPrivilegeMode.MODIFY);
 
 			// この通知設定の結果として通知された通知履歴を削除する
 			List<NotifyHistoryEntity> list = QueryUtil.getNotifyHistoryByNotifyId(notifyId);
 			for(NotifyHistoryEntity history : list){
 				try {
-					history.unchain();	// 削除前処理
 					em.remove(history);
 				} catch (Exception e) {
 					m_log.warn("delete() : "
