@@ -17,13 +17,23 @@ package com.clustercontrol.notify.session;
 
 import java.util.ArrayList;
 import java.util.Collection;
-import java.util.HashMap;
+import java.util.Date;
 import java.util.List;
+import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import com.clustercontrol.bean.HinemosModuleConstant;
+import com.clustercontrol.bean.PluginConstant;
+import com.clustercontrol.bean.ValidConstant;
+import com.clustercontrol.calendar.session.CalendarControllerBean;
+import com.clustercontrol.commons.session.CheckFacility;
+import com.clustercontrol.commons.util.AsyncTaskPersistentConfig;
+import com.clustercontrol.commons.util.HinemosSessionContext;
+import com.clustercontrol.commons.util.JpaTransactionManager;
+import com.clustercontrol.fault.CalendarNotFound;
 import com.clustercontrol.fault.FacilityNotFound;
 import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.fault.InvalidRole;
@@ -32,12 +42,7 @@ import com.clustercontrol.fault.NotifyDuplicate;
 import com.clustercontrol.fault.NotifyNotFound;
 import com.clustercontrol.fault.ObjectPrivilege_InvalidRole;
 import com.clustercontrol.fault.UsedFacility;
-import com.clustercontrol.bean.PluginConstant;
-import com.clustercontrol.bean.ValidConstant;
-import com.clustercontrol.commons.session.CheckFacility;
-import com.clustercontrol.commons.util.HinemosSessionContext;
-import com.clustercontrol.commons.util.AsyncTaskPersistentConfig;
-import com.clustercontrol.commons.util.JpaTransactionManager;
+import com.clustercontrol.notify.bean.NotifyCheckIdResultInfo;
 import com.clustercontrol.notify.bean.NotifyInfo;
 import com.clustercontrol.notify.bean.NotifyRelationInfo;
 import com.clustercontrol.notify.bean.OutputBasicInfo;
@@ -57,6 +62,7 @@ import com.clustercontrol.notify.util.NotifyCache;
 import com.clustercontrol.notify.util.NotifyRelationCache;
 import com.clustercontrol.notify.util.NotifyValidator;
 import com.clustercontrol.notify.util.OutputEvent;
+import com.clustercontrol.notify.util.OutputStatus;
 import com.clustercontrol.notify.util.QueryUtil;
 import com.clustercontrol.notify.util.SendMail;
 import com.clustercontrol.notify.util.SendSyslog;
@@ -65,22 +71,23 @@ import com.clustercontrol.repository.session.RepositoryControllerBean;
 /**
  * 通知機能の管理を行う Session Bean です。<BR>
  * クライアントからの Entity Bean へのアクセスは、Session Bean を介して行います。
- * 
  */
 public class NotifyControllerBean implements CheckFacility {
 	/** ログ出力のインスタンス。 */
 	private static Log m_log = LogFactory.getLog( NotifyControllerBean.class );
+	
+	private static SendMail m_reportingSendMail = null;
 
 	/**
 	 * 通知情報を作成します。
-	 * 
+	 *
 	 * @param info 作成対象の通知情報
 	 * @return 作成に成功した場合、<code> true </code>
 	 * @throws NotifyDuplicate
 	 * @throws InvalidSetting
 	 * @throws InvalidRole
 	 * @throws HinemosUnknown
-	 * 
+	 *
 	 * @see com.clustercontrol.notify.factory.AddNotify#add(NotifyInfo)
 	 */
 	public boolean addNotify(NotifyInfo info) throws NotifyDuplicate, InvalidSetting, InvalidRole, HinemosUnknown {
@@ -130,14 +137,14 @@ public class NotifyControllerBean implements CheckFacility {
 
 	/**
 	 * 通知情報を変更します。
-	 * 
+	 *
 	 * @param info 変更対象の通知情報
 	 * @return 変更に成功した場合、<code> true </code>
 	 * @throws NotifyDuplicate
 	 * @throws HinemosUnknown
 	 * @throws InvalidSetting
 	 * @throws InvalidSetting
-	 * 
+	 *
 	 * @see com.clustercontrol.notify.factory.ModifyNotify#modify(NotifyInfo)
 	 */
 	public boolean modifyNotify(NotifyInfo info) throws NotifyDuplicate, InvalidRole, HinemosUnknown, InvalidSetting {
@@ -189,26 +196,28 @@ public class NotifyControllerBean implements CheckFacility {
 
 	/**
 	 * 通知情報を削除します。
-	 * 
-	 * @param notifyId 削除対象の通知ID
+	 *
+	 * @param notifyIds 削除対象の通知IDリスト
 	 * @return 削除に成功した場合、<code> true </code>
 	 * @throws NotifyDuplicate
 	 * @throws HinemosUnknown
 	 * @throws InvalidRole
-	 * 
+	 *
 	 * @see com.clustercontrol.notify.factory.DeleteNotify#delete(String)
 	 */
-	public boolean deleteNotify(String notifyId) throws NotifyNotFound, InvalidRole, HinemosUnknown {
+	public boolean deleteNotify(String[] notifyIds) throws NotifyNotFound, InvalidRole, HinemosUnknown {
 		JpaTransactionManager jtm = null;
 
 		// 通知情報を削除
 		DeleteNotify notify = new DeleteNotify();
-		boolean flag;
+		boolean flag = true;
 		try {
 			jtm = new JpaTransactionManager();
 			jtm.begin();
 
-			flag = notify.delete(notifyId);
+			for (String notifyId : notifyIds) {
+				flag = flag && notify.delete(notifyId);
+			}
 
 			jtm.commit();
 
@@ -241,13 +250,13 @@ public class NotifyControllerBean implements CheckFacility {
 
 	/**
 	 * 引数で指定された通知情報を返します。
-	 * 
+	 *
 	 * @param notifyId 取得対象の通知ID
 	 * @return 通知情報
 	 * @throws NotifyNotFound
 	 * @throws InvalidRole
 	 * @throws HinemosUnknown
-	 * 
+	 *
 	 * @see com.clustercontrol.notify.factory.SelectNotify#getNotify(String)
 	 */
 	public NotifyInfo getNotify(String notifyId) throws NotifyNotFound, InvalidRole, HinemosUnknown {
@@ -288,12 +297,12 @@ public class NotifyControllerBean implements CheckFacility {
 
 	/**
 	 * 通知情報一覧を返します。
-	 * 
+	 *
 	 * @return 通知情報一覧（Objectの2次元配列）
 	 * @throws NotifyNotFound
 	 * @throws HinemosUnknown
 	 * @throws InvalidRole
-	 * 
+	 *
 	 * @see com.clustercontrol.notify.factory.SelectNotify#getNotifyList()
 	 */
 	public ArrayList<NotifyInfo> getNotifyList() throws NotifyNotFound, InvalidRole, HinemosUnknown {
@@ -331,12 +340,12 @@ public class NotifyControllerBean implements CheckFacility {
 
 	/**
 	 * オーナーロールIDを指定して通知情報一覧を返します。
-	 * 
+	 *
 	 * @param ownerRoleId オーナーロールID
 	 * @return 通知情報一覧（Objectの2次元配列）
 	 * @throws InvalidRole
 	 * @throws HinemosUnknown
-	 * 
+	 *
 	 */
 	public ArrayList<NotifyInfo> getNotifyListByOwnerRole(String ownerRoleId) throws InvalidRole, HinemosUnknown {
 		JpaTransactionManager jtm = null;
@@ -365,52 +374,15 @@ public class NotifyControllerBean implements CheckFacility {
 		return list;
 	}
 
-	/**
-	 * 通知情報マップを返します。
-	 * 
-	 * @return 通知情報マップ
-	 * @throws HinemosUnknown
-	 * @throws InvalidRole
-	 * 
-	 * @see com.clustercontrol.notify.factory.SelectNotify#getNotifyMap()
-	 */
-	public HashMap<String, NotifyInfo> getNotifyMap() throws InvalidRole, HinemosUnknown {
-		JpaTransactionManager jtm = null;
-
-		// 通知一覧を取得
-		SelectNotify notify = new SelectNotify();
-		HashMap<String, NotifyInfo> map = null;
-		try {
-			jtm = new JpaTransactionManager();
-			jtm.begin();
-
-			map = notify.getNotifyMap();
-			jtm.commit();
-		} catch (ObjectPrivilege_InvalidRole e) {
-			jtm.rollback();
-			throw new InvalidRole(e.getMessage(), e);
-		} catch (HinemosUnknown e){
-			jtm.rollback();
-			throw e;
-		} catch (Exception e) {
-			m_log.warn("getNotifyMap() : "
-					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
-			jtm.rollback();
-			throw new HinemosUnknown(e.getMessage(), e);
-		} finally {
-			jtm.close();
-		}
-		return map;
-	}
 
 	/**
 	 * 通知グループに対応する通知を取得します。
-	 * 
+	 *
 	 * @param notifyGroupId  通知グループID
 	 * @return 通知
 	 * @throws InvalidRole
 	 * @throws HinemosUnknown
-	 * 
+	 *
 	 */
 	public  ArrayList<NotifyRelationInfo> getNotifyRelation(String notifyGroupId) throws InvalidRole, HinemosUnknown {
 		JpaTransactionManager jtm = null;
@@ -440,14 +412,14 @@ public class NotifyControllerBean implements CheckFacility {
 
 	/**
 	 * 通知グループを変更します。
-	 * 
+	 *
 	 * @param info 通知のセット
 	 * @param notifyGroupId 通知グループID
 	 * @return 変更に成功した場合、<code> true </code>
 	 * @throws NotifyNotFound
 	 * @throws InvalidRole
 	 * @throws HinemosUnknown
-	 * 
+	 *
 	 */
 	public boolean modifyNotifyRelation(Collection<NotifyRelationInfo> info, String notifyGroupId)
 			throws NotifyNotFound, InvalidRole, HinemosUnknown {
@@ -485,12 +457,12 @@ public class NotifyControllerBean implements CheckFacility {
 
 	/**
 	 * 通知グループを削除します。
-	 * 
+	 *
 	 * @param notifyGroupId 通知グループID
 	 * @return 削除に成功した場合、<code> true </code>
 	 * @throws InvalidRole
 	 * @throws HinemosUnknown
-	 * 
+	 *
 	 */
 	public boolean deleteNotifyRelation(String notifyGroupId) throws InvalidRole, HinemosUnknown {
 		JpaTransactionManager jtm = null;
@@ -524,7 +496,7 @@ public class NotifyControllerBean implements CheckFacility {
 
 	/**
 	 * 通知グループを作成します。
-	 * 
+	 *
 	 * @param info 通知グループ
 	 * @return 作成に成功した場合、<code> true </code>
 	 * @throws InvalidRole
@@ -566,23 +538,28 @@ public class NotifyControllerBean implements CheckFacility {
 
 	/**
 	 *　引数で指定した通知IDを利用している通知グループIDを取得する。
-	 * 
-	 * @param notifyId
+	 *
+	 * @param notifyIds
 	 * @return　通知グループIDのリスト
 	 * @throws InvalidRole
 	 * @throws HinemosUnknown
 	 */
-	public ArrayList<String> checkNotifyId(String notifyId) throws InvalidRole, HinemosUnknown {
+	public ArrayList<NotifyCheckIdResultInfo> checkNotifyId(String[] notifyIds) throws InvalidRole, HinemosUnknown {
 		JpaTransactionManager jtm = null;
 
-		ArrayList<String> ret = null;
-
+		ArrayList<NotifyCheckIdResultInfo> ret = new ArrayList<NotifyCheckIdResultInfo>();
 		SelectNotifyRelation notify = new SelectNotifyRelation();
 		try {
 			jtm = new JpaTransactionManager();
 			jtm.begin();
 
-			ret = notify.getNotifyGroupIdBaseOnNotifyId(notifyId);
+			for (int i = 0; i < notifyIds.length; i++) {
+				String notifyId = notifyIds[i];
+				NotifyCheckIdResultInfo result = new NotifyCheckIdResultInfo();
+				result.setNotifyId(notifyId);
+				result.setNotifyGroupIdList(notify.getNotifyGroupIdBaseOnNotifyId(notifyId));
+				ret.add(result);
+			}
 			jtm.commit();
 		} catch (ObjectPrivilege_InvalidRole e) {
 			jtm.rollback();
@@ -600,7 +577,7 @@ public class NotifyControllerBean implements CheckFacility {
 
 	/**
 	 *　指定した通知IDを有効化/無効化する。
-	 * 
+	 *
 	 * @param notifyId
 	 * @throws HinemosUnknown
 	 * @throws NotifyNotFound
@@ -673,8 +650,8 @@ public class NotifyControllerBean implements CheckFacility {
 
 	/**
 	 * 指定したファシリティIDが利用されているか確認する
-	 * 
-	 * 
+	 *
+	 *
 	 */
 	@Override
 	public void isUseFacilityId(String facilityId) throws UsedFacility {
@@ -725,9 +702,9 @@ public class NotifyControllerBean implements CheckFacility {
 
 	/**
 	 * イベント通知
-	 * 
+	 *
 	 * トランザクションは引き継がれたものを使用
-	 * 
+	 *
 	 * @throws HinemosUnknown
 	 * @throws InvalidRole
 	 */
@@ -750,15 +727,47 @@ public class NotifyControllerBean implements CheckFacility {
 			jtm.rollback();
 			throw new HinemosUnknown(e.getMessage(), e);
 		} finally {
-			jtm.close();
+			if (jtm != null) {
+				jtm.close();
+			}
+		}
+	}
+	
+	/**
+	 * ステータス通知
+	 * 
+	 * トランザクションは引き継がれたものを使用
+	 * 
+	 * @param output
+	 * @throws HinemosUnknown
+	 */
+	public void updateStatusLog(OutputBasicInfo output) throws HinemosUnknown {
+		JpaTransactionManager jtm = null;
+
+		try {
+			jtm = new JpaTransactionManager();
+			jtm.begin();
+			
+			new OutputStatus().updateStatus(output);
+
+			jtm.commit();
+		} catch (Exception e) {
+			m_log.warn("insertEventLog() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			jtm.rollback();
+			throw new HinemosUnknown(e.getMessage(), e);
+		} finally {
+			if (jtm != null) {
+				jtm.close();
+			}
 		}
 	}
 
 	/**
 	 * Syslog通知
-	 * 
+	 *
 	 * トランザクションは引き継がれたものを使用
-	 * 
+	 *
 	 * @throws InvalidRole
 	 * @throws HinemosUnknown
 	 */
@@ -787,9 +796,9 @@ public class NotifyControllerBean implements CheckFacility {
 
 	/**
 	 * メール通知
-	 * 
+	 *
 	 * トランザクションは引き継がれたものを使用
-	 * 
+	 *
 	 * @throws InvalidRole
 	 * @throws HinemosUnknown
 	 */
@@ -799,8 +808,32 @@ public class NotifyControllerBean implements CheckFacility {
 		try {
 			jtm = new JpaTransactionManager();
 			jtm.begin();
-
-			SendMail sendMail = new SendMail();
+			SendMail sendMail;
+			
+			// レポーティングオプション用添付ファイル対応 
+			if(outputBasicInfo.getPluginId().equals(HinemosModuleConstant.REPORTING) 
+					&& outputBasicInfo.getSubKey() != null) {
+				
+				// 最初の1回だけ実施
+				if(m_reportingSendMail == null) {
+					String sendMailClass = "com.clustercontrol.notify.util.ReportingSendMail";
+					try {
+						Class<? extends SendMail> clazz = (Class<? extends SendMail>) Class.forName(sendMailClass);
+						m_reportingSendMail = clazz.newInstance();
+						m_log.info("load " + sendMailClass + ".");
+					} catch (Exception e) {
+						throw new HinemosUnknown(e.getMessage(), e);
+					}
+				}
+				
+				m_log.debug("m_reportingSendMail.notify");
+				sendMail = m_reportingSendMail;
+				
+			} else {
+				m_log.debug("sendMail.notify");
+				sendMail = new SendMail();
+			}
+			
 			String mailSubject = sendMail.getSubject(outputBasicInfo, null);
 			String mailBody = sendMail.getContent(outputBasicInfo, null);
 			sendMail.sendMail(address, mailSubject, mailBody);
@@ -838,7 +871,7 @@ public class NotifyControllerBean implements CheckFacility {
 
 	/**
 	 * 外部から直接通知処理を実行します。
-	 * 
+	 *
 	 * @param pluginId プラグインID
 	 * @param monitorId 監視項目ID
 	 * @param facilityId ファシリティID
@@ -965,18 +998,12 @@ public class NotifyControllerBean implements CheckFacility {
 				notify(output, confirmedNotifyIdList);
 
 				jtm.commit();
-			} catch (FacilityNotFound e) {
-				jtm.rollback();
-				throw e;
 			} catch (NotifyNotFound e) {
 				jtm.rollback();
 				throw e;
 			} catch (InvalidRole e) {
 				jtm.rollback();
 				throw e;
-			} catch (HinemosUnknown e) {
-				jtm.rollback();
-				throw new HinemosUnknown(e.getMessage(), e);
 			} catch (Exception e) {
 				m_log.warn("notify() : "
 						+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
@@ -990,11 +1017,12 @@ public class NotifyControllerBean implements CheckFacility {
 
 	/**
 	 * 外部から直接通知処理を実行します。
-	 * 
+	 *
 	 * @param notifyInfo 通知情報
 	 * @param notifyGroupId
+	 * @throws HinemosUnknown 
 	 */
-	public void notify(OutputBasicInfo notifyInfo, String notifyGroupId) {
+	public void notify(OutputBasicInfo notifyInfo, String notifyGroupId) throws HinemosUnknown {
 
 		JpaTransactionManager jtm = null;
 
@@ -1009,31 +1037,115 @@ public class NotifyControllerBean implements CheckFacility {
 
 				// 監視設定から通知IDのリストを取得する
 				List<String> notifyIdList = NotifyRelationCache.getNotifyIdList(notifyGroupId);
-
+				m_log.trace("notifyIdList.size=" + notifyIdList.size() + ", notifyGroupId=" + notifyGroupId);
 				// 該当の通知IDのリストがない場合は終了する
 				if(notifyIdList == null || notifyIdList.size() <= 0){
 					return;
 				}
 
+				//カレンダIDを取得
+				List<String> noticeList = new ArrayList<String>();
+				for (String notifyId : notifyIdList) {
+					NotifyInfo info = NotifyCache.getNotifyInfo(notifyId);
+					if (checkCalendar(info.getCalendarId())) {
+						//稼働日の場合のみ通知対象とする
+						noticeList.add(notifyId);
+					}
+				}
 				// 通知処理を行う
-				notify(notifyInfo, notifyIdList);
+				notify(notifyInfo, noticeList);
 
 				jtm.commit();
 			} catch (Exception e) {
-				m_log.warn("notify() : "
-						+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
+				m_log.warn("notify() : " + e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 				jtm.rollback();
+				
+				throw new HinemosUnknown("notify() : " + e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 			} finally {
 				jtm.close();
 			}
 		}
 	}
 
-	protected void notify(OutputBasicInfo notifyInfo, List<String> notifyIdList) {
+	private boolean checkCalendar(String calendarId) throws HinemosUnknown {
+			long now = new Date().getTime();
+
+			// 稼働日か否かチェック
+			try {
+				CalendarControllerBean calendar = new CalendarControllerBean();
+				if(!calendar.isRun(calendarId, now)){
+					// 非稼働日の場合は、処理終了
+					m_log.debug("checkCalendar() " + " calenderId = " + calendarId
+							+ ". The notice is not executed because of non-operating day.");
+					return false;
+				}
+			} catch (InvalidRole e) {
+				// 指定されたカレンダIDの参照権限がない場合は、処理終了
+				// 手動でない限りここは通らない。
+				// （ADMINISTRATORSロールのユーザ、もしくはユーザ未指定の場合はオブジェクト権限をしないため）
+				return false;
+			} catch (CalendarNotFound e) {
+				// 指定されたカレンダIDがすでに存在しない場合は、処理終了
+				return false;
+			}
+
+			return true;
+	}
+
+	protected void notify(OutputBasicInfo notifyInfo, List<String> notifyIdList) throws HinemosUnknown {
 		// 機能毎に設定されているJMSの永続化モードを取得
 		boolean persist = AsyncTaskPersistentConfig.isPersisted(notifyInfo.getPluginId());
 
 		// 通知キューへの登録処理を実行
 		NotifyDispatcher.notifyAction(notifyInfo, notifyIdList, persist);
 	}
+
+	/**
+	 * 一括通知
+	 * 前提条件：notifyInfoListの通知情報は同じ監視項目に属する。
+	 * 
+	 * @param notifyInfoList 通知情報配列
+	 * @param notifyGroupId 通知グループID
+	 */
+	public void notify(ArrayList<OutputBasicInfo> notifyInfoList,
+			String notifyGroupId) {
+
+		JpaTransactionManager jtm = null;
+		try {
+			jtm = new JpaTransactionManager();
+			jtm.begin();
+
+			// 監視設定から通知IDのリストを取得する
+			List<String> notifyIdList = NotifyRelationCache.getNotifyIdList(notifyGroupId);
+
+			// 該当の通知IDのリストがない場合は終了する
+			if(notifyIdList == null || notifyIdList.size() <= 0){
+				return;
+			}
+
+			// 通知処理を行う
+			notify(notifyInfoList, notifyIdList);
+
+			jtm.commit();
+		} catch (Exception e) {
+			m_log.warn("notify() : " + e.getClass().getSimpleName() + ", " + e.getMessage(), e);
+			jtm.rollback();
+			throw new RuntimeException("notify() : " + e.getClass().getSimpleName() + ", " + e.getMessage(), e);
+		} finally {
+			jtm.close();
+		}
+	}
+
+	private void notify(ArrayList<OutputBasicInfo> outputBasicInfoList,
+			List<String> notifyIdList) throws HinemosUnknown {
+		if (outputBasicInfoList.isEmpty()) {
+			return;
+		}
+
+		// 機能毎に設定されているJMSの永続化モードを取得
+		boolean persist = AsyncTaskPersistentConfig.isPersisted(outputBasicInfoList.get(0).getPluginId());
+
+		// 通知キューへの登録処理を実行
+		NotifyDispatcher.notifyAction(outputBasicInfoList, notifyIdList, persist);
+	}
 }
