@@ -18,12 +18,7 @@ package com.clustercontrol.notify.view;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.eclipse.jface.action.ActionContributionItem;
-import org.eclipse.jface.action.IMenuListener;
-import org.eclipse.jface.action.IMenuManager;
-import org.eclipse.jface.action.IToolBarManager;
 import org.eclipse.jface.action.MenuManager;
-import org.eclipse.jface.action.Separator;
 import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.jface.viewers.ISelectionChangedListener;
 import org.eclipse.jface.viewers.SelectionChangedEvent;
@@ -36,38 +31,40 @@ import org.eclipse.swt.widgets.Menu;
 import org.eclipse.ui.IViewPart;
 import org.eclipse.ui.IWorkbenchPage;
 import org.eclipse.ui.PlatformUI;
+import org.eclipse.ui.commands.ICommandService;
 
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.accesscontrol.util.ObjectBean;
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.Property;
 import com.clustercontrol.notify.action.GetNotifyTableDefineNoCheckBox;
 import com.clustercontrol.notify.composite.NotifyListComposite;
-import com.clustercontrol.notify.view.action.NotifyAddAction;
 import com.clustercontrol.notify.view.action.NotifyCopyAction;
 import com.clustercontrol.notify.view.action.NotifyDeleteAction;
 import com.clustercontrol.notify.view.action.NotifyDisableAction;
 import com.clustercontrol.notify.view.action.NotifyEnableAction;
 import com.clustercontrol.notify.view.action.NotifyModifyAction;
+import com.clustercontrol.notify.view.action.NotifyRefreshAction;
+import com.clustercontrol.notify.view.action.ObjectPrivilegeNotifyListAction;
 import com.clustercontrol.view.CommonViewPart;
 import com.clustercontrol.view.ObjectPrivilegeTargetListView;
-import com.clustercontrol.view.action.ObjectPrivilegeAction;
 
 /**
  * 監視[一覧]ビュークラス<BR>
- * 
- * @version 4.0.0
+ *
+ * @version 5.0.0
  * @since 4.0.0
  */
 public class NotifyListView extends CommonViewPart implements ObjectPrivilegeTargetListView {
 
 	/** 監視[一覧]ビューID */
-	public static final String ID = "com.clustercontrol.monitor.view.NotifyListView";
+	public static final String ID = NotifyListView.class.getName();
 
 	/** 監視設定一覧コンポジット */
 	private NotifyListComposite composite = null;
 
-	/** 検索条件 */
-	private Property condition = null;
+	/** 選択レコード数 */
+	private int rowNum = 0;
 
 	/**
 	 * コンストラクタ
@@ -78,7 +75,7 @@ public class NotifyListView extends CommonViewPart implements ObjectPrivilegeTar
 
 	/**
 	 * ViewPartへのコントロール作成処理<BR>
-	 * 
+	 *
 	 * @see org.eclipse.ui.IWorkbenchPart#createPartControl(org.eclipse.swt.widgets.Composite)
 	 */
 	@Override
@@ -89,6 +86,7 @@ public class NotifyListView extends CommonViewPart implements ObjectPrivilegeTar
 		layout.marginWidth = 0;
 
 		composite = new NotifyListComposite(parent, SWT.NONE, false, null);
+		WidgetTestUtil.setTestId(this, null, composite);
 		GridData gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
@@ -127,71 +125,22 @@ public class NotifyListView extends CommonViewPart implements ObjectPrivilegeTar
 
 	/**
 	 * コンテキストメニューを作成します。
-	 * 
+	 *
 	 * @see org.eclipse.jface.action.MenuManager
 	 * @see org.eclipse.swt.widgets.Menu
 	 */
 	private void createContextMenu() {
 		MenuManager menuManager = new MenuManager();
 		menuManager.setRemoveAllWhenShown(true);
-		menuManager.addMenuListener(new IMenuListener() {
-			/* (non-Javadoc)
-			 * @see org.eclipse.jface.action.IMenuListener#menuAboutToShow(org.eclipse.jface.action.IMenuManager)
-			 */
-			@Override
-			public void menuAboutToShow(IMenuManager manager) {
-				//メニュー項目設定
-				fillContextMenu(manager);
-			}
-		});
-
 		Menu menu = menuManager.createContextMenu(composite.getTable());
+		WidgetTestUtil.setTestId(this, null, menu);
 		composite.getTable().setMenu(menu);
-	}
-
-	/**
-	 * コンテキストメニューに項目を追加します。
-	 * 
-	 * @param manager メニューマネージャ
-	 * 
-	 * @see org.eclipse.jface.action.IToolBarManager
-	 * @see org.eclipse.jface.action.IMenuManager
-	 */
-	private void fillContextMenu(IMenuManager manager) {
-		//ビューのアクションのインスタンスを取得
-		IToolBarManager toolbar =
-				this.getViewSite().getActionBars().getToolBarManager();
-		ActionContributionItem notifyAdd =
-				(ActionContributionItem) toolbar.find(NotifyAddAction.ID);
-		ActionContributionItem notifyModify =
-				(ActionContributionItem) toolbar.find(NotifyModifyAction.ID);
-		ActionContributionItem notifyDelete =
-				(ActionContributionItem) toolbar.find(NotifyDeleteAction.ID);
-		ActionContributionItem notifyCopy =
-				(ActionContributionItem) toolbar.find(NotifyCopyAction.ID);
-		ActionContributionItem notifyEnable =
-				(ActionContributionItem) toolbar.find(NotifyEnableAction.ID);
-		ActionContributionItem notifyDisable =
-				(ActionContributionItem) toolbar.find(NotifyDisableAction.ID);
-		ActionContributionItem objPrivilege =
-				(ActionContributionItem) toolbar.find(ObjectPrivilegeAction.ID);
-
-		//ポップアップメニューにアクションを追加
-		manager.add(notifyAdd.getAction());
-		manager.add(notifyModify.getAction());
-		manager.add(notifyDelete.getAction());
-		manager.add(new Separator());
-		manager.add(notifyCopy.getAction());
-		manager.add(new Separator());
-		manager.add(notifyEnable.getAction());
-		manager.add(notifyDisable.getAction());
-		manager.add(new Separator());
-		manager.add(objPrivilege.getAction());
+		getSite().registerContextMenu( menuManager, this.composite.getTableViewer() );
 	}
 
 	/**
 	 * 追加コンポジットを返します。
-	 * 
+	 *
 	 * @return 追加コンポジット
 	 */
 	public Composite getListComposite() {
@@ -201,22 +150,20 @@ public class NotifyListView extends CommonViewPart implements ObjectPrivilegeTar
 	/**
 	 * 検索条件にヒットした監視設定の一覧を表示します。
 	 * <p>
-	 * 
+	 *
 	 * conditionがnullの場合、全監視設定を表示します。
-	 * 
+	 *
 	 * @param condition
 	 *            検索条件
 	 */
 	public void update(Property condition) {
-		this.condition = condition;
-
 		this.update();
 	}
 
 	/**
 	 * ビューを更新します。
 	 * <p>
-	 * 
+	 *
 	 * 検索条件が事前に設定されている場合、その条件にヒットする監視設定の一覧を 表示します <br>
 	 * 検索条件が設定されていない場合は、全監視設定を表示します。
 	 */
@@ -225,48 +172,46 @@ public class NotifyListView extends CommonViewPart implements ObjectPrivilegeTar
 		this.composite.update();
 	}
 
+	/**
+	 * 選択レコード数を返します。
+	 * @return rowNum
+	 */
+	public int getSelectedNum(){
+		return this.rowNum;
+	}
+
 	/**
 	 * ビューのアクションの有効/無効を設定します。
-	 * 
+	 *
 	 * @param num 選択イベント数
 	 * @param selection ボタン（アクション）を有効にするための情報
 	 */
 	public void setEnabledAction(int num, ISelection selection) {
+		this.rowNum = num;
+
 		//ビューアクションの使用可/不可を設定
-		super.setEnabledAction(ObjectPrivilegeAction.ID, selection);
-		super.setEnabledAction(NotifyCopyAction.ID, selection);
-		super.setEnabledAction(NotifyDeleteAction.ID, selection);
-		super.setEnabledAction(NotifyModifyAction.ID, selection);
-		super.setEnabledAction(NotifyEnableAction.ID, selection);
-		super.setEnabledAction(NotifyDisableAction.ID, selection);
+		ICommandService service = (ICommandService) PlatformUI.getWorkbench().getService( ICommandService.class );
+		if( null != service ){
+			service.refreshElements(ObjectPrivilegeNotifyListAction.ID, null);
+			service.refreshElements(NotifyCopyAction.ID, null);
+			service.refreshElements(NotifyDeleteAction.ID, null);
+			service.refreshElements(NotifyModifyAction.ID, null);
+			service.refreshElements(NotifyEnableAction.ID, null);
+			service.refreshElements(NotifyDisableAction.ID, null);
+			service.refreshElements(NotifyRefreshAction.ID, null);
+
+			// Update ToolBar after elements refreshed
+			// WARN : Both ToolBarManager must be updated after updateActionBars(), otherwise icon won't change.
+			getViewSite().getActionBars().updateActionBars();
+			getViewSite().getActionBars().getToolBarManager().update(false);
 
-		if (num > 0){
-			super.setEnabledAction(NotifyEnableAction.ID, true);
-			super.setEnabledAction(NotifyDisableAction.ID, true);
-			super.setEnabledAction(ObjectPrivilegeAction.ID, true);
-			if(num == 1){
-				super.setEnabledAction(NotifyCopyAction.ID, true);
-				super.setEnabledAction(NotifyDeleteAction.ID, true);
-				super.setEnabledAction(NotifyModifyAction.ID, true);
-			}else{
-				super.setEnabledAction(NotifyCopyAction.ID, false);
-				super.setEnabledAction(NotifyDeleteAction.ID, false);
-				super.setEnabledAction(NotifyModifyAction.ID, false);
-			}
-		} else {
-			super.setEnabledAction(ObjectPrivilegeAction.ID, false);
-			super.setEnabledAction(NotifyCopyAction.ID, false);
-			super.setEnabledAction(NotifyDeleteAction.ID, false);
-			super.setEnabledAction(NotifyModifyAction.ID, false);
-			super.setEnabledAction(NotifyEnableAction.ID, false);
-			super.setEnabledAction(NotifyDisableAction.ID, false);
 		}
 	}
 
 	public String getSelectedId() {
 		StructuredSelection selection = (StructuredSelection) this.composite.getTableViewer().getSelection();
 
-		List list = (List) selection.getFirstElement();
+		List<?> list = (List<?>) selection.getFirstElement();
 		String id = null;
 		if (list != null) {
 			id = (String) list.get(GetNotifyTableDefineNoCheckBox.NOTIFY_ID);
@@ -279,12 +224,14 @@ public class NotifyListView extends CommonViewPart implements ObjectPrivilegeTar
 		StructuredSelection selection = (StructuredSelection) this.composite.getTableViewer().getSelection();
 		Object [] objs = selection.toArray();
 
+		String managerName = null;
 		String objectType = HinemosModuleConstant.PLATFORM_NOTIFY;
 		String objectId = null;
 		List<ObjectBean> objectBeans = new ArrayList<ObjectBean>();
 		for (Object obj : objs) {
-			objectId = (String) ((List)obj).get(GetNotifyTableDefineNoCheckBox.NOTIFY_ID);
-			ObjectBean objectBean = new ObjectBean(objectType, objectId);
+			objectId = (String) ((List<?>)obj).get(GetNotifyTableDefineNoCheckBox.NOTIFY_ID);
+			managerName = (String) ((List<?>)obj).get(GetNotifyTableDefineNoCheckBox.MANAGER_NAME);
+			ObjectBean objectBean = new ObjectBean(managerName, objectType, objectId);
 			objectBeans.add(objectBean);
 		}
 		return objectBeans;
@@ -294,7 +241,7 @@ public class NotifyListView extends CommonViewPart implements ObjectPrivilegeTar
 	public String getSelectedOwnerRoleId() {
 		StructuredSelection selection = (StructuredSelection) this.composite.getTableViewer().getSelection();
 
-		List list = (List) selection.getFirstElement();
+		List<?> list = (List<?>) selection.getFirstElement();
 		String id = null;
 		if (list != null) {
 			id = (String) list.get(GetNotifyTableDefineNoCheckBox.OWNER_ROLE);
