@@ -16,6 +16,7 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.performance.composite;
 
 import java.awt.Color;
+import java.awt.Rectangle;
 import java.text.DateFormat;
 import java.text.SimpleDateFormat;
 import java.util.ArrayList;
@@ -30,10 +31,13 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.swt.SWT;
+import org.eclipse.swt.browser.Browser;
 import org.eclipse.swt.events.ModifyEvent;
 import org.eclipse.swt.events.ModifyListener;
 import org.eclipse.swt.events.SelectionAdapter;
 import org.eclipse.swt.events.SelectionEvent;
+import org.eclipse.swt.graphics.Point;
+import org.eclipse.swt.layout.FillLayout;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.widgets.Button;
@@ -43,41 +47,45 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.ui.IViewReference;
 import org.eclipse.ui.IWorkbenchPage;
 import org.eclipse.ui.PlatformUI;
+import org.jfree.chart.ChartColor;
 import org.jfree.chart.ChartFactory;
 import org.jfree.chart.JFreeChart;
 import org.jfree.chart.StandardChartTheme;
 import org.jfree.chart.axis.DateAxis;
 import org.jfree.chart.axis.NumberAxis;
 import org.jfree.chart.axis.ValueAxis;
-import org.jfree.chart.renderer.xy.StandardXYItemRenderer;
 import org.jfree.chart.renderer.xy.XYAreaRenderer;
 import org.jfree.chart.renderer.xy.XYItemRenderer;
+import org.jfree.chart.renderer.xy.XYLineAndShapeRenderer;
 import org.jfree.data.time.Second;
 import org.jfree.data.time.TimeSeries;
 import org.jfree.data.time.TimeSeriesCollection;
 import org.jfree.experimental.chart.swt.ChartComposite;
+import org.jfree.graphics2d.svg.SVGGraphics2D;
 
+import com.clustercontrol.ClusterControlPlugin;
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.monitor.util.PerformanceDataSettingsUtil;
 import com.clustercontrol.performance.action.RecordController;
-import com.clustercontrol.performance.bean.CollectedDataErrorTypeConstant;
 import com.clustercontrol.performance.bean.GraphConstant;
+import com.clustercontrol.performance.preference.PerformancePreferencePage;
 import com.clustercontrol.performance.util.CollectedDataSetUtil;
 import com.clustercontrol.performance.util.CollectorItemCodeFactory;
 import com.clustercontrol.performance.view.PerformanceGraphView;
 import com.clustercontrol.repository.bean.FacilityConstant;
 import com.clustercontrol.util.Messages;
-import com.clustercontrol.ws.collector.CollectedDataSet;
 import com.clustercontrol.ws.collector.CollectedDataInfo;
+import com.clustercontrol.ws.collector.CollectedDataSet;
 import com.clustercontrol.ws.collector.CollectorItemInfo;
 import com.clustercontrol.ws.collector.CollectorItemParentInfo;
 import com.clustercontrol.ws.collector.PerformanceDataSettings;
 import com.clustercontrol.ws.repository.FacilityTreeItem;
+import com.clustercontrol.util.WidgetTestUtil;
 
 /**
  * 性能グラフを表示するコンポジットクラス<BR>
- * 
- * @version 4.0.0
+ *
+ * @version 5.0.0
  * @since 4.0.0
  */
 public class PerformanceGraphComposite extends Composite {
@@ -160,69 +168,46 @@ public class PerformanceGraphComposite extends Composite {
 
 	// グラフ描画用
 	private ChartComposite chartComposite = null;
+	private Browser chartBrowser = null;
 	private JFreeChart jfreeChart = null;
 	private TimeSeriesCollection timeSeriesCollection = null;
 	private TimeSeries[] timeSeries = null;
-	private int GRAPH_MAX = 0; // default
 
-	// 初期化の設定
-	private Composite parent = null;
-	private int style = 0;
+	private String managerName = null;
 
 	// レンダラと色を選択
-	private Color[] color = {
-			Color.RED, Color.BLUE, Color.GREEN, Color.ORANGE, Color.CYAN,
-			Color.MAGENTA, Color.YELLOW, Color.PINK,Color.GRAY, Color.BLACK,
-			Color.LIGHT_GRAY, Color.DARK_GRAY,
-			Color.WHITE };
+	private static Color[] color = {
+			Color.RED, Color.BLUE, Color.GREEN, Color.ORANGE, Color.CYAN, Color.MAGENTA, Color.DARK_GRAY, 
+			ChartColor.DARK_RED, ChartColor.DARK_BLUE, ChartColor.DARK_GREEN, ChartColor.VERY_DARK_YELLOW, ChartColor.DARK_CYAN, ChartColor.DARK_MAGENTA };
 
 	/**
 	 * コンストラクタ
-	 * 
+	 *
 	 * @param settings グラフのヘッダ情報
 	 * @param parent 親のコンポジット
 	 * @param style スタイル
 	 */
-	public PerformanceGraphComposite(PerformanceDataSettings settings, Composite parent, int style) {
+	public PerformanceGraphComposite(String managerName, PerformanceDataSettings settings, Composite parent, int style) {
 		super(parent, style);
-		this.parent = parent;
-		this.style = style;
+		this.managerName = managerName;
 
-		// グラフ本数
-		GRAPH_MAX = PerformanceGraphView.GRAPH_MAX;
 		// ヘッダ情報の設定
 		setPerformanceDataSettings(settings);
+
 		// 初期化
-		initialize(this.parent, this.style);
+		initialize();
 	}
 
-	/**
-	 * グラフコンポジットのウィジェットの構成初期化
-	 * 
-	 * @param parent
-	 * @param style
-	 */
-	private void initialize(Composite parent, int style) {
-
-		timeSeriesCollection = new TimeSeriesCollection();
-		// ここでサブスコープグラフ表示用にSeriesを10個準備します
-		timeSeries = new TimeSeries[GRAPH_MAX];
-		for (int i = 0; i < timeSeries.length; i++) {
-			timeSeries[i] = new TimeSeries("");
-		}
-		GridData gridData = null;
-
-		// View用のレイアウト(グリッド数=15)
-		GridLayout viewLayout = new GridLayout(13, true);
-		viewLayout.marginHeight = 0;
-		viewLayout.marginWidth = 0;
-		this.setLayout(viewLayout);
+	private void createButtonBar(Composite parent){
+		parent.setLayout( new GridLayout(13, true) );
+		GridData gridData;
 
 		//////
 		// 1行目
 		//////
 		// 1行目左：表示種別ラベル
-		Label displayTypeLabel = new Label(this, SWT.CENTER);
+		Label displayTypeLabel = new Label(parent, SWT.CENTER);
+		WidgetTestUtil.setTestId(this, "displaytype", displayTypeLabel);
 		displayTypeLabel.setText(Messages.getString("collection.label.display.type") + " : ");
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
@@ -232,7 +217,8 @@ public class PerformanceGraphComposite extends Composite {
 		displayTypeLabel.setLayoutData(gridData);
 
 		// 1行目左：表示種別(プルダウン)
-		this.displayTypeCombo = new Combo(this, SWT.DROP_DOWN | SWT.READ_ONLY);
+		this.displayTypeCombo = new Combo(parent, SWT.DROP_DOWN | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, "displaycombo", displayTypeCombo);
 		gridData = new GridData();
 		gridData.horizontalSpan = 4;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -244,10 +230,10 @@ public class PerformanceGraphComposite extends Composite {
 		this.displayTypeCombo.add(STRING_DISPLAY_DEVICE);
 		this.displayTypeCombo.select(INDEX_DISPLAY_NODE);//default
 		this.displayTypeCombo.addModifyListener(new ModifyListener() {
-
 			@Override
 			public void modifyText(ModifyEvent e) {
 				Combo combo = (Combo)e.widget;
+
 				String selectedDisplayType = combo.getText();
 				m_log.debug("displayTypeCombo : select " + selectedDisplayType);
 
@@ -280,7 +266,8 @@ public class PerformanceGraphComposite extends Composite {
 		});
 
 		// 1行目中央：グラフ種別ラベル
-		Label graphTypeLabel = new Label(this, SWT.CENTER);
+		Label graphTypeLabel = new Label(parent, SWT.CENTER);
+		WidgetTestUtil.setTestId(this, "graphtype", graphTypeLabel);
 		graphTypeLabel.setText(Messages.getString("collection.label.graph.type") + " : ");
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
@@ -290,7 +277,8 @@ public class PerformanceGraphComposite extends Composite {
 		graphTypeLabel.setLayoutData(gridData);
 
 		// 1行目中央：グラフ種別(プルダウン)
-		this.graphTypeCombo = new Combo(this, SWT.DROP_DOWN | SWT.READ_ONLY);
+		this.graphTypeCombo = new Combo(parent, SWT.DROP_DOWN | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, "graphtype", graphTypeCombo);
 		gridData = new GridData();
 		gridData.horizontalSpan = 4;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -302,7 +290,8 @@ public class PerformanceGraphComposite extends Composite {
 		this.graphTypeCombo.select(INDEX_GRAPH_LINE);//default
 
 		// 1行目右：スペース
-		Label space1 = new Label(this, SWT.CENTER);
+		Label space1 = new Label(parent, SWT.CENTER);
+		WidgetTestUtil.setTestId(this, "space1", space1);
 		space1.setText("");
 		gridData = new GridData();
 		gridData.horizontalSpan = 1;
@@ -315,7 +304,8 @@ public class PerformanceGraphComposite extends Composite {
 		// 2行目
 		//////
 		// 2行目左：表示項目ラベル
-		Label displayItemLabel = new Label(this, SWT.CENTER);
+		Label displayItemLabel = new Label(parent, SWT.CENTER);
+		WidgetTestUtil.setTestId(this, "labelitem", displayItemLabel);
 		displayItemLabel.setText(Messages.getString("collection.label.item") + " : ");
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
@@ -325,7 +315,8 @@ public class PerformanceGraphComposite extends Composite {
 		displayItemLabel.setLayoutData(gridData);
 
 		// 2行目左：表示項目(プルダウン)
-		this.displayItem = new Combo(this, SWT.DROP_DOWN | SWT.READ_ONLY);
+		this.displayItem = new Combo(parent, SWT.DROP_DOWN | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, "displayitem", displayItem);
 		gridData = new GridData();
 		gridData.horizontalSpan = 4;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -334,14 +325,13 @@ public class PerformanceGraphComposite extends Composite {
 		this.displayItem.setLayoutData(gridData);
 		this.displayItem.removeAll();
 		for (CollectorItemParentInfo itemCodeInfo : this.performanceDataSettings.getItemCodeList()){
-
-			this.displayItem.add(
-					getFullItemName(itemCodeInfo));
+			this.displayItem.add(getFullItemName(itemCodeInfo));
 		}
 		this.displayItem.select(0);//default
 
 		// 2行目中央：表示項目ラベル
-		Label updateLabel = new Label(this, SWT.CENTER);
+		Label updateLabel = new Label(parent, SWT.CENTER);
+		WidgetTestUtil.setTestId(this, "update", updateLabel);
 		updateLabel.setText(Messages.getString("collection.label.update") + " : ");
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
@@ -351,7 +341,8 @@ public class PerformanceGraphComposite extends Composite {
 		updateLabel.setLayoutData(gridData);
 
 		// 2行目中央：自動更新有無(チェックボックス)
-		this.autoUpdate = new Button(this, SWT.CHECK);
+		this.autoUpdate = new Button(parent, SWT.CHECK);
+		WidgetTestUtil.setTestId(this, "autoupdate", autoUpdate);
 		this.autoUpdate.setText(Messages.getString("collection.label.auto.update"));
 		gridData = new GridData();
 		gridData.horizontalSpan = 4;
@@ -406,7 +397,8 @@ public class PerformanceGraphComposite extends Composite {
 
 
 		// 2行目右：更新ボタン
-		this.updateButton = new Button(this, SWT.CENTER);
+		this.updateButton = new Button(parent, SWT.CENTER);
+		WidgetTestUtil.setTestId(this, "update", updateButton);
 		this.updateButton.setText(Messages.getString("collection.button.apply"));
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
@@ -417,6 +409,8 @@ public class PerformanceGraphComposite extends Composite {
 		this.updateButton.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
+				long start = System.currentTimeMillis();
+
 				// target変数の更新
 				int graphType = 0;
 				int displayType = 0;
@@ -429,11 +423,9 @@ public class PerformanceGraphComposite extends Composite {
 				case INDEX_GRAPH_LINE:
 					graphType = GraphConstant.GRAPH_LINE;
 					break;
-
 				case INDEX_GRAPH_STACK:
 					graphType = GraphConstant.GRAPH_STACK;
 					break;
-
 				default:
 					graphType = GraphConstant.GRAPH_LINE;//default
 					break;
@@ -471,31 +463,25 @@ public class PerformanceGraphComposite extends Composite {
 					break;
 				}
 
-
 				// グラフ再描画
-				updateGraph(graphType, displayType, itemCodeInfo);
+				updateGraph(managerName, graphType, displayType, itemCodeInfo);
+
+				m_log.debug(String.format("updateButton SelectionEvent: %dms", System.currentTimeMillis() - start));
 			}
 		});
-
 		//////
 		// 3行目
 		//////
 		// 3行目：グラフ
-		this.chartComposite = new ChartComposite(this, SWT.NONE, jfreeChart, true);
-		gridData = new GridData();
-		gridData.horizontalSpan = 13;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.verticalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		gridData.grabExcessVerticalSpace = true;
-		this.chartComposite.setLayoutData(gridData);
 
 		//////
 		// 4行目
 		//////
 		// 4行目左：表示期間を過去へ
+		// 4行目左：表示期間を過去へ
 		// 前の期間へ(4行目)
-		this.firstButton = new Button(this, SWT.CENTER);
+		this.firstButton = new Button(parent, SWT.CENTER);
+		WidgetTestUtil.setTestId(this, "first", firstButton);
 		this.firstButton.setText(STRING_ACTION_OLDEST);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
@@ -513,7 +499,8 @@ public class PerformanceGraphComposite extends Composite {
 		});
 
 		// 4行目左：表示期間を過去へ
-		this.backButton = new Button(this, SWT.CENTER);
+		this.backButton = new Button(parent, SWT.CENTER);
+		WidgetTestUtil.setTestId(this, "back", backButton);
 		this.backButton.setText(STRING_ACTION_PREV);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
@@ -531,7 +518,8 @@ public class PerformanceGraphComposite extends Composite {
 		});
 
 		// スペース
-		Label space4 = new Label(this, SWT.CENTER);
+		Label space4 = new Label(parent, SWT.CENTER);
+		WidgetTestUtil.setTestId(this, "space4", space4);
 		space4.setText("");
 		gridData = new GridData();
 		gridData.horizontalSpan = 1;
@@ -541,7 +529,8 @@ public class PerformanceGraphComposite extends Composite {
 		space4.setLayoutData(gridData);
 
 		// 4行目中央：表示期間ラベル
-		Label spanLabel = new Label(this, SWT.CENTER);
+		Label spanLabel = new Label(parent, SWT.CENTER);
+		WidgetTestUtil.setTestId(this, "spanlabel", spanLabel);
 		spanLabel.setText(Messages.getString("collection.label.span") + " : ");
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
@@ -551,7 +540,8 @@ public class PerformanceGraphComposite extends Composite {
 		spanLabel.setLayoutData(gridData);
 
 		// 4行目中央：表示期間「時」
-		this.hourButton = new Button(this, SWT.TOGGLE);
+		this.hourButton = new Button(parent, SWT.TOGGLE);
+		WidgetTestUtil.setTestId(this, "hour", hourButton);
 		this.hourButton.setText(STRING_TIME_HOUR);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
@@ -575,7 +565,8 @@ public class PerformanceGraphComposite extends Composite {
 		this.hourButton.setSelection(true);
 
 		// 4行目中央：表示期間「日」
-		this.dayButton = new Button(this, SWT.TOGGLE);
+		this.dayButton = new Button(parent, SWT.TOGGLE);
+		WidgetTestUtil.setTestId(this, "day", dayButton);
 		this.dayButton.setText(STRING_TIME_DAY);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
@@ -598,7 +589,8 @@ public class PerformanceGraphComposite extends Composite {
 		});
 
 		// 4行目中央：表示期間「週」
-		this.weekButton = new Button(this, SWT.TOGGLE);
+		this.weekButton = new Button(parent, SWT.TOGGLE);
+		WidgetTestUtil.setTestId(this, "week", weekButton);
 		this.weekButton.setText(STRING_TIME_WEEK);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
@@ -621,7 +613,8 @@ public class PerformanceGraphComposite extends Composite {
 		});
 
 		// 4行目中央：表示期間「月」
-		this.monthButton = new Button(this, SWT.TOGGLE);
+		this.monthButton = new Button(parent, SWT.TOGGLE);
+		WidgetTestUtil.setTestId(this, "month", monthButton);
 		this.monthButton.setText(STRING_TIME_MONTH);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
@@ -644,7 +637,8 @@ public class PerformanceGraphComposite extends Composite {
 		});
 
 		// スペース
-		Label space5 = new Label(this, SWT.CENTER);
+		Label space5 = new Label(parent, SWT.CENTER);
+		WidgetTestUtil.setTestId(this, "space5", space5);
 		space5.setText("");
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
@@ -654,7 +648,8 @@ public class PerformanceGraphComposite extends Composite {
 		space5.setLayoutData(gridData);
 
 		// 4行目右：表示期間を未来へ
-		this.forwardButton = new Button(this, SWT.CENTER);
+		this.forwardButton = new Button(parent, SWT.CENTER);
+		WidgetTestUtil.setTestId(this, "forward", forwardButton);
 		this.forwardButton.setText(STRING_ACTION_NEXT);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
@@ -672,7 +667,8 @@ public class PerformanceGraphComposite extends Composite {
 		});
 
 		// 4行目右：表示期間を未来へ
-		this.lastButton = new Button(this, SWT.CENTER);
+		this.lastButton = new Button(parent, SWT.CENTER);
+		WidgetTestUtil.setTestId(this, "last", lastButton);
 		this.lastButton.setText(STRING_ACTION_NEWEST);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
@@ -688,6 +684,53 @@ public class PerformanceGraphComposite extends Composite {
 				updateByRangeAction(ACTION_NEWEST);
 			}
 		});
+	}
+
+	/**
+	 * グラフコンポジットのウィジェットの構成初期化
+	 *
+	 * @param parent
+	 * @param style
+	 */
+	private void initialize() {
+		timeSeriesCollection = new TimeSeriesCollection();
+		// ここでサブスコープグラフ表示用にSeriesを10個準備します
+
+		// グラフ本数
+		int lineNumMax = ClusterControlPlugin.getDefault().getPreferenceStore().getInt(PerformancePreferencePage.P_GRAPH_MAX);
+		timeSeries = new TimeSeries[lineNumMax];
+		for (int i = 0; i < timeSeries.length; i++) {
+			timeSeries[i] = new TimeSeries("");
+		}
+
+		GridLayout layout = new GridLayout();
+		layout.marginWidth = 0;
+		layout.marginHeight = 0;
+		layout.horizontalSpacing = 0;
+		layout.verticalSpacing = 0;
+		this.setLayout( layout );
+
+		// Button bar
+		Composite buttonBar = new Composite( this, SWT.NONE );
+		WidgetTestUtil.setTestId(this, "button", buttonBar);
+		buttonBar.setLayoutData( new GridData( GridData.CENTER, GridData.BEGINNING, false, false ) );
+		createButtonBar(buttonBar);
+
+		// Graph Composite
+		// TODO Encapsulate the following chart generator
+		// Choose chart generator according to platform
+		Composite chartBox = new Composite( this, SWT.NONE );
+		WidgetTestUtil.setTestId(this, "chart", chartBox);
+		chartBox.setLayoutData( new GridData( GridData.FILL_BOTH ) );
+		chartBox.setLayout( new FillLayout() );
+
+		if( ClusterControlPlugin.isRAP() ){
+			this.chartBrowser = new Browser(chartBox, SWT.NONE );
+			WidgetTestUtil.setTestId(this, "chart", chartBrowser);
+		}else{
+			this.chartComposite = new ChartComposite(chartBox, SWT.NONE, jfreeChart, true);
+			WidgetTestUtil.setTestId(this, "chart", chartComposite);
+		}
 
 		// 初回表示時は、必ずView.doSelectTreeItem()が呼ばれるため、この処理の最後でグラフは作成しない
 	}
@@ -698,19 +741,26 @@ public class PerformanceGraphComposite extends Composite {
 	 * @return
 	 */
 	private String getFullItemName(CollectorItemParentInfo info){
+		String str = "";
 		if(info.getDisplayName() != null && !"".equals(info.getDisplayName())){
-			return PerformanceDataSettingsUtil.getItemName(this.performanceDataSettings,
+			str = PerformanceDataSettingsUtil.getItemName(this.performanceDataSettings,
 					info.getItemCode()) + "[" + info.getDisplayName() + "]";
 		}
 		else{
-			return PerformanceDataSettingsUtil.getItemName(this.performanceDataSettings,
+			str = PerformanceDataSettingsUtil.getItemName(this.performanceDataSettings,
 					info.getItemCode());
 		}
+		int maxStr = 30;
+		if (maxStr < str.length()) {
+			str = str.substring(0, maxStr);
+			str += "...";
+		}
+		return str;
 	}
 
 	/**
 	 * グラフのヘッダ情報(ファシリティツリー、収集ID、デバイス、などの情報)をビューに設定する
-	 * 
+	 *
 	 * @param info グラフのヘッダ情報
 	 */
 	private void setPerformanceDataSettings(PerformanceDataSettings info) {
@@ -767,18 +817,20 @@ public class PerformanceGraphComposite extends Composite {
 				targetItemCodeInfo.getDisplayName())){
 
 			this.targetFacilityTreeItem = item;
+
 			updateGraph();
 		}
 	}
 
 	/**
 	 * 更新ボタンを押下した際に呼ばれるメソッド
-	 * 
+	 *
+	 * @param managerName マネージャ名
 	 * @param graphType グラフ種別
 	 * @param displayType 表示種別
 	 * @param itemCodeInfo 収集項目ID
 	 */
-	private void updateGraph(int graphType, int displayType, CollectorItemParentInfo itemCodeInfo){
+	private void updateGraph(String managerName, int graphType, int displayType, CollectorItemParentInfo itemCodeInfo){
 		m_log.debug("updateGrap() graphType = " + graphType +
 				", displayType = " + displayType +
 				", itemCode = " + itemCodeInfo.getItemCode() +
@@ -818,34 +870,42 @@ public class PerformanceGraphComposite extends Composite {
 		ChartFactory.setChartTheme(StandardChartTheme.createLegacyTheme());
 		jfreeChart =
 				ChartFactory.createTimeSeriesChart("", // タイトルはここで未設定
-						com.clustercontrol.performance.util.Messages.getString("TIME"),
+						Messages.getString("timestamp"),
 						performanceDataSettings.getMeasure(),
 						timeSeriesCollection,
 						true, true, false);
-		chartComposite.setChart(jfreeChart);
+
+		// Show chart directly if in RAP
+		if( ! ClusterControlPlugin.isRAP() ){
+			chartComposite.setChart(jfreeChart);
+		}
 
 		////
 		// Renderer/Color Settings(積み上げ、折れ線)
-		////
-		XYItemRenderer renderer = null;
+		int lineNumMax = ClusterControlPlugin.getDefault().getPreferenceStore().getInt(PerformancePreferencePage.P_GRAPH_MAX);
+
 		switch (targetGraphType) {
 		case GraphConstant.GRAPH_LINE:
-			renderer = new StandardXYItemRenderer();
-			for (int i = 0; i < GRAPH_MAX; i++) {
-				renderer.setSeriesPaint(i, color[i%color.length]);
+			XYItemRenderer simplerenderer = jfreeChart.getXYPlot().getRenderer();
+			if( simplerenderer instanceof XYLineAndShapeRenderer ){
+				XYLineAndShapeRenderer renderer = (XYLineAndShapeRenderer)simplerenderer;
+				renderer.setBaseShapesVisible( false );
+				renderer.setDrawSeriesLineAsPath( true );
+				// set the default stroke for all series
+				renderer.setAutoPopulateSeriesStroke(false);
 			}
-			jfreeChart.getXYPlot().setRenderer(renderer);
+			for (int i = 0; i < lineNumMax; i++) {
+				simplerenderer.setSeriesPaint(i, color[i%color.length]);
+			}
+			//jfreeChart.getXYPlot().setRenderer(renderer);
 			break;
-
 		case GraphConstant.GRAPH_STACK:
-			renderer = new XYAreaRenderer();
-			for (int i = 0; i < GRAPH_MAX; i++) {
+			XYItemRenderer renderer = new XYAreaRenderer();
+			for (int i = 0; i < lineNumMax; i++) {
 				renderer.setSeriesPaint(i, color[i%color.length]);
 			}
 			jfreeChart.getXYPlot().setRenderer(renderer);
-
 			break;
-
 		default:
 			m_log.warn("updateGraph() targetGraphType is not defined. targetGraphType = " + targetGraphType);
 			break;
@@ -857,6 +917,7 @@ public class PerformanceGraphComposite extends Composite {
 		if((HinemosModuleConstant.MONITOR_PERFORMANCE).equals(performanceDataSettings.getMonitorTypeId())){
 			boolean rangeFixed =
 					CollectorItemCodeFactory.isRangeFixed(
+							managerName,
 							performanceDataSettings.getTargetItemCode(),
 							targetGraphType);
 
@@ -885,7 +946,7 @@ public class PerformanceGraphComposite extends Composite {
 		case FacilityConstant.TYPE_SCOPE:
 			// 指定したスコープ配下に含まれる全てのノードを対象
 			targetConditionFacilityIdList.clear();
-			setTargetNodeFacilityId(targetFacilityTreeItem, targetConditionFacilityIdList);
+			setTargetNodeFacilityId(targetFacilityTreeItem, targetConditionFacilityIdList, lineNumMax);
 
 			break;
 		}
@@ -938,7 +999,6 @@ public class PerformanceGraphComposite extends Composite {
 			}
 
 			break;
-
 		}
 
 		updateGraphRange();
@@ -946,15 +1006,15 @@ public class PerformanceGraphComposite extends Composite {
 
 	/**
 	 * FacilityTreeItemに所属する全てのノード(スコープではない)のファシリティIDをArrayListに設定する
-	 * 
+	 *
 	 * @param item
 	 * @param facilityIdList
 	 */
-	private void setTargetNodeFacilityId(FacilityTreeItem treeItem, ArrayList<String> facilityIdList){
+	private void setTargetNodeFacilityId(FacilityTreeItem treeItem, ArrayList<String> facilityIdList, int lineNumMax){
 		m_log.debug("setTargetNodeFacilityId() treeItem = " + treeItem.getData().getFacilityId());
-		if(facilityIdList != null && facilityIdList.size() >= GRAPH_MAX){
-			m_log.info("setTargetNodeFacilityId() target facilityId is over GRAPH_MAX = " + GRAPH_MAX);
-			String[] args = { Integer.toString(GRAPH_MAX) };
+		if(facilityIdList != null && facilityIdList.size() >= lineNumMax){
+			m_log.info("setTargetNodeFacilityId() target facilityId is over GRAPH_MAX = " + lineNumMax);
+			String[] args = { Integer.toString(lineNumMax) };
 			MessageDialog.openInformation(null, Messages.getString("message"),
 					Messages.getString("message.performance.2", args));
 			return;
@@ -966,9 +1026,9 @@ public class PerformanceGraphComposite extends Composite {
 			FacilityTreeItem item = children.get(i);
 			switch (item.getData().getFacilityType()) {
 			case FacilityConstant.TYPE_NODE:
-				if(facilityIdList != null && facilityIdList.size() >= GRAPH_MAX){
-					m_log.info("setTargetNodeFacilityId() target facilityId is over GRAPH_MAX = " + GRAPH_MAX);
-					String[] args = { Integer.toString(GRAPH_MAX) };
+				if(facilityIdList != null && facilityIdList.size() >= lineNumMax){
+					m_log.info("setTargetNodeFacilityId() target facilityId is over GRAPH_MAX = " + lineNumMax);
+					String[] args = { Integer.toString(lineNumMax) };
 					MessageDialog.openInformation(null, Messages.getString("message"),
 							Messages.getString("message.performance.2", args));
 					return;
@@ -977,7 +1037,7 @@ public class PerformanceGraphComposite extends Composite {
 				break;
 
 			case FacilityConstant.TYPE_SCOPE:
-				setTargetNodeFacilityId(item, facilityIdList);
+				setTargetNodeFacilityId(item, facilityIdList, lineNumMax);
 				break;
 
 			default:
@@ -988,10 +1048,12 @@ public class PerformanceGraphComposite extends Composite {
 
 	/**
 	 * グラフの表示範囲の更新(時、日、週、月、の範囲変更)
-	 * 
+	 *
 	 * @param range
 	 */
 	private void updateGraphRange(int range){
+		long start = System.currentTimeMillis();
+
 		m_log.debug("updateGraphRange() range = " + range);
 		// NULL CHECK
 		if(targetConditionStartDate == null || targetConditionEndDate == null){
@@ -1005,11 +1067,13 @@ public class PerformanceGraphComposite extends Composite {
 		setTargetTimePeriod(range, targetConditionStartDate);
 
 		updateGraphRange();
+
+		m_log.debug(String.format("updateGraphRange: %dms", System.currentTimeMillis() - start));
 	}
 
 	/**
 	 * X軸の単位形式を設定する
-	 * 
+	 *
 	 * @param range
 	 */
 	private void setRanePlotFormat(){
@@ -1041,7 +1105,7 @@ public class PerformanceGraphComposite extends Composite {
 
 	/**
 	 * targetDateの時刻を含むrangeの期間の最初(tartDate)と最後(endDate)を設定する
-	 * 
+	 *
 	 * @param range
 	 * @param targetDate
 	 */
@@ -1097,10 +1161,11 @@ public class PerformanceGraphComposite extends Composite {
 
 	/**
 	 * グラフの表示範囲の更新(次へ、前へ、等ボタン押下)
-	 * 
+	 *
 	 * @param action
 	 */
 	private void updateByRangeAction(int action){
+		long start = System.currentTimeMillis();
 		m_log.debug("updateByRangeAction() action = " + action);
 		// NULL CHECK
 		if(targetConditionStartDate == null || targetConditionEndDate == null){
@@ -1115,32 +1180,26 @@ public class PerformanceGraphComposite extends Composite {
 		switch (action) {
 		case ACTION_OLDEST:
 			setTargetTimePeriod(targetRange, new Date(this.performanceDataSettings.getOldestDate()));
-
 			break;
-
 		case ACTION_PREV:
 			distance = targetConditionEndDate.getTime() - targetConditionStartDate.getTime();
 			targetConditionEndDate = targetConditionStartDate;
 			targetConditionStartDate = new Date(targetConditionStartDate.getTime() - distance);
 			break;
-
 		case ACTION_NEXT:
 			distance = targetConditionEndDate.getTime() - targetConditionStartDate.getTime();
 			targetConditionStartDate = targetConditionEndDate;
 			targetConditionEndDate = new Date(targetConditionEndDate.getTime() + distance);
-
 			break;
-
 		case ACTION_NEWEST:
 			setTargetTimePeriod(targetRange, new Date(this.performanceDataSettings.getLatestDate()));
-
 			break;
-
 		default:
 			break;
 		}
 
 		updateGraphRange();
+		m_log.debug(String.format("updateByRangeAction: %dms", System.currentTimeMillis() - start));
 	}
 
 	/**
@@ -1162,12 +1221,9 @@ public class PerformanceGraphComposite extends Composite {
 		updateGraphData();
 	}
 
-
-
-
 	/**
 	 * グラフデータの更新(ビュー更新時はこのメソッドを呼ぶ)
-	 * 
+	 *
 	 */
 	private void updateGraphData(){
 		m_log.debug("updateGraphData()");
@@ -1181,6 +1237,7 @@ public class PerformanceGraphComposite extends Composite {
 		////
 		CollectedDataSet dataSet =
 				new RecordController().getRecordCollectedData(
+						this.managerName,
 						targetConditionFacilityIdList,
 						targetConditionItemList,
 						targetConditionStartDate,
@@ -1199,9 +1256,10 @@ public class PerformanceGraphComposite extends Composite {
 		////
 
 		// 表示されているものを削除
+		int lineNumMax = ClusterControlPlugin.getDefault().getPreferenceStore().getInt(PerformancePreferencePage.P_GRAPH_MAX);
 		//TODO 更新時は差分のみ追加する
 		timeSeriesCollection.removeAllSeries();
-		timeSeries = new TimeSeries[GRAPH_MAX];
+		timeSeries = new TimeSeries[lineNumMax];
 		for (int i = 0; i < timeSeries.length; i++) {
 			timeSeries[i] = new TimeSeries("");
 		}
@@ -1211,8 +1269,8 @@ public class PerformanceGraphComposite extends Composite {
 		List<CollectedDataInfo> collectedDataListTotal = null;
 		outside: for (String facilityId : targetConditionFacilityIdList) {
 			for (CollectorItemInfo itemInfo : targetConditionItemList){
-				if(dataIndex == GRAPH_MAX){
-					String[] args = { Integer.toString(GRAPH_MAX) };
+				if(dataIndex == lineNumMax){
+					String[] args = { Integer.toString(lineNumMax) };
 					MessageDialog.openInformation(null, Messages.getString("message"),
 							Messages.getString("message.performance.2", args));
 					break outside;
@@ -1249,11 +1307,24 @@ public class PerformanceGraphComposite extends Composite {
 		// タイトルに時刻を表示
 		String title = getGraphTitle();
 		this.jfreeChart.setTitle(title);
+
+		// Draw SVG after data updated
+		if( ClusterControlPlugin.isRAP() ){
+			// Reload or Redraw
+			Point size = chartBrowser.getSize();
+			if( 0 != size.x ){
+				SVGGraphics2D g2d = new SVGGraphics2D(size.x, size.y);
+				g2d.setRenderingHint(JFreeChart.KEY_SUPPRESS_SHADOW_GENERATION, true);
+				Rectangle r = new Rectangle(0, 0, size.x, size.y);
+				jfreeChart.draw(g2d, r);
+				chartBrowser.setText( g2d.getSVGDocument() );
+			}
+		}
 	}
 
 	/**
 	 * 表示種別(ノード別、収集項目別、デバイス別)の各々で示す凡例を返却する
-	 * 
+	 *
 	 * @param itemInfo
 	 * @return
 	 */
@@ -1303,7 +1374,11 @@ public class PerformanceGraphComposite extends Composite {
 			break;
 
 		case GraphConstant.DISPLAY_ITEMCODE:
-			title = PerformanceDataSettingsUtil.getItemName(performanceDataSettings, targetItemCodeInfo.getItemCode());
+			if(targetItemCodeInfo.getDisplayName() != null && !"".equals(targetItemCodeInfo.getDisplayName())){
+				title = PerformanceDataSettingsUtil.getItemName(performanceDataSettings, targetItemCodeInfo.getItemCode()) + "[" + targetItemCodeInfo.getDisplayName() + "]";
+			}else{
+				title = PerformanceDataSettingsUtil.getItemName(performanceDataSettings, targetItemCodeInfo.getItemCode());
+			}
 			title = title + " " + STRING_DISPLAY_ITEMCODE;
 			break;
 
@@ -1325,7 +1400,7 @@ public class PerformanceGraphComposite extends Composite {
 	/**
 	 * 2つの収集データの和を取得する。
 	 * 積み上げグラフ用の前回値との和の取得用。
-	 * 
+	 *
 	 * @param dataSet1
 	 * @param dataSet2
 	 * @return
@@ -1342,31 +1417,16 @@ public class PerformanceGraphComposite extends Composite {
 			return new ArrayList<CollectedDataInfo>();
 		}
 
-		// 空 Check
-		if(dataSet1.size() == 0 && dataSet2.size() > 0){
-			return dataSet2;
-		}
-		if(dataSet2.size() == 0 && dataSet1.size() > 0){
-			return dataSet1;
-		}
-		if(dataSet1.size() == 0 && dataSet2.size() == 0){
-			return new ArrayList<CollectedDataInfo>();
-		}
-		
+
 		ArrayList<CollectedDataInfo> dataList = new ArrayList<CollectedDataInfo>();
 
 		// 時刻がずれている場合は、別時刻の収集値であるため加算しない
 		for(CollectedDataInfo data1: dataSet1){
 			for(CollectedDataInfo data2: dataSet2){
-				if(data1.getDate().longValue() == data2.getDate().longValue()){
+				if(data1.getD().longValue() == data2.getD().longValue()){
 					CollectedDataInfo returnData = new CollectedDataInfo();
-					returnData.setFacilityId(data1.getFacilityId());
-					returnData.setItemCode(data1.getItemCode());
-					returnData.setDisplayName(data1.getDisplayName());
-					returnData.setDate(data1.getDate());
-					returnData.setValue(data1.getValue() + data2.getValue());
-					returnData.setErrorType(CollectedDataErrorTypeConstant.NOT_ERROR);
-
+					returnData.setD(data1.getD());
+					returnData.setV(data1.getV() + data2.getV());
 					dataList.add(returnData);
 					break;
 				}
@@ -1375,6 +1435,7 @@ public class PerformanceGraphComposite extends Composite {
 
 		return dataList;
 	}
+
 	/**
 	 * index番目の線に凡例nameの線としてcollectedDataListをセットする
 	 * @param index
@@ -1383,6 +1444,7 @@ public class PerformanceGraphComposite extends Composite {
 	 */
 	private void setGraphData(int index, String name, List<CollectedDataInfo> collectedDataList){
 		m_log.debug("setGraphData() index = " + index + ", name = " + name);
+		long start = System.currentTimeMillis();
 
 		// 凡例name
 		TimeSeries a = timeSeriesCollection.getSeries(name);
@@ -1392,27 +1454,33 @@ public class PerformanceGraphComposite extends Composite {
 		}
 
 		Iterator<CollectedDataInfo> itr = collectedDataList.iterator();
+		long date = 0;
+		long datePrev = 0;
 		while (itr.hasNext()) {
 			CollectedDataInfo data = itr.next();
-
-			if (!Double.isNaN(data.getValue())) {
-				if (data.getValue() >= 0.0) {
-					timeSeries[index].addOrUpdate(new Second(new Date(data.getDate())), data.getValue());
+			if (!Double.isNaN(data.getV())) {
+				if (date == data.getD()) {
+					continue;
+				}
+				date = data.getD();
+				if( data.getV() >= 0.0 && 1 < (date - datePrev) / 1000 ){ // Only add if > 1 sec. Preventing x-label duplicates
+					timeSeries[index].add(new Second(new Date(date)), data.getV(), !(itr.hasNext()));
+					datePrev = date;
 				}
 
 				// 表示するデータがヘッダの最新時刻より新しいものなら、ヘッダ情報を更新する
-				if(data.getDate() > performanceDataSettings.getLatestDate()){
-					performanceDataSettings.setLatestDate(data.getDate());
-					m_log.debug("LatestDate Update = " + performanceDataSettings.getLatestDate());
+				if(data.getD() > performanceDataSettings.getLatestDate()){
+					performanceDataSettings.setLatestDate(data.getD());
+					m_log.trace("LatestDate Update = " + performanceDataSettings.getLatestDate());
 				}
 			}
 		}
-
+		m_log.debug("setGraphData() time=" + (System.currentTimeMillis() - start) + "ms, size=" + collectedDataList.size());
 	}
 
 	/**
 	 * 指定の組み合わせでグラフの表示が可能かをチェックする
-	 * 
+	 *
 	 * @param facilityType 指定したファシリティIDの種別(ノードかスコープか)
 	 * @param displayType 表示種別(ノード別、収集項目別、デバイス別)
 	 * @param itemCode 表示項目ID
@@ -1460,7 +1528,6 @@ public class PerformanceGraphComposite extends Composite {
 							Messages.getString("message.collection.4"));
 				}
 				break;
-
 			case GraphConstant.DISPLAY_ITEMCODE:
 				for (CollectorItemParentInfo itemCodeInfo : this.performanceDataSettings.getItemCodeList()){
 					if(itemCodeInfo.getParentItemCode() != null && itemCodeInfo.getParentItemCode().equals(itemCode)){
@@ -1473,9 +1540,7 @@ public class PerformanceGraphComposite extends Composite {
 							Messages.getString("message.hinemos.1"), // "確認"
 							Messages.getString("message.collection.5"));
 				}
-
 				break;
-
 			default:
 				valid = true;
 
@@ -1490,24 +1555,16 @@ public class PerformanceGraphComposite extends Composite {
 
 	/**
 	 * jfreeChart の取得
-	 * 
+	 *
 	 * @return
 	 */
 	public JFreeChart getChart() {
 		return jfreeChart;
 	}
 
-	/**
-	 * グラフの表示本数の最大値を設定する
-	 * @param max
-	 */
-	public void setGraphMax(int max){
-		this.GRAPH_MAX = max;
-	}
-
 	/**
 	 * グラフのヘッダ情報
-	 * 
+	 *
 	 * @return
 	 */
 	public PerformanceDataSettings getPerformanceDataSettings() {
