@@ -15,9 +15,13 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.performance.dialog;
 
+import java.util.Map;
+import java.util.concurrent.ConcurrentHashMap;
+
 import org.eclipse.jface.dialogs.IDialogConstants;
+import org.eclipse.rap.rwt.RWT;
+import org.eclipse.rap.rwt.service.UISession;
 import org.eclipse.swt.SWT;
-import org.eclipse.swt.custom.TableTree;
 import org.eclipse.swt.events.SelectionAdapter;
 import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.graphics.Point;
@@ -27,6 +31,7 @@ import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
+import org.eclipse.swt.widgets.Tree;
 
 import com.clustercontrol.bean.Property;
 import com.clustercontrol.dialog.CommonDialog;
@@ -35,10 +40,11 @@ import com.clustercontrol.performance.action.GetPerformanceListFilterProperty;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.PropertyUtil;
 import com.clustercontrol.viewer.PropertySheet;
+import com.clustercontrol.util.WidgetTestUtil;
 
 /**
  * 性能[一覧のフィルタ処理]ダイアログクラス<BR>
- * 
+ *
  * @version 4.0.0
  * @since 4.0.0
  */
@@ -47,19 +53,16 @@ public class PerformanceListFilterDialog extends CommonDialog {
 	/** プロパティシート。 */
 	private PropertySheet propertySheet = null;
 
-	/**
-	 * プロパティ。
-	 * 前回ダイアログオープン時の情報を保持するために使用します。
-	 */
-	private static Property filterProperty = null;
-
 	// 後でpackするためsizeXはダミーの値。
 	private final int sizeX = 500;
 	private final int sizeY = 500;
 
+	/** Cache map of filter properties for each UI session */
+	private static Map<UISession, Property> filterPropertyCache = new ConcurrentHashMap<>();
+
 	/**
 	 * インスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
 	 */
 	public PerformanceListFilterDialog(Shell parent) {
@@ -68,7 +71,7 @@ public class PerformanceListFilterDialog extends CommonDialog {
 
 	/**
 	 * ダイアログの初期サイズを返します。
-	 * 
+	 *
 	 * @return 初期サイズ
 	 */
 	@Override
@@ -78,9 +81,9 @@ public class PerformanceListFilterDialog extends CommonDialog {
 
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
-	 * 
+	 *
 	 * @see com.clustercontrol.monitor.action.GetEventFilterProperty#getProperty()
 	 */
 	@Override
@@ -102,6 +105,7 @@ public class PerformanceListFilterDialog extends CommonDialog {
 
 		// ラベル
 		Label label = new Label(parent, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "attribute", label);
 		GridData gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
@@ -110,8 +114,9 @@ public class PerformanceListFilterDialog extends CommonDialog {
 		label.setText(Messages.getString("attribute") + " : ");
 
 		// プロパティシート
-		TableTree table = new TableTree(parent, SWT.H_SCROLL | SWT.V_SCROLL
+		Tree table = new Tree(parent, SWT.H_SCROLL | SWT.V_SCROLL
 				| SWT.FULL_SELECTION | SWT.MULTI | SWT.BORDER);
+		WidgetTestUtil.setTestId(this, null, table);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
@@ -120,17 +125,11 @@ public class PerformanceListFilterDialog extends CommonDialog {
 		gridData.horizontalSpan = 1;
 		table.setLayoutData(gridData);
 
-		this.propertySheet = new PropertySheet(table);
-
-		// プロパティ設定
-		if(filterProperty == null){
-			filterProperty = new GetPerformanceListFilterProperty().getProperty();
-		}
-		this.propertySheet.setInput(filterProperty);
-		this.propertySheet.expandAll();
+		createPropertySheet(table);
 
 		// ラインを引く
 		Label line = new Label(parent, SWT.SEPARATOR | SWT.HORIZONTAL);
+		WidgetTestUtil.setTestId(this, "line", line);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
@@ -150,7 +149,7 @@ public class PerformanceListFilterDialog extends CommonDialog {
 
 	/**
 	 * 入力値チェックをします。
-	 * 
+	 *
 	 * @return 検証結果
 	 */
 	@Override
@@ -161,17 +160,16 @@ public class PerformanceListFilterDialog extends CommonDialog {
 	/**
 	 * 入力値を保持したプロパティを返します。<BR>
 	 * プロパティオブジェクトのコピーを返します。
-	 * 
+	 *
 	 * @return プロパティ
-	 * 
+	 *
 	 * @see com.clustercontrol.util.PropertyUtil#copy(Property)
 	 */
 	public Property getInputData() {
-		if(filterProperty != null){
-			Property copy = PropertyUtil.copy(filterProperty);
-			return copy;
-		}
-		else{
+		Property property = getOrInitFilterProperty();
+		if( null != property ){
+			return PropertyUtil.copy( property );
+		}else{
 			return null;
 		}
 	}
@@ -179,9 +177,9 @@ public class PerformanceListFilterDialog extends CommonDialog {
 	/**
 	 * 既存のボタンに加え、クリアボタンを追加します。<BR>
 	 * クリアボタンがクリックされた場合、 プロパティを再取得します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット（ボタンバー）
-	 * 
+	 *
 	 * @see org.eclipse.swt.widgets.Button#addSelectionListener(SelectionListener)
 	 * @see com.clustercontrol.monitor.action.GetEventFilterProperty#getProperty()
 	 */
@@ -195,8 +193,7 @@ public class PerformanceListFilterDialog extends CommonDialog {
 					@Override
 					public void widgetSelected(SelectionEvent e) {
 						// プロパティ設定
-						filterProperty = new GetPerformanceListFilterProperty().getProperty();
-						propertySheet.setInput(filterProperty);
+						resetPropertySheet();
 					}
 				});
 
@@ -205,7 +202,7 @@ public class PerformanceListFilterDialog extends CommonDialog {
 
 	/**
 	 * ＯＫボタンのテキストを返します。
-	 * 
+	 *
 	 * @return ＯＫボタンのテキスト
 	 */
 	@Override
@@ -215,11 +212,52 @@ public class PerformanceListFilterDialog extends CommonDialog {
 
 	/**
 	 * キャンセルボタンのテキストを返します。
-	 * 
+	 *
 	 * @return キャンセルボタンのテキスト
 	 */
 	@Override
 	protected String getCancelButtonText() {
 		return Messages.getString("cancel");
 	}
-}
\ No newline at end of file
+
+	/**
+	 * 検索条件用プロパティ設定
+	 * 前回ダイアログオープン時の情報を保持するために使用します。
+	 */
+	private void createPropertySheet( Tree table ){
+		propertySheet = new PropertySheet(table);
+		Property filterProperty = getOrInitFilterProperty();
+		propertySheet.setInput(filterProperty);
+		propertySheet.expandAll();
+	}
+
+	/**
+	 * Reset property sheet
+	 * The filter properties will be cleared
+	 */
+	private void resetPropertySheet(){
+		Property filterProperty = initFilterProperty();
+		propertySheet.setInput(filterProperty);
+	}
+
+	/**
+	 * Initialize a filter property
+	 */
+	private Property initFilterProperty() {
+		Property property = new GetPerformanceListFilterProperty().getProperty();
+		filterPropertyCache.put(RWT.getUISession(), property);
+		return property;
+	}
+
+	/**
+	 * Get the cached filter property if existed,
+	 * or initialize one while not.
+	 */
+	private Property getOrInitFilterProperty() {
+		Property property = filterPropertyCache.get(RWT.getUISession());
+		if( null == property ){
+			property = initFilterProperty();
+		}
+		return property;
+	}
+}
