@@ -15,13 +15,15 @@
 
 package com.clustercontrol.performance.monitor.action;
 
+import java.util.List;
+
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.monitor.action.DeleteInterface;
 import com.clustercontrol.monitor.util.MonitorSettingEndpointWrapper;
 
 /**
  * リソース監視情報を削除するクラス
- * 
+ *
  * @version 4.0.0
  * @since 2.0.0
  */
@@ -29,12 +31,13 @@ public class DeletePerformance implements DeleteInterface{
 
 	/**
 	 * リソース監視情報を削除します。
-	 * 
-	 * @param monitorId 状態監視ID
+	 *
+	 * @param monitorIdList 状態監視IDリスト
 	 * @return 削除に成功した場合、true
 	 */
 	@Override
-	public boolean delete(String monitorId) throws Exception{
-		return MonitorSettingEndpointWrapper.deleteMonitor(monitorId, HinemosModuleConstant.MONITOR_PERFORMANCE);
+	public boolean delete(String managerName, List<String> monitorIdList) throws Exception{
+		MonitorSettingEndpointWrapper wrapper = MonitorSettingEndpointWrapper.getWrapper(managerName);
+		return wrapper.deleteMonitor(monitorIdList, HinemosModuleConstant.MONITOR_PERFORMANCE);
 	}
-}
\ No newline at end of file
+}
