@@ -41,10 +41,11 @@ import com.clustercontrol.ws.collector.CollectorItemInfo;
 import com.clustercontrol.ws.collector.InvalidRole_Exception;
 import com.clustercontrol.ws.monitor.MonitorInfo;
 import com.clustercontrol.ws.monitor.PerfCheckInfo;
+import com.clustercontrol.util.WidgetTestUtil;
 
 /**
  * 収集項目コードを選択するコンポジットクラス
- * 
+ *
  * @version 4.0.0
  * @since 2.0.0
  */
@@ -87,6 +88,7 @@ public class CollectorItemComboComposite extends Composite {
 		 */
 		// ラベル
 		label = new Label(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "monitoritem", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_TITLE_WIDE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -96,6 +98,7 @@ public class CollectorItemComboComposite extends Composite {
 
 		// 空白
 		label = new Label(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space1", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 1;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -104,6 +107,7 @@ public class CollectorItemComboComposite extends Composite {
 
 		// コンボボックス
 		this.m_comboCollectorItem = new Combo(this, SWT.DROP_DOWN | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, null, m_comboCollectorItem);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_VALUE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -117,6 +121,7 @@ public class CollectorItemComboComposite extends Composite {
 		});
 		// 空白
 		label = new Label(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space2", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 1;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -129,7 +134,7 @@ public class CollectorItemComboComposite extends Composite {
 
 	/**
 	 * 更新処理
-	 * 
+	 *
 	 */
 	@Override
 	public void update(){
@@ -144,15 +149,16 @@ public class CollectorItemComboComposite extends Composite {
 
 	/**
 	 * 収集項目を選択するコンボボックスを生成します。
-	 * 
+	 *
 	 * @param facilityId ファシリティID
 	 */
-	public void setCollectorItemCombo(String facilityId){
+	public void setCollectorItemCombo(String managerName, String facilityId){
 		// 収集項目の一覧を生成
 		List<CollectorItemInfo> itemInfoList = null;
 
 		try{
-			itemInfoList = CollectorEndpointWrapper.getAvailableCollectorItemList(facilityId);
+			CollectorEndpointWrapper wrapper = CollectorEndpointWrapper.getWrapper(managerName);
+			itemInfoList = wrapper.getAvailableCollectorItemList(facilityId);
 		} catch (InvalidRole_Exception e) {
 			// アクセス権なしの場合、エラーダイアログを表示する
 			MessageDialog.openInformation(
@@ -182,7 +188,7 @@ public class CollectorItemComboComposite extends Composite {
 		while(itr.hasNext()){
 			CollectorItemInfo itemInfo = itr.next();
 
-			String itemName = CollectorItemCodeFactory.getFullItemName(itemInfo);
+			String itemName = CollectorItemCodeFactory.getFullItemName(managerName, itemInfo);
 			m_comboCollectorItem.add(itemName);
 			m_comboCollectorItem.setData(itemName, itemInfo);
 		}
@@ -204,7 +210,7 @@ public class CollectorItemComboComposite extends Composite {
 	 * 監視設定から選択されている監視項目を設定する。
 	 * @param monitor
 	 */
-	public void select(MonitorInfo monitor){
+	public void select(String managerName, MonitorInfo monitor){
 		// 性能監視情報
 		PerfCheckInfo perfCheckInfo = monitor.getPerfCheckInfo();
 
@@ -215,13 +221,14 @@ public class CollectorItemComboComposite extends Composite {
 
 		String facilityId = monitor.getFacilityId();
 
-		setCollectorItemCombo(facilityId);
+		setCollectorItemCombo(managerName, facilityId);
 
 		int index = 0;
 
 		List<CollectorItemInfo> itemInfoList = null;
 		try{
-			itemInfoList = CollectorEndpointWrapper.getAvailableCollectorItemList(facilityId);
+			CollectorEndpointWrapper wrapper = CollectorEndpointWrapper.getWrapper(managerName);
+			itemInfoList = wrapper.getAvailableCollectorItemList(facilityId);
 		} catch (InvalidRole_Exception e) {
 			// アクセス権なしの場合、エラーダイアログを表示する
 			MessageDialog.openInformation(
@@ -260,7 +267,7 @@ public class CollectorItemComboComposite extends Composite {
 
 	/**
 	 * 入力値を用いて監視情報を生成します。
-	 * 
+	 *
 	 * @return 検証結果
 	 */
 	public ValidateResult createInputData(MonitorInfo info) {
@@ -293,7 +300,7 @@ public class CollectorItemComboComposite extends Composite {
 
 	/**
 	 * 無効な入力値の情報を設定します
-	 * 
+	 *
 	 */
 	protected ValidateResult setValidateResult(String id, String message) {
 
