@@ -22,10 +22,9 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.concurrent.ExecutionException;
+import java.util.concurrent.ExecutorCompletionService;
 import java.util.concurrent.Future;
 
-import javax.persistence.EntityExistsException;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
@@ -36,6 +35,8 @@ import com.clustercontrol.fault.FacilityNotFound;
 import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.fault.InvalidRole;
 import com.clustercontrol.fault.MonitorNotFound;
+import com.clustercontrol.http.util.CallableTaskHttpScenario;
+import com.clustercontrol.maintenance.util.HinemosPropertyUtil;
 import com.clustercontrol.monitor.run.bean.MonitorRunResultInfo;
 import com.clustercontrol.monitor.run.factory.RunMonitor;
 import com.clustercontrol.monitor.run.factory.RunMonitorNumericValueType;
@@ -54,7 +55,6 @@ import com.clustercontrol.performance.util.PerformanceDataUtil;
 import com.clustercontrol.performance.util.PollingDataManager;
 import com.clustercontrol.performance.util.code.CollectorItemCodeTable;
 import com.clustercontrol.poller.NotInitializedException;
-import com.clustercontrol.poller.PollingController;
 import com.clustercontrol.repository.bean.NodeDeviceInfo;
 import com.clustercontrol.repository.session.RepositoryControllerBean;
 import com.clustercontrol.util.Messages;
@@ -85,7 +85,7 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 
 	/**
 	 * コンストラクタ
-	 * 
+	 *
 	 */
 	public RunMonitorPerformance() {
 		super();
@@ -93,7 +93,7 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 
 	/**
 	 * マルチスレッドを実現するCallableTaskに渡すためのインスタンスを作成するメソッド
-	 * 
+	 *
 	 * @see com.clustercontrol.monitor.run.factory.RunMonitor#runMonitorInfo()
 	 * @see com.clustercontrol.monitor.run.util.CallableTask
 	 */
@@ -104,13 +104,13 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 
 	/**
 	 * [リソース監視用]監視を実行します。（並列処理）
-	 * 
+	 *
 	 * リソース監視では1つのファシリティIDに対して、複数の収集項目ID及び、デバイスに対するリソースを監視・収集します。
 	 * この動作に対応するため、独自のrunMonitorInfoを実装します。
-	 * 
+	 *
 	 */
 	@Override
-	protected boolean runMonitorInfo() throws FacilityNotFound, MonitorNotFound, EntityExistsException, InvalidRole, HinemosUnknown {
+	protected boolean runMonitorInfo() throws FacilityNotFound, MonitorNotFound, InvalidRole, HinemosUnknown {
 		m_log.debug("runMonitorInfo()");
 
 		m_now = new Date(System.currentTimeMillis());
@@ -143,13 +143,9 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 				return true;
 			}
 
-			m_isNode = new RepositoryControllerBean().isNode(m_facilityId);
-
 			m_log.debug("monitor start : monitorTypeId : " + m_monitorTypeId + ", monitorId : " + m_monitorId);
 
 			String facilityId = null;
-			// ファシリティIDをキーとしたハッシュマップを作成
-			HashMap<String,Future<ArrayList<MonitorRunResultInfo> >> futuresMap = new HashMap<String,Future<ArrayList<MonitorRunResultInfo> >>(facilityList.size());
 
 			/**
 			 * 監視の実行
@@ -157,6 +153,9 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 			// ファシリティIDの数だけ、各監視処理を実行する
 			Iterator<String> itr = facilityList.iterator();
 
+			ExecutorCompletionService<ArrayList<MonitorRunResultInfo>> ecs = new ExecutorCompletionService<ArrayList<MonitorRunResultInfo>>(ParallelExecution.instance().getExecutorService());
+			int taskCount = 0;
+			
 			while(itr.hasNext()){
 				facilityId = itr.next();
 				if(facilityId != null && !"".equals(facilityId)){
@@ -173,10 +172,9 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 					runMonitor.m_priorityMap = this.m_priorityMap;
 					runMonitor.setJudgementInfo();
 					runMonitor.setCheckInfo();
-
-					Future<ArrayList<MonitorRunResultInfo> > future = ParallelExecution.submitPerf(new CallablePerfTask(runMonitor, facilityId));
-
-					futuresMap.put(facilityId, future);
+					
+					ecs.submit(new CallablePerfTask(runMonitor, facilityId));
+					taskCount++;
 				}
 				else {
 					facilityList.remove(facilityId);
@@ -185,83 +183,49 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 			/**
 			 * 監視結果の集計
 			 */
-			ArrayList<String> facilityListCopy = null;	// ファシリティリストのコピーを格納（監視を完了したものから削除するためコピーを作成）
-			ArrayList<String> facilityListComplete = null;	// 監視を完了したファシリティIDを格納
-			boolean isGet = false;	// 監視が完了したかを判定
 			ArrayList<MonitorRunResultInfo> resultList = null;
 
 			m_log.debug("total start : monitorTypeId : " + m_monitorTypeId + ", monitorId : " + m_monitorId);
 
-			// ログ出力情報を送信
-			facilityListCopy = new ArrayList<String>(facilityList);
-			facilityListComplete = new ArrayList<String>();
-
 			// 収集値の入れ物を作成
 			Sample sample = null;
 			if(m_monitor.getCollectorFlg() == ValidConstant.TYPE_VALID){
 				sample = new Sample(m_monitorId, new Date());
 			}
-
-			while(true) {
-
-				facilityListComplete.clear();	// 収集したファシリティID情報を削除する
-				itr = facilityListCopy.iterator();	// 収集が完了していない情報のみを確認するためIteratorを取得しなおす
-
-				while(itr.hasNext()) {
-					facilityId = itr.next();
-					isGet = futuresMap.get(facilityId).isDone();	//監視完了の有無を取得
-
-					// 監視が終了していた場合
-					if(isGet){
-						m_log.debug("output result : monitorTypeId : " + m_monitorTypeId + ", m_monitorId : " + m_monitorId + ", m_facilityId : " + facilityId);
-
-						resultList = futuresMap.get(facilityId).get();	// 監視結果を取得
-						for(MonitorRunResultInfo result : resultList){
-							m_nodeDate = result.getNodeDate();
-
-							// 監視結果を通知
-							if(result.getMonitorFlg()){
-								notify(true, facilityId, result.getCheckResult(), new Date(m_nodeDate), result);
-							}
-
-							// 個々の収集値の登録
-							if(sample != null && result.getCollectorFlg()){
-								if(result.isCollectorResult()){
-									sample.set(facilityId,result.getItemCode(), result.getDisplayName(), result.getValue(), CollectedDataErrorTypeConstant.NOT_ERROR);
-								}else{
-									sample.set(facilityId,result.getItemCode(), result.getDisplayName(), result.getValue(), CollectedDataErrorTypeConstant.UNKNOWN);
-								}
-							}
-
-							// 監視が完了したファシリティIDをfacilityListCompleteに追加する
-
-						}
-						facilityListComplete.add(facilityId);
+			
+			ArrayList<String> notifyFacilityIdList = new ArrayList<String>();
+			ArrayList<MonitorRunResultInfo> notifyResultList = new ArrayList<MonitorRunResultInfo>();
+			for (int i = 0; i < taskCount; i++) {
+				Future<ArrayList<MonitorRunResultInfo>> future = ecs.take();
+				resultList = future.get();	// 監視結果を取得
+				
+				for(MonitorRunResultInfo result : resultList){
+					m_nodeDate = result.getNodeDate();
+					
+					facilityId = result.getFacilityId();
+					
+					// 監視結果を通知
+					if(result.getMonitorFlg()){
+						notifyFacilityIdList.add(facilityId);
+						notifyResultList.add(result);
 					}
-				}
 
-				// 監視が完了したファシリティIDをfacilityListCopyから削除する
-				itr = facilityListComplete.iterator();
-				while(itr.hasNext()){
-					facilityListCopy.remove(itr.next());
-				}
-
-				// すべてのファシリティIDの監視が完了したかの確認
-				if(facilityListCopy.size() == 0) {
-					m_log.debug("end collect (node) : monitorTypeId : " + m_monitorTypeId + ", m_monitorId : " + m_monitorId);
-					break;
-				}
-				else {
-					m_log.debug("collect (node) : monitorTypeId : " + m_monitorTypeId + ", m_monitorId : " + m_monitorId);
-					if(m_log.isDebugEnabled()){
-						for(String facility : facilityListCopy){
-							m_log.debug("collect (node) : remain node = " + facility);
+					// 個々の収集値の登録
+					if(sample != null && result.getCollectorFlg()){
+						if(result.isCollectorResult()){
+							sample.set(facilityId,result.getItemCode(), result.getDisplayName(), result.getValue(), CollectedDataErrorTypeConstant.NOT_ERROR);
+						}else{
+							sample.set(facilityId,result.getItemCode(), result.getDisplayName(), result.getValue(), CollectedDataErrorTypeConstant.UNKNOWN);
 						}
 					}
-					Thread.sleep(RETRY_INTERVAL);	// まだ結果が出揃っていない場合は「RETRY_INTERVAL」秒sleepする
+
+					// 監視が完了したファシリティIDをfacilityListCompleteに追加する
+
 				}
 			}
 
+			notify(notifyFacilityIdList, notifyResultList);
+
 			// 収集値をまとめて登録
 			if(sample != null){
 				PerformanceDataUtil.put(sample);
@@ -271,12 +235,6 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 
 			return true;
 
-		} catch (EntityExistsException e) {
-			throw e;
-		} catch (FacilityNotFound e) {
-			throw e;
-		} catch (InvalidRole e) {
-			throw e;
 		} catch (InterruptedException e) {
 			m_log.info("runMonitorInfo() monitorTypeId = " + m_monitorTypeId + ", monitorId = " + m_monitorId + " : "
 					+ e.getClass().getSimpleName() + ", " + e.getMessage());
@@ -284,6 +242,7 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 		} catch (ExecutionException e) {
 			m_log.info("runMonitorInfo() monitorTypeId = " + m_monitorTypeId + ", monitorId = " + m_monitorId + " : "
 					+ e.getClass().getSimpleName() + ", " + e.getMessage());
+			m_log.error(e);
 			return false;
 		}
 	}
@@ -299,7 +258,7 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 
 	/**
 	 * 監視の実態。対象ノードのfacilityId毎に呼ばれる
-	 * 
+	 *
 	 */
 	public ArrayList<MonitorRunResultInfo> collectList(String facilityId) throws FacilityNotFound {
 		m_log.debug("collectList() monitorTypeId = " + m_monitorTypeId + ",monitorId = " + m_monitorId  + ", facilityId = " + facilityId);
@@ -338,7 +297,7 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 
 		// 2つ分のSharedTableのfetchが失敗した場合
 		if(!fetchFlg){
-			m_log.info("collectList() SharedTable is not update. Create or replace node poller. " +
+			m_log.debug("collectList() SharedTable is not update. Create or replace node poller. " +
 					"monitorTypeId = " + m_monitorTypeId + ",monitorId = " + m_monitorId  + ", facilityId = " + facilityId);
 
 			// スケジューラの再登録は条件にかまわず実施する
@@ -371,21 +330,13 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 
 						ret = false; // デバイス毎に判定結果を初期化
 						result = new MonitorRunResultInfo();
+						result.setFacilityId(facilityId);
 						itemInfo = new CollectorItemInfo(m_monitorId, itemCode, deviceInfo.getDeviceDisplayName());
 						m_itemName = CollectorItemCodeTable.getFullItemName(itemInfo.getItemCode(), itemInfo.getDisplayName());
 						try{
 							m_value = node.calcValue(itemInfo);
 							if(!Double.isNaN(m_value)){
 								ret = true;
-							} else {
-								// FIXME 5.1では下記の機構は不要になるよう設計変更をすること（センシティブな修正なので、細かくコメントを記載します）
-								//
-								// 不明となった場合、実は直前のポーリング時に管理対象フラグがたっていなかった可能性がある。
-								// そのため管理対象フラグが無効だった最後の時刻から、この情報を通知すべきか否かを検討する
-								// リソース監視なので、2回分以上前のタイミングかを確認する
-								if (PollingController.skipResourceMonitorNotifyByNodeFlagHistory(facilityId, m_runInterval)) {
-									break;
-								}
 							}
 						} catch (NotInitializedException e) {
 							m_value = Double.NaN;
@@ -429,6 +380,7 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 				if(deviceList != null && deviceList.size() > 0){
 
 					result = new MonitorRunResultInfo();
+					result.setFacilityId(facilityId);
 					itemInfo = new CollectorItemInfo(m_monitorId, itemCode, m_perf.getDeviceDisplayName());
 					m_itemName = CollectorItemCodeTable.getFullItemName(itemInfo.getItemCode(), itemInfo.getDisplayName());
 
@@ -436,15 +388,6 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 						m_value = node.calcValue(itemInfo);
 						if(!Double.isNaN(m_value)){
 							ret = true;
-						} else {
-							// FIXME 5.1では下記の機構は不要になるよう設計変更をすること（センシティブな修正なので、細かくコメントを記載します）
-							//
-							// 不明となった場合、実は直前のポーリング時に管理対象フラグがたっていなかった可能性がある。
-							// そのため管理対象フラグが無効だった最後の時刻から、この情報を通知すべきか否かを検討する
-							// リソース監視なので、2回分以上前のタイミングかを確認する
-							if (PollingController.skipResourceMonitorNotifyByNodeFlagHistory(facilityId, m_runInterval)) {
-								break;
-							}
 						}
 					} catch (NotInitializedException e) {
 						m_value = Double.NaN;
@@ -490,21 +433,13 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 				m_log.debug("collectList() monitorId = " + m_monitorId + ", itemCode = " + itemCode + " , displayName = " + m_perf.getDeviceDisplayName());
 
 				result = new MonitorRunResultInfo();
+				result.setFacilityId(facilityId);
 				itemInfo = new CollectorItemInfo(m_monitorId, itemCode, "");
 				m_itemName = CollectorItemCodeTable.getFullItemName(itemInfo.getItemCode(), itemInfo.getDisplayName());
 				try{
 					m_value = node.calcValue(itemInfo);
 					if(!Double.isNaN(m_value)){
 						ret = true;
-					} else {
-						// FIXME 5.1では下記の機構は不要になるよう設計変更をすること（センシティブな修正なので、細かくコメントを記載します）
-						//
-						// 不明となった場合、実は直前のポーリング時に管理対象フラグがたっていなかった可能性がある。
-						// そのため管理対象フラグが無効だった最後の時刻から、この情報を通知すべきか否かを検討する
-						// リソース監視なので、2回分以上前のタイミングかを確認する
-						if (PollingController.skipResourceMonitorNotifyByNodeFlagHistory(facilityId, m_runInterval)) {
-							break;
-						}
 					}
 				} catch (NotInitializedException e) {
 					m_value = Double.NaN;
@@ -540,8 +475,49 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 		return resultList;
 	}
 
+	private void notify(ArrayList<String> notifyFacilityIdList,
+			ArrayList<MonitorRunResultInfo> notifyResultList) {
+		if(m_monitor.getMonitorFlg() == ValidConstant.TYPE_INVALID){
+			return;
+		}
+		// 通知IDが指定されていない場合、通知しない
+		String notifyGroupId = m_monitor.getNotifyGroupId();
+		if(notifyGroupId == null || "".equals(notifyGroupId)){
+			return;
+		}
+
+		ArrayList<OutputBasicInfo> outputBasicInfoList = new ArrayList<OutputBasicInfo>(notifyFacilityIdList.size());
+		for (int i = 0; i < notifyFacilityIdList.size(); i++) {
+			String facilityId = notifyFacilityIdList.get(i);
+			MonitorRunResultInfo resultInfo = notifyResultList.get(i);
+
+			// 通知情報を設定
+			OutputBasicInfo outputBasicInfo = new OutputBasicInfo();
+			outputBasicInfo.setPluginId(m_monitorTypeId);
+			outputBasicInfo.setMonitorId(m_monitorId);
+			outputBasicInfo.setApplication(m_monitor.getApplication());
+
+			// 通知抑制用のサブキーを設定。
+			if(resultInfo.getDisplayName() != null && !"".equals(resultInfo.getDisplayName())){
+				// 監視結果にデバイス名を含むものは、デバイス名をサブキーとして設定。
+				outputBasicInfo.setSubKey(resultInfo.getDisplayName());
+			}
+
+			outputBasicInfo.setFacilityId(facilityId);
+			outputBasicInfo.setScopeText(facilityId);
+			outputBasicInfo.setPriority(resultInfo.getPriority());
+			outputBasicInfo.setMessageId(resultInfo.getMessageId());
+			outputBasicInfo.setMessage(resultInfo.getMessage());
+			outputBasicInfo.setMessageOrg(resultInfo.getMessageOrg());
+			outputBasicInfo.setGenerationDate(resultInfo.getNodeDate());
+
+			outputBasicInfoList.add(outputBasicInfo);
+		}
+		new NotifyControllerBean().notify(outputBasicInfoList, m_monitor.getNotifyGroupId());
+	}
+
 	/**
-	 * 
+	 *
 	 */
 	@Override
 	protected void notify(
