@@ -17,30 +17,29 @@ package com.clustercontrol.performance.operator;
 
 import java.math.BigInteger;
 import java.util.ArrayList;
-import java.util.Collection;
-import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
+import java.util.Map;
 import java.util.Set;
-
-import javax.ejb.FinderException;
-import javax.naming.NamingException;
+import java.util.concurrent.ConcurrentHashMap;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import com.clustercontrol.performance.monitor.ejb.entity.CollectorPollingMstData;
-import com.clustercontrol.performance.monitor.ejb.entity.CollectorPollingMstLocal;
-import com.clustercontrol.performance.monitor.ejb.entity.CollectorPollingMstPK;
-import com.clustercontrol.performance.monitor.ejb.entity.CollectorPollingMstUtil;
+import com.clustercontrol.fault.CollectorNotFound;
+import com.clustercontrol.performance.monitor.entity.CollectorPollingMstData;
+import com.clustercontrol.performance.monitor.model.CollectorPollingMstEntity;
+import com.clustercontrol.performance.monitor.util.QueryUtil;
 import com.clustercontrol.poller.bean.PollerProtocolConstant;
 import com.clustercontrol.sharedtable.DataTable;
 import com.clustercontrol.sharedtable.TableEntry;
-import com.clustercontrol.util.apllog.AplLogger;
 
 abstract public class Operator {
 	private static Log m_log = LogFactory.getLog( Operator.class );
 
+	// 計算式の文字列
+	private String expression;
+
 	// 生成直後に初期化する項目
 	private String collectMethod;
 	private String platformId;
@@ -48,88 +47,41 @@ abstract public class Operator {
 	private String itemCode;
 	private List<String> variables = new ArrayList<String>();
 
-	// 値算出直前に設定する変数
-	private DataTable currentTable;
-	private DataTable previousTable;
-	private long deviceIndex;
-	private String deviceName;
-
 	// SNMPで取得する値の型がCOUNTER32であった場合の最大値
 	private final static long COUNTER32_MAX_VALUE = ((long)(Integer.MAX_VALUE))*2+1;
 	private final static BigInteger COUTNER64_MAX_VALUE = BigInteger.valueOf(Long.MAX_VALUE).shiftLeft(1).add(BigInteger.valueOf(1));
 
-	private HashMap<String, CollectorPollingMstData> m_oidMap = new HashMap<String, CollectorPollingMstData>();
+	private Map<String, CollectorPollingMstData> m_oidMap = new ConcurrentHashMap<String, CollectorPollingMstData>();
 
 
-	public abstract double calc() throws CollectedDataNotFoundException, InvalidValueException;
-
-	protected void setDataTable(DataTable currentTable, DataTable previousTable){
-		this.currentTable = currentTable;
-		this.previousTable = previousTable;
-	}
+	public abstract double calc(DataTable currentTable, DataTable previousTable, String deviceName) throws CollectedDataNotFoundException, InvalidValueException;
 
 	/**
 	 * 直近の収集時の値を取得します
 	 * @param variable 変数名
+	 * @param currentTable
+	 * @param deviceName
 	 * @return 収集値
 	 * @throws CollectedDataNotFoundException
 	 * @throws InvalidValueException
 	 */
-	protected double getCurrentMibValue(String variable)
-	throws CollectedDataNotFoundException, InvalidValueException {
-		return getValue(variable, getCurrentTable());
+	protected double getCurrentMibValue(String variable, DataTable currentTable, String deviceName)
+			throws CollectedDataNotFoundException, InvalidValueException {
+		return getValue(variable, currentTable, deviceName);
 	}
 
 	/**
 	 * 前回収集時の値を取得します
 	 * @param variable 変数名
+	 * @param previousTable
+	 * @param deviceName
 	 * @return 収集値
 	 * @throws CollectedDataNotFoundException
 	 * @throws InvalidValueException
 	 */
-	protected double getPreviousMibValue(String variable)
-	throws CollectedDataNotFoundException, InvalidValueException{
-		return getValue(variable, getPreviousTable());
-	}
-
-	/**
-	 * 全変数の直近収集値の合計値を取得します
-	 * @return 合計値
-	 * @throws CollectedDataNotFoundException
-	 * @throws InvalidValueException
-	 */
-	protected double getCurrentMibValueTotal()
-	throws CollectedDataNotFoundException, InvalidValueException{
-		Iterator<String> itr = getVariables().iterator();
-
-		double total = 0;
-		while(itr.hasNext()){
-			String variable = itr.next();
-
-			total = total + getCurrentMibValue(variable);
-		}
-
-		return total;
-	}
-
-	/**
-	 * 全変数の前回収集値の合計値を取得します
-	 * @return 合計値
-	 * @throws CollectedDataNotFoundException
-	 * @throws InvalidValueException
-	 */
-	protected double getPreviousMibValueTotal()
-	throws CollectedDataNotFoundException, InvalidValueException{
-		Iterator<String> itr = getVariables().iterator();
-
-		double total = 0;
-		while(itr.hasNext()){
-			String variable = itr.next();
-
-			total = total + getPreviousMibValue(variable);
-		}
-
-		return total;
+	protected double getPreviousMibValue(String variable, DataTable previousTable, String deviceName)
+			throws CollectedDataNotFoundException, InvalidValueException{
+		return getValue(variable, previousTable, deviceName);
 	}
 
 	/**
@@ -137,12 +89,15 @@ abstract public class Operator {
 	 * entryKeyの最後の一文字が"*"の場合は、差分の合計を求めます（合計の差分ではない）。
 	 * 
 	 * @param variable 変数名
+	 * @param currentTable
+	 * @param previousTable
+	 * @param deviceName
 	 * @return 差分値
 	 * @throws CollectedDataNotFoundException
 	 * @throws InvalidValueException
 	 */
-	protected double getDifferenceValue(String variable)
-	throws CollectedDataNotFoundException, InvalidValueException{
+	protected double getDifferenceValue(String variable, DataTable currentTable, DataTable previousTable, String deviceName)
+			throws CollectedDataNotFoundException, InvalidValueException{
 		if(m_log.isDebugEnabled()){
 			m_log.debug("getDifferenceValue() variable : " + variable);
 		}
@@ -156,9 +111,6 @@ abstract public class Operator {
 			m_log.debug("getDifferenceValue() targetIndex : " + targetIndex);
 		}
 
-		DataTable currentTable = getCurrentTable();
-		DataTable previousTable = getPreviousTable();
-
 		// entryKeyインデックスの定義によって処理を変える
 		if ("?".equals(targetIndex)){
 			// SNMP・WBEMのポーリング結果の場合
@@ -181,8 +133,9 @@ abstract public class Operator {
 					Set<TableEntry> previousEntrys = previousTable.getValueSetStartWith(PollerProtocolConstant.getEntryKey(getCollectMethod() ,pollingTarget));
 					if(currentEntrys == null || previousEntrys == null){
 						// エラー処理
-						m_log.debug("getDifferenceValue() currentEntrys or previousEntrys is null, currentEntrys : " + currentEntrys + ", previousEntrys : " + previousEntrys);
-						throw new CollectedDataNotFoundException();
+						String message = "getDifferenceValue() currentEntrys or previousEntrys is null, currentEntrys : " + currentEntrys + ", previousEntrys : " + previousEntrys;
+						m_log.debug(message);
+						throw new CollectedDataNotFoundException(message);
 					}
 
 					// CurrentTable
@@ -194,7 +147,7 @@ abstract public class Operator {
 							m_log.debug("getDifferenceValue() CurrentTable deviceName : " + getCollectMethod() + ", entry.getValue() : " + entry.getValue());
 							m_log.debug("getDifferenceValue() CurrentTable entry.getValue() is " + (entry.getValue()).getClass().getCanonicalName());
 						}
-						
+
 						// value はString で判定するため、念のためObjectのClass check
 						String value = null;
 						if(entry.getValue() instanceof String){
@@ -202,7 +155,7 @@ abstract public class Operator {
 						}else{
 							value = entry.getValue().toString();
 						}
-						if( value.equals(getDeviceName()) ){
+						if( value.equals(deviceName) ){
 							currentIndex = entry.getKey().substring(entry.getKey().lastIndexOf("."));
 							break;
 						}
@@ -217,6 +170,7 @@ abstract public class Operator {
 							m_log.debug("getDifferenceValue() PreviousTable deviceName : " + getCollectMethod() + ", entry.getValue() : " + entry.getValue());
 							m_log.debug("getDifferenceValue() PreviousTable entry.getValue() is " + (entry.getValue()).getClass().getCanonicalName());
 						}
+
 						// value はString で判定するため、念のためObjectのClass check
 						String value = null;
 						if(entry.getValue() instanceof String){
@@ -224,20 +178,20 @@ abstract public class Operator {
 						}else{
 							value = entry.getValue().toString();
 						}
-						if( value.equals(getDeviceName()) ){
+						if( value.equals(deviceName) ){
 							previousIndex = entry.getKey().substring(entry.getKey().lastIndexOf("."));
 							break;
 						}
 					}
 
 					if(m_log.isDebugEnabled()){
-						m_log.debug("getDifferenceValue() deviceName : " + getDeviceName() + ", currentIndex : " + currentIndex + ", previousIndex : " + previousIndex);
+						m_log.debug("getDifferenceValue() deviceName : " + deviceName + ", currentIndex : " + currentIndex + ", previousIndex : " + previousIndex);
 					}
 					// デバイス名が見つからない場合
 					if(currentIndex == null) {
 						// エラー処理
 						StringBuffer detailMsg = new StringBuffer();
-						detailMsg.append("DeviceName " + getDeviceName() + " is not exists\n");
+						detailMsg.append("DeviceName " + deviceName + " is not exists\n");
 						detailMsg.append("Search Device Name is ...\n");
 
 						itr = currentEntrys.iterator();
@@ -246,13 +200,15 @@ abstract public class Operator {
 							detailMsg.append(" [" + (String)entry.getValue() + "]\n");
 						}
 
-						m_log.info("getDifferenceValue() deviceName : " + getDeviceName() + ", currentIndex is null");
-						throw new CollectedDataNotFoundException();
+						String message = "getDifferenceValue() deviceName : " + deviceName + ", currentIndex is null";
+						m_log.info(message);
+						throw new CollectedDataNotFoundException(message);
 					}
 					if(previousIndex == null) {
 						// エラー処理
-						m_log.debug("getDifferenceValue() deviceName : " + getDeviceName() + ", previousIndex is null");
-						throw new CollectedDataNotFoundException();
+						String message = "getDifferenceValue() deviceName : " + deviceName + ", previousIndex is null";
+						m_log.debug(message);
+						throw new CollectedDataNotFoundException(message);
 					}
 
 					// pollingTargetにTableEntryから取得するためのKeyを与える
@@ -260,20 +216,24 @@ abstract public class Operator {
 				} catch (CollectedDataNotFoundException e) {
 					throw e;
 				} catch (Exception e) {
-					m_log.error("getDifferenceValue() Unknown Error", e);
+					m_log.warn("getDifferenceValue() : "
+							+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 				}
 
 				try {
 					return getMibValueDiff(data, currentTable, previousTable,
 							PollerProtocolConstant.getEntryKey(getCollectMethod() ,pollingTarget + currentIndex),
 							PollerProtocolConstant.getEntryKey(getCollectMethod() ,pollingTarget + previousIndex));
-				}
-				catch (InvalidValueException e){
+				} catch (CollectedDataNotFoundException e){
 					throw e;
 				} catch (Exception e){
-					m_log.debug(e.getMessage(), e);
+					// 直前のgetMibValueDiff()の処理にて、failureValueが定義されていないpolling targetの場合に
+					// NullPointerExceptionが発生する。
+					// これはver4.0までの動作と同様のため、通常ルートではstacktraceを出力しないようにする。
+					String message = "getDifferenceValue() : " + e.getClass().getSimpleName() + ", " + e.getMessage();
+					m_log.debug(message, e);
 					// エラー処理
-					throw new CollectedDataNotFoundException();
+					throw new CollectedDataNotFoundException(message);
 				}
 			}
 			// VMのポーリング結果の場合
@@ -288,18 +248,22 @@ abstract public class Operator {
 				 */
 				try {
 					// entryKeyの最後の一文字が"?"の場合
-					String pollingTarget = data.getPollingTarget() + "." + getDeviceName();
+					String pollingTarget = data.getPollingTarget() + "." + deviceName;
 
 					// VMの場合は、現在のテーブルと過去のテーブルでentryKeyを変更することができないため、同じentryKeyを与える
 					return getMibValueDiff(data, currentTable, previousTable,
 							PollerProtocolConstant.getEntryKey(getCollectMethod() ,pollingTarget),
 							PollerProtocolConstant.getEntryKey(getCollectMethod() ,pollingTarget));
-				} catch (InvalidValueException e){
+				} catch (CollectedDataNotFoundException e){
 					throw e;
 				} catch (Exception e){
-					m_log.debug(e.getMessage(), e);
+					// 直前のgetMibValueDiff()の処理にて、failureValueが定義されていないpolling targetの場合に
+					// NullPointerExceptionが発生する。
+					// これはver4.0までの動作と同様のため、通常ルートではstacktraceを出力しないようにする。
+					String message = "getDifferenceValue() : " + e.getClass().getSimpleName() + ", " + e.getMessage();
+					m_log.debug(message, e);
 					// エラー処理
-					throw new CollectedDataNotFoundException();
+					throw new CollectedDataNotFoundException(message);
 				}
 			}
 
@@ -309,16 +273,18 @@ abstract public class Operator {
 				String pollingTarget = data.getPollingTarget();
 
 				// 直近の取得時のデータテーブルからベースとなるpollingTarget配下の値全てを取得
-				Set<TableEntry> entrys = currentTable.getValueSetStartWith(PollerProtocolConstant.getEntryKey(getCollectMethod() ,pollingTarget));
+				Set<TableEntry> entries = currentTable.getValueSetStartWith(PollerProtocolConstant.getEntryKey(getCollectMethod() ,pollingTarget));
 
-				if(entrys == null){
+				if(entries == null){
+					String message = "getDifferenceValue() : entries is null";
+					m_log.info(message);
 					// エラー処理
-					throw new CollectedDataNotFoundException();
+					throw new CollectedDataNotFoundException(message);
 				}
 
 				// 合計を求める
 				double total = 0;  // 初期値0で初期化
-				Iterator<TableEntry> itr = entrys.iterator();
+				Iterator<TableEntry> itr = entries.iterator();
 				while(itr.hasNext()){
 					String tableEntryKey = itr.next().getKey();
 					total = total + getMibValueDiff(data, currentTable, previousTable, tableEntryKey, tableEntryKey);
@@ -326,49 +292,34 @@ abstract public class Operator {
 				}
 
 				return total;
-			} catch (InvalidValueException e){
+			} catch (CollectedDataNotFoundException e) {
 				throw e;
 			} catch (Exception e){
 				// エラー処理
-				m_log.debug(e.getMessage(), e);
-				throw new CollectedDataNotFoundException();
+				String message = "getDifferenceValue() : " + e.getClass().getSimpleName() + ", " + e.getMessage();
+				m_log.warn(message, e);
+				throw new CollectedDataNotFoundException(message);
 			}
 		} else {
 			try {
 				return getMibValueDiff(data, currentTable, previousTable,
 						PollerProtocolConstant.getEntryKey(getCollectMethod() ,entryKey),
 						PollerProtocolConstant.getEntryKey(getCollectMethod() ,entryKey));
-			} catch (InvalidValueException e){
+			} catch (CollectedDataNotFoundException e){
 				throw e;
 			} catch (Exception e){
-				// エラー処理
-				m_log.debug(e.getMessage(), e);
-				throw new CollectedDataNotFoundException();
+				// 直前のgetMibValueDiff()の処理にて、failureValueが定義されていないpolling targetの場合に
+				// NullPointerExceptionが発生する。
+				// これはver4.0までの動作と同様のため、通常ルートではstacktraceを出力しないようにする。
+				String message = "getDifferenceValue() : " + e.getClass().getSimpleName() + ", " + e.getMessage();
+				m_log.debug(message, e);
+				throw new CollectedDataNotFoundException(message);
 			}
 		}
 	}
 
-	/**
-	 * 全変数の前回収集時からの差分の合計を取得します。
-	 * @return 差分値
-	 */
-	protected double getDifferenceValueTotal()
-	throws CollectedDataNotFoundException, InvalidValueException {
-
-		Iterator<String> itr = getVariables().iterator();
-
-		double total = 0;
-		while(itr.hasNext()){
-			String variable = itr.next();
-
-			total = total + getDifferenceValue(variable);
-		}
-
-		return total;
-	}
-
-	protected double getValue(String variable, DataTable table)
-	throws CollectedDataNotFoundException, InvalidValueException{
+	private double getValue(String variable, DataTable table, String deviceName)
+			throws CollectedDataNotFoundException, InvalidValueException{
 		if(m_log.isDebugEnabled()){
 			m_log.debug("getValue() variable : " + variable);
 		}
@@ -403,8 +354,9 @@ abstract public class Operator {
 					Set<TableEntry> entrys = table.getValueSetStartWith(PollerProtocolConstant.getEntryKey(getCollectMethod() ,pollingTarget));
 					if(entrys == null){
 						// エラー処理
-						m_log.debug("getValue() entrys is null, entrys : " + entrys);
-						throw new CollectedDataNotFoundException();
+						String message = "getValue() entrys is null, entrys : " + entrys;
+						m_log.debug(message);
+						throw new CollectedDataNotFoundException(message);
 					}
 
 					Iterator<TableEntry> itr = entrys.iterator();
@@ -421,7 +373,7 @@ abstract public class Operator {
 						}else{
 							value = entry.getValue().toString();
 						}
-						if( value.equals(getDeviceName()) ){
+						if( value.equals(deviceName) ){
 							index = entry.getKey().substring(entry.getKey().lastIndexOf("."));
 							break;
 						}
@@ -434,7 +386,7 @@ abstract public class Operator {
 					if(index == null) {
 						// エラー処理
 						StringBuffer detailMsg = new StringBuffer();
-						detailMsg.append("DeviceName " + getDeviceName() + " is not exists\n");
+						detailMsg.append("DeviceName " + deviceName + " is not exists\n");
 						detailMsg.append("Search Device Name is ...\n");
 
 						itr = entrys.iterator();
@@ -443,8 +395,9 @@ abstract public class Operator {
 							detailMsg.append(" [" + (String)entry.getValue() + "]\n");
 						}
 
-						m_log.info("getValue() deviceName : " + getDeviceName() + ", index is null");
-						throw new CollectedDataNotFoundException();
+						String message = "getValue() deviceName : " + deviceName + ", index is null";
+						m_log.info(message);
+						throw new CollectedDataNotFoundException(message);
 					}
 
 					// pollingTargetにTableEntryから取得するためのKeyを与える
@@ -453,18 +406,20 @@ abstract public class Operator {
 				} catch (CollectedDataNotFoundException e) {
 					throw e;
 				} catch (Exception e) {
-					m_log.error("getValue() Unknown Error", e);
+					m_log.warn("getValue() : "
+							+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 				}
 
 				try {
 					return getMibValueDouble(table, data, PollerProtocolConstant.getEntryKey(getCollectMethod() ,pollingTarget + index));
 				}
-				catch (InvalidValueException e){
+				catch (CollectedDataNotFoundException e){
 					throw e;
 				} catch (Exception e){
-					m_log.debug(e.getMessage(), e);
+					String message = "getValue() : " + e.getClass().getSimpleName() + ", " + e.getMessage();
+					m_log.warn(message, e);
 					// エラー処理
-					throw new CollectedDataNotFoundException();
+					throw new CollectedDataNotFoundException(message);
 				}
 			}
 			// VMのポーリング結果の場合
@@ -479,14 +434,15 @@ abstract public class Operator {
 				 */
 				try {
 					// entryKeyの最後の一文字が"?"の場合
-					String pollingTarget = data.getPollingTarget() + "." + getDeviceName();
+					String pollingTarget = data.getPollingTarget() + "." + deviceName;
 					return getMibValueDouble(table, data, PollerProtocolConstant.getEntryKey(getCollectMethod() ,pollingTarget));
-				} catch (InvalidValueException e){
+				} catch (CollectedDataNotFoundException e) {
 					throw e;
 				} catch (Exception e){
-					m_log.debug(e.getMessage(), e);
+					String message = "getValue() : " + e.getClass().getSimpleName() + ", " + e.getMessage();
+					m_log.warn(message, e);
 					// エラー処理
-					throw new CollectedDataNotFoundException();
+					throw new CollectedDataNotFoundException(message);
 				}
 			}
 
@@ -496,16 +452,18 @@ abstract public class Operator {
 				String pollingTarget = data.getPollingTarget();
 
 				// 直近の取得時のデータテーブルからベースとなるpollingTarget配下の値全てを取得
-				Set<TableEntry> entrys = table.getValueSetStartWith(PollerProtocolConstant.getEntryKey(getCollectMethod() ,pollingTarget));
+				Set<TableEntry> entries = table.getValueSetStartWith(PollerProtocolConstant.getEntryKey(getCollectMethod() ,pollingTarget));
 
-				if(entrys == null){
+				if(entries == null){
+					String message = "getValue() : entries is null";
+					m_log.info(message);
 					// エラー処理
-					throw new CollectedDataNotFoundException();
+					throw new CollectedDataNotFoundException(message);
 				}
 
 				// 合計を求める
 				double total = 0;  // 初期値0で初期化
-				Iterator<TableEntry> itr = entrys.iterator();
+				Iterator<TableEntry> itr = entries.iterator();
 				while(itr.hasNext()){
 					String tableEntryKey = itr.next().getKey();
 					total = total + getMibValueDouble(table, data, tableEntryKey);
@@ -513,20 +471,24 @@ abstract public class Operator {
 				}
 
 				return total;
+			} catch (CollectedDataNotFoundException e) {
+				throw e;
 			} catch (Exception e){
 				// エラー処理
-				m_log.debug(e.getMessage(), e);
-				throw new CollectedDataNotFoundException();
+				String message = "getValue() : " + e.getClass().getSimpleName() + ", " + e.getMessage();
+				m_log.warn(message, e);
+				throw new CollectedDataNotFoundException(message);
 			}
 		} else {
 			try {
 				return getMibValueDouble(table, data, PollerProtocolConstant.getEntryKey(getCollectMethod() ,entryKey));
-			} catch (InvalidValueException e){
+			} catch (CollectedDataNotFoundException e) {
 				throw e;
 			} catch (Exception e){
 				// エラー処理
-				m_log.debug(e.getMessage(), e);
-				throw new CollectedDataNotFoundException();
+				String message = "getValue() : " + e.getClass().getSimpleName() + ", " + e.getMessage();
+				m_log.warn(message, e);
+				throw new CollectedDataNotFoundException(message);
 			}
 		}
 	}
@@ -543,10 +505,10 @@ abstract public class Operator {
 	 * @param data
 	 * @param entryKey
 	 * @return
-	 * @throws InvalidValueException
+	 * @throws CollectedDataNotFoundException 
 	 */
 	private long getMibValueLong(DataTable table, CollectorPollingMstData data,
-			String entryKey) throws InvalidValueException {
+			String entryKey) throws CollectedDataNotFoundException {
 
 		if(m_log.isDebugEnabled()){
 			m_log.debug("getMibValueLong() entryKey : " + entryKey);
@@ -556,6 +518,12 @@ abstract public class Operator {
 
 		// 指定のOIDの値が存在しない場合
 		if(entry == null){
+			if (data.getFailureValue() == null) {
+				String message = "failure value is null";
+				m_log.debug(message);
+				throw new CollectedDataNotFoundException(message);
+			}
+			
 			// 値取得失敗と判定し、値取得失敗時の返却値を返す
 			return Long.parseLong(data.getFailureValue());
 		} else {
@@ -583,10 +551,10 @@ abstract public class Operator {
 	 * @param data
 	 * @param entryKey
 	 * @return
-	 * @throws InvalidValueException
+	 * @throws CollectedDataNotFoundException 
 	 */
 	private double getMibValueDouble(DataTable table, CollectorPollingMstData data,
-			String entryKey) throws InvalidValueException {
+			String entryKey) throws CollectedDataNotFoundException {
 
 		long longValue = getMibValueLong(table, data, entryKey);
 		return convLongToDouble(longValue);
@@ -611,11 +579,11 @@ abstract public class Operator {
 
 	/**
 	 * 直近収集と前回収集のデータテーブルから指定のpollingTargetの値を取得しその差分を求める
-	 * @throws InvalidValueException
+	 * @throws CollectedDataNotFoundException 
 	 */
 	private double getMibValueDiff(CollectorPollingMstData data,
 			DataTable currentTable, DataTable previousTable, String currentEntryKey, String previousEntryKey)
-	throws InvalidValueException {
+					throws CollectedDataNotFoundException {
 
 		// return用の変数
 		double ret = 0;
@@ -676,8 +644,9 @@ abstract public class Operator {
 
 			// 登録できなかった場合
 			if(data == null){
+				m_log.info("data=null");
 				// エラー処理
-				throw new IllegalStateException();
+				throw new IllegalStateException("variable=" + variable);
 			}
 		}
 		return data;
@@ -689,45 +658,36 @@ abstract public class Operator {
 				m_log.debug(getPlatformId() + ", " +  getItemCode() + ", " + variable);
 			}
 
-			CollectorPollingMstLocal bean = CollectorPollingMstUtil.getLocalHome()
-			.findByPrimaryKey(new CollectorPollingMstPK(getCollectMethod(), getPlatformId(), getSubPlatformId(), getItemCode(), variable));
+			CollectorPollingMstEntity bean = null;
+			try {
+				bean = QueryUtil.getCollectorPollingMstPK(getCollectMethod(),
+						getPlatformId(),
+						getSubPlatformId(),
+						getItemCode(),
+						variable);
+			} catch (CollectorNotFound e) {
+			}
+			if (bean != null) {
+				CollectorPollingMstData data = new CollectorPollingMstData(
+						bean.getId().getCollectMethod(),
+						bean.getId().getPlatformId(),
+						bean.getId().getSubPlatformId(),
+						bean.getId().getItemCode(),
+						bean.getId().getVariableId(),
+						bean.getEntryKey(),
+						bean.getSnmpValueTypeMstEntity().getValueType(),
+						bean.getPollingTarget(),
+						bean.getFailureValue());
 
-			CollectorPollingMstData data = new CollectorPollingMstData(
-					bean.getCollectMethod(),
-					bean.getPlatformId(),
-					bean.getSubPlatformId(),
-					bean.getItemCode(),
-					bean.getVariableId(),
-					bean.getEntryKey(),
-					bean.getValueType(),
-					bean.getPollingTarget(),
-					bean.getFailureValue());
-
-			m_oidMap.put(variable, data);
-		} catch (FinderException e) {
-			m_log.error(e.getMessage(), e);
-		} catch (NamingException e) {
-			m_log.error(e.getMessage(), e);
+				m_oidMap.put(variable, data);
+			}
+		} catch (Exception e) {
+			m_log.warn("registerOidMap() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 		}
 	}
 
 
-	public DataTable getCurrentTable() {
-		return currentTable;
-	}
-
-	public void setCurrentTable(DataTable currentTable) {
-		this.currentTable = currentTable;
-	}
-
-	public DataTable getPreviousTable() {
-		return previousTable;
-	}
-
-	public void setPreviousTable(DataTable previousTable) {
-		this.previousTable = previousTable;
-	}
-
 	public String getCollectMethod() {
 		return collectMethod;
 	}
@@ -765,38 +725,27 @@ abstract public class Operator {
 
 		try{
 			// 収集項目コードから変数情報を取得する
-			Collection<CollectorPollingMstLocal> beans =
-				CollectorPollingMstUtil.getLocalHome().findByCollectMethodAndPlatformIdAndSubPlatformIdAndItemCode(
-						getCollectMethod(),
-						getPlatformId(),
-						getSubPlatformId(),
-						itemCode);
-
+			List<CollectorPollingMstEntity> beans =
+					QueryUtil.getAllCollectorPollingMstVariableId(getCollectMethod(),
+							getPlatformId(),
+							getSubPlatformId(),
+							itemCode);
 			// 保持している全ての変数IDをクリア
 			getVariables().clear();
 
 			// この収集項目で利用可能な変数IDをリストに保存
-			for(CollectorPollingMstLocal bean : beans){
+			for(CollectorPollingMstEntity bean : beans){
 				if(m_log.isDebugEnabled()){
-					m_log.debug("add " + bean.getVariableId());
+					m_log.debug("add " + bean.getId().getVariableId());
 				}
-				getVariables().add(bean.getVariableId());
+				getVariables().add(bean.getId().getVariableId());
 			}
-		} catch (FinderException e) {
-			m_log.error(e.getMessage(), e);
-		} catch (NamingException e) {
-			m_log.error(e.getMessage(), e);
+		} catch (Exception e) {
+			m_log.warn("setItemCode() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 		}
 	}
 
-	public String getDeviceName() {
-		return deviceName;
-	}
-
-	public void setDeviceName(String deviceName) {
-		this.deviceName = deviceName;
-	}
-
 	public List<String> getVariables() {
 		return variables;
 	}
@@ -811,5 +760,17 @@ abstract public class Operator {
 
 	public class CollectedDataNotFoundException extends Exception {
 		private static final long serialVersionUID = 6306555743811316089L;
+		
+		public CollectedDataNotFoundException(String messages) {
+			super(messages + ", itemcode=" + itemCode);
+		}
+	}
+
+	public void setExpression(String expression) {
+		this.expression = expression;
+	}
+
+	public String getExpression() {
+		return expression;
 	}
 }
