@@ -15,12 +15,20 @@ GNU General Public License for more details.
 
 package com.clustercontrol.performance.operator;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+
+import com.clustercontrol.sharedtable.DataTable;
+
 /**
  * 計算方法が未定義の場合
  */
 public class Undefined extends Operator {
-@Override
-public double calc() throws CollectedDataNotFoundException, InvalidValueException{
-return Double.NaN;
-}
+	private static Log m_log = LogFactory.getLog(Undefined.class);
+	
+	@Override
+	public double calc(DataTable currentTable, DataTable previousTable, String deviceName) throws CollectedDataNotFoundException, InvalidValueException{
+		m_log.warn("undefined");
+		return Double.NaN;
+	}
 }
