@@ -24,15 +24,16 @@ import com.clustercontrol.ClusterControlPlugin;
 
 /**
  * 性能管理機能のプリファレンスの初期化<BR>
- * 
+ *
  * @version 4.0.0
  * @since 4.0.0
  */
 public class PerformanceInitializer extends AbstractPreferenceInitializer {
 
-	private static Log log = LogFactory.getLog(PerformanceInitializer.class);
-	public static int GRAPH_MAX_DEFAULT = 10; // グラフ表示線の最大数(デフォルト)
-	public static int DL_MAX_WAIT_DEFAULT = 10; // ダウンロード待ち時間最大値(分)
+	private static final Log log = LogFactory.getLog( PerformanceInitializer.class );
+
+	public static final int GRAPH_MAX_DEFAULT = 10; // グラフ表示線の最大数(デフォルト)
+	public static final int DL_MAX_WAIT_DEFAULT = 10; // ダウンロード待ち時間最大値(分)
 
 	/**
 	 * プリファレンスの初期化
