@@ -34,12 +34,11 @@ import java.util.List;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.accesscontrol.session.AccessControllerBean;
-import com.clustercontrol.commons.util.HinemosProperties;
 import com.clustercontrol.commons.util.HinemosSessionContext;
 import com.clustercontrol.commons.util.JpaTransactionManager;
-import com.clustercontrol.monitor.run.model.MonitorInfoEntity;
+import com.clustercontrol.fault.HinemosUnknown;
+import com.clustercontrol.maintenance.util.HinemosPropertyUtil;
 import com.clustercontrol.performance.bean.CollectorItemParentInfo;
 import com.clustercontrol.performance.bean.PerformanceDataSettings;
 import com.clustercontrol.performance.model.CalculatedDataEntity;
@@ -58,46 +57,20 @@ public class ExportCollectedDataFile {
 	private static Log m_log = LogFactory
 			.getLog(ExportCollectedDataFile.class);
 
-	public static String exportDirectory = null;
-	private static String exportEncode = null;
-	private static String exportLineSeparator = null;
-	private static int exportFetchSize = 1000;
 	public final static String NOT_EXISTS = "";
 	public final static String NOT_A_NUMBER = "?";
 
-	static {
-		exportDirectory = HinemosProperties.getProperty(
-				"performance.export.dir", "/opt/hinemos/var/export/");
-		exportEncode = HinemosProperties.getProperty(
-				"performance.export.encode", "UTF-8");
-		exportLineSeparator = HinemosProperties.getProperty(
-				"performance.export.line.separator", "\r\n");
-
-		String exportFetchSizeStr = HinemosProperties.getProperty(
-				"performance.export.fetchsize", "1000");
-		try {
-			exportFetchSize = Integer.valueOf(exportFetchSizeStr);
-		} catch (NumberFormatException e) {
-			m_log.info("static() performance.export.fetchsize is not number format");
-			exportFetchSize = 1000;
-		}
-
-		m_log.info("exportDirectory = " + exportDirectory);
-		m_log.info("exportEncode = " + exportEncode);
-		m_log.info("exportFetchSize = " + exportFetchSize);
-	}
-
 	/**
-	 * 
+	 *
 	 * ①1 File / 1 Node でCSV性能データファイルを作成する<BR>
 	 * facilityId = Node の場合：1ファイル facilityId = Scope
 	 * の場合：配下の(有効な)ノード毎に1ファイルを作成する
-	 * 
+	 *
 	 * ②header が有効な場合 各CSVファイルに収集項目の項目名をヘッダとして出力する
-	 * 
+	 *
 	 * ③archiveが有効な場合 facilityId = Node の場合：対象1ファイルをzip圧縮する facilityId = Scope
 	 * の場合：対象1ファイル群を1ファイルにzip圧縮する
-	 * 
+	 *
 	 * @param monitorId
 	 * @param facilityId
 	 * @param header
@@ -127,7 +100,7 @@ public class ExportCollectedDataFile {
 
 		ArrayList<String> targetFileNameList = new ArrayList<String>();
 		try {
-			MonitorInfoEntity entity = com.clustercontrol.monitor.run.util.QueryUtil.getMonitorInfoPK_NONE(monitorId);
+			com.clustercontrol.monitor.run.util.QueryUtil.getMonitorInfoPK_NONE(monitorId);
 			ArrayList<String> targetFacilityIdList
 			= new RepositoryControllerBean().getExecTargetFacilityIdList(facilityId, null);
 
@@ -171,7 +144,7 @@ public class ExportCollectedDataFile {
 	}
 
 	/**
-	 * 
+	 *
 	 * @param monitorId
 	 * @param targetFacilityId
 	 * @param fileId
@@ -185,7 +158,7 @@ public class ExportCollectedDataFile {
 
 	/**
 	 * 性能データがない場合の空ファイルを作成する
-	 * 
+	 *
 	 * @param filepath
 	 * @throws HinemosUnknown
 	 */
@@ -216,7 +189,7 @@ public class ExportCollectedDataFile {
 	}
 
 	/**
-	 * 
+	 *
 	 * @param monitorId
 	 * @param facilityId
 	 * @param filepath
@@ -230,6 +203,21 @@ public class ExportCollectedDataFile {
 
 		PrintWriter pw = null;
 
+		String exportEncode = HinemosPropertyUtil.getHinemosPropertyStr(
+				"performance.export.encode", "UTF-8");
+		
+		String exportLineSeparator = "\r\n";
+		String exportLineSeparatorStr = HinemosPropertyUtil.getHinemosPropertyStr(
+				"performance.export.line.separator", "CRLF");
+		
+		if ("CRLF".equals(exportLineSeparatorStr)) {
+			exportLineSeparator = "\r\n";
+		} else if ("LF".equals(exportLineSeparatorStr)) {
+			exportLineSeparator = "\n";
+		} else if ("CR".equals(exportLineSeparatorStr)) {
+			exportLineSeparator = "\r";
+		}
+		
 		try{
 			pw = new PrintWriter(new BufferedWriter(new OutputStreamWriter(new FileOutputStream(filepath, true),exportEncode)));
 
@@ -248,6 +236,8 @@ public class ExportCollectedDataFile {
 			try{
 				jtm = new JpaTransactionManager();
 				jtm.begin();
+				int exportFetchSize = HinemosPropertyUtil.getHinemosPropertyNum("performance.export.fetchsize", 1000);
+
 				List<CalculatedDataEntity> calculatedDataEntityList
 				= QueryUtil.getCalculatedDataByCollectoridFacilityidDateTime(monitorId,
 						facilityId,
@@ -352,7 +342,7 @@ public class ExportCollectedDataFile {
 
 	/**
 	 * 指定したファイルにItemCodeのリスト(itemInfoList)のヘッダ情報を出力する。
-	 * 
+	 *
 	 * @param filepath
 	 * @param itemInfoList
 	 */
@@ -366,6 +356,11 @@ public class ExportCollectedDataFile {
 			File file = new File(filepath);
 
 			if (checkBeforeWritefile(file)) {
+				String exportEncode = HinemosPropertyUtil.getHinemosPropertyStr(
+						"performance.export.encode", "UTF-8");
+				String exportLineSeparator = HinemosPropertyUtil.getHinemosPropertyStr(
+						"performance.export.line.separator", "\r\n");
+
 				pw = new PrintWriter(new BufferedWriter(new OutputStreamWriter(new FileOutputStream(file, true),exportEncode)));
 
 				// File Header
@@ -419,13 +414,16 @@ public class ExportCollectedDataFile {
 
 	/**
 	 * 指定したファイル名のリストを削除する。ディレクトリはperformance.export.dirで指定。
-	 * 
+	 *
 	 * @param filePathList
 	 */
 	public static void deleteFile(ArrayList<String> fileNameList)
 			throws HinemosUnknown {
 		m_log.debug("deleteFile()");
 
+		String exportDirectory = HinemosPropertyUtil.getHinemosPropertyStr(
+				"performance.export.dir", "/opt/hinemos/var/export/");
+
 		for (String fileName : fileNameList) {
 			String filePath = exportDirectory + fileName;
 			m_log.debug("deleteFile() targetFileName = " + fileName);
@@ -447,7 +445,7 @@ public class ExportCollectedDataFile {
 
 	/**
 	 * 指定したファイルパスのリストを削除する。ディレクトリチェックは行わない。
-	 * 
+	 *
 	 * @param filePathList
 	 */
 	private static void deleteFilePath(ArrayList<String> filePathList) {
@@ -473,7 +471,7 @@ public class ExportCollectedDataFile {
 
 	/**
 	 * ファイルパスをfromからtoにリネームする
-	 * 
+	 *
 	 * @param from
 	 * @param to
 	 */
@@ -487,11 +485,14 @@ public class ExportCollectedDataFile {
 
 	/**
 	 * 対象ファイルが存在するかをチェックする
-	 * 
+	 *
 	 * @param fileName
 	 * @return
 	 */
 	public static boolean isCreatedFile(String fileName) {
+		String exportDirectory = HinemosPropertyUtil.getHinemosPropertyStr(
+				"performance.export.dir", "/opt/hinemos/var/export/");
+
 		String createFilePath = exportDirectory + fileName;
 		File file = new File(createFilePath);
 
@@ -500,7 +501,7 @@ public class ExportCollectedDataFile {
 
 	/**
 	 * 指定したファイルに書き込み可能かをチェックする。ファイルが存在しない場合は、新規作成を試み、その可否を返す。
-	 * 
+	 *
 	 * @param file
 	 * @return
 	 * @throws IOException
@@ -519,8 +520,7 @@ public class ExportCollectedDataFile {
 
 	/**
 	 * ダウンロードするファイルを作成する処理クラス
-	 * 
-	 * @author hinemos
+	 *
 	 *
 	 */
 	private class CreatePerfFileTask implements Runnable {
@@ -535,7 +535,7 @@ public class ExportCollectedDataFile {
 
 		/**
 		 * デフォルトコンストラクタ
-		 * 
+		 *
 		 * @param monitorId
 		 * @param targetFacilityId
 		 * @param facilityIdList
@@ -577,12 +577,15 @@ public class ExportCollectedDataFile {
 			try {
 				// 新たなスレッドとして開始される場合は、ユーザ情報が格納されていないため、ユーザ情報を改めて格納
 				HinemosSessionContext.instance().setProperty(HinemosSessionContext.LOGIN_USER_ID, m_userId);
-				HinemosSessionContext.instance().setProperty(HinemosSessionContext.IS_ADMINISTRATOR, 
+				HinemosSessionContext.instance().setProperty(HinemosSessionContext.IS_ADMINISTRATOR,
 						new AccessControllerBean().isAdministrator());
-				
+
 				PerformanceDataSettings dataSettings
 				= new CollectorControllerBean().getPerformanceGraphInfo(m_monitorId);
 
+				String exportDirectory = HinemosPropertyUtil.getHinemosPropertyStr(
+						"performance.export.dir", "/opt/hinemos/var/export/");
+
 				////
 				// CSVファイルの作成
 				////
