@@ -23,13 +23,14 @@ import com.clustercontrol.bean.DataRangeConstant;
 import com.clustercontrol.bean.Property;
 import com.clustercontrol.bean.PropertyDefineConstant;
 import com.clustercontrol.performance.bean.PerformanceFilterConstant;
+import com.clustercontrol.util.EndpointManager;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.PropertyUtil;
 import com.clustercontrol.ws.collector.PerformanceFilterInfo;
 
 /**
  * 監視[一覧]のフィルタダイアログに関するutilityクラス
- * 
+ *
  * @version 4.0.0
  * @since 4.0.0
  */
@@ -47,7 +48,7 @@ public class PerformanceFilterPropertyUtil {
 		Timestamp oldestFromDate = null;
 		Timestamp oldestToDate = null;
 
-		ArrayList values = null;
+		ArrayList<?> values = null;
 
 		// 監視ID
 		values = PropertyUtil.getPropertyValue(property,
@@ -118,10 +119,10 @@ public class PerformanceFilterPropertyUtil {
 
 	/**
 	 * 性能[一覧]フィルタ用プロパティを取得します。<BR>
-	 * 
+	 *
 	 * @param locale ロケール情報
 	 * @return 性能[一覧]フィルタ用プロパティ
-	 * 
+	 *
 	 * @see com.clustercontrol.bean.Property
 	 * @see com.clustercontrol.bean.PropertyDefineConstant
 	 * @see com.clustercontrol.bean.PriorityConstant
@@ -129,6 +130,9 @@ public class PerformanceFilterPropertyUtil {
 	 */
 	public static Property getProperty(Locale locale) {
 
+		//マネージャ
+		Property manager =
+				new Property(PerformanceFilterConstant.MANAGER, Messages.getString("facility.manager", locale), PropertyDefineConstant.EDITOR_SELECT);
 		//監視項目ID
 		Property monitorId =
 				new Property(PerformanceFilterConstant.MONITOR_ID, Messages.getString("monitor.id", locale), PropertyDefineConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_64);
@@ -157,6 +161,16 @@ public class PerformanceFilterPropertyUtil {
 		Property latestDate =
 				new Property(PerformanceFilterConstant.LATEST_DATE, Messages.getString("collection.latest.date", locale), PropertyDefineConstant.EDITOR_TEXT);
 
+		Object[] obj = EndpointManager.getActiveManagerSet().toArray();
+		Object[] val = new Object[obj.length + 1];
+		val[0] = "";
+		for(int i = 0; i<obj.length; i++) {
+			val[i + 1] = obj[i];
+		}
+
+		Object[][] managerValues = {val, val};
+		manager.setSelectValues(managerValues);
+		manager.setValue("");
 
 		//値を初期化
 		monitorId.setValue("");
@@ -172,6 +186,7 @@ public class PerformanceFilterPropertyUtil {
 		latestDate.setValue("");
 
 		//修正可否を設定
+		manager.setModify(PropertyDefineConstant.MODIFY_OK);
 		monitorId.setModify(PropertyDefineConstant.MODIFY_OK);
 		monitorTypeId.setModify(PropertyDefineConstant.MODIFY_OK);
 		description.setModify(PropertyDefineConstant.MODIFY_OK);
@@ -187,6 +202,7 @@ public class PerformanceFilterPropertyUtil {
 
 		// 初期表示ツリーを構成。
 		property.removeChildren();
+		property.addChildren(manager);
 		property.addChildren(monitorId);
 		property.addChildren(monitorTypeId);
 		property.addChildren(description);
@@ -206,4 +222,18 @@ public class PerformanceFilterPropertyUtil {
 
 		return property;
 	}
+
+	public static String getManagerName(Property property) {
+		String manager = null;
+		ArrayList<?> values = null;
+
+		// 監視ID
+		values = PropertyUtil.getPropertyValue(property,
+				PerformanceFilterConstant.MANAGER);
+		if (!"".equals(values.get(0))) {
+			manager = (String) values.get(0);
+		}
+
+		return manager;
+	}
 }
