@@ -22,7 +22,9 @@ import java.util.Comparator;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
+import java.util.Map;
 import java.util.Set;
+import java.util.concurrent.ConcurrentHashMap;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -55,24 +57,24 @@ import com.clustercontrol.repository.session.RepositoryControllerBean;
  */
 public class CollectorItemCodeTable {
 	private static Log m_log = LogFactory.getLog( CollectorItemCodeTable.class );
-	private static final HashMap<String, CollectorItemTreeItem> m_codeTable;
+	private static final Map<String, CollectorItemTreeItem> m_codeTable;
 
 	/**
 	 * static field
 	 */
 	static {
-		m_codeTable = new HashMap<String, CollectorItemTreeItem>(); // 収集項目コードがキー
+		m_codeTable = new ConcurrentHashMap<String, CollectorItemTreeItem>(); // 収集項目コードがキー
 
 		JpaTransactionManager jtm = new JpaTransactionManager();
 		if (!jtm.isNestedEm()) {
 			m_log.warn("refresh() : transactioin has not been begined.");
 			jtm.close();
 		} else {
-	
+
 			// カテゴリコードからカテゴリ情報を参照するためのテーブル
 			HashMap<String, CollectorItemTreeItem> categoryTable =
 					new HashMap<String, CollectorItemTreeItem>();
-	
+
 			// カテゴリ情報の読み込み
 			Collection<CollectorCategoryMstData> cate = null;
 			try {
@@ -81,52 +83,54 @@ public class CollectorItemCodeTable {
 				m_log.warn("static() : "
 						+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 			}
-	
+
 			for(CollectorCategoryMstData category : cate) {
 				CollectorItemTreeItem categoryItem =
 						new CollectorItemTreeItem(null, null, category, null, null);  // 親の要素はないためnull
-	
+
 				// カテゴリコードにマッピングするようにカテゴリ情報を登録
 				categoryTable.put(category.getCategoryCode(), categoryItem);
 			}
-	
-	
-	
+
+
+
 			try {
 				// 収集項目コードの読み込み
 				Collection<CollectorItemCodeMstData> ctItemCodeMst
 				= new OperateCollectItemCodeMaster().findAll();
-	
+
 				for (CollectorItemCodeMstData codeData : ctItemCodeMst) {
 					String itemCode = codeData.getItemCode();
-	
+
 					if(itemCode == null){
 						continue;
 					}
-	
+
 					if(itemCode != null && codeData.getCategoryCode() != null
 							&& codeData.getDeviceSupport() != null && codeData.getGraphRange() != null){
-	
+
 						// カテゴリ名を調べます
 						CollectorItemTreeItem categoryTreeItem = categoryTable.get(codeData.getCategoryCode());
-	
+
 						// 親のオブジェクトを取得（存在しない場合はnull）
-						CollectorItemTreeItem parentItem =
-								m_codeTable.get(codeData.getParentItemCode());
-	
+						CollectorItemTreeItem parentItem = null;
+						if (codeData.getParentItemCode() != null) {
+							m_codeTable.get(codeData.getParentItemCode());
+						}
+
 						// 親のコードが存在しない場合はカテゴリの直下の要素とする
 						if(parentItem == null){
 							parentItem = categoryTreeItem;
 						}
-	
+
 						CollectorItemTreeItem ctItem =
 								new CollectorItemTreeItem(parentItem, codeData, null, null, null);
-	
+
 						// 収集項目コードをキーとして登録
 						m_codeTable.put(itemCode, ctItem);
 					}
 				}
-	
+
 			} catch (Exception e) {
 				m_codeTable.clear();
 				// エラー処理
@@ -138,7 +142,6 @@ public class CollectorItemCodeTable {
 	/**
 	 * 収集項目IDを探索するためのテンポラリ用の内部クラス
 	 * 
-	 * @author hinemos
 	 */
 	private static class PlatformIdAndSubPlatformId {
 		private String m_platformId;
@@ -272,7 +275,7 @@ public class CollectorItemCodeTable {
 							platform.getPlatformId(),
 							platform.getSubPlatformId());
 					if (m_log.isDebugEnabled()) {
-						m_log.debug("getEnableCodeSet() " + "platformId = " + platform.getPlatformId() + 
+						m_log.debug("getEnableCodeSet() " + "platformId = " + platform.getPlatformId() +
 								", subPlatformId = " + platform.getSubPlatformId() +
 								", CollectorCategoryCollectMstEntity size = " + collects.size() +
 								", CollectorItemCalcMethodMstEntity size = " + calsMethods.size());
@@ -289,7 +292,7 @@ public class CollectorItemCodeTable {
 						collects.addAll(physicalCollects);
 						calsMethods.addAll(physicalCalsMethods);
 						if (m_log.isDebugEnabled()) {
-							m_log.debug("getEnableCodeSet() " + "platformId = " + platform.getPlatformId() + 
+							m_log.debug("getEnableCodeSet() " + "platformId = " + platform.getPlatformId() +
 									", physical platform, " +
 									", CollectorCategoryCollectMstEntity size = " + physicalCollects.size() +
 									", CollectorItemCalcMethodMstEntity size = " + physicalCalsMethods.size());
@@ -550,7 +553,7 @@ public class CollectorItemCodeTable {
 	 * 収集項目コードをキーにした、CollectorItemTreeItemのHashMapを返します。
 	 * @return
 	 */
-	public static HashMap<String, CollectorItemTreeItem> getItemCodeMap(){
+	public static Map<String, CollectorItemTreeItem> getItemCodeMap(){
 		return m_codeTable;
 	}
 
