@@ -15,10 +15,6 @@
 
 package com.clustercontrol.performance.view;
 
-import org.eclipse.jface.action.ActionContributionItem;
-import org.eclipse.jface.action.IMenuListener;
-import org.eclipse.jface.action.IMenuManager;
-import org.eclipse.jface.action.IToolBarManager;
 import org.eclipse.jface.action.MenuManager;
 import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.swt.SWT;
@@ -26,7 +22,10 @@ import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Menu;
+import org.eclipse.ui.PlatformUI;
+import org.eclipse.ui.commands.ICommandService;
 
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.bean.Property;
 import com.clustercontrol.performance.bean.PerformanceStatusConstant;
 import com.clustercontrol.performance.composite.PerformanceListComposite;
@@ -38,15 +37,15 @@ import com.clustercontrol.performance.view.action.RefreshPerformanceListAction;
 import com.clustercontrol.view.CommonViewPart;
 /**
  * 性能[一覧]ビュークラス<BR>
- * 
- * @version 4.0.0
+ *
+ * @version 5.0.0
  * @since 4.0.0
  */
 public class PerformanceListView extends CommonViewPart {
 
 
 	/** 性能[一覧]ビューID */
-	public static final String ID = "com.clustercontrol.performance.view.PerformanceListView";
+	public static final String ID = PerformanceListView.class.getName();
 
 	/** 性能一覧コンポジット */
 	private PerformanceListComposite composite = null;
@@ -54,6 +53,9 @@ public class PerformanceListView extends CommonViewPart {
 	/** 検索条件 */
 	private Property condition = null;
 
+	/** 実績収集の状態 */
+	private int status = PerformanceStatusConstant.TYPE_INIT;
+
 	/**
 	 * コンストラクタ
 	 */
@@ -63,7 +65,7 @@ public class PerformanceListView extends CommonViewPart {
 
 	/**
 	 * ViewPartへのコントロール作成処理<BR>
-	 * 
+	 *
 	 * @see org.eclipse.ui.IWorkbenchPart#createPartControl(org.eclipse.swt.widgets.Composite)
 	 */
 	@Override
@@ -74,6 +76,7 @@ public class PerformanceListView extends CommonViewPart {
 		layout.marginWidth = 0;
 
 		composite = new PerformanceListComposite(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, null, composite);
 		GridData gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
@@ -93,56 +96,23 @@ public class PerformanceListView extends CommonViewPart {
 
 	/**
 	 * コンテキストメニューを作成します。
-	 * 
+	 *
 	 * @see org.eclipse.jface.action.MenuManager
 	 * @see org.eclipse.swt.widgets.Menu
 	 */
 	private void createContextMenu() {
 		MenuManager menuManager = new MenuManager();
 		menuManager.setRemoveAllWhenShown(true);
-		menuManager.addMenuListener(new IMenuListener() {
-			/* (non-Javadoc)
-			 * @see org.eclipse.jface.action.IMenuListener#menuAboutToShow(org.eclipse.jface.action.IMenuManager)
-			 */
-			@Override
-			public void menuAboutToShow(IMenuManager manager) {
-				//メニュー項目設定
-				fillContextMenu(manager);
-			}
-		});
 
 		Menu menu = menuManager.createContextMenu(composite.getTable());
+		WidgetTestUtil.setTestId(this, null, menu);
 		composite.getTable().setMenu(menu);
-	}
-
-	/**
-	 * コンテキストメニューに項目を追加します。
-	 * 
-	 * @param manager メニューマネージャ
-	 * 
-	 * @see org.eclipse.jface.action.IToolBarManager
-	 * @see org.eclipse.jface.action.IMenuManager
-	 */
-	private void fillContextMenu(IMenuManager manager) {
-		//ビューのアクションのインスタンスを取得
-		//		import com.clustercontrol.performance.view.action.AddGraphAction;
-		//		import com.clustercontrol.performance.view.action.ExportCollectedDataAction;
-
-		IToolBarManager toolbar =
-				this.getViewSite().getActionBars().getToolBarManager();
-		ActionContributionItem addGraph =
-				(ActionContributionItem) toolbar.find(AddGraphAction.ID);
-		ActionContributionItem exportCollectedData =
-				(ActionContributionItem) toolbar.find(ExportCollectedDataAction.ID);
-
-		//ポップアップメニューにアクションを追加
-		manager.add(addGraph.getAction());
-		manager.add(exportCollectedData.getAction());
+		getSite().registerContextMenu( menuManager, this.composite.getTableViewer() );
 	}
 
 	/**
 	 * 追加コンポジットを返します。
-	 * 
+	 *
 	 * @return 追加コンポジット
 	 */
 	public Composite getListComposite() {
@@ -152,9 +122,9 @@ public class PerformanceListView extends CommonViewPart {
 	/**
 	 * 検索条件にヒットした監視設定の一覧を表示します。
 	 * <p>
-	 * 
+	 *
 	 * conditionがnullの場合、全監視設定を表示します。
-	 * 
+	 *
 	 * @param condition
 	 *            検索条件
 	 */
@@ -167,7 +137,7 @@ public class PerformanceListView extends CommonViewPart {
 	/**
 	 * 検索条件を設定します。
 	 * <p>設定後の<code>update</code>は、この検索条件の結果が表示されます。
-	 * 
+	 *
 	 * @param condition 検索条件
 	 */
 	public void setCondition(Property condition) {
@@ -177,7 +147,7 @@ public class PerformanceListView extends CommonViewPart {
 	/**
 	 * ビューを更新します。
 	 * <p>
-	 * 
+	 *
 	 * 検索条件が事前に設定されている場合、その条件にヒットする監視設定の一覧を 表示します <br>
 	 * 検索条件が設定されていない場合は、全監視設定を表示します。
 	 */
@@ -202,53 +172,52 @@ public class PerformanceListView extends CommonViewPart {
 	}
 
 	/**
-	 * ビューのアクションの有効/無効を設定します。
-	 * 
-	 * @param eventNum 表示イベント数
-	 * @param selection ボタン（アクション）を有効にするための情報
-	 * 
-	 * @see com.clustercontrol.bean.FacilityConstant
+	 * 選択されているマネージャ名を返します。
+	 * @return
 	 */
-	public void setEnabledAction(int eventNum) {
-		//ビューアクションの使用可/不可を設定
-		if (eventNum == 0) {
-			super.setEnabledAction(AddGraphAction.ID, false);
-			super.setEnabledAction(ExportCollectedDataAction.ID, false);
-		}else if (eventNum > 0) {
-			super.setEnabledAction(AddGraphAction.ID, true);
-			super.setEnabledAction(ExportCollectedDataAction.ID, true);
-		}
-		super.setEnabledAction(PerformanceListFilterAction.ID, true);
-		super.setEnabledAction(RefreshPerformanceListAction.ID, true);
+	public String getSelectedManagerName(){
+		return composite.getSelectedManagerName();
+	}
+
+	/**
+	 * 実績収集ステータスを返します。
+	 * @return status
+	 */
+	public int getStatus() {
+		return this.status;
+	}
+
+	/**
+	 * ボタンを初期状態へ戻す
+	 */
+	public void initButton() {
+		setEnabledAction(-1, null);
 	}
 
 	/**
 	 * ビューのアクションの有効/無効を設定します。
-	 * 
+	 *
 	 * @param num 選択イベント数
 	 * @param selection ボタン（アクション）を有効にするための情報
 	 */
 	public void setEnabledAction(int status, ISelection selection) {
+		this.status = status;
+
 		//ビューアクションの使用可/不可を設定
-		super.setEnabledAction(AddGraphAction.ID, selection);
-		super.setEnabledAction(ExportCollectedDataAction.ID, selection);
-		super.setEnabledAction(PerformanceListFilterAction.ID, selection);
-		super.setEnabledAction(RefreshPerformanceListAction.ID, selection);
+		ICommandService service = (ICommandService) PlatformUI.getWorkbench().getService( ICommandService.class );
+		if( null != service ){
 
-		if (status == PerformanceStatusConstant.TYPE_RUNNING) {
-			super.setEnabledAction(AddGraphAction.ID, true);
-			super.setEnabledAction(ExportCollectedDataAction.ID, true);
-			super.setEnabledAction(PerformanceListFilterAction.ID, true);
-			super.setEnabledAction(RefreshPerformanceListAction.ID, true);
+			service.refreshElements(AddGraphAction.ID, null);
+			service.refreshElements(ExportCollectedDataAction.ID, null);
+			service.refreshElements(PerformanceListFilterAction.ID, null);
+			service.refreshElements(RefreshPerformanceListAction.ID, null);
 
-		} else if (status == PerformanceStatusConstant.TYPE_STOP) {
-			super.setEnabledAction(AddGraphAction.ID, true);
-			super.setEnabledAction(ExportCollectedDataAction.ID, true);
-			super.setEnabledAction(PerformanceListFilterAction.ID, true);
-			super.setEnabledAction(RefreshPerformanceListAction.ID, true);
+			// Update ToolBar after elements refreshed
+			// WARN : Both ToolBarManager must be updated after updateActionBars(), otherwise icon won't change.
+			getViewSite().getActionBars().updateActionBars();
+			getViewSite().getActionBars().getToolBarManager().update(false);
 
 		}
-
 	}
 
 }
