@@ -23,19 +23,17 @@ import org.eclipse.swt.events.ModifyEvent;
 import org.eclipse.swt.events.ModifyListener;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
-import org.eclipse.swt.widgets.Combo;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Group;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.monitor.run.dialog.CommonMonitorNumericDialog;
 import com.clustercontrol.monitor.util.MonitorSettingEndpointWrapper;
-import com.clustercontrol.notify.util.NotifyGroupIdGenerator;
-import com.clustercontrol.ping.bean.PingRunCountConstant;
 import com.clustercontrol.ping.bean.PingRunIntervalConstant;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.monitor.InvalidRole_Exception;
@@ -45,7 +43,7 @@ import com.clustercontrol.ws.monitor.PingCheckInfo;
 
 /**
  * ping監視作成・変更ダイアログクラス<BR>
- * 
+ *
  * @version 4.0.0
  * @since 2.0.0
  */
@@ -59,35 +57,33 @@ public class PingCreateDialog extends CommonMonitorNumericDialog {
 	private Text m_textTimeout = null;
 
 	/** 実行回数 */
-	private Combo m_comboRunCount = null;
+	private Text m_textRunCount = null;
 
 	/** 実行間隔（秒） */
-	private Combo m_comboRunInterval = null;
+	private Text m_textRunInterval = null;
 
 	// ----- コンストラクタ ----- //
 
 	/**
 	 * 作成用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のシェルオブジェクト
 	 */
 	public PingCreateDialog(Shell parent) {
-		super(parent);
+		super(parent, null);
 	}
 
 	/**
 	 * 変更用ダイアログのインスタンスを返します。
-	 * 
-	 * @param parent
-	 *            親のシェルオブジェクト
-	 * @param monitorId
-	 *            監視ID
-	 * @param updateFlg
-	 *            更新するか否か（true:変更、false:新規登録）
+	 *
+	 * @param parent 親のシェルオブジェクト
+	 * @param managerName マネージャ名
+	 * @param monitorId 監視ID
+	 * @param updateFlg 更新するか否か（true:変更、false:新規登録）
 	 */
-	public PingCreateDialog(Shell parent, String monitorId, boolean updateFlg) {
-		super(parent);
+	public PingCreateDialog(Shell parent, String managerName, String monitorId, boolean updateFlg) {
+		super(parent, managerName);
 
 		this.monitorId = monitorId;
 		this.updateFlg = updateFlg;
@@ -97,7 +93,7 @@ public class PingCreateDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のインスタンス
 	 */
@@ -126,13 +122,14 @@ public class PingCreateDialog extends CommonMonitorNumericDialog {
 		 * チェック設定グループ（条件グループの子グループ）
 		 */
 		Group groupCheckRule = new Group(groupRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "checkrule", groupCheckRule);
 		GridLayout layout = new GridLayout(1, true);
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
-		layout.numColumns = 15;
+		layout.numColumns = BASIC_UNIT;
 		groupCheckRule.setLayout(layout);
 		gridData = new GridData();
-		gridData.horizontalSpan = 15;
+		gridData.horizontalSpan = BASIC_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		groupCheckRule.setLayoutData(gridData);
@@ -144,28 +141,37 @@ public class PingCreateDialog extends CommonMonitorNumericDialog {
 		 */
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "runcount", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("run.count") + " : ");
-		// コンボボックス
-		this.m_comboRunCount = new Combo(groupCheckRule, SWT.DROP_DOWN | SWT.READ_ONLY);
-		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_VALUE;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		this.m_comboRunCount.setLayoutData(gridData);
-		this.m_comboRunCount.add(PingRunCountConstant.STRING_COUNT_01);
-		this.m_comboRunCount.add(PingRunCountConstant.STRING_COUNT_02);
 
-		// 空白
-		label = new Label(groupCheckRule, SWT.NONE);
+		// テキスト
+		this.m_textRunCount= new Text(groupCheckRule, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "runcount", m_textRunCount);
 		gridData = new GridData();
-		gridData.horizontalSpan = 8;
+		gridData.horizontalSpan = WIDTH_VALUE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
+		this.m_textRunCount.setLayoutData(gridData);
+		this.m_textRunCount.addModifyListener(new ModifyListener(){
+			@Override
+			public void modifyText(ModifyEvent arg0) {
+				update();
+			}
+		});
+
+		// 単位
+		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "count", label);
+		gridData = new GridData();
+		gridData.horizontalSpan = WIDTH_TEXT_LONG;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		label.setText(Messages.getString("count"));
 		label.setLayoutData(gridData);
 
 		/*
@@ -173,29 +179,37 @@ public class PingCreateDialog extends CommonMonitorNumericDialog {
 		 */
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "runinterval", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("run.interval") + " : ");
-		// コンボボックス
-		this.m_comboRunInterval = new Combo(groupCheckRule, SWT.DROP_DOWN | SWT.READ_ONLY);
-		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_VALUE;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		this.m_comboRunInterval.setLayoutData(gridData);
-		this.m_comboRunInterval.add(PingRunIntervalConstant.STRING_SEC_01);
-		this.m_comboRunInterval.add(PingRunIntervalConstant.STRING_SEC_02);
-		this.m_comboRunInterval.add(PingRunIntervalConstant.STRING_SEC_05);
 
-		// 空白
-		label = new Label(groupCheckRule, SWT.NONE);
+		// テキスト
+		this.m_textRunInterval= new Text(groupCheckRule, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "runinterval", m_textRunInterval);
 		gridData = new GridData();
-		gridData.horizontalSpan = 8;
+		gridData.horizontalSpan = WIDTH_VALUE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
+		this.m_textRunInterval.setLayoutData(gridData);
+		this.m_textRunInterval.addModifyListener(new ModifyListener(){
+			@Override
+			public void modifyText(ModifyEvent arg0) {
+				update();
+			}
+		});
+
+		// 単位
+		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "millisec", label);
+		gridData = new GridData();
+		gridData.horizontalSpan = WIDTH_TEXT_LONG;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		label.setText(Messages.getString("milli.sec"));
 		label.setLayoutData(gridData);
 
 		/*
@@ -203,8 +217,9 @@ public class PingCreateDialog extends CommonMonitorNumericDialog {
 		 */
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "timeout", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -212,8 +227,9 @@ public class PingCreateDialog extends CommonMonitorNumericDialog {
 
 		// テキスト
 		this.m_textTimeout = new Text(groupCheckRule, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "timeout", m_textTimeout);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_VALUE;
+		gridData.horizontalSpan = WIDTH_VALUE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.m_textTimeout.setLayoutData(gridData);
@@ -226,8 +242,9 @@ public class PingCreateDialog extends CommonMonitorNumericDialog {
 
 		// ラベル（単位）
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "labelmillisec", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_VALUE;
+		gridData.horizontalSpan = WIDTH_VALUE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -235,8 +252,9 @@ public class PingCreateDialog extends CommonMonitorNumericDialog {
 
 		// 空白
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "responsetime", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = 7;
+		gridData.horizontalSpan = 14;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -247,9 +265,6 @@ public class PingCreateDialog extends CommonMonitorNumericDialog {
 		// 収集値単位のデフォルト値を設定
 		this.measure.setText(Messages.getString("time.msec"));
 
-		// 閾値検証フラグを設定
-		this.m_numericValueInfo.setRangeFlg(false);
-
 		// ダイアログを調整
 		this.adjustDialog();
 
@@ -262,7 +277,8 @@ public class PingCreateDialog extends CommonMonitorNumericDialog {
 		} else {
 			// 変更の場合、情報取得
 			try {
-				info = MonitorSettingEndpointWrapper.getMonitor(this.monitorId, HinemosModuleConstant.MONITOR_PING);
+				MonitorSettingEndpointWrapper wrapper = MonitorSettingEndpointWrapper.getWrapper(getManagerName());
+				info = wrapper.getMonitor(this.monitorId, HinemosModuleConstant.MONITOR_PING);
 			} catch (InvalidRole_Exception e) {
 				// アクセス権なしの場合、エラーダイアログを表示する
 				MessageDialog.openInformation(
@@ -287,7 +303,7 @@ public class PingCreateDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * 更新処理
-	 * 
+	 *
 	 */
 	@Override
 	public void update(){
@@ -304,7 +320,7 @@ public class PingCreateDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * 各項目に入力値を設定します。
-	 * 
+	 *
 	 * @param monitor
 	 *            設定値として用いる通知情報
 	 */
@@ -317,10 +333,11 @@ public class PingCreateDialog extends CommonMonitorNumericDialog {
 		// 監視条件 ping監視情報
 		PingCheckInfo pingInfo = monitor.getPingCheckInfo();
 		if (pingInfo.getRunCount() != null) {
-			this.m_comboRunCount.setText(PingRunCountConstant.typeToString(pingInfo.getRunCount().intValue()));
+			this.m_textRunCount.setText(pingInfo.getRunCount().toString());
 		}
 		if (pingInfo.getRunInterval() != null) {
-			this.m_comboRunInterval.setText(PingRunIntervalConstant.typeToString(pingInfo.getRunInterval().intValue()));
+			//this.m_comboRunInterval.setText(PingRunIntervalConstant.typeToString(pingInfo.getRunInterval().intValue()));
+			this.m_textRunInterval.setText(pingInfo.getRunInterval().toString());
 		}
 		if (pingInfo.getTimeout() != null) {
 			this.m_textTimeout.setText(pingInfo.getTimeout().toString());
@@ -331,7 +348,7 @@ public class PingCreateDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * 入力値を用いて通知情報を生成します。
-	 * 
+	 *
 	 * @return 入力値を保持した通知情報
 	 */
 	@Override
@@ -349,13 +366,28 @@ public class PingCreateDialog extends CommonMonitorNumericDialog {
 
 		pingInfo.setMonitorTypeId(HinemosModuleConstant.MONITOR_PING);
 		pingInfo.setMonitorId(monitorInfo.getMonitorId());
-		if (this.m_comboRunCount.getText() != null
-				&& !"".equals((this.m_comboRunCount.getText()).trim())) {
-			pingInfo.setRunCount(PingRunCountConstant.stringToType(this.m_comboRunCount.getText()));
+
+		if (!"".equals((this.m_textRunCount.getText()).trim())) {
+
+			try{
+				Integer runcount = new Integer(this.m_textRunCount.getText().trim());
+				pingInfo.setRunCount(runcount);
+			}
+			catch(NumberFormatException e){
+				this.setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.ping.1"));
+				return null;
+			}
 		}
-		if (this.m_comboRunInterval.getText() != null
-				&& !"".equals((this.m_comboRunInterval.getText()).trim())) {
-			pingInfo.setRunInterval(PingRunIntervalConstant.stringToType(this.m_comboRunInterval.getText()));
+		if (!"".equals((this.m_textRunInterval.getText()).trim())) {
+
+			try{
+				Integer runinterval = new Integer(this.m_textRunInterval.getText().trim());
+				pingInfo.setRunInterval(runinterval);
+			}
+			catch(NumberFormatException e){
+				this.setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.ping.2"));
+				return null;
+			}
 		}
 		if (!"".equals((this.m_textTimeout.getText()).trim())) {
 
@@ -377,8 +409,6 @@ public class PingCreateDialog extends CommonMonitorNumericDialog {
 		}
 
 		// 通知関連情報とアプリケーションの設定
-		// 通知グループIDの設定
-		monitorInfo.setNotifyGroupId(NotifyGroupIdGenerator.createNotifyGroupId(HinemosModuleConstant.MONITOR_PING, pingInfo.getMonitorId()));
 		validateResult = m_notifyInfo.createInputData(monitorInfo);
 		if (validateResult != null) {
 			if(validateResult.getID() == null){	// 通知ID警告用出力
@@ -397,9 +427,9 @@ public class PingCreateDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * 入力値をマネージャに登録します。
-	 * 
+	 *
 	 * @return true：正常、false：異常
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#action()
 	 */
 	@Override
@@ -407,12 +437,14 @@ public class PingCreateDialog extends CommonMonitorNumericDialog {
 		boolean result = false;
 
 		MonitorInfo info = this.inputData;
+		String managerName = this.getManagerName();
+		MonitorSettingEndpointWrapper wrapper = MonitorSettingEndpointWrapper.getWrapper(managerName);
 		if(info != null){
-			String[] args = { info.getMonitorId() };
+			String[] args = { info.getMonitorId(), managerName };
 			if(!this.updateFlg){
 				// 作成の場合
 				try {
-					result = MonitorSettingEndpointWrapper.addMonitor(info);
+					result = wrapper.addMonitor(info);
 
 					if(result){
 						MessageDialog.openInformation(
@@ -456,7 +488,7 @@ public class PingCreateDialog extends CommonMonitorNumericDialog {
 				// 変更の場合
 				String errMessage = "";
 				try {
-					result = MonitorSettingEndpointWrapper.modifyMonitor(info);
+					result = wrapper.modifyMonitor(info);
 				} catch (InvalidRole_Exception e) {
 					// アクセス権なしの場合、エラーダイアログを表示する
 					MessageDialog.openInformation(
@@ -487,7 +519,7 @@ public class PingCreateDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * MonitorInfoに初期値を設定します
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonMonitorDialog#setInfoInitialValue()
 	 */
 	@Override
@@ -497,7 +529,7 @@ public class PingCreateDialog extends CommonMonitorNumericDialog {
 
 		PingCheckInfo pingCheckInfo = new PingCheckInfo();
 		// 実行回数
-		pingCheckInfo.setRunCount(PingRunCountConstant.TYPE_COUNT_01);
+		pingCheckInfo.setRunCount(RUNCOUNT_COUNT);
 		// 実行間隔（秒）
 		pingCheckInfo.setRunInterval(PingRunIntervalConstant.TYPE_SEC_01);
 		// タイムアウト（ミリ秒）
@@ -505,4 +537,4 @@ public class PingCreateDialog extends CommonMonitorNumericDialog {
 		monitor.setPingCheckInfo(pingCheckInfo);
 	}
 
-}
\ No newline at end of file
+}
