@@ -26,25 +26,16 @@ import java.util.Iterator;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
-import javax.ejb.CreateException;
-import javax.ejb.FinderException;
-import javax.ejb.RemoveException;
-import javax.naming.NamingException;
-import javax.transaction.HeuristicMixedException;
-import javax.transaction.HeuristicRollbackException;
-import javax.transaction.InvalidTransactionException;
-import javax.transaction.NotSupportedException;
-import javax.transaction.RollbackException;
-import javax.transaction.SystemException;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import com.clustercontrol.fault.FacilityNotFound;
-import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.bean.ValidConstant;
+import com.clustercontrol.fault.FacilityNotFound;
+import com.clustercontrol.fault.HinemosUnknown;
+import com.clustercontrol.fault.InvalidRole;
+import com.clustercontrol.fault.MonitorNotFound;
 import com.clustercontrol.monitor.bean.MonitorBlockConstant;
 import com.clustercontrol.monitor.run.bean.MonitorNumericValueInfo;
 import com.clustercontrol.monitor.run.factory.RunMonitor;
@@ -55,13 +46,14 @@ import com.clustercontrol.performance.util.PerformanceDataUtil;
 import com.clustercontrol.ping.bean.PingResult;
 import com.clustercontrol.ping.bean.PingRunCountConstant;
 import com.clustercontrol.ping.bean.PingRunIntervalConstant;
-import com.clustercontrol.ping.ejb.entity.MonitorPingInfoLocal;
-import com.clustercontrol.ping.ejb.entity.MonitorPingInfoUtil;
+import com.clustercontrol.ping.model.MonitorPingInfoEntity;
 import com.clustercontrol.ping.util.PingProperties;
+import com.clustercontrol.ping.util.QueryUtil;
 import com.clustercontrol.ping.util.ReachAddress;
 import com.clustercontrol.ping.util.ReachAddressFping;
 import com.clustercontrol.priority.util.PriorityJudgment;
 import com.clustercontrol.repository.bean.NodeInfo;
+import com.clustercontrol.repository.session.RepositoryControllerBean;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.apllog.AplLogger;
 
@@ -84,7 +76,7 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 	private static boolean fpingEnable;
 
 	/** ping監視情報 */
-	private MonitorPingInfoLocal m_ping = null;
+	private MonitorPingInfoEntity m_ping = null;
 
 	/** 実行回数 */
 	private int m_runCount = PingRunCountConstant.TYPE_COUNT_01;
@@ -113,27 +105,21 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 	//fping実行
 	private ReachAddressFping m_reachabilityFping = null;
 
-	//fping利用時のfping出力メッセージ
-	private ArrayList m_MsgOrg= null;
+	//fping利用時のfpingエラー出力メッセージ
+	private ArrayList<String> m_MsgErr= null;
 
 	//fping利用時のfpingエラー出力メッセージ
-	private ArrayList m_MsgErr= null;
-
-	//fping利用時のfping出力メッセージ
-	private ArrayList m_MsgOrgV6= null;
-
-	//fping利用時のfpingエラー出力メッセージ
-	private ArrayList m_MsgErrV6= null;
+	private ArrayList<String> m_MsgErrV6= null;
 
 
-	private Hashtable m_Target;
+	private Hashtable<String, String[]> m_Target;
 
 	/**
 	 * 
 	 * コンストラクタ
 	 * 
 	 */
-	public RunMonitorPing() throws NamingException, CreateException{
+	public RunMonitorPing() {
 		super();
 
 		PingProperties.getProperties();
@@ -147,7 +133,7 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 	 * @see com.clustercontrol.monitor.run.util.CallableTask
 	 */
 	@Override
-	protected RunMonitor createMonitorInstance() throws NamingException, CreateException{
+	protected RunMonitor createMonitorInstance() {
 		return new RunMonitorPing();
 	}
 
@@ -158,7 +144,6 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 	 * @return 値取得に成功した場合、true
 	 */
 	@Override
-	@SuppressWarnings("unchecked")
 	public boolean collect(String facilityId) {
 
 		if (m_now != null) {
@@ -176,7 +161,7 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 
 		try{
 			// ノードの属性取得
-			NodeInfo info = m_repository.getNode(facilityId);
+			NodeInfo info = new RepositoryControllerBean().getNode(facilityId);
 
 			String ipNetworkNumber = info.getIpAddressV4();
 			String nodeName = info.getNodeName();
@@ -192,8 +177,10 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 			return result;
 		}
 		catch(FacilityNotFound e){
-			m_log.debug("run():" + e.getMessage());
-
+			m_message = Messages.getString("message.ping.4");
+			m_messageOrg = e.getMessage();
+			return false;
+		} catch(HinemosUnknown e){
 			m_message = Messages.getString("message.ping.4");
 			m_messageOrg = e.getMessage();
 			return false;
@@ -202,12 +189,11 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 
 	/**
 	 * 　fpingによるping数の取得を行います。<BR>
-	 * @author Yosuke Miyamoto
-	 * @version 2.2.3 bata
 	 * @param facilityId Ping対象のファシリティID(スコープ)collectのfacilityIDとは異なる
 	 * @return 値取得に成功した場合、true
+	 * @throws HinemosUnknown
 	 */
-	private boolean collectFping(ArrayList facilityList, ArrayList priporityList) {
+	private boolean collectFping(ArrayList<String> facilityList, ArrayList<Integer> priporityList) throws HinemosUnknown {
 
 		//ノードの収集時刻を保存
 		if (m_now != null) {
@@ -219,16 +205,15 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 		// hostsv6[] → IPv6アドレスリスト(Stringの配列)
 		// node    → IPアドレスとノード名のリスト
 		// target  → nodoのリスト
-
-		HashSet hosts     = new HashSet();
-		HashSet hostsv6   = new HashSet();
-		m_Target = new Hashtable();
+		HashSet<String> hosts     = new HashSet<String>();
+		HashSet<String> hostsv6   = new HashSet<String>();
+		m_Target = new Hashtable<String, String[]>();
 
 		String facilityId = null;
 		int version = 4;
 		String[] node;
 		for(int index=0; index<facilityList.size(); index++){
-			facilityId = (String)facilityList.get(index);
+			facilityId = facilityList.get(index);
 			if(facilityId != null && !"".equals(facilityId)){
 
 				node = new String[2];
@@ -236,7 +221,7 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 				try{
 
 					// ノードの属性取得
-					NodeInfo info = m_repository.getNode(facilityId);
+					NodeInfo info = new RepositoryControllerBean().getNode(facilityId);
 
 					//m_log.error(facilityAttrMap.get(FacilityAttributeConstant.IPPROTOCOLNUMBER));
 					//プロトコルのバージョンが指定されていればversionを指定する。
@@ -254,7 +239,10 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 						if(ip.length != 1){
 							//IPアドレスをInetAddressクラスでデコードしているのに1つじゃないときは
 							//UnnownHostExcption
-							throw new UnknownHostException();
+							UnknownHostException e = new UnknownHostException();
+							m_log.info("collectFping() : "
+									+ e.getClass().getSimpleName() + ", " + e.getMessage());
+							throw e;
 						}
 
 						node[0] = ip[0].getHostAddress();
@@ -278,14 +266,11 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 						m_Target.put(facilityId,node);
 					}
 				}catch(FacilityNotFound e){
-					m_log.error("collectFping():" + e.getMessage());
-
 					m_message = Messages.getString("message.ping.4");
 					m_messageOrg = e.getMessage();
 					return false;
 				} catch (UnknownHostException e) {
-
-					e.printStackTrace();
+					// 何もしない
 				}
 			}
 		}
@@ -301,15 +286,12 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 
 			result = m_reachabilityFping.isReachable(hosts , 4);
 			m_MsgErr = m_reachabilityFping.getM_errMsg();
-			m_MsgOrg = m_reachabilityFping.getM_resultMsg();
-
 		}
 		//IPv6のホストが在ればfping6を利用して監視
 		if(hostsv6.size() !=0 ) {
 
 			resultTmp = m_reachabilityFping.isReachable(hostsv6 , 6);
 			m_MsgErrV6 = m_reachabilityFping.getM_errMsg();
-			m_MsgOrgV6 = m_reachabilityFping.getM_resultMsg();
 
 			//結果は&であわせる
 			result = result & resultTmp;
@@ -396,13 +378,14 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 				String[] strs = message.split(" ");
 				try
 				{
-					InetAddress address = InetAddress.getByName(strs[0]);
+					InetAddress.getByName(strs[0]);
 					bValidIP = true;
 				}
 				catch (Exception e)
 				{
-					m_log.error("wrapUpFping(): invalid IPv6 adress: original message: " + message);
-					m_log.error("wrapUpFping(): stack trace: " + e.getMessage());
+					m_log.warn("wrapUpFping() invalid IPv6 adress: original message: " + message, e);
+					m_log.warn("wrapUpFping() stack trace: "
+							+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 				}
 			}
 			else
@@ -590,10 +573,10 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 	 * @see com.clustercontrol.monitor.run.factory.OperationNumericValueInfo#setMonitorAdditionInfo()
 	 */
 	@Override
-	protected void setCheckInfo() throws FinderException, NamingException{
+	protected void setCheckInfo() throws MonitorNotFound {
 
 		// ping監視情報を取得
-		m_ping = MonitorPingInfoUtil.getLocalHome().findByPrimaryKey(m_monitorId);
+		m_ping = QueryUtil.getMonitorPingInfoPK(m_monitorId);
 
 		// ping監視情報を設定
 		if(m_ping.getRunCount() != null)
@@ -717,11 +700,7 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 	 * </ol>
 	 * 
 	 * @return 実行に成功した場合、</code> true </code>
-	 * @throws FinderException
-	 * @throws RemoveException
-	 * @throws JMSException
-	 * @throws NamingException
-	 * @throws CreateException
+	 * @throws MonitorNotFound
 	 * @throws HinemosUnknown
 	 * 
 	 * @see #setMonitorInfo(String, String)
@@ -732,227 +711,222 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 	 * @see #getPriority(int)
 	 * @see #notify(boolean, String, int, Date)
 	 */
-	@SuppressWarnings("unchecked")
 	@Override
-	protected boolean runMonitorInfo()throws FinderException, RemoveException, NamingException, CreateException, HinemosUnknown {
+	protected boolean runMonitorInfo()throws MonitorNotFound, HinemosUnknown {
 
 		m_now = new Date();
-
-		m_priorityMap = new HashMap();
+		m_priorityMap = new HashMap<Integer, ArrayList<String>>();
 		m_priorityMap.put(Integer.valueOf(PriorityConstant.TYPE_INFO),		new ArrayList<String>());
 		m_priorityMap.put(Integer.valueOf(PriorityConstant.TYPE_WARNING),	new ArrayList<String>());
 		m_priorityMap.put(Integer.valueOf(PriorityConstant.TYPE_CRITICAL),	new ArrayList<String>());
 		m_priorityMap.put(Integer.valueOf(PriorityConstant.TYPE_UNKNOWN),	new ArrayList<String>());
 
-		try
-		{
-			// 監視基本情報を設定
-			boolean run = this.setMonitorInfo(m_monitorTypeId, m_monitorId);
-			if(!run){
-				// 処理終了
-				return true;
-			}
+		// 監視基本情報を設定
+		boolean run = this.setMonitorInfo(m_monitorTypeId, m_monitorId);
+		if(!run){
+			// 処理終了
+			return true;
+		}
 
-			// 判定情報を設定
-			setJudgementInfo();
+		// 判定情報を設定
+		setJudgementInfo();
 
-			// チェック条件情報を設定
-			setCheckInfo();
+		// チェック条件情報を設定
+		setCheckInfo();
 
-			// ファシリティIDの配下全ての一覧を取得
-			ArrayList facilityList = m_repository.getExecTargetFacilityIdList(m_facilityId);
-			if (facilityList.size() == 0) return true;
+		// ファシリティIDの配下全ての一覧を取得
+		ArrayList<String> facilityList = new RepositoryControllerBean().getExecTargetFacilityIdList(m_facilityId, m_monitor.getOwnerRoleId());
+		if (facilityList.size() == 0) return true;
 
 
-			// ファシリティ毎に監視情報を収集
-			ArrayList<Integer> priorityList = new ArrayList<Integer>();
+		// ファシリティ毎に監視情報を収集
+		ArrayList<Integer> priorityList = new ArrayList<Integer>();
 
-			// 収集値の入れ物を作成
-			Sample sample = null;
-			if(m_monitor.getCollectorFlg() == ValidConstant.TYPE_VALID){
-				sample = new Sample(m_monitorId, new Date());
-			}
+		// 収集値の入れ物を作成
+		Sample sample = null;
+		if(m_monitor.getCollectorFlg() == ValidConstant.TYPE_VALID){
+			sample = new Sample(m_monitorId, new Date());
+		}
 
-			//fping利用フラグがfalseの時はver2.2までの方式でping監視を行う。
-			if(!fpingEnable){
+		//fping利用フラグがfalseの時はver2.2までの方式でping監視を行う。
+		if(!fpingEnable){
 
-				String facilityId = null;
-				for(int index=0; index<facilityList.size(); index++){
-					facilityId = (String)facilityList.get(index);
-					if(facilityId != null && !"".equals(facilityId)){
+			String facilityId = null;
+			for(int index=0; index<facilityList.size(); index++){
+				facilityId = facilityList.get(index);
+				if(facilityId != null && !"".equals(facilityId)){
 
-						// 監視値を収集
-						boolean ret = collect(facilityId);
+					// 監視値を収集
+					boolean ret = collect(facilityId);
 
-						// 監視値より判定結果を取得
-						int checkResult = getCheckResult(ret);
+					// 監視値より判定結果を取得
+					int checkResult = getCheckResult(ret);
 
-						// 監視単位がスコープとノードの場合、スコープ用の情報を設定
-						if(MonitorBlockConstant.TYPE_SCOPE == m_monitorBlock ||
-								MonitorBlockConstant.TYPE_ALL == m_monitorBlock){
+					// 監視単位がスコープとノードの場合、スコープ用の情報を設定
+					if(MonitorBlockConstant.TYPE_SCOPE == m_monitorBlock ||
+							MonitorBlockConstant.TYPE_ALL == m_monitorBlock){
 
-							// 判定結果よりノードの重要度を取得
-							int priority = getPriority(checkResult);
-							// スコープの重要度を設定
-							priorityList.add(Integer.valueOf(priority));
-							// 重要度別にファシリティIDを設定
-							setPriorityMap(Integer.valueOf(priority), facilityId);
-						}
+						// 判定結果よりノードの重要度を取得
+						int priority = getPriority(checkResult);
+						// スコープの重要度を設定
+						priorityList.add(Integer.valueOf(priority));
+						// 重要度別にファシリティIDを設定
+						setPriorityMap(Integer.valueOf(priority), facilityId);
+					}
 
-						// スコープの値取得時刻を設定
-						if(m_nodeDate > m_scopeDate){
-							m_scopeDate = m_nodeDate;
-						}
+					// スコープの値取得時刻を設定
+					if(m_nodeDate > m_scopeDate){
+						m_scopeDate = m_nodeDate;
+					}
 
-						// ノードのログ出力情報を送信
-						if(MonitorBlockConstant.TYPE_NODE == m_monitorBlock ||
-								(MonitorBlockConstant.TYPE_SCOPE == m_monitorBlock && m_isNode) ||
-								MonitorBlockConstant.TYPE_ALL == m_monitorBlock){
+					// ノードのログ出力情報を送信
+					if(MonitorBlockConstant.TYPE_NODE == m_monitorBlock ||
+							(MonitorBlockConstant.TYPE_SCOPE == m_monitorBlock && m_isNode) ||
+							MonitorBlockConstant.TYPE_ALL == m_monitorBlock){
 
-							// 監視管m_now = new Date();理へ通知
-							notify(true, facilityId, checkResult, new Date(m_nodeDate));
+						// 監視管m_now = new Date();理へ通知
+						notify(true, facilityId, checkResult, new Date(m_nodeDate));
 
-							// 収集値の登録
-							if(sample != null){
-								if(ret){
-									sample.set(facilityId, m_monitorId, "", m_value, CollectedDataErrorTypeConstant.NOT_ERROR);
-								}else{
-									sample.set(facilityId, m_monitorId, "", m_value, CollectedDataErrorTypeConstant.UNKNOWN);
-								}
+						// 収集値の登録
+						if(sample != null){
+							if(ret){
+								sample.set(facilityId, m_monitorId, "", m_value, CollectedDataErrorTypeConstant.NOT_ERROR);
+							}else{
+								sample.set(facilityId, m_monitorId, "", m_value, CollectedDataErrorTypeConstant.UNKNOWN);
 							}
 						}
 					}
 				}
-			}//fping利用フラグがtrueの時は新しいping監視を行う。
-			else{
-				//	 監視値を収集
-				//   fpingを利用する場合には、ファシリティのリストを与えて一気にpingします。
-				boolean ret = collectFping(facilityList,priorityList);
+			}
+		}//fping利用フラグがtrueの時は新しいping監視を行う。
+		else{
+			//	 監視値を収集
+			//   fpingを利用する場合には、ファシリティのリストを与えて一気にpingします。
+			boolean ret = collectFping(facilityList,priorityList);
 
 
-				if(ret){
-					Hashtable fpingResultSet = new Hashtable();
-					Hashtable fpingResultSetV6 = new Hashtable();
-					//データの整形を行います。
-					if(m_MsgErr != null){
-						fpingResultSet = wrapUpFping(m_MsgErr, m_runCount,4);
-					}
-					if(m_MsgErrV6 != null){
-						m_log.debug("runMonitorInfo(): fpingResultSetV6 check");
-						fpingResultSetV6 = wrapUpFping(m_MsgErrV6, m_runCount,6);
-					}
+			if(ret){
+				Hashtable<String, PingResult> fpingResultSet = new Hashtable<String, PingResult>();
+				Hashtable<String, PingResult> fpingResultSetV6 = new Hashtable<String, PingResult>();
+				//データの整形を行います。
+				if(m_MsgErr != null){
+					fpingResultSet = wrapUpFping(m_MsgErr, m_runCount,4);
+				}
+				if(m_MsgErrV6 != null){
+					m_log.debug("runMonitorInfo(): fpingResultSetV6 check");
+					fpingResultSetV6 = wrapUpFping(m_MsgErrV6, m_runCount,6);
+				}
 
-					//IPv4の情報が存在しない場合は、IPv6の情報で上書きする
-					m_log.debug("runMonitorInfo(): before fpingResultSet check");
-					if( fpingResultSet.size() == 0){
-						m_log.debug("runMonitorInfo(): after fpingResultSet check");
-						fpingResultSet = fpingResultSetV6;
-					}
-					//IPv4の情報が存在する場合は、IPv6の情報を追加する
-					else if(fpingResultSetV6 .size()!= 0){
-						fpingResultSet.putAll(fpingResultSetV6);
-					}
+				//IPv4の情報が存在しない場合は、IPv6の情報で上書きする
+				m_log.debug("runMonitorInfo(): before fpingResultSet check");
+				if( fpingResultSet.size() == 0){
+					m_log.debug("runMonitorInfo(): after fpingResultSet check");
+					fpingResultSet = fpingResultSetV6;
+				}
+				//IPv4の情報が存在する場合は、IPv6の情報を追加する
+				else if(fpingResultSetV6 .size()!= 0){
+					fpingResultSet.putAll(fpingResultSetV6);
+				}
 
-					//最初に呼び出されたIPアドレスのリスト
-					Iterator it = facilityList.iterator();
+				//最初に呼び出されたIPアドレスのリスト
+				Iterator<String> it = facilityList.iterator();
 
-					String targetFacility;
-					PingResult nodeResult;
-					String[] node;
+				String targetFacility;
+				PingResult nodeResult;
+				String[] node;
 
-					while(it.hasNext()){
+				while(it.hasNext()){
 
-						//与えられたFacilityId個々に
-						targetFacility = (String)it.next();
-						//ノード名、IPアドレスを取得
-						node = (String[]) m_Target.get(targetFacility);
+					//与えられたFacilityId個々に
+					targetFacility = it.next();
+					//ノード名、IPアドレスを取得
+					node = m_Target.get(targetFacility);
 
-						// ポーリングされていないノード(IPアドレス未記入のノード)を除く。
-						if(node != null) {
+					// ポーリングされていないノード(IPアドレス未記入のノード)を除く。
+					if(node != null) {
 
-							m_log.debug("runMonitorInfo(): before fpingResultSet.get()");
-							nodeResult = (PingResult)fpingResultSet.get(node[0]);
+						m_log.debug("runMonitorInfo(): before fpingResultSet.get()");
+						nodeResult = fpingResultSet.get(node[0]);
 
-							if(nodeResult ==null){
-								m_log.debug("runMonitorInfo(): after fpingResultSet.get()");
+						if(nodeResult ==null){
+							m_log.debug("runMonitorInfo(): after fpingResultSet.get()");
 
-								/* fping失敗で結果がありません。*/
-								AplLogger apllog = new AplLogger(HinemosModuleConstant.MONITOR_PING, "ping");
-								String[] args = {m_monitorId};
-								String logMsg = "";
-								if (m_MsgErr != null)
-								{
-									logMsg = m_MsgErr.toString();
-								}
-								if (m_MsgErrV6 != null)
-								{
-									logMsg += " , " + m_MsgErrV6.toString();
-								}
-								apllog.put("SYS", "001", args,logMsg);
-								m_log.error("Fping no response.");
+							/* fping失敗で結果がありません。*/
+							AplLogger apllog = new AplLogger(HinemosModuleConstant.MONITOR_PING, "ping");
+							String[] args = {m_monitorId};
+							String logMsg = "";
+							if (m_MsgErr != null)
+							{
+								logMsg = m_MsgErr.toString();
+							}
+							if (m_MsgErrV6 != null)
+							{
+								logMsg += " , " + m_MsgErrV6.toString();
+							}
+							apllog.put("SYS", "001", args,logMsg);
+							m_log.info("Fping no response.");
 
-								/* fping失敗で結果がありません。*/
-								sample.set(targetFacility, m_monitorId, "", Double.NaN, CollectedDataErrorTypeConstant.UNKNOWN);
-							}else{
+							/* fping失敗で結果がありません。*/
+							sample.set(targetFacility, m_monitorId, "", Double.NaN, CollectedDataErrorTypeConstant.UNKNOWN);
+						}else{
 
-								//結果データからイベントを生成するためにデータを読みだす。
-								m_lost = nodeResult.getLost();
-								//現行の使用の平均応答時間はmsec(long)のため変換する。
-								m_average  = (long)nodeResult.getAverage();
-								m_message  = nodeResult.getMesseage();
-								m_messageOrg = nodeResult.getMesseageOrg();
-								m_value = m_average;
+							//結果データからイベントを生成するためにデータを読みだす。
+							m_lost = nodeResult.getLost();
+							//現行の使用の平均応答時間はmsec(long)のため変換する。
+							m_average  = (long)nodeResult.getAverage();
+							m_message  = nodeResult.getMesseage();
+							m_messageOrg = nodeResult.getMesseageOrg();
+							m_value = m_average;
 
-								if(m_log.isDebugEnabled()){
-									m_log.debug("runMonitorInfo() monitorId = " + m_monitorId + ", facilityId = " + targetFacility + ", average = " + nodeResult.getAverage() + ", value = " + m_value);
-								}
+							if(m_log.isDebugEnabled()){
+								m_log.debug("runMonitorInfo() monitorId = " + m_monitorId + ", facilityId = " + targetFacility + ", average = " + nodeResult.getAverage() + ", value = " + m_value);
+							}
 
-								// 監視値より判定結果を取得
-								int checkResult;
-								// 値取得に失敗している場合
-								if (m_lost == -1) {
-									checkResult = getCheckResult(false);
-								}
-								else {
-									checkResult = getCheckResult(true);
-								}
-								boolean collectorResult = true;
-								if (m_lost == -1 || m_lost == 100) {
-									collectorResult = false;
-								}
+							// 監視値より判定結果を取得
+							int checkResult;
+							// 値取得に失敗している場合
+							if (m_lost == -1) {
+								checkResult = getCheckResult(false);
+							}
+							else {
+								checkResult = getCheckResult(true);
+							}
+							boolean collectorResult = true;
+							if (m_lost == -1 || m_lost == 100) {
+								collectorResult = false;
+							}
 
-								// 監視単位がスコープとノードの場合、スコープ用の情報を設定
-								if(MonitorBlockConstant.TYPE_SCOPE == m_monitorBlock ||
-										MonitorBlockConstant.TYPE_ALL == m_monitorBlock){
+							// 監視単位がスコープとノードの場合、スコープ用の情報を設定
+							if(MonitorBlockConstant.TYPE_SCOPE == m_monitorBlock ||
+									MonitorBlockConstant.TYPE_ALL == m_monitorBlock){
 
-									// 判定結果よりノードの重要度を取得
-									int priority = getPriority(checkResult);
-									// スコープの重要度を設定
-									priorityList.add(Integer.valueOf(priority));
-									// 重要度別にファシリティIDを設定
-									setPriorityMap(Integer.valueOf(priority), targetFacility);
-								}
+								// 判定結果よりノードの重要度を取得
+								int priority = getPriority(checkResult);
+								// スコープの重要度を設定
+								priorityList.add(Integer.valueOf(priority));
+								// 重要度別にファシリティIDを設定
+								setPriorityMap(Integer.valueOf(priority), targetFacility);
+							}
 
-								// スコープの値取得時刻を設定
-								if(m_nodeDate > m_scopeDate){
-									m_scopeDate = m_nodeDate;
-								}
+							// スコープの値取得時刻を設定
+							if(m_nodeDate > m_scopeDate){
+								m_scopeDate = m_nodeDate;
+							}
 
-								// ノードのログ出力情報を送信
-								if(MonitorBlockConstant.TYPE_NODE == m_monitorBlock ||
-										(MonitorBlockConstant.TYPE_SCOPE == m_monitorBlock && m_isNode) ||
-										MonitorBlockConstant.TYPE_ALL == m_monitorBlock){
+							// ノードのログ出力情報を送信
+							if(MonitorBlockConstant.TYPE_NODE == m_monitorBlock ||
+									(MonitorBlockConstant.TYPE_SCOPE == m_monitorBlock && m_isNode) ||
+									MonitorBlockConstant.TYPE_ALL == m_monitorBlock){
 
-									// 監視管理へ通知
-									notify(true, targetFacility, checkResult, new Date(m_nodeDate));
+								// 監視管理へ通知
+								notify(true, targetFacility, checkResult, new Date(m_nodeDate));
 
-									// 収集値の登録
-									if(sample != null){
-										if(collectorResult){
-											sample.set(targetFacility, m_monitorId, "", nodeResult.getAverage(), CollectedDataErrorTypeConstant.NOT_ERROR);
-										}else{
-											sample.set(targetFacility, m_monitorId, "", nodeResult.getAverage(), CollectedDataErrorTypeConstant.UNKNOWN);
-										}
+								// 収集値の登録
+								if(sample != null){
+									if(collectorResult){
+										sample.set(targetFacility, m_monitorId, "", nodeResult.getAverage(), CollectedDataErrorTypeConstant.NOT_ERROR);
+									}else{
+										sample.set(targetFacility, m_monitorId, "", nodeResult.getAverage(), CollectedDataErrorTypeConstant.UNKNOWN);
 									}
 								}
 							}
@@ -960,48 +934,38 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 					}
 				}
 			}
-
-			// 収集値をまとめて登録
-			if(sample != null){
-				PerformanceDataUtil.put(sample);
-			}
-
-			// スコープのログ出力情報を送信
-			if(!m_isNode){
-				if(MonitorBlockConstant.TYPE_SCOPE == m_monitorBlock ||
-						MonitorBlockConstant.TYPE_ALL == m_monitorBlock){
-
-					Integer priority = PriorityJudgment.judgment(priorityList);
-					if(priority == null){
-						priority = Integer.valueOf(m_failurePriority);
-					}
-
-					// 各ノードの内、最新日付を設定
-					Date generationDate = null;
-					if(m_scopeDate > 0){
-						generationDate = new Date(m_scopeDate);
-					}
-					else{
-						generationDate = m_now;
-					}
-
-					// 監視管理へ通知
-					notify(false, m_facilityId, priority.intValue(), generationDate);
-				}
-			}
-			return true;
-
-		} catch (FinderException e) {
-			m_log.error("run(): monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ", " + e.getMessage());
-			throw e;
-		} catch (CreateException e) {
-			m_log.error("run(): monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ", " + e.getMessage());
-			throw e;
-		} catch (NamingException e) {
-			m_log.error("run(): monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ", " + e.getMessage());
-			throw e;
 		}
 
+		// 収集値をまとめて登録
+		if(sample != null){
+			PerformanceDataUtil.put(sample);
+		}
+
+		// スコープのログ出力情報を送信
+		if(!m_isNode){
+			if(MonitorBlockConstant.TYPE_SCOPE == m_monitorBlock ||
+					MonitorBlockConstant.TYPE_ALL == m_monitorBlock){
+
+				Integer priority = PriorityJudgment.judgment(priorityList);
+				if(priority == null){
+					priority = Integer.valueOf(m_failurePriority);
+				}
+
+				// 各ノードの内、最新日付を設定
+				Date generationDate = null;
+				if(m_scopeDate > 0){
+					generationDate = new Date(m_scopeDate);
+				}
+				else{
+					generationDate = m_now;
+				}
+
+				// 監視管理へ通知
+				notify(false, m_facilityId, priority.intValue(), generationDate);
+			}
+		}
+		return true;
+
 	}
 
 
@@ -1010,24 +974,15 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 	 * 
 	 * @param monitorTypeId 監視対象ID
 	 * @param monitorId 監視項目ID
-	 * @throws FinderException
-	 * @throws CreateException
-	 * @throws RemoveException
-	 * @throws JMSException
-	 * @throws NamingException
-	 * @throws NotSupportedException
-	 * @throws HeuristicMixedException
-	 * @throws HeuristicRollbackException
-	 * @throws RollbackException
-	 * @throws InvalidTransactionException
-	 * @throws IllegalStateException
-	 * @throws SystemException
+	 * @throws MonitorNotFound
+	 * @throws FacilityNotFound
+	 * @throws InvalidRole
 	 * @throws HinemosUnknown
 	 * 
 	 * @see #runMonitorInfo()
 	 */
 	@Override
-	public void run(String monitorTypeId, String monitorId) throws FinderException, RemoveException, NamingException, NotSupportedException, HeuristicMixedException, HeuristicRollbackException, RollbackException, InvalidTransactionException, IllegalStateException, SystemException, CreateException, HinemosUnknown {
+	public void run(String monitorTypeId, String monitorId) throws MonitorNotFound, FacilityNotFound, InvalidRole, HinemosUnknown {
 		super.run(monitorTypeId,monitorId);
 	}
 }
\ No newline at end of file
