@@ -51,9 +51,6 @@ public class ReachAddress {
 	/** オリジナルメッセージ */
 	private String m_messageOrg = null;
 
-	/** ping到達率（%） */
-	private int m_reachRatio = 0;
-
 	/** パケット紛失率（%） */
 	private int m_lost = 0;
 
@@ -109,7 +106,6 @@ public class ReachAddress {
 
 		m_message = null;
 		m_messageOrg = null;
-		m_reachRatio = 0;
 		m_lost = 0;
 		m_average = 0;
 
@@ -189,9 +185,6 @@ public class ReachAddress {
 				m_lost = (i - num) * 100 / i;
 			}
 
-			//ping到達率
-			//          m_reachRatio = num/i * 100 ;
-			m_reachRatio = num * 100 /i;
 			//メッセージ
 			m_message = "Packets: Sent = " + i +
 					", Received = " + num +
