@@ -15,6 +15,7 @@ GNU General Public License for more details.
 
 package com.clustercontrol.poller;
 
+import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.HashMap;
@@ -23,23 +24,21 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Map.Entry;
 import java.util.Set;
-import java.util.concurrent.ConcurrentHashMap;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.bean.SnmpVersionConstant;
-import com.clustercontrol.commons.util.EmptyJpaTransactionCallback; 
-import com.clustercontrol.commons.util.JpaTransactionManager; 
-import com.clustercontrol.commons.util.HinemosProperties;
+import com.clustercontrol.commons.util.EmptyJpaTransactionCallback;
+import com.clustercontrol.commons.util.JpaTransactionManager;
+import com.clustercontrol.commons.util.ObjectSharingService;
 import com.clustercontrol.fault.FacilityNotFound;
 import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.plugin.impl.SchedulerPlugin;
-import com.clustercontrol.plugin.impl.SharedTablePlugin;
 import com.clustercontrol.plugin.impl.SchedulerPlugin.SchedulerType;
+import com.clustercontrol.plugin.impl.SharedTablePlugin;
 import com.clustercontrol.poller.bean.PollerProtocolConstant;
-import com.clustercontrol.poller.impl.SnmpBulkPollerImpl;
-import com.clustercontrol.poller.impl.SnmpPollerImpl;
+import com.clustercontrol.poller.impl.Snmp4jPollerImpl;
 import com.clustercontrol.poller.impl.WbemPollerImpl;
 import com.clustercontrol.poller.session.PollingJobBean;
 import com.clustercontrol.repository.bean.NodeInfo;
@@ -47,16 +46,12 @@ import com.clustercontrol.repository.factory.NodeProperty;
 import com.clustercontrol.sharedtable.DataTable;
 import com.clustercontrol.sharedtable.DataTableNotFoundException;
 import com.clustercontrol.sharedtable.SharedTable;
-import com.clustercontrol.commons.util.ObjectSharingService;
 
-public class PollingController {
+public class PollingController implements Serializable {
 	private static Log m_log = LogFactory.getLog( PollingController.class );
 
-	private Object modifyLock = new Object();
-
 	public final static String POLLER_MANAGER_JNDI_NAME = "PollerManager";
 
-	private final static int RUNNING = 1;
 	private final static int STOPPED = 2;
 
 	private final String m_quartzJndiName = "RAMScheduler";
@@ -76,20 +71,6 @@ public class PollingController {
 	// ポーラの状態を示す
 	volatile private int m_status;
 
-	// SNMP BULKを利用するフラグ。
-	private static boolean snmpBulkFlag = false;
-	static {
-		String key = "monitor.resource.snmpbulk";
-		try {
-			String str = HinemosProperties.getProperty(key);
-			if (str != null && "true".equals(str)) {
-				snmpBulkFlag = true;
-			}
-		} catch (Exception e) {
-			m_log.warn(key + " is not available. " + e.getMessage(), e);
-		}
-	}
-
 	protected PollingController(
 			String pollerGroup,
 			String pollerName,
@@ -98,6 +79,7 @@ public class PollingController {
 			String tableGroup,
 			String tableName)
 					throws NotInitializedException, DataTableNotFoundException{
+
 		m_pollerGroup = pollerGroup;
 		m_pollerName = pollerName;
 		m_targetFacilityId = targetFacilityId;
@@ -131,16 +113,16 @@ public class PollingController {
 			public void postCommit() {
 				// 収集間隔を取得する
 				int interval = m_pollingConfig.getMinPollingInterval();
-
+				
 				// デバッグ出力
 				m_log.debug("scheduleJob : " + interval);
-
+				
 				// 収集間隔が-1の場合は新規に登録しない
 				if(interval == -1){
 					try {
 						// 既に登録されているジョブを削除する(登録されていない場合は何もおこらない)
 						SchedulerPlugin.deleteJob(SchedulerType.RAM, m_quartzJobName, m_quartzGroupName);
-
+						
 						// ステータス変更
 						m_status = PollingController.STOPPED;
 					} catch (HinemosUnknown e) {
@@ -152,15 +134,15 @@ public class PollingController {
 				// CronTrigger でジョブをスケジューリング登録
 				try{
 					// EJBアクセス引数を定義する
-					Object[] jdArgs = new Object[3];
-					Class[] jdArgsType = new Class[3];
+					Serializable[] jdArgs = new Serializable[3];
+					Class<? extends Serializable>[] jdArgsType = new Class[3];
 					jdArgs[0] = POLLER_MANAGER_JNDI_NAME;
 					jdArgsType[0] = String.class;
 					jdArgs[1] = m_pollerGroup;
 					jdArgsType[1] = String.class;
 					jdArgs[2] = m_pollerName;
 					jdArgsType[2] = String.class;
-
+					
 					String cronString = PollingInterval.parseCronExpression(interval);
 					if(cronString == null){
 						m_log.info("Illegal argument : interval = " + interval);
@@ -173,12 +155,14 @@ public class PollingController {
 				}
 			}
 		});
+
+
 	}
 
 	/**
 	 * ポーリングを開始する
 	 * 既に指定の収集名が登録されている場合は設定を上書きする（ver3.2以降）
-	 * 
+	 *
 	 * @param collectorName 収集名
 	 * @param interval 収集間隔
 	 * @param maps 収集プロトコルとポーリング対象のマップ
@@ -189,7 +173,9 @@ public class PollingController {
 			HashMap<String, List<String>> maps) {
 		m_log.debug("startPolling() collectorName = " + collectorName + ", interval = " + interval);
 
-		synchronized (modifyLock) {
+		try {
+			PollerManager._lock.writeLock();
+			
 			// 指定の収集名が既に登録されている場合も、上書きする（ver3.2より）
 			if(m_pollingConfig.containsCollectorName(collectorName)){
 				m_log.debug(collectorName + "is already exist.");
@@ -212,6 +198,10 @@ public class PollingController {
 
 			// ポーリングのスケジュールを設定
 			scheduleJob();
+			
+			PollerManager.storeCache(m_pollerGroup, m_pollerName, this);
+		} finally {
+			PollerManager._lock.writeUnlock();
 		}
 	}
 
@@ -221,7 +211,9 @@ public class PollingController {
 	 * @throws FacilityNotFoundBK
 	 */
 	public void stopPolling(String collectorName){
-		synchronized (modifyLock) {
+		try {
+			PollerManager._lock.writeLock();
+			
 			m_log.debug("stop polling : " + m_pollerGroup + ", " + m_pollerName + ", " + collectorName);
 
 			// 指定の収集名で、収集間隔、ポーリング対象のリストを削除する
@@ -241,6 +233,10 @@ public class PollingController {
 				m_log.warn(e.getMessage(), e);
 				return;
 			}
+			
+			PollerManager.storeCache(m_pollerGroup, m_pollerName, this);
+		} finally {
+			PollerManager._lock.writeUnlock();
 		}
 	}
 
@@ -249,7 +245,9 @@ public class PollingController {
 	 * @throws FacilityNotFoundBK
 	 */
 	public void stopPollingAll(){
-		synchronized (modifyLock) {
+		try {
+			PollerManager._lock.writeLock();
+			
 			m_log.debug("stop polling : " + m_pollerGroup + ", " + m_pollerName);
 
 			// 全ての収集間隔、ポーリング対象のリストを削除する
@@ -265,6 +263,10 @@ public class PollingController {
 			if(sharedtable != null){
 				sharedtable.removeDataTable(m_tableGroup, m_tableName);
 			}
+			
+			PollerManager.storeCache(m_pollerGroup, m_pollerName, this);
+		} finally {
+			PollerManager._lock.writeUnlock();
 		}
 	}
 
@@ -279,6 +281,9 @@ public class PollingController {
 		// 共有テーブルを取得する
 		sharedTable = SharedTablePlugin.getSharedTable();
 
+		List<Integer> intervals = null;
+		HashMap<String, List<String>> pollingTargetMap = null;
+		
 		try {
 
 			Set<String> stCollectorNames =
@@ -294,8 +299,10 @@ public class PollingController {
 			Set<String> pcCollectoName =
 					new HashSet<String>(m_pollingConfig.getCollectorNames());
 			pcCollectoName.removeAll(stCollectorNames);
-			synchronized (modifyLock) {
-
+			
+			try {
+				PollerManager._lock.writeLock();
+				
 				boolean modifyFlg = false;
 				for(String collectorName : pcCollectoName){
 					// 指定の収集名で、収集間隔、ポーリング対象のリストを削除する
@@ -306,6 +313,8 @@ public class PollingController {
 				if(modifyFlg){
 					scheduleJob();
 				}
+			} finally {
+				PollerManager._lock.writeUnlock();
 			}
 
 		} catch (DataTableNotFoundException e) {
@@ -334,7 +343,7 @@ public class PollingController {
 
 		// 今のタイミングで更新すべきテーブルを特定するため、
 		// 更新の必要のある収集間隔のリストを取得する
-		List<Integer> intervals = m_pollingConfig.getCurrentRefreshIntervals(now);
+		intervals = m_pollingConfig.getCurrentRefreshIntervals(now);
 
 		ArrayList<Integer> tmpList = new ArrayList<Integer>(intervals);
 
@@ -355,7 +364,9 @@ public class PollingController {
 		}
 
 		// ポーリング対象の中から今のタイミングで収集すべきものを抽出する
-		HashMap<String, List<String>> pollingTargetMap = m_pollingConfig.getCurrentTargetMap(now);
+		pollingTargetMap = m_pollingConfig.getCurrentTargetMap(now);
+		
+		PollerManager.storeCache(m_pollerGroup, m_pollerName, this);
 
 		m_log.debug("run() pollingTargetMap : " + pollingTargetMap);
 		// 収集すべきポーリング対象がない場合は処理終了
@@ -390,15 +401,6 @@ public class PollingController {
 			// ポーリングは実行しない
 			// 取得値が空のテーブルを作成する
 			dataTable = new DataTable();
-			
-			// 管理対象フラグがOFFの場合、ポーリング処理直後に管理対象フラグがONになった場合に
-			// 4.1.3までの実装では集計処理側で単純に「集計タイミングでの」管理対象フラグを見て、
-			// 結果として上でセットした空のデータを読んでしまうことで、不明となることへの対策。
-			//
-			// 「管理対象フラグがOFFの状態で最後にポーリングの処理を通過した時間」をノード単位で記録しておくことで、
-			// 集計処理時にもしも「不明」となった場合には、ここでセットした時間と監視間隔をもとに、
-			// 通知をスキップするか否かを決定する。
-			setLastPollingSkipTime(nodeInfo.getFacilityId());
 		}
 
 		// ポーリングを行い値を収集
@@ -442,48 +444,21 @@ public class PollingController {
 		// SNMPのpollerの設定
 		// *****************************
 		if(pollingTargetMap.get(PollerProtocolConstant.PROTOCOL_SNMP) != null) {
-			// joeSNMPではint型でSNMPのバージョンを定義
-			// 0:SNMP V1 protocol, 1:SNMP V2 protocol
-			int snmpVersionForJoeSNMP = 1;
-			String versionStr = nodeInfo.getSnmpVersion();
-			m_log.debug("version   : " + versionStr);
-			if(versionStr != null && versionStr != ""){
-				Integer version = SnmpVersionConstant.stringToType(versionStr);
-				if(versionStr != null){
-					// 未定義(-1)の場合はv2cに設定
-					if(version == -1){
-						version = 1;
-					}
+			tmpDataTable = Snmp4jPollerImpl.getInstance().polling(
+					nodeInfo.getAvailableIpAddress(),
+					nodeInfo.getSnmpPort(),
+					SnmpVersionConstant.stringToSnmpType(nodeInfo.getSnmpVersion()),
+					nodeInfo.getSnmpCommunity(),
+					retries == -1 ? nodeInfo.getSnmpRetryCount() : retries,
+							timeout == -1 ? nodeInfo.getSnmpTimeout() : timeout,
+									pollingTargetMap.get(PollerProtocolConstant.PROTOCOL_SNMP),
+					nodeInfo.getSnmpSecurityLevel(),
+					nodeInfo.getSnmpUser(),
+					nodeInfo.getSnmpAuthPassword(),
+					nodeInfo.getSnmpPrivPassword(),
+					nodeInfo.getSnmpAuthProtocol(),
+					nodeInfo.getSnmpPrivProtocol());
 
-					snmpVersionForJoeSNMP = version;
-				}
-			}
-
-			if (snmpBulkFlag && "2c".equals(versionStr)) {
-				m_log.trace("SnmpBulkPoller version=" + versionStr);
-				SnmpBulkPollerImpl poller = new SnmpBulkPollerImpl();
-				tmpDataTable = poller.polling(
-						nodeInfo.getAvailableIpAddress(),
-						nodeInfo.getSnmpPort(),
-						snmpVersionForJoeSNMP,
-						nodeInfo.getSnmpCommunity(),
-						retries == -1 ? nodeInfo.getSnmpRetryCount() : retries,
-								timeout == -1 ? nodeInfo.getSnmpTimeout() : timeout,
-										pollingTargetMap.get(PollerProtocolConstant.PROTOCOL_SNMP),
-										m_pollingConfig.isIndexCheckFlg());
-			} else {
-				m_log.trace("SnmpPoller version=" + versionStr);
-				SnmpPollerImpl poller = new SnmpPollerImpl();
-				tmpDataTable = poller.polling(
-						nodeInfo.getAvailableIpAddress(),
-						nodeInfo.getSnmpPort(),
-						snmpVersionForJoeSNMP,
-						nodeInfo.getSnmpCommunity(),
-						retries == -1 ? nodeInfo.getSnmpRetryCount() : retries,
-								timeout == -1 ? nodeInfo.getSnmpTimeout() : timeout,
-										pollingTargetMap.get(PollerProtocolConstant.PROTOCOL_SNMP),
-										m_pollingConfig.isIndexCheckFlg());
-			}
 			dataTable.putAll(tmpDataTable);
 		}
 
@@ -536,7 +511,7 @@ public class PollingController {
 			// 2013年8月末時点で、VM・クラウドの2オプションで本機構を使用している
 			////
 			if(pollerProtocol != null){
-				
+
 				IPoller poller = null;
 				try {
 					poller = ObjectSharingService.objectRegistry().get(IPoller.class, pollerProtocol);
@@ -569,7 +544,7 @@ public class PollingController {
 
 	/**
 	 * 指定のOIDに対してポーリングを実行します。
-	 * 
+	 *
 	 * @param targetValues ポーリング対象
 	 * @return 収集したMIB値が格納されたデータテーブル
 	 */
@@ -635,101 +610,4 @@ public class PollingController {
 	public int getStatus() {
 		return m_status;
 	}
-
-
-	/**
-	 * 指定されたノードの管理対象フラグの直近の状態を見て、リソース監視による通知をスキップすべきか否かを判定します。
-	 * 
-	 * @param facilityId 対象となるノードのfacilityId
-	 * @param interval 対象となる監視項目の監視間隔
-	 * @return リソース監視を行うために十分な時間、管理対象フラグが有効になっていなかった場合、trueが返る
-	 */
-	public static boolean skipResourceMonitorNotifyByNodeFlagHistory(String facilityId, int interval) {
-		long currentTime = System.currentTimeMillis();
-		long lastPollingSkipTime = getLastPollingSkipTime(facilityId);
-		if (currentTime - lastPollingSkipTime < interval * 1000 * 2 /* 2回分 */) {
-			// 管理対象フラグをOFFとしていた期間が、監視間隔 * 2 よりも直近で存在している、あるいは
-			// 直近でマネージャを再起動したなどの状態にあたるため、通知をスキップ
-			m_log.info("skipResourceMonitorNotifyByNodeFlagHistory() : skip resource monitor notify because of node flag change timing. "
-					+ "facilityId = " + facilityId + ", currentTime = " + currentTime + ", lastPollingSkipTime = " + lastPollingSkipTime);
-			return true;
-		}
-		// 管理対象フラグがOFFだった期間がかなり昔 or そのノードについて何の情報も登録されていない状態
-		// なので、通知はスキップしない
-		return false;
-	}
-
-	/**
-	 * 指定されたノードの管理対象フラグの直近の状態を見て、プロセス監視による通知をスキップすべきか否かを判定します。
-	 * 監視結果が「不明」となった場合以外には本関数は呼び出さないでください。
-	 * @param facilityId 対象となるノードのfacilityId
-	 * @param interval 対象となる監視項目の監視間隔
-	 * @return 通知をスキップすべき状況（プロセス監視を行うために十分な時間、管理対象フラグが有効になっていなかったなど）の場合、trueが返る。<br>
-	 *         通知をスキップするべきでなければ、falseが返る。
-	 */
-	public static boolean skipProcessMonitorNotifyByNodeFlagHistory(String facilityId, int interval) {
-		long currentTime = System.currentTimeMillis();
-		long lastPollingSkipTime = getLastPollingSkipTime(facilityId);
-		if (currentTime - lastPollingSkipTime < interval * 1000 ) {
-			// 管理対象フラグをOFFとしていた期間が、監視間隔よりも直近で存在している、あるいは
-			// 直近でマネージャを再起動したなどの状態にあたるため、通知をスキップ
-			m_log.info("skipProcessMonitorNotifyByNodeFlagHistory() : skip process monitor notify because of node flag change timing. "
-					+ "facilityId = " + facilityId + ", currentTime = " + currentTime + ", lastPollingSkipTime = " + lastPollingSkipTime);
-			return true;
-		}
-		// 管理対象フラグがOFFだった期間がかなり昔 or そのノードについて何の情報も登録されていない状態
-		// なので、通知はスキップしない
-		return false;
-	}
-
-	/**
-	 * FacilityIdごとに最も直近で管理対象フラグがたっていなかったことによりポーリングがスキップされた時間を保持したキャッシュ
-	 */
-	private static ConcurrentHashMap<String, Long> lastPollingSkipTimeMap = new ConcurrentHashMap<String, Long>();
-	
-	/**
-	 * 最も直近に、管理対象フラグがたっていなかったことによりポーリングがスキップされた時間を返す。
-	 * @param facilityId
-	 * @return
-	 */
-	public static long getLastPollingSkipTime(String facilityId) {
-		Long lastPollingDisableTime = lastPollingSkipTimeMap.get(facilityId);
-
-		if (lastPollingDisableTime != null) {
-			return lastPollingDisableTime;
-		} else {
-			// キャッシュそのものが存在しない、キャッシュが異常、またはキャッシュ中にそのファシリティIDの情報が格納されていない場合、
-			// 従来通り、不明が出ても何の抑制もしないように、遠い過去(0L)を返す = 遥か昔の時点から管理対象がONであったことを示す
-			return 0L;
-		}
-	}
-	/**
-	 * 指定されたノードのポーリング処理を「管理対象フラグが立っていないこと」を理由にスキップした場合に呼び出す。<br>
-	 * （呼び出しにより、このファシリティIDのポーリングが最後にスキップされた時刻として現在時刻がセットされる）
-	 * @param facilityId 対象となるfacilityId
-	 */
-	public static void setLastPollingSkipTime(String facilityId) {
-		// mapに当該ファシリティIDをキーとして、現在時刻をセット
-		lastPollingSkipTimeMap.put(facilityId, System.currentTimeMillis());
-		
-		if (m_log.isDebugEnabled()) {
-			m_log.debug("setLastPollingSkipTime() : current map size = " + lastPollingSkipTimeMap.size());
-			m_log.debug("setLastPollingSkipTime() : current map entry = " + lastPollingSkipTimeMap.entrySet());
-		}
-	}
-
-	/**
-	 * 指定されたノードのポーリング処理の最終スキップ時刻の情報をリセットする。
-	* 本関数は、ノードが削除された際に呼び出す。
-	* @param facilityId 削除対象のfacilityId
-	*/
-	public static void removeLastPollingSkipTime(String facilityId) {
-		// mapに当該ファシリティの情報がある場合には削除する
-		lastPollingSkipTimeMap.remove(facilityId);
-		
-		if (m_log.isDebugEnabled()) {
-			m_log.debug("setLastPollingSkipTime() : current map size = " + lastPollingSkipTimeMap.size());
-			m_log.debug("setLastPollingSkipTime() : current map entry = " + lastPollingSkipTimeMap.entrySet());
-		}
-	}
-}
\ No newline at end of file
+}
