@@ -114,7 +114,7 @@ public class WbemPollerImpl {
 			int retries,
 			int timeout,
 			List<String> cimList // cimクラスとプロパティ名のリスト
-	) {
+			) {
 		// クラス変数を初期化
 		init();
 
@@ -174,7 +174,7 @@ public class WbemPollerImpl {
 			// 1. Create user credentials
 			// *****************************
 			UserPrincipal userPr = new UserPrincipal(user);
-			PasswordCredential pwCred = new PasswordCredential(password);
+			PasswordCredential pwCred = new PasswordCredential(password.toCharArray());
 
 			// *****************************
 			// 2. Set NameSpace
@@ -314,7 +314,8 @@ public class WbemPollerImpl {
 					}
 				} catch(CIMException e){
 					errorFlg = true;
-					m_log.warn("polling() warning :" + m_ipAddress.toString() + ", " + cimClass + ", " + e.getID());
+					m_log.warn("polling() warning :" + m_ipAddress.toString() +
+							", cimClass=" + cimClass + ", ID=" + e.getID() + ", message=" + e.getMessage());
 				} catch(Exception e) {
 					errorFlg = true;
 					m_log.warn("polling() warning :" + m_ipAddress.toString() + ", " + cimClass + " unforeseen error. " + e.getMessage(), e);
@@ -340,7 +341,7 @@ public class WbemPollerImpl {
 					cimClient.close();
 				}
 				catch (Exception e) {
-					m_log.warn("polling():" + m_ipAddress.toString() + " Session close failed");
+					m_log.warn("polling():" + m_ipAddress.toString() + " Session close failed", e);
 				}
 			}
 		}
@@ -453,7 +454,8 @@ public class WbemPollerImpl {
 
 			}
 		} catch (Exception e) { // 何か例外が生じた場合は収集を停止する
-			m_log.error("InternalError ", e);
+			m_log.warn("polling() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 
 			// 収集したデータを全てクリアする
 			dataTable.clear();
@@ -463,11 +465,11 @@ public class WbemPollerImpl {
 
 	private boolean checkCIMData(CIMValue value) {
 		if (value == null) {
-			m_log.warn("checkCIMData : value is null");
+			m_log.info("checkCIMData : value is null");
 			return false;
 		}
 		if (value.getType() == null) {
-			m_log.warn("checkCIMData : value.getType is null, " +
+			m_log.info("checkCIMData : value.getType is null, " +
 					"refClassName=" + value.getType().getRefClassName() +
 					"stringType=" + value.getType().getStringType() +
 					"toString=" + value.getType().toString());
@@ -482,7 +484,7 @@ public class WbemPollerImpl {
 		} else if(type == CIMDataType.STRING_ARRAY){
 			Vector<String> ret = (Vector<String>)value.getValue();
 			if (ret.size() == 0) {
-				m_log.warn("checkCIMData : CIMValue has fault. : ip=" + m_ipAddress);
+				m_log.info("checkCIMData : CIMValue has fault. : ip=" + m_ipAddress);
 				return false;
 			}
 		} else if(value.getType().getType() == CIMDataType.DATETIME) {
