@@ -18,7 +18,7 @@ public class FactoryTest {
 		int[] runInterval = { 1000, 2000, 3000, 1000 };
 		int[] timeout = { 1000, 2000, 3000, 1000 };
 
-		Class cls = Class.forName(protocolClassName);
+		Class<?> cls = Class.forName(protocolClassName);
 		m_reachability = (ReachAddressProtocol)cls.newInstance();
 
 		for (int i = 0; i < address.length; i++) {
