@@ -15,9 +15,6 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.process.factory;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-
 import com.clustercontrol.bean.ValidConstant;
 import com.clustercontrol.bean.YesNoConstant;
 import com.clustercontrol.fault.InvalidRole;
@@ -38,8 +35,6 @@ import com.clustercontrol.process.util.ProcessProperties;
  */
 public class AddMonitorProcess extends AddMonitorNumericValueType{
 
-	private static Log m_log = LogFactory.getLog( AddMonitorProcess.class );
-
 	/* (非 Javadoc)
 	 * @see com.clustercontrol.monitor.run.factory.AddMonitor#addCheckInfo()
 	 */
