@@ -20,7 +20,7 @@ import com.clustercontrol.ws.repository.FacilityTreeItem;
 
 /**
  * スコープ情報をツリー構造化するためのクラス<BR>
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  */
@@ -34,9 +34,9 @@ public class FacilityPath {
 	/**
 	 * ツリーアイテムの親子関係を表現するパス文字列を取得します。<BR>
 	 * <p>
-	 * 
+	 *
 	 * 例）getPath() ⇒ "料金システム>顧客管理>WEB"
-	 * 
+	 *
 	 * @param separator
 	 *            セパレーター
 	 * @return パス文字列
@@ -60,7 +60,8 @@ public class FacilityPath {
 		if (item.getData().getFacilityType() == FacilityConstant.TYPE_SCOPE) {
 			FacilityTreeItem parent = item.getParent();
 			while (parent != null
-					&& parent.getData().getFacilityType() != FacilityConstant.TYPE_COMPOSITE) {
+					&& parent.getData().getFacilityType() != FacilityConstant.TYPE_COMPOSITE
+					&& parent.getData().getFacilityType() != FacilityConstant.TYPE_MANAGER) {
 
 				buffer.insert(0, separator);
 				buffer.insert(0, parent.getData().getFacilityName());
@@ -74,7 +75,7 @@ public class FacilityPath {
 
 	/**
 	 * セパレータを取得します。<BR>
-	 * 
+	 *
 	 * @return Returns the separator.
 	 */
 	public String getSeparator() {
@@ -89,4 +90,4 @@ public class FacilityPath {
 	public void setSeparator(String separator) {
 		this.separator = separator;
 	}
-}
\ No newline at end of file
+}
