@@ -74,6 +74,7 @@ public class FacilityInfo implements Serializable, Cloneable
 	 * @param description
 	 * @param displaySortOrder
 	 * @param valid
+	 * @param autoDeviceSearch
 	 * @param createUserId
 	 * @param createDatetime
 	 * @param modifyUserId
@@ -82,7 +83,7 @@ public class FacilityInfo implements Serializable, Cloneable
 	 * @param ownerRoleId
 	 * @param notReferFlg
 	 */
-	public FacilityInfo( String facilityId, String facilityName, Integer facilityType, String description, Integer displaySortOrder, String iconImage, Boolean valid, String createUserId, Long createDatetime, String modifyUserId, Long modifyDatetime, Boolean builtInFlg, String ownerRoleId, Boolean notReferFlg )
+	public FacilityInfo( String facilityId, String facilityName, Integer facilityType, String description, Integer displaySortOrder, String iconImage, Boolean valid, Boolean autoDeviceSearch, String createUserId, Long createDatetime, String modifyUserId, Long modifyDatetime, Boolean builtInFlg, String ownerRoleId, Boolean notReferFlg )
 	{
 		setFacilityId(facilityId);
 		setFacilityName(facilityName);
@@ -237,7 +238,7 @@ public class FacilityInfo implements Serializable, Cloneable
 		this.iconImage = iconImage;
 	}
 
-	
+
 	/**
 	 * 管理対象のgetterです。
 	 * @return Boolean
@@ -347,7 +348,7 @@ public class FacilityInfo implements Serializable, Cloneable
 
 	/**
 	 * 参照不可フラグを取得します。<BR>
-	 * 
+	 *
 	 * @return 参照不可フラグ
 	 */
 	public Boolean isNotReferFlg() {
@@ -356,7 +357,7 @@ public class FacilityInfo implements Serializable, Cloneable
 
 	/**
 	 * 参照不可フラグを設定します。<BR>
-	 * 
+	 *
 	 * @param notReferFlg 参照不可フラグ（true：参照権限のないスコープ）
 	 */
 	public void setNotReferFlg(Boolean notReferFlg) {
@@ -522,7 +523,7 @@ public class FacilityInfo implements Serializable, Cloneable
 		result = 37*result + ((this.description != null) ? this.description.hashCode() : 0);
 
 		result = 37*result + ((this.displaySortOrder != null) ? this.displaySortOrder.hashCode() : 0);
-		
+
 		result = 37*result + ((this.iconImage != null) ? this.iconImage.hashCode() : 0);
 
 		result = 37*result + ((this.valid != null) ? this.valid.hashCode() : 0);
