@@ -19,18 +19,16 @@ import java.util.ArrayList;
 
 import javax.xml.bind.annotation.XmlType;
 
-import com.clustercontrol.repository.bean.NodeDeviceInfo;
-import com.clustercontrol.repository.bean.NodeFilesystemInfo;
-import com.clustercontrol.repository.bean.NodeHostnameInfo;
-import com.clustercontrol.repository.bean.NodeNoteInfo;
+import com.clustercontrol.bean.SnmpProtocolConstant;
+import com.clustercontrol.bean.SnmpSecurityLevelConstant;
 
 /**
  * このクラスはノード詳細のクラスです。
  * ノードの詳細を保持するために使用されます。
- * 
+ *
  * TODO
  * HinemosClientのNodePropertyUtil.javaのsetDefaultNodeと値をあわせておくこと！
- * 
+ *
  * @since 0.8
  */
 @XmlType(namespace = "http://repository.ws.clustercontrol.com")
@@ -38,6 +36,8 @@ public class NodeInfo extends FacilityInfo implements Serializable
 {
 	private static final long serialVersionUID = -4120880233299545923L;
 
+	private Boolean autoDeviceSearch = Boolean.TRUE;
+
 	// HW
 	private java.lang.String platformFamily = "";
 	private java.lang.String subPlatformFamily = "";
@@ -64,9 +64,15 @@ public class NodeInfo extends FacilityInfo implements Serializable
 	private java.lang.Integer jobMultiplicity = null;
 
 	// SNMP
+	private java.lang.String snmpUser = "";
+	private java.lang.String snmpAuthPassword = "";
+	private java.lang.String snmpPrivPassword = "";
 	private java.lang.Integer snmpPort = null;
 	private java.lang.String snmpCommunity = "";
 	private java.lang.String snmpVersion = "";
+	private java.lang.String snmpSecurityLevel = SnmpSecurityLevelConstant.NOAUTH_NOPRIV;
+	private java.lang.String snmpAuthProtocol = SnmpProtocolConstant.MD5;
+	private java.lang.String snmpPrivProtocol = SnmpProtocolConstant.DES;
 	private java.lang.Integer snmpTimeout = null;
 	private java.lang.Integer snmpRetryCount = null;
 
@@ -97,6 +103,14 @@ public class NodeInfo extends FacilityInfo implements Serializable
 	private java.lang.Integer winrmTimeout = null;
 	private java.lang.Integer winrmRetries = null;
 
+	// SSH
+	private java.lang.String sshUser = "";
+	private java.lang.String sshUserPassword = "";
+	private java.lang.String sshPrivateKeyFilepath = "";
+	private java.lang.String sshPrivateKeyPassphrase = "";
+	private java.lang.Integer sshPort = null;
+	private java.lang.Integer sshTimeout = null;
+
 	// デバイス
 	private ArrayList<NodeDeviceInfo> nodeDeviceInfo;
 	private ArrayList<NodeCpuInfo> nodeCpuInfo;
@@ -105,29 +119,13 @@ public class NodeInfo extends FacilityInfo implements Serializable
 	private ArrayList<NodeNetworkInterfaceInfo> nodeNetworkInterfaceInfo;
 	private ArrayList<NodeFilesystemInfo> nodeFilesystemInfo;
 
-	// サーバ仮想化
-	private java.lang.String vmNodeType = "";
-	private java.lang.String vmManagementNode = "";
-	private java.lang.String vmName = "";
-	private java.lang.String vmId = "";
-	private java.lang.String vmUser = "";
-	private java.lang.String vmUserPassword = "";
-	private java.lang.String vmProtocol = "";
-
-	// ネットワーク仮想化
-	private java.lang.String vNetSwitchType = "";
-	private java.lang.String vNetHostNode = "";
-	private java.lang.String openFlowDataPathId = "";
-	private java.lang.String openFlowCtrlIpAddress = "";
-
-	// クラウド
-	private java.lang.String cloudNodeType = "";
+	// クラウド・仮想化
 	private java.lang.String cloudService = "";
-	private java.lang.String cloudAccountResouce = "";
+	private java.lang.String cloudScope = "";
 	private java.lang.String cloudResourceType = "";
+	private java.lang.String cloudResourceName = "";
 	private java.lang.String cloudResourceId = "";
-	private java.lang.String cloudRegion = "";
-	private java.lang.String cloudZone = "";
+	private java.lang.String cloudLocation = "";
 
 	// ノード変数
 	private ArrayList<NodeVariableInfo> nodeVariableInfo;
@@ -229,6 +227,60 @@ public class NodeInfo extends FacilityInfo implements Serializable
 		this.hardwareType = hardwareType;
 	}
 
+	/**
+	 * SNMP->接続ユーザ名のgetterです。
+	 * @return String
+	 */
+	public java.lang.String getSnmpUser()
+	{
+		return this.snmpUser;
+	}
+
+	/**
+	 * SNMP->接続ユーザ名のsetterです。
+	 * @param snmpUser
+	 */
+	public void setSnmpUser( java.lang.String snmpUser )
+	{
+		this.snmpUser = snmpUser;
+	}
+
+	/**
+	 * SNMP->接続ユーザ認証パスワードのgetterです。
+	 * @return String
+	 */
+	public java.lang.String getSnmpAuthPassword()
+	{
+		return this.snmpAuthPassword;
+	}
+
+	/**
+	 * SNMP->接続ユーザ認証パスワードのsetterです。
+	 * @param snmpUserPassword
+	 */
+	public void setSnmpAuthPassword( java.lang.String snmpUserPassword )
+	{
+		this.snmpAuthPassword = snmpUserPassword;
+	}
+
+	/**
+	 * SNMP->接続ユーザ暗号化パスワードのgetterです。
+	 * @return String
+	 */
+	public java.lang.String getSnmpPrivPassword()
+	{
+		return this.snmpPrivPassword;
+	}
+
+	/**
+	 * SNMP->接続ユーザ暗号化パスワードのsetterです。
+	 * @param snmpPrivPassword
+	 */
+	public void setSnmpPrivPassword( java.lang.String snmpPrivPassword )
+	{
+		this.snmpPrivPassword = snmpPrivPassword;
+	}
+
 	/**
 	 * SNMP->ポート番号のgetterです。
 	 * @return Integer
@@ -283,6 +335,60 @@ public class NodeInfo extends FacilityInfo implements Serializable
 		this.snmpVersion = snmpVersion;
 	}
 
+	/**
+	 * SNMP->セキュリティレベルのgetterです。
+	 * @return String
+	 */
+	public java.lang.String getSnmpSecurityLevel()
+	{
+		return this.snmpSecurityLevel;
+	}
+
+	/**
+	 * SNMP->セキュリティレベルのsetterです。
+	 * @param snmpSecurityLevel
+	 */
+	public void setSnmpSecurityLevel( java.lang.String snmpSecurityLevel )
+	{
+		this.snmpSecurityLevel = snmpSecurityLevel;
+	}
+
+	/**
+	 * SNMP->認証プロトコルのgetterです。
+	 * @return String
+	 */
+	public java.lang.String getSnmpAuthProtocol()
+	{
+		return this.snmpAuthProtocol;
+	}
+
+	/**
+	 * SNMP->認証プロトコルのsetterです。
+	 * @param snmpAuthProtocol
+	 */
+	public void setSnmpAuthProtocol( java.lang.String snmpAuthProtocol )
+	{
+		this.snmpAuthProtocol = snmpAuthProtocol;
+	}
+
+	/**
+	 * SNMP->暗号化プロトコルのgetterです。
+	 * @return String
+	 */
+	public java.lang.String getSnmpPrivProtocol()
+	{
+		return this.snmpPrivProtocol;
+	}
+
+	/**
+	 * SNMP->暗号化プロトコルのsetterです。
+	 * @param snmpPrivProtocol
+	 */
+	public void setSnmpPrivProtocol( java.lang.String snmpPrivProtocol )
+	{
+		this.snmpPrivProtocol = snmpPrivProtocol;
+	}
+
 	/**
 	 * SNMP->SNMP タイムアウトのgetterです。
 	 * @return Integer
@@ -876,210 +982,6 @@ public class NodeInfo extends FacilityInfo implements Serializable
 		this.winrmRetries = winrmRetries;
 	}
 
-	/**
-	 * 仮想化->ノード種別のgetterです。
-	 * @return String
-	 */
-	public java.lang.String getVmNodeType() {
-		return vmNodeType;
-	}
-
-	/**
-	 * 仮想化->ノード種別のsetterです。
-	 * @param vmNodeType
-	 */
-	public void setVmNodeType(java.lang.String vmNodeType) {
-		this.vmNodeType = vmNodeType;
-	}
-
-	/**
-	 * 管理ノードのgetterです。
-	 * @return String
-	 */
-	public java.lang.String getVmManagementNode()
-	{
-		return this.vmManagementNode;
-	}
-
-	/**
-	 * 管理ノードのsetterです。
-	 * @param vmManagementNode
-	 */
-	public void setVmManagementNode( java.lang.String vmManagementNode )
-	{
-		this.vmManagementNode = vmManagementNode;
-	}
-
-	/**
-	 * 仮想マシン名のgetterです。
-	 * @return String
-	 */
-	public java.lang.String getVmName()
-	{
-		return this.vmName;
-	}
-
-	/**
-	 * 仮想マシン名のsetterです。
-	 * @param vmName
-	 */
-	public void setVmName( java.lang.String vmName )
-	{
-		this.vmName = vmName;
-	}
-
-	/**
-	 * 仮想マシンIDのgetterです。
-	 * @return String
-	 */
-	public java.lang.String getVmId()
-	{
-		return this.vmId;
-	}
-
-	/**
-	 * 仮想マシンIDのsetterです。
-	 * @param vmId
-	 */
-	public void setVmId( java.lang.String vmId )
-	{
-		this.vmId = vmId;
-	}
-
-	/**
-	 * 仮想化ソフト接続ユーザのgetterです。
-	 * @return String
-	 */
-	public java.lang.String getVmUser()
-	{
-		return this.vmUser;
-	}
-
-	/**
-	 * 仮想化ソフト接続ユーザのsetterです。
-	 * @param vmUser
-	 */
-	public void setVmUser( java.lang.String vmUser )
-	{
-		this.vmUser = vmUser;
-	}
-
-	/**
-	 * 仮想化ソフト接続ユーザパスワードのgetterです。
-	 * @return String
-	 */
-	public java.lang.String getVmUserPassword()
-	{
-		return this.vmUserPassword;
-	}
-
-	/**
-	 * 仮想化ソフト接続ユーザパスワードのsetterです。
-	 * @param vmUserPassword
-	 */
-	public void setVmUserPassword( java.lang.String vmUserPassword )
-	{
-		this.vmUserPassword = vmUserPassword;
-	}
-
-	/**
-	 * 仮想化ソフト接続プロトコルのgetterです。
-	 * @return String
-	 */
-	public java.lang.String getVmProtocol()
-	{
-		return this.vmProtocol;
-	}
-
-	/**
-	 * 仮想化ソフト接続プロトコルのsetterです。
-	 * @param vmProtocol
-	 */
-	public void setVmProtocol( java.lang.String vmProtocol )
-	{
-		this.vmProtocol = vmProtocol;
-	}
-
-	/**
-	 * 仮想スイッチ種別のgetter
-	 * @return vNetSwitchType
-	 */
-	public java.lang.String getvNetSwitchType() {
-		return this.vNetSwitchType;
-	}
-
-	/**
-	 * 仮想スイッチ種別のsetter
-	 * @param vNetSwitchType
-	 */
-	public void setvNetSwitchType(java.lang.String vNetSwitchType) {
-		this.vNetSwitchType = vNetSwitchType;
-	}
-
-	/**
-	 * 仮想スイッチホストノードのgetter
-	 * @return vNetHostNode
-	 */
-	public java.lang.String getvNetHostNode() {
-		return this.vNetHostNode;
-	}
-
-	/**
-	 * 仮想スイッチホストノードのsetter
-	 * @param vNetHostNode
-	 */
-	public void setvNetHostNode(java.lang.String vNetHostNode) {
-		this.vNetHostNode = vNetHostNode;
-	}
-
-	/**
-	 * OpenFlow データパスIDのgetter
-	 * @return openFlowDataPathId
-	 */
-	public java.lang.String getOpenFlowDataPathId() {
-		return this.openFlowDataPathId;
-	}
-
-	/**
-	 * OpenFlow データパスIDのgetter
-	 * @param openFlowDataPathId
-	 */
-	public void setOpenFlowDataPathId(java.lang.String openFlowDataPathId) {
-		this.openFlowDataPathId = openFlowDataPathId;
-	}
-
-	/**
-	 * OpenFlow コントローラIPアドレスのgetter
-	 * @return openFlowCtrlIpAddress
-	 */
-	public java.lang.String getOpenFlowCtrlIpAddress() {
-		return this.openFlowCtrlIpAddress;
-	}
-
-	/**
-	 * OpenFlow コントローラIPアドレスのsetter
-	 * @param openFlowCtrlIpAddress
-	 */
-	public void setOpenFlowCtrlIpAddress(java.lang.String openFlowCtrlIpAddress) {
-		this.openFlowCtrlIpAddress = openFlowCtrlIpAddress;
-	}
-
-	/**
-	 * クラウド管理->ノード種別のgetterです。
-	 * @return String
-	 */
-	public java.lang.String getCloudNodeType() {
-		return cloudNodeType;
-	}
-
-	/**
-	 * クラウド管理->ノード種別のsetterです。
-	 * @param cloudNodeType
-	 */
-	public void setCloudNodeType(java.lang.String cloudNodeType) {
-		this.cloudNodeType = cloudNodeType;
-	}
-
 	/**
 	 * クラウド管理->クラウドサービスのgetterです。
 	 * @return String
@@ -1097,19 +999,19 @@ public class NodeInfo extends FacilityInfo implements Serializable
 	}
 
 	/**
-	 * クラウド管理->クラウドアカウントリソースのgetterです。
+	 * クラウド管理->クラウドスコープのgetterです。
 	 * @return String
 	 */
-	public java.lang.String getCloudAccountResouce() {
-		return cloudAccountResouce;
+	public java.lang.String getCloudScope() {
+		return cloudScope;
 	}
 
 	/**
-	 * クラウド管理->クラウドアカウントリソースのsetterです。
-	 * @param cloudAccountResouce
+	 * クラウド管理->クラウドスコープのsetterです。
+	 * @param cloudScope
 	 */
-	public void setCloudAccountResouce(java.lang.String cloudAccountResouce) {
-		this.cloudAccountResouce = cloudAccountResouce;
+	public void setCloudScope(java.lang.String cloudScope) {
+		this.cloudScope = cloudScope;
 	}
 
 	/**
@@ -1135,7 +1037,7 @@ public class NodeInfo extends FacilityInfo implements Serializable
 	public java.lang.String getCloudResourceId() {
 		return cloudResourceId;
 	}
-
+	
 	/**
 	 * クラウド管理->クラウドリソースIdのsetterです。
 	 * @param cloudResourceId
@@ -1145,35 +1047,35 @@ public class NodeInfo extends FacilityInfo implements Serializable
 	}
 
 	/**
-	 * クラウド管理->リージョンのgetterです。
+	 * クラウド管理-> クラウドリソース名のsetterです。
+	 * @param cloudResourceName
+	 */
+	public void setCloudResourceName(java.lang.String cloudResourceName) {
+		this.cloudResourceName = cloudResourceName;
+	}
+	
+	/**
+	 * クラウド管理->クラウドリソース名のgetterです。
+	 * @return
+	 */
+	public java.lang.String getCloudResourceName() {
+		return cloudResourceName;
+	}
+	
+	/**
+	 * クラウド管理->ロケーションのgetterです。
 	 * @return String
 	 */
-	public java.lang.String getCloudRegion() {
-		return cloudRegion;
+	public java.lang.String getCloudLocation() {
+		return cloudLocation;
 	}
 
 	/**
-	 * クラウド管理->リージョンのsetterです。
-	 * @param cloudRegion
+	 * クラウド管理->ロケーションのsetterです。
+	 * @param cloudLocation
 	 */
-	public void setCloudRegion(java.lang.String cloudRegion) {
-		this.cloudRegion = cloudRegion;
-	}
-
-	/**
-	 * クラウド管理->ゾーンのgetterです。
-	 * @return String
-	 */
-	public java.lang.String getCloudZone() {
-		return cloudZone;
-	}
-
-	/**
-	 * クラウド管理->ゾーンのsetterです。
-	 * @param cloudZone
-	 */
-	public void setCloudZone(java.lang.String cloudZone) {
-		this.cloudZone = cloudZone;
+	public void setCloudLocation(java.lang.String cloudLocation) {
+		this.cloudLocation = cloudLocation;
 	}
 
 	/**
@@ -1238,6 +1140,7 @@ public class NodeInfo extends FacilityInfo implements Serializable
 		str.append('{');
 
 		str.append(
+				"autoDeviceSearch=" + isAutoDeviceSearch() + " " +
 				"platformFamily=" + getPlatformFamily() + " " +
 				"subPlatformFamily=" + getSubPlatformFamily() + " " +
 				"hardwareType=" + getHardwareType() + " " +
@@ -1255,9 +1158,15 @@ public class NodeInfo extends FacilityInfo implements Serializable
 
 				"agentAwakePort=" + getAgentAwakePort() + " " +
 
+				"snmpUser=" + getSnmpUser() + " " +
+				"snmpAuthPassword=" + getSnmpAuthPassword() + " " +
+				"snmpPrivPassword=" + getSnmpPrivPassword() + " " +
 				"snmpPort=" + getSnmpPort() + " " +
 				"snmpCommunity=" + getSnmpCommunity() + " " +
 				"snmpVersion=" + getSnmpVersion() + " " +
+				"snmpSecurityLevel=" + getSnmpSecurityLevel() + " " +
+				"snmpAuthProtocol=" + getSnmpAuthProtocol() + " " +
+				"snmpPrivProtocol=" + getSnmpPrivProtocol() + " " +
 				"snmpTimeout=" + getSnmpTimeout() + " " +
 				"snmpRetryCount=" + getSnmpRetryCount() + " " +
 
@@ -1277,26 +1186,11 @@ public class NodeInfo extends FacilityInfo implements Serializable
 				"ipmiProtocol=" + getIpmiProtocol() + " " +
 				"ipmiLevel=" + getIpmiLevel() + " " +
 
-				"vmNodeType=" + getVmNodeType() + " " +
-				"vmManagementNode=" + getVmManagementNode() + " " +
-				"vmName=" + getVmName() + " " +
-				"vmId=" + getVmId() + " " +
-				"vmUser=" + getVmUser() + " " +
-				"vmUserPassword=" + getVmUserPassword() + " " +
-				"vmProtocol=" + getVmProtocol() + " " +
-
-				"vNetSwitchType=" + getvNetSwitchType() + " " +
-				"vNetHostNode=" + getvNetHostNode() + " " +
-				"openFlowDataPathId=" + getOpenFlowDataPathId() + " " +
-				"openFlowCtrlIpAddress=" + getOpenFlowCtrlIpAddress() + " " +
-
-				"cloudNodeType=" + getCloudNodeType() + " " +
 				"cloudService=" + getCloudService() + " " +
-				"cloudAccountResouce=" + getCloudAccountResouce() + " " +
+				"cloudScope=" + getCloudScope() + " " +
 				"cloudResourceType=" + getCloudResourceType() + " " +
 				"cloudResourceId=" + getCloudResourceId() + " " +
-				"cloudRegion=" + getCloudRegion() + " " +
-				"cloudZone=" + getCloudZone() + " " +
+				"cloudLocation=" + getCloudLocation() + " " +
 
 				"administrator=" + getAdministrator() + " " +
 				"contact=" + getContact()
@@ -1316,6 +1210,14 @@ public class NodeInfo extends FacilityInfo implements Serializable
 
 			lEquals = lEquals && super.equals(pOther);
 
+			if( this.autoDeviceSearch == null )
+			{
+				lEquals = lEquals && ( lTest.autoDeviceSearch == null );
+			}
+			else
+			{
+				lEquals = lEquals && this.autoDeviceSearch.equals( lTest.autoDeviceSearch );
+			}
 			// HW
 			if( this.platformFamily == null )
 			{
@@ -1421,6 +1323,30 @@ public class NodeInfo extends FacilityInfo implements Serializable
 			}
 
 			// SNMP
+			if( this.snmpUser == null )
+			{
+				lEquals = lEquals && ( lTest.snmpUser == null );
+			}
+			else
+			{
+				lEquals = lEquals && this.snmpUser.equals( lTest.snmpUser );
+			}
+			if( this.snmpAuthPassword == null )
+			{
+				lEquals = lEquals && ( lTest.snmpAuthPassword == null );
+			}
+			else
+			{
+				lEquals = lEquals && this.snmpAuthPassword.equals( lTest.snmpAuthPassword );
+			}
+			if( this.snmpPrivPassword == null )
+			{
+				lEquals = lEquals && ( lTest.snmpPrivPassword == null );
+			}
+			else
+			{
+				lEquals = lEquals && this.snmpPrivPassword.equals( lTest.snmpPrivPassword );
+			}
 			if( this.snmpPort == null )
 			{
 				lEquals = lEquals && ( lTest.snmpPort == null );
@@ -1445,6 +1371,30 @@ public class NodeInfo extends FacilityInfo implements Serializable
 			{
 				lEquals = lEquals && this.snmpVersion.equals( lTest.snmpVersion );
 			}
+			if( this.snmpSecurityLevel == null )
+			{
+				lEquals = lEquals && ( lTest.snmpSecurityLevel == null );
+			}
+			else
+			{
+				lEquals = lEquals && this.snmpSecurityLevel.equals( lTest.snmpSecurityLevel );
+			}
+			if( this.snmpAuthProtocol == null )
+			{
+				lEquals = lEquals && ( lTest.snmpAuthProtocol == null );
+			}
+			else
+			{
+				lEquals = lEquals && this.snmpAuthProtocol.equals( lTest.snmpAuthProtocol );
+			}
+			if( this.snmpPrivProtocol == null )
+			{
+				lEquals = lEquals && ( lTest.snmpPrivProtocol == null );
+			}
+			else
+			{
+				lEquals = lEquals && this.snmpPrivProtocol.equals( lTest.snmpPrivProtocol );
+			}
 			if( this.snmpTimeout == null )
 			{
 				lEquals = lEquals && ( lTest.snmpTimeout == null );
@@ -1578,108 +1528,7 @@ public class NodeInfo extends FacilityInfo implements Serializable
 				lEquals = lEquals && this.ipmiLevel.equals( lTest.ipmiLevel );
 			}
 
-
-			// サーバ仮想化
-			if( this.vmNodeType == null )
-			{
-				lEquals = lEquals && ( lTest.vmNodeType == null );
-			}
-			else
-			{
-				lEquals = lEquals && this.vmNodeType.equals( lTest.vmNodeType );
-			}
-			if( this.vmManagementNode == null )
-			{
-				lEquals = lEquals && ( lTest.vmManagementNode == null );
-			}
-			else
-			{
-				lEquals = lEquals && this.vmManagementNode.equals( lTest.vmManagementNode );
-			}
-			if( this.vmName == null )
-			{
-				lEquals = lEquals && ( lTest.vmName == null );
-			}
-			else
-			{
-				lEquals = lEquals && this.vmName.equals( lTest.vmName );
-			}
-			if( this.vmId == null )
-			{
-				lEquals = lEquals && ( lTest.vmId == null );
-			}
-			else
-			{
-				lEquals = lEquals && this.vmId.equals( lTest.vmId );
-			}
-			if( this.vmUser == null )
-			{
-				lEquals = lEquals && ( lTest.vmUser == null );
-			}
-			else
-			{
-				lEquals = lEquals && this.vmUser.equals( lTest.vmUser );
-			}
-			if( this.vmUserPassword == null )
-			{
-				lEquals = lEquals && ( lTest.vmUserPassword == null );
-			}
-			else
-			{
-				lEquals = lEquals && this.vmUserPassword.equals( lTest.vmUserPassword );
-			}
-			if( this.vmProtocol == null )
-			{
-				lEquals = lEquals && ( lTest.vmProtocol == null );
-			}
-			else
-			{
-				lEquals = lEquals && this.vmProtocol.equals( lTest.vmProtocol );
-			}
-
-			// ネットワーク仮想化
-			if( this.vNetSwitchType == null )
-			{
-				lEquals = lEquals && ( lTest.vNetSwitchType == null );
-			}
-			else
-			{
-				lEquals = lEquals && this.vNetSwitchType.equals( lTest.vNetSwitchType );
-			}
-			if( this.vNetHostNode == null )
-			{
-				lEquals = lEquals && ( lTest.vNetHostNode == null );
-			}
-			else
-			{
-				lEquals = lEquals && this.vNetHostNode.equals( lTest.vNetHostNode );
-			}
-			if( this.openFlowDataPathId == null )
-			{
-				lEquals = lEquals && ( lTest.openFlowDataPathId == null );
-			}
-			else
-			{
-				lEquals = lEquals && this.openFlowDataPathId.equals( lTest.openFlowDataPathId );
-			}
-			if( this.openFlowCtrlIpAddress == null )
-			{
-				lEquals = lEquals && ( lTest.openFlowCtrlIpAddress == null );
-			}
-			else
-			{
-				lEquals = lEquals && this.openFlowCtrlIpAddress.equals( lTest.openFlowCtrlIpAddress );
-			}
-
-			// クラウド管理
-			if( this.cloudNodeType == null )
-			{
-				lEquals = lEquals && ( lTest.cloudNodeType == null );
-			}
-			else
-			{
-				lEquals = lEquals && this.cloudNodeType.equals( lTest.cloudNodeType );
-			}
+			// クラウド・仮想化管理
 			if( this.cloudService == null )
 			{
 				lEquals = lEquals && ( lTest.cloudService == null );
@@ -1688,13 +1537,13 @@ public class NodeInfo extends FacilityInfo implements Serializable
 			{
 				lEquals = lEquals && this.cloudService.equals( lTest.cloudService );
 			}
-			if( this.cloudAccountResouce == null )
+			if( this.cloudScope == null )
 			{
-				lEquals = lEquals && ( lTest.cloudAccountResouce == null );
+				lEquals = lEquals && ( lTest.cloudScope == null );
 			}
 			else
 			{
-				lEquals = lEquals && this.cloudAccountResouce.equals( lTest.cloudAccountResouce );
+				lEquals = lEquals && this.cloudScope.equals( lTest.cloudScope );
 			}
 			if( this.cloudResourceType == null )
 			{
@@ -1704,6 +1553,12 @@ public class NodeInfo extends FacilityInfo implements Serializable
 			{
 				lEquals = lEquals && this.cloudResourceType.equals( lTest.cloudResourceType );
 			}
+			if (this.cloudResourceName == null) 
+			{
+				lEquals = lEquals && ( lTest.cloudResourceName == null );
+			} else {
+				lEquals = lEquals && this.cloudResourceName.equals( lTest.cloudResourceName );
+			}
 			if( this.cloudResourceId == null )
 			{
 				lEquals = lEquals && ( lTest.cloudResourceId == null );
@@ -1712,21 +1567,13 @@ public class NodeInfo extends FacilityInfo implements Serializable
 			{
 				lEquals = lEquals && this.cloudResourceId.equals( lTest.cloudResourceId );
 			}
-			if( this.cloudRegion == null )
+			if( this.cloudLocation == null )
 			{
-				lEquals = lEquals && ( lTest.cloudRegion == null );
+				lEquals = lEquals && ( lTest.cloudLocation == null );
 			}
 			else
 			{
-				lEquals = lEquals && this.cloudRegion.equals( lTest.cloudRegion );
-			}
-			if( this.cloudZone == null )
-			{
-				lEquals = lEquals && ( lTest.cloudZone == null );
-			}
-			else
-			{
-				lEquals = lEquals && this.cloudZone.equals( lTest.cloudZone );
+				lEquals = lEquals && this.cloudLocation.equals( lTest.cloudLocation );
 			}
 
 			// 保守
@@ -1762,13 +1609,20 @@ public class NodeInfo extends FacilityInfo implements Serializable
 
 		result = 37*result + super.hashCode();
 
+		result = 37*result + ((this.autoDeviceSearch != null) ? this.autoDeviceSearch.hashCode() : 0);
 		result = 37*result + ((this.platformFamily != null) ? this.platformFamily.hashCode() : 0);
 		result = 37*result + ((this.subPlatformFamily != null) ? this.subPlatformFamily.hashCode() : 0);
 		result = 37*result + ((this.hardwareType != null) ? this.hardwareType.hashCode() : 0);
 
+		result = 37*result + ((this.snmpUser != null) ? this.snmpUser.hashCode() : 0);
+		result = 37*result + ((this.snmpAuthPassword != null) ? this.snmpAuthPassword.hashCode() : 0);
+		result = 37*result + ((this.snmpPrivPassword != null) ? this.snmpPrivPassword.hashCode() : 0);
 		result = 37*result + ((this.snmpPort != null) ? this.snmpPort.hashCode() : 0);
 		result = 37*result + ((this.snmpCommunity != null) ? this.snmpCommunity.hashCode() : 0);
 		result = 37*result + ((this.snmpVersion != null) ? this.snmpVersion.hashCode() : 0);
+		result = 37*result + ((this.snmpSecurityLevel != null) ? this.snmpSecurityLevel.hashCode() : 0);
+		result = 37*result + ((this.snmpAuthProtocol != null) ? this.snmpAuthProtocol.hashCode() : 0);
+		result = 37*result + ((this.snmpPrivProtocol != null) ? this.snmpPrivProtocol.hashCode() : 0);
 		result = 37*result + ((this.snmpTimeout != null) ? this.snmpTimeout.hashCode() : 0);
 		result = 37*result + ((this.snmpRetryCount != null) ? this.snmpRetryCount.hashCode() : 0);
 
@@ -1789,22 +1643,13 @@ public class NodeInfo extends FacilityInfo implements Serializable
 		result = 37*result + ((this.osVersion != null) ? this.osVersion.hashCode() : 0);
 		result = 37*result + ((this.characterSet != null) ? this.characterSet.hashCode() : 0);
 
-		result = 37*result + ((this.vmNodeType != null) ? this.vmNodeType.hashCode() : 0);
-		result = 37*result + ((this.vmManagementNode != null) ? this.vmManagementNode.hashCode() : 0);
-		result = 37*result + ((this.vmName != null) ? this.vmName.hashCode() : 0);
-		result = 37*result + ((this.vmId != null) ? this.vmId.hashCode() : 0);
-		result = 37*result + ((this.vmUser != null) ? this.vmUser.hashCode() : 0);
-		result = 37*result + ((this.vmUserPassword != null) ? this.vmUserPassword.hashCode() : 0);
-		result = 37*result + ((this.vmProtocol != null) ? this.vmProtocol.hashCode() : 0);
-
-		result = 37*result + ((this.cloudNodeType != null) ? this.cloudNodeType.hashCode() : 0);
 		result = 37*result + ((this.cloudService != null) ? this.cloudService.hashCode() : 0);
-		result = 37*result + ((this.cloudAccountResouce != null) ? this.cloudAccountResouce.hashCode() : 0);
+		result = 37*result + ((this.cloudScope != null) ? this.cloudScope.hashCode() : 0);
 		result = 37*result + ((this.cloudResourceType != null) ? this.cloudResourceType.hashCode() : 0);
+		result = 37*result + ((this.cloudResourceName != null) ? this.cloudResourceName.hashCode() : 0);
 		result = 37*result + ((this.cloudResourceId != null) ? this.cloudResourceId.hashCode() : 0);
-		result = 37*result + ((this.cloudRegion != null) ? this.cloudRegion.hashCode() : 0);
-		result = 37*result + ((this.cloudZone != null) ? this.cloudZone.hashCode() : 0);
-		
+		result = 37*result + ((this.cloudLocation != null) ? this.cloudLocation.hashCode() : 0);
+
 		result = 37*result + ((this.administrator != null) ? this.administrator.hashCode() : 0);
 		result = 37*result + ((this.contact != null) ? this.contact.hashCode() : 0);
 
@@ -1945,7 +1790,7 @@ public class NodeInfo extends FacilityInfo implements Serializable
 
 	/**
 	 * 利用可能なIPアドレスを返します。
-	 * 
+	 *
 	 * @return 利用可能なIPアドレス
 	 * @throws UnknownHostException
 	 */
@@ -1990,9 +1835,15 @@ public class NodeInfo extends FacilityInfo implements Serializable
 		if (jobMultiplicity == null) jobMultiplicity = 0;
 
 		// SNMP
+		if (snmpUser == null) snmpUser = "";
+		if (snmpAuthPassword == null) snmpAuthPassword = "";
+		if (snmpPrivPassword == null) snmpPrivPassword = "";
 		if (snmpPort == null) snmpPort = 161;
 		if (snmpCommunity == null) snmpCommunity = "";
 		if (snmpVersion == null) snmpVersion = "";
+		if (snmpSecurityLevel == null) snmpSecurityLevel = "";
+		if (snmpAuthProtocol == null) snmpAuthProtocol = "";
+		if (snmpPrivProtocol == null) snmpPrivProtocol = "";
 		if (snmpTimeout == null) snmpTimeout = 5000;
 		if (snmpRetryCount == null) snmpRetryCount = 3;
 
@@ -2023,31 +1874,22 @@ public class NodeInfo extends FacilityInfo implements Serializable
 		if (winrmTimeout == null) winrmTimeout = 5000;
 		if (winrmRetries == null) winrmRetries = 3;
 
+		if (sshUser == null) sshUser = "root";
+		if (sshUserPassword == null) sshUserPassword = "";
+		if (sshPrivateKeyFilepath == null) sshPrivateKeyFilepath = "";
+		if (sshPrivateKeyPassphrase == null) sshPrivateKeyPassphrase = "";
+		if (sshPort == null) sshPort = 22;
+		if (sshTimeout == null) sshTimeout = 50000;
+
 		// デバイス
 
-		// サーバ仮想化
-		if (vmNodeType == null) vmNodeType = "";
-		if (vmManagementNode == null) vmManagementNode = "";
-		if (vmName == null) vmName = "";
-		if (vmId == null) vmId = "";
-		if (vmUser == null) vmUser = "";
-		if (vmUserPassword == null) vmUserPassword = "";
-		if (vmProtocol == null) vmProtocol = "";
-
-		// ネットワーク仮想化
-		if (vNetSwitchType == null) vNetSwitchType = "";
-		if (vNetHostNode == null) vNetHostNode = "";
-		if (openFlowDataPathId == null) openFlowDataPathId = "";
-		if (openFlowCtrlIpAddress == null) openFlowCtrlIpAddress = "";
-
-		// サーバ仮想化
-		if (cloudNodeType == null) cloudNodeType = "";
+		// クラウド・サーバ仮想化
 		if (cloudService == null) cloudService = "";
-		if (cloudAccountResouce == null) cloudAccountResouce = "";
+		if (cloudScope == null) cloudScope = "";
 		if (cloudResourceType == null) cloudResourceType = "";
+		if (cloudResourceName == null) cloudResourceName = "";
 		if (cloudResourceId == null) cloudResourceId = "";
-		if (cloudRegion == null) cloudRegion = "";
-		if (cloudZone == null) cloudZone = "";
+		if (cloudLocation == null) cloudLocation = "";
 
 		// ノード変数
 
@@ -2055,4 +1897,218 @@ public class NodeInfo extends FacilityInfo implements Serializable
 		if (administrator == null) administrator = "";
 		if (contact == null) contact = "";
 	}
+
+	@Override
+	public NodeInfo clone() {
+		NodeInfo cloneInfo = new NodeInfo();
+		cloneInfo = (NodeInfo) super.clone();
+
+		cloneInfo.autoDeviceSearch = this.autoDeviceSearch;
+		// HW
+		cloneInfo.platformFamily = this.platformFamily;
+		cloneInfo.subPlatformFamily = this.subPlatformFamily;
+		cloneInfo.hardwareType = this.hardwareType;
+
+		// IPアドレス
+		cloneInfo.ipAddressVersion = this.ipAddressVersion;
+		cloneInfo.ipAddressV4 = this.ipAddressV4;
+		cloneInfo.ipAddressV6 = this.ipAddressV6;
+
+		//参照型は一旦別のオブジェクトへコピー（親クラスをcloneした時点で子クラスの
+		//参照型メンバ変数への参照がセットされてしまうため）
+		ArrayList<NodeHostnameInfo> tmpHostnameList = new ArrayList<NodeHostnameInfo>();
+		for (NodeHostnameInfo thisInfo : this.nodeHostnameInfo) {
+			tmpHostnameList.add(thisInfo.clone());
+		}
+		cloneInfo.nodeHostnameInfo = tmpHostnameList;
+
+		// OS
+		cloneInfo.nodeName = this.nodeName;
+		cloneInfo.osName = this.osName;
+		cloneInfo.osRelease = this.osRelease;
+		cloneInfo.osVersion = this.osVersion;
+		cloneInfo.characterSet = this.characterSet;
+
+		// Hinemosエージェント
+		cloneInfo.agentAwakePort = this.agentAwakePort;
+
+		// JOB
+		cloneInfo.jobPriority = this.jobPriority;
+		cloneInfo.jobMultiplicity = this.jobMultiplicity;
+
+		// SNMP
+		cloneInfo.snmpUser = this.snmpUser;
+		cloneInfo.snmpAuthPassword = this.snmpAuthPassword;
+		cloneInfo.snmpPrivPassword = this.snmpPrivPassword;
+		cloneInfo.snmpPort = this.snmpPort;
+		cloneInfo.snmpCommunity = this.snmpCommunity;
+		cloneInfo.snmpVersion = this.snmpVersion;
+		cloneInfo.snmpSecurityLevel = this.snmpSecurityLevel;
+		cloneInfo.snmpAuthProtocol = this.snmpAuthProtocol;
+		cloneInfo.snmpPrivProtocol = this.snmpPrivProtocol;
+		cloneInfo.snmpTimeout = this.snmpTimeout;
+		cloneInfo.snmpRetryCount = this.snmpRetryCount;
+
+		// WBEM
+		cloneInfo.wbemUser = this.wbemUser;
+		cloneInfo.wbemUserPassword = this.wbemUserPassword;
+		cloneInfo.wbemPort = this.wbemPort;
+		cloneInfo.wbemProtocol = this.wbemProtocol;
+		cloneInfo.wbemTimeout = this.wbemTimeout;
+		cloneInfo.wbemRetryCount = this.wbemRetryCount;
+
+		// IPMI
+		cloneInfo.ipmiIpAddress = this.ipmiIpAddress;
+		cloneInfo.ipmiPort = this.ipmiPort;
+		cloneInfo.ipmiUser = this.ipmiUser;
+		cloneInfo.ipmiUserPassword = this.ipmiUserPassword;
+		cloneInfo.ipmiTimeout = this.ipmiTimeout;
+		cloneInfo.ipmiRetries = this.ipmiRetries;
+		cloneInfo.ipmiProtocol = this.ipmiProtocol;
+		cloneInfo.ipmiLevel = this.ipmiLevel;
+
+		// WinRM
+		cloneInfo.winrmUser = this.winrmUser;
+		cloneInfo.winrmUserPassword = this.winrmUserPassword;
+		cloneInfo.winrmVersion = this.winrmVersion;
+		cloneInfo.winrmPort = this.winrmPort;
+		cloneInfo.winrmProtocol = this.winrmProtocol;
+		cloneInfo.winrmTimeout = this.winrmTimeout;
+		cloneInfo.winrmRetries = this.winrmRetries;
+
+		// デバイス
+		//参照型は一旦別のオブジェクトへコピー
+		ArrayList<NodeDeviceInfo> tmpDeviceList = new ArrayList<NodeDeviceInfo>();
+		for (NodeDeviceInfo thisInfo : this.nodeDeviceInfo) {
+			tmpDeviceList.add(thisInfo.clone());
+		}
+		cloneInfo.nodeDeviceInfo = tmpDeviceList;
+
+		ArrayList<NodeCpuInfo> tmpCpuList = new ArrayList<NodeCpuInfo>();
+		for (NodeCpuInfo thisInfo : this.nodeCpuInfo) {
+			tmpCpuList.add(thisInfo.clone());
+		}
+		cloneInfo.nodeCpuInfo = tmpCpuList;
+
+		ArrayList<NodeMemoryInfo> tmpMemList = new ArrayList<NodeMemoryInfo>();
+		for (NodeMemoryInfo thisInfo : this.nodeMemoryInfo) {
+			tmpMemList.add(thisInfo.clone());
+		}
+		cloneInfo.nodeMemoryInfo = tmpMemList;
+
+		ArrayList<NodeDiskInfo> tmpDiskList = new ArrayList<NodeDiskInfo>();
+		for (NodeDiskInfo thisInfo : this.nodeDiskInfo) {
+			tmpDiskList.add(thisInfo.clone());
+		}
+		cloneInfo.nodeDiskInfo = tmpDiskList;
+
+		ArrayList<NodeNetworkInterfaceInfo> tmpNwIfList = new ArrayList<NodeNetworkInterfaceInfo>();
+		for (NodeNetworkInterfaceInfo thisInfo : this.nodeNetworkInterfaceInfo) {
+			tmpNwIfList.add(thisInfo.clone());
+		}
+		cloneInfo.nodeNetworkInterfaceInfo = tmpNwIfList;
+
+		ArrayList<NodeFilesystemInfo> tmpFSList = new ArrayList<NodeFilesystemInfo>();
+		for (NodeFilesystemInfo thisInfo : this.nodeFilesystemInfo) {
+			tmpFSList.add(thisInfo.clone());
+		}
+		cloneInfo.nodeFilesystemInfo = tmpFSList;
+
+		// クラウド・仮想化
+		cloneInfo.cloudService = this.cloudService;
+		cloneInfo.cloudScope = this.cloudScope;
+		cloneInfo.cloudResourceType = this.cloudResourceType;
+		cloneInfo.cloudResourceName = this.cloudResourceName;
+		cloneInfo.cloudResourceId = this.cloudResourceId;
+		cloneInfo.cloudLocation = this.cloudLocation;
+
+		// ノード変数
+		ArrayList<NodeVariableInfo> tmpVlList = new ArrayList<NodeVariableInfo>();
+		for (NodeVariableInfo thisInfo : this.nodeVariableInfo) {
+			tmpVlList.add(thisInfo.clone());
+		}
+		cloneInfo.nodeVariableInfo = tmpVlList;
+
+		// 保守
+		cloneInfo.administrator = this.administrator;
+		cloneInfo.contact = this.contact;
+
+		// 備考
+		ArrayList<NodeNoteInfo> tmpNoteList = new ArrayList<NodeNoteInfo>();
+		for (NodeNoteInfo thisInfo : this.nodeNoteInfo) {
+			tmpNoteList.add(thisInfo.clone());
+		}
+		cloneInfo.nodeNoteInfo = tmpNoteList;
+
+		return cloneInfo;
+
+	}
+
+	public java.lang.String getSshUser() {
+		return sshUser;
+	}
+
+	public void setSshUser(java.lang.String sshUser) {
+		this.sshUser = sshUser;
+	}
+
+	public java.lang.String getSshUserPassword() {
+		return sshUserPassword;
+	}
+
+	public void setSshUserPassword(java.lang.String sshUserPassword) {
+		this.sshUserPassword = sshUserPassword;
+	}
+	
+	public java.lang.String getSshPrivateKeyFilepath() {
+		return this.sshPrivateKeyFilepath;
+	}
+	
+	public void setSshPrivateKeyFilepath(java.lang.String sshPrivateKeyFilepath) {
+		this.sshPrivateKeyFilepath = sshPrivateKeyFilepath;
+	}
+	
+	public java.lang.String getSshPrivateKeyPassphrase() {
+		return this.sshPrivateKeyPassphrase;
+	}
+	
+	public void setSshPrivateKeyPassphrase(java.lang.String sshPrivateKeyPassphrase) {
+		this.sshPrivateKeyPassphrase = sshPrivateKeyPassphrase;
+	}
+	
+	public java.lang.Integer getSshPort() {
+		return this.sshPort;
+	}
+	
+	public void setSshPort(java.lang.Integer sshPort) {
+		this.sshPort = sshPort;
+	}
+	
+	public java.lang.Integer getSshTimeout() {
+		return this.sshTimeout;
+	}
+	
+	public void setSshTimeout(java.lang.Integer sshTimeout) {
+		this.sshTimeout = sshTimeout;
+	}
+
+	/**
+	 * 自動デバイスサーチのgetterです。
+	 * @return Boolean
+	 */
+	public Boolean isAutoDeviceSearch()
+	{
+		return this.autoDeviceSearch;
+	}
+
+	/**
+	 * 自動デバイスサーチのsetterです。
+	 * 有効の場合1、無効の場合0を設定します。
+	 * @param autoDeviceSearch
+	 */
+	public void setAutoDeviceSearch( Boolean autoDeviceSearch )
+	{
+		this.autoDeviceSearch = autoDeviceSearch;
+	}
+
 }
