@@ -15,6 +15,7 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.repository.factory;
 
+import java.io.Serializable;
 import java.net.Inet4Address;
 import java.net.Inet6Address;
 import java.net.InetAddress;
@@ -27,19 +28,25 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Locale;
 import java.util.Set;
-import java.util.concurrent.ConcurrentHashMap;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.accesscontrol.util.UserRoleCache;
 import com.clustercontrol.bean.ValidConstant;
+import com.clustercontrol.commons.util.AbstractCacheManager;
+import com.clustercontrol.commons.util.CacheManagerFactory;
 import com.clustercontrol.commons.util.HinemosSessionContext;
+import com.clustercontrol.commons.util.ICacheManager;
+import com.clustercontrol.commons.util.ILock;
+import com.clustercontrol.commons.util.ILockManager;
 import com.clustercontrol.commons.util.Ipv6Util;
+import com.clustercontrol.commons.util.LockManagerFactory;
 import com.clustercontrol.commons.util.ObjectValidator;
 import com.clustercontrol.fault.FacilityNotFound;
 import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.fault.InvalidRole;
+import com.clustercontrol.plugin.impl.OsScopeInitializerPlugin;
 import com.clustercontrol.repository.bean.FacilityConstant;
 import com.clustercontrol.repository.bean.FacilityInfo;
 import com.clustercontrol.repository.bean.FacilityTreeAttributeConstant;
@@ -62,31 +69,131 @@ public class FacilitySelector {
 
 	public static final String SEPARATOR = ">";
 
+	private static ILock _hostnameIpaddrFacilityIdCacheLock;
+	private static ILock _nodenameFacilityIdCacheLock;
+	private static ILock _ipaddrFacilityIdCacheLock;
+	private static ILock _hostnameFacilityIdCacheLock;
+	private static ILock _scopeNodeFacilityIdCacheLock;
+	
+	static {
+		ILockManager lockManager = LockManagerFactory.instance().create();
+		_hostnameIpaddrFacilityIdCacheLock = lockManager.create(FacilitySelector.class.getName() + "-" + AbstractCacheManager.KEY_REPOSITORY_HOSTNAME_IPADDR_FACILITYID);
+		_nodenameFacilityIdCacheLock = lockManager.create(FacilitySelector.class.getName() + "-" + AbstractCacheManager.KEY_REPOSITORY_NODENAME_FACILITYID);
+		_ipaddrFacilityIdCacheLock = lockManager.create(FacilitySelector.class.getName() + "-" + AbstractCacheManager.KEY_REPOSITORY_IPADDR_FACILITYID);
+		_hostnameFacilityIdCacheLock = lockManager.create(FacilitySelector.class.getName() + "-" + AbstractCacheManager.KEY_REPOSITORY_HOSTNAME_FACILITYID);
+		_scopeNodeFacilityIdCacheLock = lockManager.create(FacilitySelector.class.getName() + "-" + AbstractCacheManager.KEY_REPOSITORY_SCOPE_NODE_FACILITYID);
+		
+		try {
+			_hostnameIpaddrFacilityIdCacheLock.writeLock();
+			refreshHostnameIpaddrFacilityIdCache();
+		} finally {
+			_hostnameIpaddrFacilityIdCacheLock.writeUnlock();
+		}
+		
+		try {
+			_nodenameFacilityIdCacheLock.writeLock();
+			refreshNodenameFacilityIdCache();
+		} finally {
+			_nodenameFacilityIdCacheLock.writeUnlock();
+		}
+		
+		try {
+			_ipaddrFacilityIdCacheLock.writeLock();
+			refreshIpaddrFacilityIdCache();
+		} finally {
+			_ipaddrFacilityIdCacheLock.writeUnlock();
+		}
+		
+		try {
+			_hostnameFacilityIdCacheLock.writeLock();
+			refreshHostnameFacilityIdCache();
+		} finally {
+			_hostnameFacilityIdCacheLock.writeUnlock();
+		}
+		
+		try {
+			_scopeNodeFacilityIdCacheLock.writeLock();
+			refreshScopeNodeFacilityIdCache();
+		} finally {
+			_scopeNodeFacilityIdCacheLock.writeUnlock();
+		}
+	}
+	
 	/** ----- ファシリティの木情報のキャッシュ ----- */
-
+	
 	// getFacilityIdList(hostname, ipAddress)のためのキャッシュ
-	private static ConcurrentHashMap<String, ArrayList<String>> nodeIpFacilityIdMap =
-			new ConcurrentHashMap<String, ArrayList<String>>();
-	private static final Object nodeIpFacilityIdMapLock = new Object();
-
+	@SuppressWarnings("unchecked")
+	private static HashMap<String, ArrayList<String>> getHostnameIpaddrFacilityIdCache() {
+		ICacheManager cm = CacheManagerFactory.instance().create();
+		Serializable cache = cm.get(AbstractCacheManager.KEY_REPOSITORY_HOSTNAME_IPADDR_FACILITYID);
+		if (m_log.isDebugEnabled()) m_log.debug("get cache " + AbstractCacheManager.KEY_REPOSITORY_HOSTNAME_IPADDR_FACILITYID + " : " + cache);
+		return cache == null ? null : (HashMap<String, ArrayList<String>>)cache;
+	}
+	
+	private static void storeHostnameIpaddrFacilityIdCache(HashMap<String, ArrayList<String>> newCache) {
+		ICacheManager cm = CacheManagerFactory.instance().create();
+		if (m_log.isDebugEnabled()) m_log.debug("store cache " + AbstractCacheManager.KEY_REPOSITORY_HOSTNAME_IPADDR_FACILITYID + " : " + newCache);
+		cm.store(AbstractCacheManager.KEY_REPOSITORY_HOSTNAME_IPADDR_FACILITYID, newCache);
+	}
+	
 	// <小文字ノード名, ファシリティIDのセット>（監視対象外となっているものは含まない。）
-	private static HashMap<String, HashSet<String>> nodenameFacilityIdMap;
-	private static final Object nodenameFacilityIdMapLock = new Object();
-
+	@SuppressWarnings("unchecked")
+	private static HashMap<String, HashSet<String>> getNodenameFacilityIdCache() {
+		ICacheManager cm = CacheManagerFactory.instance().create();
+		Serializable cache = cm.get(AbstractCacheManager.KEY_REPOSITORY_NODENAME_FACILITYID);
+		if (m_log.isDebugEnabled()) m_log.debug("get cache " + AbstractCacheManager.KEY_REPOSITORY_NODENAME_FACILITYID + " : " + cache);
+		return cache == null ? null : (HashMap<String, HashSet<String>>)cache;
+	}
+	
+	private static void storeNodenameFacilityIdCache(HashMap<String, HashSet<String>> newCache) {
+		ICacheManager cm = CacheManagerFactory.instance().create();
+		if (m_log.isDebugEnabled()) m_log.debug("store cache " + AbstractCacheManager.KEY_REPOSITORY_NODENAME_FACILITYID + " : " + newCache);
+		cm.store(AbstractCacheManager.KEY_REPOSITORY_NODENAME_FACILITYID, newCache);
+	}
+	
 	// <IPアドレス, ファシリティIDのセット>（監視対象外となっているものは含まない。）
-	private static HashMap<InetAddress, HashSet<String>> inetAddressFacilityIdMap;
-	private static final Object inetAddressFacilityIdMapLock = new Object();
+	@SuppressWarnings("unchecked")
+	private static HashMap<InetAddress, HashSet<String>> getIpaddrFacilityIdCache() {
+		ICacheManager cm = CacheManagerFactory.instance().create();
+		Serializable cache = cm.get(AbstractCacheManager.KEY_REPOSITORY_IPADDR_FACILITYID);
+		if (m_log.isDebugEnabled()) m_log.debug("get cache " + AbstractCacheManager.KEY_REPOSITORY_IPADDR_FACILITYID + " : " + cache);
+		return cache == null ? null : (HashMap<InetAddress, HashSet<String>>)cache;
+	}
+	
+	private static void storeIpaddrFacilityIdCache(HashMap<InetAddress, HashSet<String>> newCache) {
+		ICacheManager cm = CacheManagerFactory.instance().create();
+		if (m_log.isDebugEnabled()) m_log.debug("store cache " + AbstractCacheManager.KEY_REPOSITORY_IPADDR_FACILITYID + " : " + newCache);
+		cm.store(AbstractCacheManager.KEY_REPOSITORY_IPADDR_FACILITYID, newCache);
+	}
 
 	// <ホスト名, ファシリティIDのセット>（監視対象外となっているものは含まない。）
-	private static HashMap<String, HashSet<String>> hostnameFacilityIdMap;
-	private static final Object hostnameFacilityIdMapLock = new Object();
+	@SuppressWarnings("unchecked")
+	private static HashMap<String, HashSet<String>> getHostnameFacilityIdCache() {
+		ICacheManager cm = CacheManagerFactory.instance().create();
+		Serializable cache = cm.get(AbstractCacheManager.KEY_REPOSITORY_HOSTNAME_FACILITYID);
+		if (m_log.isDebugEnabled()) m_log.debug("get cache " + AbstractCacheManager.KEY_REPOSITORY_HOSTNAME_FACILITYID + " : " + cache);
+		return cache == null ? null : (HashMap<String, HashSet<String>>)cache;
+	}
+	
+	private static void storeHostnameFacilityIdCache(HashMap<String, HashSet<String>> newCache) {
+		ICacheManager cm = CacheManagerFactory.instance().create();
+		if (m_log.isDebugEnabled()) m_log.debug("store cache " + AbstractCacheManager.KEY_REPOSITORY_HOSTNAME_FACILITYID + " : " + newCache);
+		cm.store(AbstractCacheManager.KEY_REPOSITORY_HOSTNAME_FACILITYID, newCache);
+	}
 
 	// containsFacilityIdメソッドのためのキャッシュ
-	private static ConcurrentHashMap<String, Boolean> containsFacilityIdMap;
-	private static final Object containsFacilityIdMapLock = new Object();
-
-	static {
-		initCacheFacilityTree();
+	@SuppressWarnings("unchecked")
+	private static HashMap<String, Boolean> getScopeNodeFacilityIdCache() {
+		ICacheManager cm = CacheManagerFactory.instance().create();
+		Serializable cache = cm.get(AbstractCacheManager.KEY_REPOSITORY_SCOPE_NODE_FACILITYID);
+		if (m_log.isDebugEnabled()) m_log.debug("get cache " + AbstractCacheManager.KEY_REPOSITORY_SCOPE_NODE_FACILITYID + " : " + cache);
+		return cache == null ? null : (HashMap<String, Boolean>)cache;
+	}
+	
+	private static void storeScopeNodeFacilityIdCache(HashMap<String, Boolean> newCache) {
+		ICacheManager cm = CacheManagerFactory.instance().create();
+		if (m_log.isDebugEnabled()) m_log.debug("store cache " + AbstractCacheManager.KEY_REPOSITORY_SCOPE_NODE_FACILITYID + " : " + newCache);
+		cm.store(AbstractCacheManager.KEY_REPOSITORY_SCOPE_NODE_FACILITYID, newCache);
 	}
 
 	/**
@@ -94,21 +201,12 @@ public class FacilitySelector {
 	 */
 	public static void initCacheFacilityTree() {
 		m_log.info("initializing a facility's tree to cache.");
-		synchronized(nodeIpFacilityIdMapLock) {
-			nodeIpFacilityIdMap.clear();
-		}
-		synchronized (nodenameFacilityIdMapLock) {
-			nodenameFacilityIdMap = null;
-		}
-		synchronized (inetAddressFacilityIdMapLock) {
-			inetAddressFacilityIdMap = null;
-		}
-		synchronized (hostnameFacilityIdMapLock) {
-			hostnameFacilityIdMap = null;
-		}
-		synchronized (containsFacilityIdMapLock) {
-			containsFacilityIdMap = null;
-		}
+		
+		refreshHostnameIpaddrFacilityIdCache();
+		refreshNodenameFacilityIdCache();
+		refreshIpaddrFacilityIdCache();
+		refreshHostnameFacilityIdCache();
+		refreshScopeNodeFacilityIdCache();
 	}
 
 	/**
@@ -167,7 +265,6 @@ public class FacilitySelector {
 		String osRelease = null;
 		String administrator = null;
 		String contact = null;
-		String ownerRoleId = null;
 
 		boolean facilityIdFlg = false;
 		boolean facilityNameFlg = false;
@@ -191,8 +288,6 @@ public class FacilitySelector {
 
 		description = property.getDescription();
 
-		ownerRoleId = property.getOwnerRoleId();
-
 		ipAddressV4 = property.getIpAddressV4();
 
 		ipAddressV6 = property.getIpAddressV6();
@@ -365,7 +460,7 @@ public class FacilitySelector {
 		/** ローカル変数 */
 		ArrayList<String> facilityIdList = null;
 		ArrayList<FacilityInfo> facilityList = null;
-		
+
 		/** メイン処理 */
 		facilityList = getFacilityList(parentFacilityId, ownerRoleId, level, false);
 
@@ -457,6 +552,16 @@ public class FacilitySelector {
 		return ret;
 	}
 
+	private static void refreshHostnameIpaddrFacilityIdCache() {
+		try {
+			_hostnameIpaddrFacilityIdCacheLock.writeLock();
+			
+			storeHostnameIpaddrFacilityIdCache(new HashMap<String, ArrayList<String>>());
+		} finally {
+			_hostnameIpaddrFacilityIdCacheLock.writeUnlock();
+		}
+	}
+	
 	/**
 	 * ホスト名とIPv4アドレスを指定して、該当するノードのファシリティIDの一覧を取得する。<BR>
 	 * 
@@ -471,11 +576,20 @@ public class FacilitySelector {
 
 		/** ローカル変数 */
 		String key = hostname + "-," + ipAddress;
-		ArrayList<String> facilityIds = nodeIpFacilityIdMap.get(key);
-		if (facilityIds != null) {
-			return facilityIds;
+		
+		try {
+			_hostnameIpaddrFacilityIdCacheLock.readLock();
+			
+			HashMap<String, ArrayList<String>> cache = getHostnameIpaddrFacilityIdCache();
+			ArrayList<String> facilityIds = cache.get(key);
+			if (facilityIds != null) {
+				return facilityIds;
+			}
+		} finally {
+			_hostnameIpaddrFacilityIdCacheLock.readUnlock();
 		}
-		facilityIds = new ArrayList<String>();
+		
+		ArrayList<String> facilityIds = new ArrayList<String>();
 		Collection<FacilityEntity> facilities = null;
 
 		if (ipAddress == null || "".equals(ipAddress) ||
@@ -483,7 +597,9 @@ public class FacilitySelector {
 			return facilityIds;
 		}
 		/** メイン処理 */
-		synchronized(nodeIpFacilityIdMapLock) {
+		try {
+			_hostnameIpaddrFacilityIdCacheLock.writeLock();
+			
 			// hostname変数のNodeプロパティのnodename(必須項目)をLowerCaseで検索
 			facilities = QueryUtil.getNodeByNodename(hostname);
 			if (facilities != null){
@@ -519,7 +635,12 @@ public class FacilitySelector {
 							+ ", ipAddress = " + ipAddress + " has " + facilityId);
 				}
 			}
-			nodeIpFacilityIdMap.put(key, facilityIds);
+			
+			HashMap<String, ArrayList<String>> cache = getHostnameIpaddrFacilityIdCache();
+			cache.put(key, facilityIds);
+			storeHostnameIpaddrFacilityIdCache(cache);
+		} finally {
+			_hostnameIpaddrFacilityIdCacheLock.writeUnlock();
 		}
 		return facilityIds;
 	}
@@ -711,52 +832,37 @@ public class FacilitySelector {
 							valueTarget = node.getIpmiLevel();
 						}
 
+						// SSH関連
+						else if(attribute.compareTo(NodeConstant.SSH_USER) == 0) {
+							valueTarget = node.getSshUser();
+						} else if (attribute.compareTo(NodeConstant.SSH_USER_PASSWORD) == 0) {
+							valueTarget = node.getSshUserPassword();
+						} else if (attribute.compareTo(NodeConstant.SSH_PRIVATE_KEY_FILEPATH) == 0) {
+							valueTarget = node.getSshPrivateKeyFilepath();
+						} else if (attribute.compareTo(NodeConstant.SSH_PRIVATE_KEY_PASSPHRASE) == 0) {
+							valueTarget = node.getSshPrivateKeyPassphrase();
+						} else if (attribute.compareTo(NodeConstant.SSH_PORT) == 0) {
+							valueTarget = node.getSshPort().toString();
+						} else if (attribute.compareTo(NodeConstant.SSH_TIMEOUT) == 0) {
+							valueTarget = node.getSshTimeout().toString();
+						}
+						
 						// デバイス関連
 						// 単一項目ではないため対象外とする
 
-						// サーバ仮想化
-						else if(attribute.compareTo(NodeConstant.VMNODETYPE) == 0){
-							valueTarget = node.getVmNodeType();
-						} else if(attribute.compareTo(NodeConstant.VMMANAGEMENTNODE) == 0){
-							valueTarget = node.getVmManagementNode();
-						} else if(attribute.compareTo(NodeConstant.VMNAME) == 0){
-							valueTarget = node.getVmName();
-						} else if(attribute.compareTo(NodeConstant.VMID) == 0){
-							valueTarget = node.getVmId();
-						} else if(attribute.compareTo(NodeConstant.VMUSER) == 0){
-							valueTarget = node.getVmUser();
-						} else if(attribute.compareTo(NodeConstant.VMUSERPASSWORD) == 0){
-							valueTarget = node.getVmUserPassword();
-						} else if(attribute.compareTo(NodeConstant.VMPROTOCOL) == 0){
-							valueTarget = node.getVmProtocol();
-						}
-
-						// ネットワーク仮想化
-						else if(attribute.compareTo(NodeConstant.VNETSWITCHTYPE) == 0){
-							valueTarget = node.getVnetSwitchType();
-						} else if(attribute.compareTo(NodeConstant.VNETHOSTNODE) == 0){
-							valueTarget = node.getVnetHostNode();
-						} else if(attribute.compareTo(NodeConstant.OPEN_FLOW_DATAPATH_ID) == 0){
-							valueTarget = node.getOpenflowDataPathId().toString();
-						} else if(attribute.compareTo(NodeConstant.OPEN_FLOW_CTRL_IP_ADDRESS) == 0){
-							valueTarget = node.getOpenflowCtrlIpAddress();
-						}
-
 						// クラウド管理
-						else if(attribute.compareTo(NodeConstant.CLOUDNODETYPE) == 0){
-							valueTarget = node.getCloudNodeType();
-						} else if(attribute.compareTo(NodeConstant.CLOUDSERVICE) == 0){
+						else if(attribute.compareTo(NodeConstant.CLOUDSERVICE) == 0){
 							valueTarget = node.getCloudService();
-						} else if(attribute.compareTo(NodeConstant.CLOUDACCOUNTRESOURCE) == 0){
-							valueTarget = node.getCloudAccountResouce();
+						} else if(attribute.compareTo(NodeConstant.CLOUDSCOPE) == 0){
+							valueTarget = node.getCloudScope();
 						} else if(attribute.compareTo(NodeConstant.CLOUDRESOURCETYPE) == 0){
 							valueTarget = node.getCloudResourceType();
+						} else if(attribute.compareTo(NodeConstant.CLOUDRESOURCENAME) == 0){
+							valueTarget = node.getCloudResourceName();
 						} else if(attribute.compareTo(NodeConstant.CLOUDRESOURCEID) == 0){
 							valueTarget = node.getCloudResourceId();
-						} else if(attribute.compareTo(NodeConstant.CLOUDREGION) == 0){
-							valueTarget = node.getCloudRegion();
-						} else if(attribute.compareTo(NodeConstant.CLOUDZONE) == 0){
-							valueTarget = node.getCloudZone();
+						} else if(attribute.compareTo(NodeConstant.CLOUDLOCATION) == 0){
+							valueTarget = node.getCloudLocation();
 						}
 
 						// 管理関連
@@ -825,7 +931,7 @@ public class FacilitySelector {
 				// スコープが選択された場合
 				scope = FacilityTreeCache.getFacilityInfo(parentFacilityId);
 				if(scope.getFacilityType() == FacilityConstant.TYPE_SCOPE) {
-					List<FacilityInfo> childFacilityInfos = FacilityTreeCache.getChildrenFacilityInfo(scope.getFacilityId());
+					List<FacilityInfo> childFacilityInfos = FacilityTreeCache.getChildFacilityInfoList(scope.getFacilityId());
 					if (childFacilityInfos != null) {
 						facilityList.addAll(childFacilityInfos);
 					}
@@ -1051,13 +1157,13 @@ public class FacilitySelector {
 			List<FacilityInfo> nodeInfoList = null;
 			if (ownerRoleId != null && !ownerRoleId.isEmpty()) {
 				// オーナーロールでオブジェクト権限チェック
-				nodeInfoList = FacilityTreeCache.getNodeListByRoleId(ownerRoleId);
+				nodeInfoList = FacilityTreeCache.getNodeFacilityInfoListByRoleId(ownerRoleId);
 			} else {
 				// ログインユーザでオブジェクト権限チェック
 				String userId = (String)HinemosSessionContext.instance().getProperty(HinemosSessionContext.LOGIN_USER_ID);
-				nodeInfoList = FacilityTreeCache.getNodeListByUserId(userId);
+				nodeInfoList = FacilityTreeCache.getNodeFacilityInfoListByUserId(userId);
 			}
-			
+
 			for (FacilityInfo nodeInfo : nodeInfoList) {
 				new FacilityTreeItem(scopeTree, nodeInfo);
 			}
@@ -1095,7 +1201,7 @@ public class FacilitySelector {
 			// オーナーロール
 			rootTree = FacilityTreeCache.getFacilityTreeByRoleId(ownerRoleId);
 		}
-		
+
 		try {
 			FacilityTreeItem[] facilityTreeItemChildren = rootTree.getChildrenArray();
 			if (facilityTreeItemChildren != null) {
@@ -1132,7 +1238,7 @@ public class FacilitySelector {
 				return;
 			}
 			// 有効/無効の確認（nullならば必ず格納）
-			if (validFlg != null 
+			if (validFlg != null
 					&& tree.getData().isValid() != validFlg) {
 				return;
 			}
@@ -1170,18 +1276,6 @@ public class FacilitySelector {
 
 		return scopeList;
 	}
-	
-	private static ArrayList<FacilityInfo> removeDuplicate(ArrayList<FacilityInfo> list) {
-		ArrayList<FacilityInfo> ret = new ArrayList<FacilityInfo>();
-		ArrayList<String> idList = new ArrayList<String>();
-		for (FacilityInfo info : list) {
-			if (!idList.contains(info.getFacilityId())) {
-				idList.add(info.getFacilityId());
-				ret.add(info);
-			}
-		}
-		return ret;
-	}
 
 	/**
 	 * スコープ配下にあるファシリティの一覧を取得する。<BR>
@@ -1198,7 +1292,7 @@ public class FacilitySelector {
 			String ownerRoleId, int level, boolean scopeFlag) {
 
 		/** ローカル変数 */
-		ArrayList<FacilityInfo> facilityList = new ArrayList<FacilityInfo>();
+		HashMap<String, FacilityInfo> facilityMap = new HashMap<String, FacilityInfo>();
 
 		/** メイン処理 */
 		m_log.debug("getting facilities under a scope. (scopeFacilityId = " + parentFacilityId + ")");
@@ -1210,9 +1304,9 @@ public class FacilitySelector {
 				if (treeItem != null
 						&& treeItem.getChildrenArray()[0] != null
 						&& treeItem.getChildrenArray()[0].getChildrenArray() != null) {
-					facilityList.add(treeItem.getData());
+					facilityMap.put(treeItem.getData().getFacilityId(), treeItem.getData());
 					for (FacilityTreeItem tree : treeItem.getChildrenArray()[0].getChildrenArray()) {
-						facilityList.add(tree.getData());
+						facilityMap.put(tree.getData().getFacilityId(), tree.getData());
 					}
 				}
 			} else {
@@ -1229,10 +1323,10 @@ public class FacilitySelector {
 				if (treeItem != null
 						&& treeItem.getChildrenArray()[0] != null
 						&& treeItem.getChildrenArray()[0].getChildrenArray() != null) {
-					facilityList.add(treeItem.getData());
+					facilityMap.put(treeItem.getData().getFacilityId(), treeItem.getData());
 					for (FacilityTreeItem tree : treeItem.getChildrenArray()[0].getChildrenArray()) {
-						facilityList.add(tree.getData());
-						getFacilityListRecursive(tree, level > 1 ? level - 1 : level, facilityList, scopeFlag);
+						facilityMap.put(tree.getData().getFacilityId(), tree.getData());
+						getFacilityListRecursive(tree, level > 1 ? level - 1 : level, facilityMap, scopeFlag);
 					}
 				}
 			}
@@ -1251,16 +1345,16 @@ public class FacilitySelector {
 				m_log.info("getFacilityList() : Entity is not found. : facilityId = " + parentFacilityId);
 			} else {
 				if (parentFacilityTreeItem.getData().getFacilityType() == FacilityConstant.TYPE_NODE) {
-					facilityList.add(parentFacilityTreeItem.getData());
-					return removeDuplicate(facilityList);
+					facilityMap.put(parentFacilityTreeItem.getData().getFacilityId(), parentFacilityTreeItem.getData());
+					return new ArrayList<FacilityInfo>(facilityMap.values());
 				} else if (scopeFlag) {
-					facilityList.add(parentFacilityTreeItem.getData());
+					facilityMap.put(parentFacilityTreeItem.getData().getFacilityId(), parentFacilityTreeItem.getData());
 				}
-				getFacilityListRecursive(parentFacilityTreeItem, level, facilityList, scopeFlag);
+				getFacilityListRecursive(parentFacilityTreeItem, level, facilityMap, scopeFlag);
 			}
 		}
 		m_log.debug("successful in getting facilities under a scope. (scopeFacilityId = " + parentFacilityId + ")");
-		return removeDuplicate(facilityList);
+		return new ArrayList<FacilityInfo>(facilityMap.values());
 	}
 
 	/**
@@ -1292,11 +1386,11 @@ public class FacilitySelector {
 	 * 
 	 * @param parentFacilityTreeItem スコープのファシリティインスタンス
 	 * @param level 取得する階層数
-	 * @param facilityList 格納先となるファシリティの配列
+	 * @param facilityMap 格納先となるファシリティの配列
 	 * @param scopeFlag スコープ自身を含めるか（含める:true 含めない:false)
 	 */
-	private static void getFacilityListRecursive(FacilityTreeItem parentFacilityTreeItem, 
-			int level, ArrayList<FacilityInfo> facilityList, boolean scopeFlag) {
+	private static void getFacilityListRecursive(FacilityTreeItem parentFacilityTreeItem,
+			int level, HashMap<String, FacilityInfo> facilityMap, boolean scopeFlag) {
 		/** ローカル変数 */
 		boolean recursive = false;
 		int nextLevel = 0;
@@ -1317,15 +1411,15 @@ public class FacilitySelector {
 			for (FacilityTreeItem childFacilityTreeItem : childFacilityTreeItems) {
 				if (childFacilityTreeItem.getData().getFacilityType() == FacilityConstant.TYPE_SCOPE) {
 					if (scopeFlag) {
-						facilityList.add(childFacilityTreeItem.getData());
+						facilityMap.put(childFacilityTreeItem.getData().getFacilityId(), childFacilityTreeItem.getData());
 						m_log.debug("add scope = " + childFacilityTreeItem.getData().getFacilityId());
 					}
 				} else {
-					facilityList.add(childFacilityTreeItem.getData());
+					facilityMap.put(childFacilityTreeItem.getData().getFacilityId(), childFacilityTreeItem.getData());
 					m_log.debug("add node = " + childFacilityTreeItem.getData().getFacilityId());
 				}
 				if (recursive) {
-					getFacilityListRecursive(childFacilityTreeItem, nextLevel, facilityList, scopeFlag);
+					getFacilityListRecursive(childFacilityTreeItem, nextLevel, facilityMap, scopeFlag);
 				}
 			}
 		}
@@ -1343,13 +1437,14 @@ public class FacilitySelector {
 			return false;
 		}
 
-		if (facility.getFacilityId().compareTo(FacilityTreeAttributeConstant.INTERNAL_SCOPE) == 0) {
-			return true;
-		} else if (facility.getFacilityId().compareTo(FacilityTreeAttributeConstant.REGISTEREFD_SCOPE) == 0) {
-			return true;
-		} else if (facility.getFacilityId().compareTo(FacilityTreeAttributeConstant.UNREGISTEREFD_SCOPE) == 0) {
-			return true;
-		} else if (facility.getFacilityId().compareTo(FacilityTreeAttributeConstant.OWNER_SCOPE) == 0) {
+		Set<String> buildInScopeFacilityIdSet = new HashSet<String>();
+		buildInScopeFacilityIdSet.add(FacilityTreeAttributeConstant.INTERNAL_SCOPE);
+		buildInScopeFacilityIdSet.add(FacilityTreeAttributeConstant.REGISTEREFD_SCOPE);
+		buildInScopeFacilityIdSet.add(FacilityTreeAttributeConstant.UNREGISTEREFD_SCOPE);
+		buildInScopeFacilityIdSet.add(FacilityTreeAttributeConstant.OWNER_SCOPE);
+		buildInScopeFacilityIdSet.add(FacilityTreeAttributeConstant.OS_PARENT_SCOPE);
+		buildInScopeFacilityIdSet.addAll(OsScopeInitializerPlugin.getOsScopeIdSet());
+		if (buildInScopeFacilityIdSet.contains(facility.getFacilityId())) {
 			return true;
 		} else {
 			// ロールスコープは組み込みスコープとする
@@ -1391,46 +1486,55 @@ public class FacilitySelector {
 	 * @return ファシリティIDのセット。存在しない場合は"UNREGISTEREFD"だけを含めたセット。
 	 */
 	public static Set<String> getNodeListByNodename(String nodename){
-		synchronized (nodenameFacilityIdMapLock) {
-			// キャッシュに乗っていない場合は全ファシリティをチェックする。結果はキャッシュに乗せる。
-			if(nodenameFacilityIdMap == null){
-				long start = System.currentTimeMillis();
-				try {
-					List<FacilityEntity> allNodes = QueryUtil.getAllNode();
-					nodenameFacilityIdMap = new HashMap<String, HashSet<String>>();
-
-					for(FacilityEntity facility : allNodes){
-						NodeEntity node = facility.getNodeEntity();
-						String facilityId = facility.getFacilityId();
-
-						// ノード名からファシリティIDのセットを引けるようにする
-						// ノード名は小文字に変換して処理する
-						String checkNodename = node.getNodeName().toLowerCase();
-						HashSet<String> nodenameFacilityIdSet = nodenameFacilityIdMap.get(checkNodename);
-						if(nodenameFacilityIdSet == null){
-							nodenameFacilityIdSet = new HashSet<String>();
-							nodenameFacilityIdMap.put(checkNodename, nodenameFacilityIdSet);
-						}
-
-						// 管理対象フラグ「有効」のノードのみセットに追加する。管理対象フラグ「無効」のノードはセットに追加しない。
-						// よって、最終的にノード名でnodenameFacilityIdSetから取得したファシリティのセットは存在するが、
-						// その中にエンティティが含まれない場合は、該当ノード名のノードは存在するが、全て無効だったことなる。
-						if(facility.getValid() == ValidConstant.TYPE_VALID){
-							nodenameFacilityIdSet.add(facilityId);
-						}
-					}
-				} catch (Exception e) {
-					m_log.warn("initCacheFacilityTree() : "
-							+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
-				}
-				m_log.info("refresh nodenameFacilityIdMap(Cache). " +
-						(System.currentTimeMillis() - start) + "ms.");
-			}
-
-			return nodenameFacilityIdMap.get(nodename.toLowerCase());
-		}
+		// 並列してキャッシュ更新処理が実行されている場合、更新処理完了を待機しない（更新前・後のどちらが取得されるか保証されない）
+		// (部分書き換えでなく全置換えのキャッシュ更新特性、ロックに伴う処理コストの観点から参照ロックは意図的に取得しない)
+		HashMap<String, HashSet<String>> cache = getNodenameFacilityIdCache();
+		return cache.get(nodename.toLowerCase());
 	}
 
+	/**
+	 * getNodeListByNodenameで利用するキャッシュを現在のDBに基づき再構成する。<br/>
+	 */
+	private static void refreshNodenameFacilityIdCache() {
+		long start = System.currentTimeMillis();
+		
+		try {
+			_nodenameFacilityIdCacheLock.writeLock();
+			
+			List<FacilityEntity> allNodes = QueryUtil.getAllNode();
+			
+			HashMap<String, HashSet<String>> nodenameFacilityIdMap = new HashMap<String, HashSet<String>>();
+
+			for(FacilityEntity facility : allNodes){
+				NodeEntity node = facility.getNodeEntity();
+				String facilityId = facility.getFacilityId();
+
+				// ノード名からファシリティIDのセットを引けるようにする
+				// ノード名は小文字に変換して処理する
+				String checkNodename = node.getNodeName().toLowerCase();
+				HashSet<String> nodenameFacilityIdSet = nodenameFacilityIdMap.get(checkNodename);
+				if(nodenameFacilityIdSet == null){
+					nodenameFacilityIdSet = new HashSet<String>();
+					nodenameFacilityIdMap.put(checkNodename, nodenameFacilityIdSet);
+				}
+
+				// 管理対象フラグ「有効」のノードのみセットに追加する。管理対象フラグ「無効」のノードはセットに追加しない。
+				// よって、最終的にノード名でnodenameFacilityIdSetから取得したファシリティのセットは存在するが、
+				// その中にエンティティが含まれない場合は、該当ノード名のノードは存在するが、全て無効だったことなる。
+				if(facility.getValid() == ValidConstant.TYPE_VALID){
+					nodenameFacilityIdSet.add(facilityId);
+				}
+			}
+			
+			storeNodenameFacilityIdCache(nodenameFacilityIdMap);
+		} finally {
+			_nodenameFacilityIdCacheLock.writeUnlock();
+			
+			m_log.info("refresh nodenameFacilityIdMap(Cache). " +
+					(System.currentTimeMillis() - start) + "ms.");
+		}
+	}
+	
 	/**
 	 * 指定のIPアドレスで登録されているノードのファシリティIDのセットを返す。
 	 * 管理対象フラグ「無効」となっているノードのファシリティIDは含まない。
@@ -1441,57 +1545,67 @@ public class FacilitySelector {
 	 * @return ファシリティIDのセット。存在しない場合はnullを返す。
 	 * 	 */
 	public static Set<String> getNodeListByIpAddress(InetAddress ipAddress){
-
-		synchronized (inetAddressFacilityIdMapLock) {
-			// キャッシュに乗っていない場合は全ファシリティをチェックする。結果はキャッシュに乗せる。
-			if(inetAddressFacilityIdMap == null){
-				long start = System.currentTimeMillis();
-				try {
-					List<FacilityEntity> allNodes = QueryUtil.getAllNode();
-
-					inetAddressFacilityIdMap = new HashMap<InetAddress, HashSet<String>>();
-
-					for(FacilityEntity facility : allNodes){
-						NodeEntity node = facility.getNodeEntity();
-						String facilityId = node.getFacilityId();
-
-						// 「IPアドレスのバージョン」により指定されたIPアドレスを設定する。
-						Integer ipVersion = node.getIpAddressVersion();
-						String ipAddressString = null;
-						if(ipVersion != null && ipVersion.intValue() == 6){
-							ipAddressString = node.getIpAddressV6();
-						} else {
-							ipAddressString = node.getIpAddressV4();
-						}
-						InetAddress checkIpAddress = InetAddress.getByName(ipAddressString);
-
-						// 監視対象のノードは、IPアドレスからファシリティIDのセットを引けるようにする
-						HashSet<String> inetAddressFacilityIdSet = inetAddressFacilityIdMap.get(checkIpAddress);
-						if(inetAddressFacilityIdSet == null){
-							inetAddressFacilityIdSet = new HashSet<String>();
-							inetAddressFacilityIdMap.put(checkIpAddress, inetAddressFacilityIdSet);
-						}
-
-						// 管理対象フラグ「有効」のノードのみセットに追加する。管理対象フラグ「無効」のノードはセットに追加しない。
-						// よって、最終的にIPアドレスでinetAddressFacilityIdMapから取得したファシリティのセットは存在するが、
-						// その中にエンティティが含まれない場合は、該当IPアドレスのノードは存在するが、全て無効だったことなる。
-						FacilityEntity entity = node.getFacilityEntity();
-						if(entity.getValid() == ValidConstant.TYPE_VALID){
-							inetAddressFacilityIdSet.add(facilityId);
-						}
-					}
-				} catch (Exception e) {
-					m_log.warn("getNodeListByIpAddress() : "
-							+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
-				}
-				m_log.info("refresh inetAddressFacilityIdMap(Cache). " +
-						(System.currentTimeMillis() - start) + "ms.");
-			}
-
-			return inetAddressFacilityIdMap.get(ipAddress);
-		}
+		// 並列してキャッシュ更新処理が実行されている場合、更新処理完了を待機しない（更新前・後のどちらが取得されるか保証されない）
+		// (部分書き換えでなく全置換えのキャッシュ更新特性、ロックに伴う処理コストの観点から参照ロックは意図的に取得しない)
+		HashMap<InetAddress, HashSet<String>> cache = getIpaddrFacilityIdCache();
+		return cache.get(ipAddress);
 	}
 
+	/**
+	 * getNodeListByIpAddressのためのキャッシュを現在のDBから再構成する。<br/>
+	 */
+	private static void refreshIpaddrFacilityIdCache() {
+		long start = System.currentTimeMillis();
+		
+		try {
+			_ipaddrFacilityIdCacheLock.writeLock();
+			
+			List<FacilityEntity> allNodes = QueryUtil.getAllNode();
+
+			HashMap<InetAddress, HashSet<String>> inetAddressFacilityIdMap = new HashMap<InetAddress, HashSet<String>>();
+
+			for(FacilityEntity facility : allNodes){
+				NodeEntity node = facility.getNodeEntity();
+				String facilityId = node.getFacilityId();
+
+				// 「IPアドレスのバージョン」により指定されたIPアドレスを設定する。
+				Integer ipVersion = node.getIpAddressVersion();
+				String ipAddressString = null;
+				if(ipVersion != null && ipVersion.intValue() == 6){
+					ipAddressString = node.getIpAddressV6();
+				} else {
+					ipAddressString = node.getIpAddressV4();
+				}
+				InetAddress checkIpAddress = InetAddress.getByName(ipAddressString);
+
+				// 監視対象のノードは、IPアドレスからファシリティIDのセットを引けるようにする
+				HashSet<String> inetAddressFacilityIdSet = inetAddressFacilityIdMap.get(checkIpAddress);
+				if(inetAddressFacilityIdSet == null){
+					inetAddressFacilityIdSet = new HashSet<String>();
+					inetAddressFacilityIdMap.put(checkIpAddress, inetAddressFacilityIdSet);
+				}
+
+				// 管理対象フラグ「有効」のノードのみセットに追加する。管理対象フラグ「無効」のノードはセットに追加しない。
+				// よって、最終的にIPアドレスでinetAddressFacilityIdMapから取得したファシリティのセットは存在するが、
+				// その中にエンティティが含まれない場合は、該当IPアドレスのノードは存在するが、全て無効だったことなる。
+				FacilityEntity entity = node.getFacilityEntity();
+				if(entity.getValid() == ValidConstant.TYPE_VALID){
+					inetAddressFacilityIdSet.add(facilityId);
+				}
+			}
+			
+			storeIpaddrFacilityIdCache(inetAddressFacilityIdMap);
+		} catch (Exception e) {
+			m_log.warn("refreshIpaddrFacilityIdCache() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
+		} finally {
+			_ipaddrFacilityIdCacheLock.writeUnlock();
+			
+			m_log.info("refresh inetAddressFacilityIdMap(Cache). " +
+					(System.currentTimeMillis() - start) + "ms.");
+		}
+	}
+	
 	/**
 	 * 指定のホスト名（複数登録可能）で登録されているノードのファシリティIDを返す。
 	 * 管理対象フラグ「無効」となっているものは含まない。
@@ -1502,51 +1616,69 @@ public class FacilitySelector {
 	 * @return ファシリティIDのセット。存在しない場合は"UNREGISTEREFD"だけを含めたセット。
 	 */
 	public static Set<String> getNodeListByHostname(String hostname){
-		synchronized (hostnameFacilityIdMapLock) {
-			// キャッシュに乗っていない場合は全ファシリティをチェックする。結果はキャッシュに乗せる。
-			if(hostnameFacilityIdMap == null){
-				long start = System.currentTimeMillis();
-				try {
-					List<NodeHostnameEntity> allNodes = QueryUtil.getAllNodeHostname();
+		// 並列してキャッシュ更新処理が実行されている場合、更新処理完了を待機しない（更新前・後のどちらが取得されるか保証されない）
+		// (部分書き換えでなく全置換えのキャッシュ更新特性、ロックに伴う処理コストの観点から参照ロックは意図的に取得しない)
+		HashMap<String, HashSet<String>> cache = getHostnameFacilityIdCache();
+		return cache.get(hostname);
+	}
+	
+	/**
+	 * getNodeListByHostnameのためのキャッシュを現在のDBから再構成する。<br/>
+	 */
+	private static void refreshHostnameFacilityIdCache() {
+		long start = System.currentTimeMillis();
+		
+		try {
+			_hostnameFacilityIdCacheLock.writeLock();
+			
+			List<NodeHostnameEntity> allNodes = QueryUtil.getAllNodeHostname();
 
-					hostnameFacilityIdMap = new HashMap<String, HashSet<String>>();
+			HashMap<String, HashSet<String>> hostnameFacilityIdMap = new HashMap<String, HashSet<String>>();
 
-					for(NodeHostnameEntity node : allNodes){
-						String facilityId = node.getId().getFacilityId();
+			for(NodeHostnameEntity node : allNodes){
+				String facilityId = node.getId().getFacilityId();
 
-						// ホスト名は大文字小文字を区別する
-						String checkHostname = node.getId().getHostname();
-						HashSet<String> hostnameFacilityIdSet = hostnameFacilityIdMap.get(checkHostname);
-						if(hostnameFacilityIdSet == null){
-							hostnameFacilityIdSet = new HashSet<String>();
-							hostnameFacilityIdMap.put(checkHostname, hostnameFacilityIdSet);
-						}
-
-						// 管理対象フラグ「有効」のノードのみセットに追加する。管理対象フラグ「無効」のノードはセットに追加しない。
-						// よって、最終的にホスト名でhostnameFacilityIdSetから取得したファシリティのセットは存在するが、
-						// その中にエンティティが含まれない場合は、該当ホスト名のノードは存在するが、全て無効だったことなる。
-						FacilityEntity entity = null;
-						try {
-							entity = QueryUtil.getFacilityPK(facilityId);
-						} catch (FacilityNotFound e) {
-						} catch (InvalidRole e) {
-						}
-						if(entity != null && entity.getValid() == ValidConstant.TYPE_VALID){
-							hostnameFacilityIdSet.add(facilityId);
-						}
-					}
-				} catch (Exception e) {
-					m_log.warn("getNodeListByHostname() : "
-							+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
+				// ホスト名は大文字小文字を区別する
+				String checkHostname = node.getId().getHostname();
+				HashSet<String> hostnameFacilityIdSet = hostnameFacilityIdMap.get(checkHostname);
+				if(hostnameFacilityIdSet == null){
+					hostnameFacilityIdSet = new HashSet<String>();
+					hostnameFacilityIdMap.put(checkHostname, hostnameFacilityIdSet);
 				}
-				m_log.info("refresh hostnameFacilityIdMap(Cache). " +
-						(System.currentTimeMillis() - start) + "ms.");
-			}
 
-			return hostnameFacilityIdMap.get(hostname);
+				// 管理対象フラグ「有効」のノードのみセットに追加する。管理対象フラグ「無効」のノードはセットに追加しない。
+				// よって、最終的にホスト名でhostnameFacilityIdSetから取得したファシリティのセットは存在するが、
+				// その中にエンティティが含まれない場合は、該当ホスト名のノードは存在するが、全て無効だったことなる。
+				FacilityEntity entity = null;
+				try {
+					entity = QueryUtil.getFacilityPK(facilityId);
+				} catch (FacilityNotFound e) {
+				} catch (InvalidRole e) {
+				}
+				if(entity != null && entity.getValid() == ValidConstant.TYPE_VALID){
+					hostnameFacilityIdSet.add(facilityId);
+				}
+			}
+			
+			storeHostnameFacilityIdCache(hostnameFacilityIdMap);
+		} finally {
+			_hostnameFacilityIdCacheLock.writeUnlock();
+			
+			m_log.info("refresh hostnameFacilityIdMap(Cache). " +
+					(System.currentTimeMillis() - start) + "ms.");
 		}
 	}
 
+	private static void refreshScopeNodeFacilityIdCache() {
+		try {
+			_scopeNodeFacilityIdCacheLock.writeLock();
+			
+			storeScopeNodeFacilityIdCache(new HashMap<String, Boolean>());
+		} finally {
+			_scopeNodeFacilityIdCacheLock.writeUnlock();
+		}
+	}
+	
 	/**
 	 * 指定のノードが、指定スコープ配下の有効なノードに含まれるかチェックする
 	 * @param scopeFacilityId 確認対象のスコープ（このスコープ配下をチェックする）
@@ -1557,17 +1689,32 @@ public class FacilitySelector {
 	public static boolean containsFaciliyId(String scopeFacilityId, String nodeFacilityId, String ownerRoleId){
 		Boolean ret = null;
 		String key = scopeFacilityId + "," + nodeFacilityId;
-		synchronized (containsFacilityIdMapLock) {
-			if (containsFacilityIdMap == null) {
-				containsFacilityIdMap = new ConcurrentHashMap<String, Boolean>();
-			}
-			ret = containsFacilityIdMap.get(key);
-			if (ret == null) {
-				ret = getNodeFacilityIdList(scopeFacilityId, ownerRoleId, RepositoryControllerBean.ALL, false, true).contains(nodeFacilityId);
-				m_log.debug("containsFacilityId key=" + key + ", ret=" + ret);
-				containsFacilityIdMap.put(key, ret);
+		
+		try {
+			_scopeNodeFacilityIdCacheLock.readLock();
+			
+			HashMap<String, Boolean> cache = getScopeNodeFacilityIdCache();
+			ret = cache.get(key);
+			if (ret != null) {
+				return ret;
 			}
+		} finally {
+			_scopeNodeFacilityIdCacheLock.readUnlock();
+		}
+		
+		try {
+			_scopeNodeFacilityIdCacheLock.writeLock();
+			
+			HashMap<String, Boolean> cache = getScopeNodeFacilityIdCache();
+			ret = getNodeFacilityIdList(scopeFacilityId, ownerRoleId, RepositoryControllerBean.ALL, false, true).contains(nodeFacilityId);
+			m_log.debug("containsFacilityId key=" + key + ", ret=" + ret);
+			cache.put(key, ret);
+			
+			storeScopeNodeFacilityIdCache(cache);
+			
+			return ret;
+		} finally {
+			_scopeNodeFacilityIdCacheLock.writeUnlock();
 		}
-		return ret;
 	}
 }
