@@ -28,15 +28,16 @@ import java.util.HashMap;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
-import javax.naming.NamingException;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.bean.SnmpVersionConstant;
-import com.clustercontrol.commons.util.HinemosProperties;
+import com.clustercontrol.fault.FacilityNotFound;
+import com.clustercontrol.fault.HinemosUnknown;
+import com.clustercontrol.fault.SnmpResponseError;
+import com.clustercontrol.maintenance.util.HinemosPropertyUtil;
 import com.clustercontrol.poller.bean.PollerProtocolConstant;
-import com.clustercontrol.poller.impl.SnmpPollerImpl;
+import com.clustercontrol.poller.impl.Snmp4jPollerImpl;
 import com.clustercontrol.repository.bean.DeviceTypeConstant;
 import com.clustercontrol.repository.bean.NodeCpuInfo;
 import com.clustercontrol.repository.bean.NodeDeviceInfo;
@@ -44,14 +45,16 @@ import com.clustercontrol.repository.bean.NodeDiskInfo;
 import com.clustercontrol.repository.bean.NodeFilesystemInfo;
 import com.clustercontrol.repository.bean.NodeHostnameInfo;
 import com.clustercontrol.repository.bean.NodeInfo;
+import com.clustercontrol.repository.bean.NodeMemoryInfo;
 import com.clustercontrol.repository.bean.NodeNetworkInterfaceInfo;
-import com.clustercontrol.repository.util.SearchNodeProperties;
+import com.clustercontrol.repository.model.CollectorPlatformMstEntity;
+import com.clustercontrol.repository.util.QueryUtil;
+import com.clustercontrol.repository.util.SearchDeviceProperties;
 import com.clustercontrol.sharedtable.DataTable;
 import com.clustercontrol.sharedtable.TableEntry;
 
 /**
  * SNMPでノードのデータを作成するクラス<BR>
- * @author miyamoto
  * @version 4.0.0
  * @since 2.1.2
  */
@@ -60,81 +63,86 @@ public class SearchNodeBySNMP {
 
 	private static Log m_log = LogFactory.getLog(SearchNodeBySNMP.class);
 
-	private static final String OID_NAME      =".1.3.6.1.2.1.1.5.0";
-	private static final String OID_DESCR     =".1.3.6.1.2.1.1.1.0";
-	private static final String OID_CONTACT   =".1.3.6.1.2.1.1.4.0";
-
-	private static final String OID_CPU_INDEX=".1.3.6.1.2.1.25.3.3.1.2";
-
-	private static final String OID_DISK_INDEX=".1.3.6.1.4.1.2021.13.15.1.1.1";
-	private static final String OID_DISK_NAME =".1.3.6.1.4.1.2021.13.15.1.1.2";
-	private static final String OID_DISK_ION_READ = ".1.3.6.1.4.1.2021.13.15.1.1.3";
-	private static final String OID_DISK_ION_WRITE = ".1.3.6.1.4.1.2021.13.15.1.1.4";
-	private static final String OID_DISK_IO_READ = ".1.3.6.1.4.1.2021.13.15.1.1.5";
-	private static final String OID_DISK_IO_WRITE = ".1.3.6.1.4.1.2021.13.15.1.1.6";
-
-	private static final String OID_NIC_INDEX =".1.3.6.1.2.1.2.2.1.1";
-	private static final String OID_NIC_NAME  =".1.3.6.1.2.1.2.2.1.2";
-	private static final String OID_NIC_MAC_ADDRESS = ".1.3.6.1.2.1.2.2.1.6";
-	private static final String OID_NIC_IP_ADDRESSV4 = ".1.3.6.1.2.1.4.34.1.3.1.4";
-	private static final String OID_NIC_IP_ADDRESSV6 = ".1.3.6.1.2.1.4.34.1.3.2.16";
-	private static final String OID_NIC_IP_ADDRESSV4_TYPE = ".1.3.6.1.2.1.4.34.1.4.1.4";
-	private static final String OID_NIC_IP_ADDRESSV6_TYPE = ".1.3.6.1.2.1.4.34.1.4.2.16";
-	private static final String OID_NIC_IN_UCAST_PKTS = ".1.3.6.1.2.1.2.2.1.11";
-	private static final String OID_NIC_OUT_UCAST_PKTS = ".1.3.6.1.2.1.2.2.1.17";
-	private static final String OID_NIC_IN_ERROR = ".1.3.6.1.2.1.2.2.1.14";
-	private static final String OID_NIC_OUT_ERROR = ".1.3.6.1.2.1.2.2.1.20";
-	private static final String OID_NIC_IN_OCTET = ".1.3.6.1.2.1.2.2.1.10";
-	private static final String OID_NIC_OUT_OCTET = ".1.3.6.1.2.1.2.2.1.16";
-
-	private static final String OID_FILESYSTEM_INDEX = ".1.3.6.1.2.1.25.2.3.1.1";
-	private static final String OID_FILESYSTEM_TYPE = ".1.3.6.1.2.1.25.2.3.1.2";
-	private static final String OID_FILESYSTEM_NAME=   ".1.3.6.1.2.1.25.2.3.1.3";
-
+	// プラットフォーム一覧にSORARISがあるか確認する。
+	private static boolean solarisFlag = false;
 
+	static {
+		try {
+			CollectorPlatformMstEntity entity = QueryUtil.getCollectorPlatformMstPK("SOLARIS");
+			if (entity != null) {
+				solarisFlag = true; 
+			}
+		} catch (FacilityNotFound e) {
+			m_log.debug("not found + " + e.getMessage());
+		}
+		m_log.info("solarisFlag=" + solarisFlag);
+	}
+	
 	/**
 	 * ノードの情報を探す。
-	 * @param pollingData
-	 * @param mode
-	 * @param locale
+	 * @param ipAddress
+	 * @param port
+	 * @param community
+	 * @param version
+	 * @param facilityId
 	 * @return
+	 * @throws UnknownHostException
 	 */
-	public static NodeInfo searchNode(String ipAddress, int port, String community, String version) throws NamingException, UnknownHostException{
+	public static NodeInfo searchNode(String ipAddress, int port,
+			String community, String version, String facilityId,
+			String securityLevel, String user, String authPass,
+			String privPass, String authProtocol, String privProtocol)
+			throws UnknownHostException, SnmpResponseError, HinemosUnknown,
+			FacilityNotFound {
 		m_log.debug("searchNode() ipAddress = " + ipAddress + ", port = " + port + ", community = " + community + ", version = " + version);
 
 		// 初期化
-		SearchNodeProperties pollingProp = SearchNodeProperties.getProperties();
+		SearchDeviceProperties pollingProp = SearchDeviceProperties.getProperties();
 		int retries = pollingProp.getRetry();
 		int timeout = pollingProp.getTimeOut();
-		ArrayList<String> oidList = pollingProp.getOidList();
-
-		int versionInt = SnmpVersionConstant.stringToType(version);
-
-		//pollingします。
-		SnmpPollerImpl poller = new SnmpPollerImpl();
-		m_log.debug("searchNode() polling start");
-		DataTable tmpDataTable = poller.polling(ipAddress,
-				port,
-				versionInt,
-				community,
-				retries,
-				timeout,
-				oidList,
-				false,
-				true);
-		m_log.debug("searchNode() polling stop");
-
-		// 取得したデータを詰め替える
+		boolean pollingFault = true;
+		
 		DataTable ret = new DataTable();
-		ret.putAll(tmpDataTable);
+		for (int i = 0; i < pollingProp.getListSize(); i++) {
+			ArrayList<String> oidList = pollingProp.getOidList(i);
+			//pollingします。
+			m_log.debug("searchNode() polling start ipAddress = " + ipAddress);
+			DataTable tmpDataTable = Snmp4jPollerImpl.getInstance().polling(ipAddress,
+					port,
+					SnmpVersionConstant.stringToSnmpType(version),
+					community,
+					retries,
+					timeout,
+					oidList,
+					securityLevel,
+					user,
+					authPass,
+					privPass,
+					authProtocol,
+					privProtocol);
+			m_log.debug("searchNode() polling stop ipAddress = " + ipAddress);
+
+			// 応答がある場合取得したデータをつめる
+			if (tmpDataTable.keySet().size() > 0) {
+				ret.putAll(tmpDataTable);
+				pollingFault = false;
+			}
+		}
+		
+		// 応答がまったくない場合エラーを返す
+		if (pollingFault) {
+			m_log.info("searchNode: no response ipAddress = " + ipAddress);
+			throw new SnmpResponseError();
+		}
 
 		//ポーリングした結果をつめるメソッドを呼び出します
-		return stractProperty(ipAddress, port, community, version, ret);
+		return stractProperty(ipAddress, port, community, version, securityLevel, user, authPass,
+				privPass, authProtocol, privProtocol, ret);
 	}
 
 	/**
 	 * DataTableに格納するためのEntryKeyを返すメソッド
-	 * 
+	 *
 	 * @param oidString OID
 	 */
 	private static String getEntryKey(String oidString){
@@ -149,22 +157,25 @@ public class SearchNodeBySNMP {
 	 * @param mode
 	 * @param locale
 	 * @return
+	 * @throws UnknownHostException
 	 */
-	private static NodeInfo stractProperty(String ipAddress, int port, String community, String version,DataTable ret) throws NamingException, UnknownHostException {
+	private static NodeInfo stractProperty(String ipAddress, int port, String community, String version,
+			String securityLevel, String user, String authPass, String privPass, 
+			String authProtocol, String privProtocol, DataTable ret) throws UnknownHostException {
 
 		NodeInfo property = new NodeInfo();
 
 		/*
-		 * hinemos.propertiesにrepository.find.by.snmp.verbose=trueと書くと、
-		 * ディスクIOが0でも、そのディスクがfind対象になる。
-		 * デフォルトはfalseであり、0のものはfind対象から外れる。
+		 * hinemos.propertiesにrepository.device.search.verbose=trueと書くと、
+		 * ディスクIOが0でも、そのディスクがsearch対象になる。
+		 * デフォルトはfalseであり、0のものはsearch対象から外れる。
 		 * since 3.2.0
 		 */
-		String verbose = HinemosProperties.getProperty("repository.find.by.snmp.verbose", "false");
+		boolean verbose = HinemosPropertyUtil.getHinemosPropertyBool("repository.device.search.verbose", false);
 
 		//ノード情報"説明"の生成
-		if(ret.getValue(getEntryKey(OID_DESCR)) != null){
-			if(((String)ret.getValue(getEntryKey(OID_DESCR)).getValue()).length() !=0){
+		if(ret.getValue(getEntryKey(SearchDeviceProperties.getOidDescr())) != null){
+			if(((String)ret.getValue(getEntryKey(SearchDeviceProperties.getOidDescr())).getValue()).length() !=0){
 				property.setDescription("Auto detect at " + (new Date()).toString());
 			}
 		}
@@ -189,27 +200,35 @@ public class SearchNodeBySNMP {
 			//IPアドレスのバージョン
 			property.setIpAddressVersion(new Integer(ipAddressVersion));
 		} catch (UnknownHostException e) {
-			m_log.error(e.getMessage());
+			m_log.info("stractProperty() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage());
 			throw e;
 		}
 
 
 		//SNMP関連データの設定
 		property.setSnmpPort(port);
-
 		property.setSnmpCommunity(community);
-
 		property.setSnmpVersion(version);
-
+		property.setSnmpSecurityLevel(securityLevel);
+		property.setSnmpUser(user);
+		property.setSnmpAuthPassword(authPass);
+		property.setSnmpPrivPassword(privPass);
+		property.setSnmpAuthProtocol(authProtocol);
+		property.setSnmpPrivProtocol(privProtocol);
 
 		//hostname の設定
-		if(ret.getValue(getEntryKey(OID_NAME)) != null){
-			String hostname = (String)ret.getValue(getEntryKey(OID_NAME)).getValue();
+		if(ret.getValue(getEntryKey(SearchDeviceProperties.getOidName())) != null){
+			String hostname = (String)ret.getValue(getEntryKey(SearchDeviceProperties.getOidName())).getValue();
 			if(hostname.length() != 0){
 				//hosname.domainであればhostnameだけを入力
 				if(hostname.indexOf(".") != -1){
 					hostname = hostname.substring(0,hostname.indexOf("."));
 				}
+				//ファシリティID、ファシリティ名
+				property.setFacilityId(hostname);
+				property.setFacilityName(hostname);
+				
 				//ホスト名、ノード名にそれぞれ設定
 				ArrayList<NodeHostnameInfo> list = new ArrayList<NodeHostnameInfo> ();
 				list.add(new NodeHostnameInfo(hostname));
@@ -220,17 +239,16 @@ public class SearchNodeBySNMP {
 
 
 		//連絡先はsnmpd.confに書かれている内容を設定する。
-		if(ret.getValue(getEntryKey(OID_CONTACT)) != null){
-			if(((String)ret.getValue(getEntryKey(OID_CONTACT)).getValue()).length() != 0){
-				property.setAdministrator((String)ret.getValue(getEntryKey(OID_CONTACT)).getValue());
+		if(ret.getValue(getEntryKey(SearchDeviceProperties.getOidContact())) != null){
+			if(((String)ret.getValue(getEntryKey(SearchDeviceProperties.getOidContact())).getValue()).length() != 0){
+				property.setAdministrator((String)ret.getValue(getEntryKey(SearchDeviceProperties.getOidContact())).getValue());
 			}
 		}
 
 		//プラットフォーム名は、Windows, Linux, Solaris以外はOtherとする
 		String platform = "OTHER";
-
-		if(ret.getValue(getEntryKey(OID_DESCR)) != null){
-			String description = ((String)ret.getValue(getEntryKey(OID_DESCR)).getValue());
+		if(ret.getValue(getEntryKey(SearchDeviceProperties.getOidDescr())) != null){
+			String description = ((String)ret.getValue(getEntryKey(SearchDeviceProperties.getOidDescr())).getValue());
 			if(description.length() != 0){
 				String OsName = "";
 
@@ -242,7 +260,9 @@ public class SearchNodeBySNMP {
 				}else if(description.matches(".*inux.*")){
 					OsName = "Linux";
 					platform = "LINUX";
-				}else if(description.matches(".*SunOS.*") || description.matches("Solaris")){
+				}else if(solarisFlag && (description.matches(".*SunOS.*") || description.matches("Solaris"))){
+					// プラットフォーム一覧にSOLARISが存在するときのみ、
+					// デバイスサーチやノードサーチで、プラットフォームにSOLARISが入る。
 					OsName= "Solaris";
 					platform = "SOLARIS";
 				}else{
@@ -275,11 +295,11 @@ public class SearchNodeBySNMP {
 		ArrayList<NodeDiskInfo> diskList = new ArrayList<NodeDiskInfo> ();
 		for(String fullOid : ret.keySet()){
 			//DISK情報で始まるか判定
-			if(!fullOid.startsWith(getEntryKey(OID_DISK_INDEX) + ".")){
+			if(!fullOid.startsWith(getEntryKey(SearchDeviceProperties.getOidDiskIndex()) + ".")){
 				continue;
 			}
-			// OID_DISK_INDEX=".1.3.6.1.4.1.2021.13.15.1.1.1";
-			// OID_DISK_NAME =".1.3.6.1.4.1.2021.13.15.1.1.2";
+			// SearchDeviceProperties.getOidDISK_INDEX=".1.3.6.1.4.1.2021.13.15.1.1.1";
+			// SearchDeviceProperties.getOidDISK_NAME =".1.3.6.1.4.1.2021.13.15.1.1.2";
 			if( ret.getValue(fullOid) == null){
 				continue;
 			}
@@ -289,13 +309,17 @@ public class SearchNodeBySNMP {
 			m_log.debug("Find Disk : fullOid = " + fullOid);
 
 			String i = fullOid.substring(fullOid.lastIndexOf(".") + 1);
-			String disk = (String)ret.getValue(getEntryKey(OID_DISK_NAME+"."+i)).getValue();
-			Long ionRead = ret.getValue(getEntryKey(OID_DISK_ION_READ + "." + i)) == null ? 0 : (Long)ret.getValue(getEntryKey(OID_DISK_ION_READ + "." + i)).getValue();
-			Long ionWrite = ret.getValue(getEntryKey(OID_DISK_ION_WRITE + "." + i)) == null ? 0 : (Long)ret.getValue(getEntryKey(OID_DISK_ION_WRITE + "." + i)).getValue();
-			Long ioRead = ret.getValue(getEntryKey(OID_DISK_IO_READ + "." + i)) == null ? 0 : (Long)ret.getValue(getEntryKey(OID_DISK_IO_READ + "." + i)).getValue();
-			Long ioWrite = ret.getValue(getEntryKey(OID_DISK_IO_WRITE + "." + i)) == null ? 0 : (Long)ret.getValue(getEntryKey(OID_DISK_IO_WRITE + "." + i)).getValue();
+			String disk = (String)ret.getValue(getEntryKey(SearchDeviceProperties.getOidDiskName()+"."+i)).getValue();
+			Long ionRead = ret.getValue(getEntryKey(SearchDeviceProperties.getOidDiskIonRead() + "." + i)) == null ? 0 :
+				(Long)ret.getValue(getEntryKey(SearchDeviceProperties.getOidDiskIonRead() + "." + i)).getValue();
+			Long ionWrite = ret.getValue(getEntryKey(SearchDeviceProperties.getOidDiskIonWrite() + "." + i)) == null ? 0 :
+				(Long)ret.getValue(getEntryKey(SearchDeviceProperties.getOidDiskIonWrite() + "." + i)).getValue();
+			Long ioRead = ret.getValue(getEntryKey(SearchDeviceProperties.getOidDiskIoRead() + "." + i)) == null ? 0 :
+				(Long)ret.getValue(getEntryKey(SearchDeviceProperties.getOidDiskIoRead() + "." + i)).getValue();
+			Long ioWrite = ret.getValue(getEntryKey(SearchDeviceProperties.getOidDiskIoWrite() + "." + i)) == null ? 0 :
+				(Long)ret.getValue(getEntryKey(SearchDeviceProperties.getOidDiskIoWrite() + "." + i)).getValue();
 			//DISK_IOが0の物は除外します。
-			if("true".equals(verbose) ||
+			if(verbose ||
 					(ionRead != 0 && ionWrite != 0 && ioRead != 0 && ioWrite != 0)) {
 
 				// デバイス名が重複している場合は、(OIDインデックス)をつける
@@ -329,16 +353,16 @@ public class SearchNodeBySNMP {
 				return ret;
 			}
 		}
-		);
+				);
 		property.setNodeDiskInfo(diskList);
 
 		// NICの情報を設定
 		ArrayList<NodeNetworkInterfaceInfo> nicList = new ArrayList<NodeNetworkInterfaceInfo> ();
 		for (String fullOid : ret.keySet()) {
-			//OID_NIC_INDEX =".1.3.6.1.2.1.2.2.1.1";
-			//OID_NIC_NAME  =".1.3.6.1.2.1.2.2.1.2";
+			//SearchDeviceProperties.getOidNIC_INDEX =".1.3.6.1.2.1.2.2.1.1";
+			//SearchDeviceProperties.getOidNIC_NAME  =".1.3.6.1.2.1.2.2.1.2";
 			//NIC情報で始まるか判定
-			if(!fullOid.startsWith(getEntryKey(OID_NIC_INDEX) + ".")){
+			if(!fullOid.startsWith(getEntryKey(SearchDeviceProperties.getOidNicIndex()) + ".")){
 				continue;
 			}
 			String tmpIndex = fullOid.substring(fullOid.lastIndexOf(".") + 1);
@@ -348,11 +372,11 @@ public class SearchNodeBySNMP {
 			}
 			m_log.debug("Find Nic : fullOid = " + fullOid);
 
-			deviceName = (String)ret.getValue(getEntryKey(OID_NIC_NAME + "." + tmpIndex)).getValue();
+			deviceName = (String)ret.getValue(getEntryKey(SearchDeviceProperties.getOidNicName() + "." + tmpIndex)).getValue();
 
 			String nicMacAddress = "";
-			if (ret.getValue(getEntryKey(OID_NIC_MAC_ADDRESS + "." + tmpIndex)) != null) {
-				nicMacAddress = (String)ret.getValue(getEntryKey(OID_NIC_MAC_ADDRESS + "." + tmpIndex)).getValue();
+			if (ret.getValue(getEntryKey(SearchDeviceProperties.getOidNicMacAddress() + "." + tmpIndex)) != null) {
+				nicMacAddress = (String)ret.getValue(getEntryKey(SearchDeviceProperties.getOidNicMacAddress() + "." + tmpIndex)).getValue();
 			}
 
 			String nicIpAddress = "";
@@ -368,8 +392,8 @@ public class SearchNodeBySNMP {
 				// IP-MIB::ipAddressIfIndex.ipv4."192.168.11.211" = INTEGER: 2
 				// IP-MIB::ipAddressIfIndex.ipv4."192.168.11.255" = INTEGER: 2
 				Pattern ipAddrV4Pattern = Pattern.compile("(\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3})$");
-				if (ret.getValueSetStartWith(getEntryKey(OID_NIC_IP_ADDRESSV4)) != null) {
-					for (TableEntry entry : ret.getValueSetStartWith(getEntryKey(OID_NIC_IP_ADDRESSV4))) {
+				if (ret.getValueSetStartWith(getEntryKey(SearchDeviceProperties.getOidNicIpAddressv4())) != null) {
+					for (TableEntry entry : ret.getValueSetStartWith(getEntryKey(SearchDeviceProperties.getOidNicIpAddressv4()))) {
 						if (entry.getValue() != null && tmpIndex.equals(((Long)entry.getValue()).toString())) {
 							Matcher matcher = ipAddrV4Pattern.matcher(entry.getKey());
 							if (matcher.find()) {
@@ -378,8 +402,8 @@ public class SearchNodeBySNMP {
 								// .1.3.6.1.2.1.4.34.1.4.1.4.127.0.0.1 = INTEGER: unicast(1)
 								// .1.3.6.1.2.1.4.34.1.4.1.4.192.168.10.101 = INTEGER: unicast(1)
 								// .1.3.6.1.2.1.4.34.1.4.1.4.192.168.10.255 = INTEGER: broadcast(3)
-								if (ret.getValue(getEntryKey(OID_NIC_IP_ADDRESSV4_TYPE + "." + matcher.group(1))) != null) {
-									if ((Long)ret.getValue(getEntryKey(OID_NIC_IP_ADDRESSV4_TYPE + "." + matcher.group(1))).getValue() != 1) {
+								if (ret.getValue(getEntryKey(SearchDeviceProperties.getOidNicIpAddressv4Type() + "." + matcher.group(1))) != null) {
+									if ((Long)ret.getValue(getEntryKey(SearchDeviceProperties.getOidNicIpAddressv4Type() + "." + matcher.group(1))).getValue() != 1) {
 										continue;
 									}
 								}
@@ -400,18 +424,18 @@ public class SearchNodeBySNMP {
 				// IP-MIB::ipAddressIfIndex.ipv6."fe:80:00:00:00:00:00:00:50:54:00:ff:fe:be:83:2a" = INTEGER: 2
 				// IP-MIB::ipAddressIfIndex.ipv6."fe:80:00:00:00:00:00:00:50:54:00:ff:fe:ed:d4:3c" = INTEGER: 3
 				Pattern ipAddrV6Pattern = Pattern.compile("((\\d{1,3})\\.(\\d{1,3})\\.(\\d{1,3})\\.(\\d{1,3})\\.(\\d{1,3})\\.(\\d{1,3})\\.(\\d{1,3})\\.(\\d{1,3})\\.(\\d{1,3})\\.(\\d{1,3})\\.(\\d{1,3})\\.(\\d{1,3})\\.(\\d{1,3})\\.(\\d{1,3})\\.(\\d{1,3})\\.(\\d{1,3}))$");
-				if (ret.getValueSetStartWith(getEntryKey(OID_NIC_IP_ADDRESSV6)) != null) {
-					for (TableEntry entry : ret.getValueSetStartWith(getEntryKey(OID_NIC_IP_ADDRESSV6))) {
+				if (ret.getValueSetStartWith(getEntryKey(SearchDeviceProperties.getOidNicIpAddressv6())) != null) {
+					for (TableEntry entry : ret.getValueSetStartWith(getEntryKey(SearchDeviceProperties.getOidNicIpAddressv6()))) {
 						if (entry.getValue() != null && tmpIndex.equals(((Long)entry.getValue()).toString())) {
-							System.out.println(entry.getKey() + " : " + entry.getValue());
+							m_log.debug(entry.getKey() + " : " + entry.getValue());
 							Matcher matcher = ipAddrV6Pattern.matcher(entry.getKey());
 							if (matcher.find()) {
 								// check address type (allow only unicast)
 								// # snmpwalk -On -c public -v 2c localhost IP-MIB::ipAddressType.ipv6
 								// .1.3.6.1.2.1.4.34.1.4.2.16.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.1 = INTEGER: unicast(1)
 								// .1.3.6.1.2.1.4.34.1.4.2.16.254.128.0.0.0.0.0.0.80.84.0.255.254.190.131.42 = INTEGER: unicast(1)
-								if (ret.getValue(getEntryKey(OID_NIC_IP_ADDRESSV6_TYPE + "." + matcher.group(1))) != null) {
-									if ((Long)ret.getValue(getEntryKey(OID_NIC_IP_ADDRESSV6_TYPE + "." + matcher.group(1))).getValue() != 1) {
+								if (ret.getValue(getEntryKey(SearchDeviceProperties.getOidNicIpAddressv6Type() + "." + matcher.group(1))) != null) {
+									if ((Long)ret.getValue(getEntryKey(SearchDeviceProperties.getOidNicIpAddressv6Type() + "." + matcher.group(1))).getValue() != 1) {
 										continue;
 									}
 								}
@@ -431,22 +455,11 @@ public class SearchNodeBySNMP {
 
 			// NICのIN/OUTが0のものは除外する。
 			String key = "";
-			key = getEntryKey(OID_NIC_IN_UCAST_PKTS + "." + tmpIndex);
-			Long inPkts = ret.getValue(key) == null ? 0 :(Long)ret.getValue(key).getValue();
-			key = getEntryKey(OID_NIC_OUT_UCAST_PKTS + "." + tmpIndex);
-			Long outPkts = ret.getValue(key) == null ? 0 : (Long)ret.getValue(key).getValue();
-			key = getEntryKey(OID_NIC_IN_ERROR + "." + tmpIndex);
-			Long inError = ret.getValue(key) == null ? 0 : (Long)ret.getValue(key).getValue();
-			key = getEntryKey(OID_NIC_OUT_ERROR + "." + tmpIndex);
-			Long outError = ret.getValue(key) == null ? 0 : (Long)ret.getValue(key).getValue();
-			key = getEntryKey(OID_NIC_IN_OCTET + "." + tmpIndex);
+			key = getEntryKey(SearchDeviceProperties.getOidNicInOctet() + "." + tmpIndex);
 			Long inOctet = ret.getValue(key) == null ? 0 : (Long)ret.getValue(key).getValue();
-			key = getEntryKey(OID_NIC_OUT_OCTET + "." + tmpIndex);
+			key = getEntryKey(SearchDeviceProperties.getOidNicOutOctet() + "." + tmpIndex);
 			Long outOctet = ret.getValue(key) == null ? 0 : (Long)ret.getValue(key).getValue();
-			if (!"true".equals(verbose) &&
-					inPkts == 0 && outPkts == 0 &&
-					inError == 0 && outError == 0 &&
-					inOctet == 0 && outOctet == 0) {
+			if (!verbose && inOctet == 0 && outOctet == 0) {
 				continue;
 			}
 			NodeNetworkInterfaceInfo nicInfo = new NodeNetworkInterfaceInfo();
@@ -463,7 +476,7 @@ public class SearchNodeBySNMP {
 			// IPアドレスの設定
 			nicInfo.setNicIpAddress(nicIpAddress);
 			// デバイスINDEXの設定
-			Long deviceIndex = (Long)ret.getValue(getEntryKey(OID_NIC_INDEX + "." + tmpIndex)).getValue();
+			Long deviceIndex = (Long)ret.getValue(getEntryKey(SearchDeviceProperties.getOidNicIndex() + "." + tmpIndex)).getValue();
 			nicInfo.setDeviceIndex(deviceIndex.intValue());
 			// デバイスTypeの設定
 			nicInfo.setDeviceType(DeviceTypeConstant.DEVICE_NIC);
@@ -481,17 +494,17 @@ public class SearchNodeBySNMP {
 				return ret;
 			}
 		}
-		);
+				);
 		property.setNodeNetworkInterfaceInfo(nicList);
 
 		//ファイルシステム
 		deviceCount=0;
 		ArrayList<NodeFilesystemInfo> filesystemList = new ArrayList<NodeFilesystemInfo> ();
 		for(String fullOid : ret.keySet()) {
-			// OID_FILESYSTEM_INDEX = ".1.3.6.1.2.1.25.2.3.1.1";
-			// OID_FILESYSTEM_NAME  = ".1.3.6.1.2.1.25.2.3.1.3";
+			// SearchDeviceProperties.getOidFILESYSTEM_INDEX = ".1.3.6.1.2.1.25.2.3.1.1";
+			// SearchDeviceProperties.getOidFILESYSTEM_NAME  = ".1.3.6.1.2.1.25.2.3.1.3";
 			//DISK情報で始まるか判定
-			if(!fullOid.startsWith(getEntryKey(OID_FILESYSTEM_INDEX) + ".")){
+			if(!fullOid.startsWith(getEntryKey(SearchDeviceProperties.getOidFilesystemIndex()) + ".")){
 				continue;
 			}
 			if( ret.getValue(fullOid) == null){
@@ -505,18 +518,18 @@ public class SearchNodeBySNMP {
 			//hrStrageFixedDiskの場合のみノード情報に追加
 			//.1.3.6.1.2.1.25.2.1.4←hrStrageFixedDisk
 			String i = fullOid.substring(fullOid.lastIndexOf(".") + 1);
-			String strageType =  ret.getValue(getEntryKey(OID_FILESYSTEM_TYPE+"."+i)).getValue().toString();
+			String strageType =  ret.getValue(getEntryKey(SearchDeviceProperties.getOidFilesystemType()+"."+i)).getValue().toString();
 
 			if(strageType.equals(".1.3.6.1.2.1.25.2.1.4")){
 
 				NodeFilesystemInfo filesystem = new NodeFilesystemInfo();
 
 				//表示名
-				filesystem.setDeviceDisplayName(convStringFilessystem(((String)ret.getValue(getEntryKey(OID_FILESYSTEM_NAME+"."+i)).getValue())));
+				filesystem.setDeviceDisplayName(convStringFilessystem(((String)ret.getValue(getEntryKey(SearchDeviceProperties.getOidFilesystemName()+"."+i)).getValue())));
 				//デバイス名
-				filesystem.setDeviceName(((String)ret.getValue(getEntryKey(OID_FILESYSTEM_NAME+"."+i)).getValue()));
+				filesystem.setDeviceName(((String)ret.getValue(getEntryKey(SearchDeviceProperties.getOidFilesystemName()+"."+i)).getValue()));
 				//デバイスINDEX
-				filesystem.setDeviceIndex(((Long)ret.getValue(getEntryKey(OID_FILESYSTEM_INDEX+"."+i)).getValue()).intValue());
+				filesystem.setDeviceIndex(((Long)ret.getValue(getEntryKey(SearchDeviceProperties.getOidFilesystemIndex()+"."+i)).getValue()).intValue());
 				//デバイス種別
 				filesystem.setDeviceType(DeviceTypeConstant.DEVICE_FILESYSTEM);
 
@@ -535,15 +548,15 @@ public class SearchNodeBySNMP {
 				return ret;
 			}
 		}
-		);
+				);
 		property.setNodeFilesystemInfo(filesystemList);
 
 		// CPU
 		deviceCount=0;
 		ArrayList<NodeCpuInfo> cpuList = new ArrayList<NodeCpuInfo> ();
 		for(String fullOid : ret.keySet()) {
-			// OID_CPU_INDEX=".1.3.6.1.2.1.25.3.3.1.2";
-			if(!fullOid.startsWith(getEntryKey(OID_CPU_INDEX) + ".")){
+			// SearchDeviceProperties.getOidCPU_INDEX=".1.3.6.1.2.1.25.3.3.1.2";
+			if(!fullOid.startsWith(getEntryKey(SearchDeviceProperties.getOidCpuIndex()) + ".")){
 				continue;
 			}
 			if( ret.getValue(fullOid) == null){
@@ -551,7 +564,7 @@ public class SearchNodeBySNMP {
 			}
 			m_log.debug("Find Cpu : fullOid = " + fullOid);
 
-			String indexStr = fullOid.replaceFirst(getEntryKey(OID_CPU_INDEX) + ".","");
+			String indexStr = fullOid.replaceFirst(getEntryKey(SearchDeviceProperties.getOidCpuIndex()) + ".","");
 			m_log.debug("cpu fullOid = " + fullOid + ", index = " + indexStr);
 			NodeCpuInfo cpu = new NodeCpuInfo();
 			cpu.setDeviceDisplayName(DeviceTypeConstant.DEVICE_CPU + deviceCount);
@@ -573,11 +586,13 @@ public class SearchNodeBySNMP {
 				return ret;
 			}
 		}
-		);
+				);
 		property.setNodeCpuInfo(cpuList);
+		
+		property.setNodeMemoryInfo(new ArrayList<NodeMemoryInfo>());
 
 
-		m_log.debug("find-by-snmp " + property.toString());
+		m_log.debug("device search " + property.toString());
 		return property;
 	}
 
@@ -594,27 +609,27 @@ public class SearchNodeBySNMP {
 				short second;
 				chars=str.toCharArray();
 				StringBuffer ret = new StringBuffer();
-				
+
 				for(int i = 0; i<chars.length;){
-					
+
 					first  = (short) (chars[i] - 48); //48は"0"なので、"1"→1の変換
 					second = (short)(chars[i+1]- 48);
-					
+
 					if(second >10){
 						//16進でA-Fの場合には、さらに7を引く
 						//10 ⇔ A(16進)なので("A"→65)を10にする、 10 = "A"(65) - "0"(48) - 7
 						second -=7;
 					}
-					
+
 					ret.append((char) (first*16+second));
-					
+
 					i+=3;//1文字は"56 "とかで構成するので、配列2つを読んで" "をスキップ
 				}
-				
-				m_log.info("Find By SNMP : Filesystem Name str = " + str + " convert to " + ret.substring(0,3));
+
+				m_log.info("DeviceSearch : Filesystem Name str = " + str + " convert to " + ret.substring(0,3));
 				return ret.substring(0,3);
 			} catch(Exception e){
-				m_log.warn("Find By SNMP : " + e.getMessage());
+				m_log.warn("DeviceSearch : " + e.getMessage());
 				return str;
 			}
 		}
@@ -632,19 +647,19 @@ public class SearchNodeBySNMP {
 
 		while (true) {
 
-			// OID_DISK_INDEX=".1.3.6.1.4.1.2021.13.15.1.1.1";
-			// OID_DISK_NAME =".1.3.6.1.4.1.2021.13.15.1.1.2";
-			String oidCounter = OID_DISK_INDEX+"."+i;
+			// SearchDeviceProperties.getOidDISK_INDEX=".1.3.6.1.4.1.2021.13.15.1.1.1";
+			// SearchDeviceProperties.getOidDISK_NAME =".1.3.6.1.4.1.2021.13.15.1.1.2";
+			String oidCounter = SearchDeviceProperties.getOidDiskIndex()+"."+i;
 
 			if( dataTable.getValue(oidCounter) != null){
 				if(((String)dataTable.getValue(oidCounter).getValue()).length() != 0 ){
-					String disk = (String)dataTable.getValue(OID_DISK_NAME+"."+i).getValue();
+					String disk = (String)dataTable.getValue(SearchDeviceProperties.getOidDiskName()+"."+i).getValue();
 
 					//ramディスクは除外します。
 					if(!(disk.startsWith("ram"))){
 
 						// デバイス名
-						String diskName = (String)dataTable.getValue(OID_DISK_NAME+"."+i).getValue();
+						String diskName = (String)dataTable.getValue(SearchDeviceProperties.getOidDiskName()+"."+i).getValue();
 
 						Boolean isDuplicate = ret.get(diskName);
 						if (isDuplicate == null) {
@@ -672,17 +687,17 @@ public class SearchNodeBySNMP {
 		HashMap<String, Boolean> ret = new HashMap<String, Boolean>();
 
 		for (String fullOid : dataTable.keySet()) {
-			//OID_NIC_INDEX =".1.3.6.1.2.1.2.2.1.1";
-			//OID_NIC_NAME  =".1.3.6.1.2.1.2.2.1.2";
+			//SearchDeviceProperties.getOidNIC_INDEX =".1.3.6.1.2.1.2.2.1.1";
+			//SearchDeviceProperties.getOidNIC_NAME  =".1.3.6.1.2.1.2.2.1.2";
 
-			if(fullOid.startsWith(OID_NIC_INDEX + ".")){//NIC情報で始まるか判定
+			if(fullOid.startsWith(SearchDeviceProperties.getOidNicIndex() + ".")){//NIC情報で始まるか判定
 
 				String tmpIndex = fullOid.substring(fullOid.lastIndexOf("."));
 
 				if( ((String)dataTable.getValue(fullOid).getValue()).length() != 0 ){
 
-					//String nicName = convString((String)dataTable.getValue(OID_NIC_NAME+tmpIndex).getValue(),isWindows);
-					String nicName = (String)dataTable.getValue(OID_NIC_NAME+tmpIndex).getValue();
+					//String nicName = convString((String)dataTable.getValue(SearchDeviceProperties.getOidNIC_NAME+tmpIndex).getValue(),isWindows);
+					String nicName = (String)dataTable.getValue(SearchDeviceProperties.getOidNicName()+tmpIndex).getValue();
 					m_log.info("NIC name = " + nicName);
 
 					Boolean isDuplicate = ret.get(nicName);
@@ -698,5 +713,4 @@ public class SearchNodeBySNMP {
 
 		return ret;
 	}
-
 }
