@@ -15,10 +15,6 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.repository.view;
 
-import org.eclipse.jface.action.ActionContributionItem;
-import org.eclipse.jface.action.IMenuListener;
-import org.eclipse.jface.action.IMenuManager;
-import org.eclipse.jface.action.IToolBarManager;
 import org.eclipse.jface.action.MenuManager;
 import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.jface.viewers.ISelectionChangedListener;
@@ -32,26 +28,32 @@ import org.eclipse.swt.widgets.Menu;
 import org.eclipse.ui.IViewPart;
 import org.eclipse.ui.IWorkbenchPage;
 import org.eclipse.ui.PlatformUI;
+import org.eclipse.ui.commands.ICommandService;
 
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.repository.composite.AgentListComposite;
 import com.clustercontrol.repository.view.action.AgentRestartAction;
 import com.clustercontrol.repository.view.action.AgentUpdateAction;
+import com.clustercontrol.repository.view.action.RefreshAgentAction;
 import com.clustercontrol.view.CommonViewPart;
 
 /**
  * ノート一覧ビュークラス<BR>
- * 
- * @version 1.0.0
+ *
+ * @version 5.0.0
  * @since 1.0.0
  */
 public class AgentListView extends CommonViewPart {
-	public static final String ID = "com.clustercontrol.repository.view.AgentListView";
+	public static final String ID = AgentListView.class.getName();
 
 	// ----- instance フィールド ----- //
 
 	/** ノード一覧コンポジット */
 	private AgentListComposite composite = null;
 
+	/** 選択レコード数 */
+	private int rowNum = 0;
+
 	// ----- コンストラクタ ----- //
 
 	/**
@@ -74,6 +76,7 @@ public class AgentListView extends CommonViewPart {
 		layout.marginWidth = 0;
 
 		composite = new AgentListComposite(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, null, composite);
 		GridData gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
@@ -109,51 +112,22 @@ public class AgentListView extends CommonViewPart {
 
 	/**
 	 * ポップアップメニュー作成
-	 * 
-	 * 
+	 *
+	 *
 	 */
 	private void createContextMenu() {
 		MenuManager menuManager = new MenuManager();
 		menuManager.setRemoveAllWhenShown(true);
-		menuManager.addMenuListener(new IMenuListener() {
-			/*
-			 * (non-Javadoc)
-			 * 
-			 * @see org.eclipse.jface.action.IMenuListener#menuAboutToShow(org.eclipse.jface.action.IMenuManager)
-			 */
-			@Override
-			public void menuAboutToShow(IMenuManager manager) {
-				//メニュー項目設定
-				fillContextMenu(manager);
-			}
-		});
 
 		Menu menu = menuManager.createContextMenu(composite.getTable());
+		WidgetTestUtil.setTestId(this, null, menu);
 		composite.getTable().setMenu(menu);
-	}
-
-	/**
-	 * メニュー項目追加
-	 * 
-	 * @param manager
-	 */
-	private void fillContextMenu(IMenuManager manager) {
-		//ビューのアクションのインスタンスを取得
-		IToolBarManager toolbar = this.getViewSite().getActionBars()
-				.getToolBarManager();
-		ActionContributionItem agentRestartAction = (ActionContributionItem) toolbar
-				.find(AgentRestartAction.ID);
-		ActionContributionItem agentUpdateAction = (ActionContributionItem) toolbar
-				.find(AgentUpdateAction.ID);
-
-		//ポップアップメニューにアクションを追加
-		manager.add(agentRestartAction.getAction());
-		manager.add(agentUpdateAction.getAction());
+		getSite().registerContextMenu( menuManager, this.composite.getTableViewer() );
 	}
 
 	/**
 	 * compositeを返します。
-	 * 
+	 *
 	 * @return composite
 	 */
 	public AgentListComposite getComposite() {
@@ -165,26 +139,38 @@ public class AgentListView extends CommonViewPart {
 	 * <p>
 	 */
 	public void update() {
-
 		composite.update();
 	}
 
+	/**
+	 * 選択レコード数を返します。
+	 * @return rowNum
+	 */
+	public int getSelectedNum(){
+		return this.rowNum;
+	}
+
 	/**
 	 * ビューのアクションの有効/無効を設定します。
-	 * 
+	 *
 	 * @param num 選択イベント数
 	 * @param selection ボタン（アクション）を有効にするための情報
 	 */
 	public void setEnabledAction(int num, ISelection selection) {
-		super.setEnabledAction(AgentRestartAction.ID, selection);
-		super.setEnabledAction(AgentUpdateAction.ID, selection);
+		this.rowNum = num;
+
+		//ビューアクションの使用可/不可を設定
+		ICommandService service = (ICommandService) PlatformUI.getWorkbench().getService( ICommandService.class );
+		if( null != service ){
+			service.refreshElements(AgentRestartAction.ID, null);
+			service.refreshElements(AgentUpdateAction.ID, null);
+			service.refreshElements(RefreshAgentAction.ID, null);
+
+			// Update ToolBar after elements refreshed
+			// WARN : Both ToolBarManager must be updated after updateActionBars(), otherwise icon won't change.
+			getViewSite().getActionBars().updateActionBars();
+			getViewSite().getActionBars().getToolBarManager().update(false);
 
-		if(num > 0){
-			super.setEnabledAction(AgentRestartAction.ID, true);
-			super.setEnabledAction(AgentUpdateAction.ID, true);
-		}else{
-			super.setEnabledAction(AgentRestartAction.ID, false);
-			super.setEnabledAction(AgentUpdateAction.ID, false);
 		}
 	}
-}
\ No newline at end of file
+}
