@@ -20,6 +20,7 @@ import org.apache.commons.logging.LogFactory;
 import org.eclipse.jface.dialogs.MessageDialog;
 
 import com.clustercontrol.bean.HinemosModuleConstant;
+import com.clustercontrol.monitor.bean.MonitorTypeMstConstant;
 import com.clustercontrol.monitor.util.MonitorSettingEndpointWrapper;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.monitor.InvalidRole_Exception;
@@ -27,7 +28,7 @@ import com.clustercontrol.ws.monitor.MonitorInfo;
 
 /**
  * SNMP監視を取得するクライアント側アクションクラス<BR>
- * 
+ *
  * @version 2.1.0
  * @since 2.0.0
  */
@@ -35,18 +36,25 @@ public class GetSnmp {
 
 	// ログ
 	private static Log m_log = LogFactory.getLog( GetSnmp.class );
+	/** マネージャ名 */
 
 	/**
 	 * SNMP監視情報を返します。
-	 * 
+	 *
 	 * @param monitorId 監視項目ID
+	 * @param monitorType 監視判定タイプ
 	 * @return SNMP監視情報
 	 */
-	public MonitorInfo getSnmp(String monitorId) {
+	public MonitorInfo getSnmp(String managerName, String monitorId, int monitorType) {
 
 		MonitorInfo info = null;
 		try {
-			info = MonitorSettingEndpointWrapper.getMonitor(monitorId, HinemosModuleConstant.MONITOR_SNMP);
+			MonitorSettingEndpointWrapper wrapper = MonitorSettingEndpointWrapper.getWrapper(managerName);
+			if (monitorType == MonitorTypeMstConstant.MONITOR_TYPE_NUMERIC) {
+				info = wrapper.getMonitor(monitorId, HinemosModuleConstant.MONITOR_SNMP_N);
+			} else {
+				info = wrapper.getMonitor(monitorId, HinemosModuleConstant.MONITOR_SNMP_S);
+			}
 
 		} catch (InvalidRole_Exception e) {
 			// アクセス権なしの場合、エラーダイアログを表示する
@@ -66,4 +74,4 @@ public class GetSnmp {
 
 		return info;
 	}
-}
\ No newline at end of file
+}
