@@ -24,7 +24,7 @@ import com.clustercontrol.ws.monitor.MonitorInfo;
 
 /**
  * SNMP監視情報を更新するクライアント側アクションクラス<BR>
- * 
+ *
  * @version 2.2.0
  * @since 2.0.0
  */
@@ -32,17 +32,18 @@ public class ModifySnmp {
 
 	/**
 	 * SNMP監視情報を更新します。
-	 * 
+	 *
 	 * @param info SNMP監視情報
 	 * @return 更新に成功した場合、true
 	 */
-	public boolean modify(MonitorInfo info) {
+	public boolean modify(String managerName, MonitorInfo info) {
 
 		boolean result = false;
-		String[] args = { info.getMonitorId() };
+		String[] args = { info.getMonitorId(), managerName };
 		String errMessage = "";
 		try {
-			result = MonitorSettingEndpointWrapper.modifyMonitor(info);
+			MonitorSettingEndpointWrapper wrapper = MonitorSettingEndpointWrapper.getWrapper(managerName);
+			result = wrapper.modifyMonitor(info);
 		} catch (InvalidRole_Exception e) {
 			// アクセス権なしの場合、エラーダイアログを表示する
 			MessageDialog.openInformation(
@@ -67,4 +68,4 @@ public class ModifySnmp {
 
 		return result;
 	}
-}
\ No newline at end of file
+}
