@@ -26,11 +26,12 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.bean.SnmpVersionConstant;
+import com.clustercontrol.monitor.bean.MonitorTypeMstConstant;
 import com.clustercontrol.monitor.run.dialog.CommonMonitorStringDialog;
-import com.clustercontrol.notify.util.NotifyGroupIdGenerator;
 import com.clustercontrol.snmp.action.AddSnmp;
 import com.clustercontrol.snmp.action.GetSnmp;
 import com.clustercontrol.snmp.action.ModifySnmp;
@@ -41,7 +42,7 @@ import com.clustercontrol.ws.monitor.SnmpCheckInfo;
 
 /**
  * SNMP監視（文字列）作成・変更ダイアログクラス<BR>
- * 
+ *
  * @version 4.0.0
  * @since 2.0.0
  */
@@ -52,40 +53,46 @@ public class SnmpStringCreateDialog extends CommonMonitorStringDialog {
 	/** OID */
 	private Text m_textOid = null;
 
+	/** マネージャ名 */
+	private String managerName = null;
 	// ----- コンストラクタ ----- //
 
 	/**
 	 * 作成用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のシェルオブジェクト
 	 */
 	public SnmpStringCreateDialog(Shell parent) {
-		super(parent);
+		super(parent, null);
 	}
 
 	/**
 	 * 作成用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
+	 * @param マネージャ名
 	 * @param monitorType 監視判定タイプ
 	 */
-	public SnmpStringCreateDialog(Shell parent, int monitorType) {
-		super(parent);
+	public SnmpStringCreateDialog(Shell parent, String managerName, int monitorType) {
+		super(parent, managerName);
 
+		this.managerName = managerName;
 		this.m_monitorType = monitorType;
 	}
 
 	/**
 	 * 変更用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
+	 * @param マネージャ名
 	 * @param monitorId 変更する監視項目ID
 	 * @param updateFlg 更新するか否か（true:変更、false:新規登録）
 	 */
-	public SnmpStringCreateDialog(Shell parent, String monitorId, boolean updateFlg) {
-		super(parent);
+	public SnmpStringCreateDialog(Shell parent, String managerName, String monitorId, boolean updateFlg) {
+		super(parent, managerName);
 
+		this.managerName = managerName;
 		this.monitorId = monitorId;
 		this.updateFlg = updateFlg;
 	}
@@ -94,7 +101,7 @@ public class SnmpStringCreateDialog extends CommonMonitorStringDialog {
 
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のインスタンス
 	 */
@@ -115,13 +122,14 @@ public class SnmpStringCreateDialog extends CommonMonitorStringDialog {
 		 * チェック設定グループ（条件グループの子グループ）
 		 */
 		Group groupCheckRule = new Group(groupRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "checkrule", groupCheckRule);
 		GridLayout layout = new GridLayout(1, true);
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
-		layout.numColumns = 15;
+		layout.numColumns = BASIC_UNIT;
 		groupCheckRule.setLayout(layout);
 		gridData = new GridData();
-		gridData.horizontalSpan = 15;
+		gridData.horizontalSpan = BASIC_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		groupCheckRule.setLayoutData(gridData);
@@ -132,16 +140,18 @@ public class SnmpStringCreateDialog extends CommonMonitorStringDialog {
 		 */
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "oid", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("oid") + " : ");
 		// テキスト
 		this.m_textOid = new Text(groupCheckRule, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "oid", m_textOid);
 		gridData = new GridData();
-		gridData.horizontalSpan = 8;
+		gridData.horizontalSpan = WIDTH_TEXT_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.m_textOid.setLayoutData(gridData);
@@ -154,7 +164,7 @@ public class SnmpStringCreateDialog extends CommonMonitorStringDialog {
 		// 空白
 		label = new Label(groupCheckRule, SWT.NONE);
 		gridData = new GridData();
-		gridData.horizontalSpan = 2;
+		gridData.horizontalSpan = 4;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -171,14 +181,14 @@ public class SnmpStringCreateDialog extends CommonMonitorStringDialog {
 		}
 		else{
 			// 変更の場合、情報取得
-			info = new GetSnmp().getSnmp(this.monitorId);
+			info = new GetSnmp().getSnmp(this.managerName, this.monitorId, MonitorTypeMstConstant.MONITOR_TYPE_STRING);
 		}
 		this.setInputData(info);
 	}
 
 	/**
 	 * 更新処理
-	 * 
+	 *
 	 */
 	@Override
 	public void update(){
@@ -194,7 +204,7 @@ public class SnmpStringCreateDialog extends CommonMonitorStringDialog {
 
 	/**
 	 * 各項目に入力値を設定します。
-	 * 
+	 *
 	 * @param monitor
 	 *            設定値として用いる監視情報
 	 */
@@ -227,7 +237,7 @@ public class SnmpStringCreateDialog extends CommonMonitorStringDialog {
 
 	/**
 	 * 入力値を用いて通知情報を生成します。
-	 * 
+	 *
 	 * @return 入力値を保持した通知情報
 	 */
 	@Override
@@ -238,13 +248,13 @@ public class SnmpStringCreateDialog extends CommonMonitorStringDialog {
 		}
 
 		//SNMP監視固有情報を設定
-		monitorInfo.setMonitorTypeId(HinemosModuleConstant.MONITOR_SNMP);
+		monitorInfo.setMonitorTypeId(HinemosModuleConstant.MONITOR_SNMP_S);
 
 		// 監視条件 SNMP監視情報
 		SnmpCheckInfo snmpInfo = new SnmpCheckInfo();
 		snmpInfo.setConvertFlg(ConvertValueConstant.TYPE_DELTA);
 		snmpInfo.setSnmpVersion(SnmpVersionConstant.STRING_V1);
-		snmpInfo.setMonitorTypeId(HinemosModuleConstant.MONITOR_SNMP);
+		snmpInfo.setMonitorTypeId(HinemosModuleConstant.MONITOR_SNMP_S);
 		snmpInfo.setMonitorId(monitorInfo.getMonitorId());
 
 		if (this.m_textOid.getText() != null
@@ -256,8 +266,6 @@ public class SnmpStringCreateDialog extends CommonMonitorStringDialog {
 		monitorInfo.setSnmpCheckInfo(snmpInfo);
 
 		// 通知関連情報とアプリケーションの設定
-		// 通知グループIDの設定
-		monitorInfo.setNotifyGroupId(NotifyGroupIdGenerator.createNotifyGroupId(HinemosModuleConstant.MONITOR_SNMP, monitorInfo.getMonitorId()));
 		validateResult = m_notifyInfo.createInputData(monitorInfo);
 		if (validateResult != null) {
 			if(validateResult.getID() == null){	// 通知ID警告用出力
@@ -282,9 +290,9 @@ public class SnmpStringCreateDialog extends CommonMonitorStringDialog {
 
 	/**
 	 * 入力値をマネージャに登録します。
-	 * 
+	 *
 	 * @return true：正常、false：異常
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#action()
 	 */
 	@Override
@@ -293,13 +301,14 @@ public class SnmpStringCreateDialog extends CommonMonitorStringDialog {
 
 		MonitorInfo info = this.inputData;
 		if(info != null){
+			String managerName = this.getManagerName();
 			if(!this.updateFlg){
 				// 作成の場合
-				result = new AddSnmp().add(info);
+				result = new AddSnmp().add(managerName, info);
 			}
 			else{
 				// 変更の場合
-				result = new ModifySnmp().modify(info);
+				result = new ModifySnmp().modify(managerName, info);
 			}
 		}
 
@@ -308,7 +317,7 @@ public class SnmpStringCreateDialog extends CommonMonitorStringDialog {
 
 	/**
 	 * MonitorInfoに初期値を設定します
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonMonitorDialog#setInfoInitialValue()
 	 */
 	@Override
@@ -321,4 +330,4 @@ public class SnmpStringCreateDialog extends CommonMonitorStringDialog {
 		snmpCheckInfo.setSnmpVersion(SnmpVersionConstant.STRING_V1);
 		monitor.setSnmpCheckInfo(snmpCheckInfo);
 	}
-}
\ No newline at end of file
+}
