@@ -29,7 +29,7 @@ import com.clustercontrol.ws.monitor.JdbcDriverInfo;
 
 /**
  * JDBC情報を取得するクライアント側アクションクラス<BR>
- * 
+ *
  * @version 2.1.0
  * @since 2.0.0
  */
@@ -40,17 +40,18 @@ public class GetJdbc {
 
 	/**
 	 * SQL監視情報を返します。
-	 * 
+	 *
 	 * @param monitorId 監視項目ID
 	 * @param monitorType 監視判定タイプ
 	 * @return SQL監視情報
 	 */
-	public static List<List> getJdbcDriverList() {
+	public static List<List<String>> getJdbcDriverList(String managerName) {
 
-		List<List> list = new ArrayList();
+		List<List<String>> list = new ArrayList<List<String>>();
 
 		try {
-			List<JdbcDriverInfo> driverList = MonitorSettingEndpointWrapper.getJdbcDriverList();
+			MonitorSettingEndpointWrapper wrapper = MonitorSettingEndpointWrapper.getWrapper(managerName);
+			List<JdbcDriverInfo> driverList = wrapper.getJdbcDriverList();
 			for (JdbcDriverInfo driver : driverList) {
 				ArrayList<String> a = new ArrayList<String>();
 				a.add(driver.getJdbcDriverName());
@@ -75,4 +76,4 @@ public class GetJdbc {
 		return list;
 	}
 
-}
\ No newline at end of file
+}
