@@ -20,6 +20,8 @@ import java.util.List;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.ModifyEvent;
 import org.eclipse.swt.events.ModifyListener;
+import org.eclipse.swt.events.SelectionAdapter;
+import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.graphics.Color;
 import org.eclipse.swt.graphics.RGB;
 import org.eclipse.swt.layout.GridData;
@@ -31,11 +33,12 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.composite.TextWithParameterComposite;
+import com.clustercontrol.monitor.bean.MonitorTypeMstConstant;
 import com.clustercontrol.monitor.run.dialog.CommonMonitorNumericDialog;
-import com.clustercontrol.notify.util.NotifyGroupIdGenerator;
 import com.clustercontrol.sql.action.AddSql;
 import com.clustercontrol.sql.action.GetJdbc;
 import com.clustercontrol.sql.action.GetSql;
@@ -46,7 +49,7 @@ import com.clustercontrol.ws.monitor.SqlCheckInfo;
 
 /**
  * SQL監視（数値）作成・変更ダイアログクラス<BR>
- * 
+ *
  * @version 4.0.0
  * @since 2.0.0
  */
@@ -73,35 +76,39 @@ public class SqlNumericCreateDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * 作成用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
 	 */
 	public SqlNumericCreateDialog(Shell parent) {
-		super(parent);
+		super(parent, null);
 	}
 
 	/**
 	 * 作成用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
+	 * @param マネージャ名
 	 * @param monitorType 監視判定タイプ
 	 */
-	public SqlNumericCreateDialog(Shell parent, int monitorType) {
-		super(parent);
+	public SqlNumericCreateDialog(Shell parent, String managerName, int monitorType) {
+		super(parent, managerName);
 
+		this.managerName = managerName;
 		this.m_monitorType = monitorType;
 	}
 
 	/**
 	 * 変更用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
+	 * @param マネージャ名
 	 * @param monitorId 変更する監視項目ID
 	 * @param updateFlg 更新するか否か（true:変更、false:新規登録）
 	 */
-	public SqlNumericCreateDialog(Shell parent, String monitorId, boolean updateFlg) {
-		super(parent);
+	public SqlNumericCreateDialog(Shell parent, String managerName, String monitorId, boolean updateFlg) {
+		super(parent, managerName);
 
+		this.managerName = managerName;
 		this.monitorId = monitorId;
 		this.updateFlg = updateFlg;
 	}
@@ -110,7 +117,7 @@ public class SqlNumericCreateDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のインスタンス
 	 */
@@ -134,13 +141,14 @@ public class SqlNumericCreateDialog extends CommonMonitorNumericDialog {
 		 * チェック設定グループ（条件グループの子グループ）
 		 */
 		Group groupCheckRule = new Group(groupRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "checkrule", groupCheckRule);
 		GridLayout layout = new GridLayout(1, true);
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
-		layout.numColumns = 15;
+		layout.numColumns = BASIC_UNIT;
 		groupCheckRule.setLayout(layout);
 		gridData = new GridData();
-		gridData.horizontalSpan = 15;
+		gridData.horizontalSpan = BASIC_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		groupCheckRule.setLayoutData(gridData);
@@ -149,16 +157,18 @@ public class SqlNumericCreateDialog extends CommonMonitorNumericDialog {
 		// 接続文字列
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "connectionurl", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("connection.url") + " : ");
 		// テキスト
 		this.textUrl = new TextWithParameterComposite(groupCheckRule, SWT.BORDER | SWT.LEFT | SWT.SINGLE);
+		WidgetTestUtil.setTestId(this, "url", textUrl);
 		gridData = new GridData();
-		gridData.horizontalSpan = 10;
+		gridData.horizontalSpan = LONG_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.textUrl.setLayoutData(gridData);
@@ -174,8 +184,9 @@ public class SqlNumericCreateDialog extends CommonMonitorNumericDialog {
 
 		// 空白
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space1", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = 1;
+		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -183,20 +194,22 @@ public class SqlNumericCreateDialog extends CommonMonitorNumericDialog {
 		// 接続先DB
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "connectiondb", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("connection.db") + " : ");
 		// コンボ
 		this.textJdbcDriver = new Combo(groupCheckRule, SWT.BORDER | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, "jdbcdriver", textJdbcDriver);
 		gridData = new GridData();
-		gridData.horizontalSpan = 10;
+		gridData.horizontalSpan = LONG_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.textJdbcDriver.setLayoutData(gridData);
-		List<List> list = getJdbcDriver();
+		List<List<String>> list = getJdbcDriver();
 		if(list != null){
 			for(int i = 0; i < list.size(); i++){
 				List<String> driver = list.get(i);
@@ -215,8 +228,9 @@ public class SqlNumericCreateDialog extends CommonMonitorNumericDialog {
 
 		// 空白
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space2", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = 1;
+		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -224,16 +238,18 @@ public class SqlNumericCreateDialog extends CommonMonitorNumericDialog {
 		// ユーザ
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "userid", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("user.id") + " : ");
 		// テキスト
 		this.textUser = new Text(groupCheckRule, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "user", textUser);
 		gridData = new GridData();
-		gridData.horizontalSpan = 10;
+		gridData.horizontalSpan = LONG_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.textUser.setLayoutData(gridData);
@@ -246,8 +262,9 @@ public class SqlNumericCreateDialog extends CommonMonitorNumericDialog {
 
 		// 空白
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space3", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = 1;
+		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -255,16 +272,18 @@ public class SqlNumericCreateDialog extends CommonMonitorNumericDialog {
 		// パスワード
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "password", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("password") + " : ");
 		// テキスト
 		this.textPassword = new Text(groupCheckRule, SWT.BORDER | SWT.LEFT | SWT.PASSWORD);
+		WidgetTestUtil.setTestId(this, "password", textPassword);
 		gridData = new GridData();
-		gridData.horizontalSpan = 10;
+		gridData.horizontalSpan = LONG_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.textPassword.setLayoutData(gridData);
@@ -277,8 +296,9 @@ public class SqlNumericCreateDialog extends CommonMonitorNumericDialog {
 
 		// 空白
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space4", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = 1;
+		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -286,16 +306,18 @@ public class SqlNumericCreateDialog extends CommonMonitorNumericDialog {
 		// SQL文
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "sqlstring", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("sql.string") + " : ");
 		// テキスト
 		this.textQuery= new Text(groupCheckRule, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "query", textQuery);
 		gridData = new GridData();
-		gridData.horizontalSpan = 10;
+		gridData.horizontalSpan = LONG_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.textQuery.setLayoutData(gridData);
@@ -306,20 +328,26 @@ public class SqlNumericCreateDialog extends CommonMonitorNumericDialog {
 			}
 		});
 
+		//マネージャを変更した場合(作成の場合のみ）
+		if(!updateFlg) {
+			this.getMonitorBasicScope().getManagerListComposite()
+			.getComboManagerName().addSelectionListener(new SelectionAdapter() {
+				@Override
+				public void widgetSelected(SelectionEvent e) {
+					createJdbcCombo();
+				}
+			});
+		}
+
 		// 空白
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space5", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = 1;
+		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 
-		// 収集値表示名のデフォルト値を設定
-		this.itemName.setText(Messages.getString("select.value"));
-
-		// 収集値単位のデフォルト値を設定
-		this.measure.setText("");
-
 		// ダイアログを調整
 		this.adjustDialog();
 
@@ -332,14 +360,14 @@ public class SqlNumericCreateDialog extends CommonMonitorNumericDialog {
 		}
 		else{
 			// 変更の場合、情報取得
-			info = new GetSql().getSql(this.monitorId);
+			info = new GetSql().getSql(this.getManagerName(), this.monitorId, MonitorTypeMstConstant.MONITOR_TYPE_NUMERIC);
 		}
 		this.setInputData(info);
 	}
 
 	/**
 	 * 更新処理
-	 * 
+	 *
 	 */
 	@Override
 	public void update(){
@@ -375,7 +403,7 @@ public class SqlNumericCreateDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * 各項目に入力値を設定します。
-	 * 
+	 *
 	 * @param monitor
 	 *            設定値として用いる監視情報
 	 */
@@ -398,13 +426,13 @@ public class SqlNumericCreateDialog extends CommonMonitorNumericDialog {
 				this.textPassword.setText(sqlInfo.getPassword());
 			}
 			if (sqlInfo.getJdbcDriver() != null) {
-				List<List> list = getJdbcDriver();
+				List<List<String>> list = getJdbcDriver();
 				if(list != null){
 					for(int i = 0; i < list.size(); i++){
-						List driver = list.get(i);
-						String className = (String)driver.get(1);
+						List<String> driver = list.get(i);
+						String className = driver.get(1);
 						if(className.equals(sqlInfo.getJdbcDriver())){
-							this.textJdbcDriver.setText((String)driver.get(0));
+							this.textJdbcDriver.setText(driver.get(0));
 							break;
 						}
 					}
@@ -424,7 +452,7 @@ public class SqlNumericCreateDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * 入力値を用いて通知情報を生成します。
-	 * 
+	 *
 	 * @return 入力値を保持した通知情報
 	 */
 	@Override
@@ -435,11 +463,11 @@ public class SqlNumericCreateDialog extends CommonMonitorNumericDialog {
 		}
 
 		//SQL監視固有情報を設定
-		monitorInfo.setMonitorTypeId(HinemosModuleConstant.MONITOR_SQL);
+		monitorInfo.setMonitorTypeId(HinemosModuleConstant.MONITOR_SQL_N);
 
 		// 監視条件 SQL監視情報
 		SqlCheckInfo sqlInfo = new SqlCheckInfo();
-		sqlInfo.setMonitorTypeId(HinemosModuleConstant.MONITOR_SQL);
+		sqlInfo.setMonitorTypeId(HinemosModuleConstant.MONITOR_SQL_N);
 		sqlInfo.setMonitorId(monitorInfo.getMonitorId());
 
 		//接続先URL
@@ -467,13 +495,13 @@ public class SqlNumericCreateDialog extends CommonMonitorNumericDialog {
 		if (this.textJdbcDriver.getText() != null
 				&& !"".equals((this.textJdbcDriver.getText()).trim())) {
 
-			List<List> list = getJdbcDriver();
+			List<List<String>> list = getJdbcDriver();
 			if(list != null){
 				for(int i = 0; i < list.size(); i++){
-					List driver = list.get(i);
-					String name = (String)driver.get(0);
+					List<String> driver = list.get(i);
+					String name = driver.get(0);
 					if(name.equals(this.textJdbcDriver.getText())){
-						sqlInfo.setJdbcDriver((String)driver.get(1));
+						sqlInfo.setJdbcDriver(driver.get(1));
 						break;
 					}
 				}
@@ -481,10 +509,7 @@ public class SqlNumericCreateDialog extends CommonMonitorNumericDialog {
 		}
 		monitorInfo.setSqlCheckInfo(sqlInfo);
 
-
 		// 通知関連情報とアプリケーションの設定
-		//通知グループIDの設定
-		monitorInfo.setNotifyGroupId(NotifyGroupIdGenerator.createNotifyGroupId(HinemosModuleConstant.MONITOR_SQL,monitorInfo.getMonitorId()));
 		validateResult = m_notifyInfo.createInputData(monitorInfo);
 		if (validateResult != null) {
 			if(validateResult.getID() == null){	// 通知ID警告用出力
@@ -510,9 +535,9 @@ public class SqlNumericCreateDialog extends CommonMonitorNumericDialog {
 
 	/**
 	 * 入力値をマネージャに登録します。
-	 * 
+	 *
 	 * @return true：正常、false：異常
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#action()
 	 */
 	@Override
@@ -521,26 +546,38 @@ public class SqlNumericCreateDialog extends CommonMonitorNumericDialog {
 
 		MonitorInfo info = this.inputData;
 		if(info != null){
+			String managerName = this.getManagerName();
 			if(!this.updateFlg){
 				// 作成の場合
-				result = new AddSql().add(info);
+				result = new AddSql().add(managerName, info);
 			}
 			else{
 				// 変更の場合
-				result = new ModifySql().modify(info);
+				result = new ModifySql().modify(managerName, info);
 			}
 		}
 
 		return result;
 	}
 
-
-
 	/**
 	 * JDBC情報を返却します
 	 * @return
 	 */
-	private List<List> getJdbcDriver(){
-		return GetJdbc.getJdbcDriverList();
+	private List<List<String>> getJdbcDriver(){
+		return GetJdbc.getJdbcDriverList(m_monitorBasic.getManagerListComposite().getText());
 	}
-}
\ No newline at end of file
+
+	private void createJdbcCombo() {
+		this.textJdbcDriver.removeAll();
+		List<List<String>> list = getJdbcDriver();
+		if(list != null){
+			for(int i = 0; i < list.size(); i++){
+				List<String> driver = list.get(i);
+				String name = driver.get(0);
+				this.textJdbcDriver.add(name);
+			}
+			this.textJdbcDriver.select(0);
+		}
+	}
+}
