@@ -1,6 +1,6 @@
 ﻿/*
  
-Copyright (C) 2012 NTT DATA Corporation
+Copyright (C) 2015 NTT DATA Corporation
  
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License 
@@ -176,7 +176,7 @@ AsnCounter GetCpuRawIdle(){
 	}
 
 	// カウンタをクエリーに追加
-	status = PdhAddCounter(hQuery, "\\Process(Idle)\\% Processor Time", 0, &hCounter);
+	status = PdhAddCounter(hQuery, "\\Processor(_Total)\\% Idle Time", 0, &hCounter);
 	if(verbose == 1 && CheckErrorCode(status)){
 		PostEvtLog( errorEventLevel, "GetCpuRawIdle", "PdhAddCounter", status);
 	}
@@ -205,11 +205,7 @@ AsnCounter GetCpuRawIdle(){
 		PostEvtLog( errorEventLevel, "GetCpuRawIdle", "PdhCloseQuery", status);
 	}
 	
-	// プロセッサの数を計算
-	SYSTEM_INFO siSysInfo;
-	GetSystemInfo(&siSysInfo);
-	
-	return ret/siSysInfo.dwNumberOfProcessors;
+	return ret;
 }
 
 
