@@ -29,11 +29,11 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.monitor.run.dialog.CommonMonitorTruthDialog;
 import com.clustercontrol.monitor.util.MonitorSettingEndpointWrapper;
-import com.clustercontrol.notify.util.NotifyGroupIdGenerator;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.monitor.InvalidRole_Exception;
 import com.clustercontrol.ws.monitor.MonitorDuplicate_Exception;
@@ -42,7 +42,7 @@ import com.clustercontrol.ws.monitor.WinServiceCheckInfo;
 
 /**
  * Windowsサービス監視作成・変更ダイアログクラス<BR>
- * 
+ *
  * @version 4.0.0
  * @since 4.0.0
  */
@@ -59,7 +59,7 @@ public class WinServiceCreateDialog extends CommonMonitorTruthDialog {
 
 	/**
 	 * 作成用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のシェルオブジェクト
 	 */
@@ -69,7 +69,7 @@ public class WinServiceCreateDialog extends CommonMonitorTruthDialog {
 
 	/**
 	 * 変更用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のシェルオブジェクト
 	 * @param monitorId
@@ -77,10 +77,9 @@ public class WinServiceCreateDialog extends CommonMonitorTruthDialog {
 	 * @param updateFlg
 	 *            更新するか否か（true:変更、false:新規登録）
 	 */
-	public WinServiceCreateDialog(Shell parent, String monitorId, boolean updateFlg) {
-		super(parent);
+	public WinServiceCreateDialog(Shell parent, String managerName, String monitorId, boolean updateFlg) {
+		super(parent, managerName, monitorId);
 
-		this.monitorId = monitorId;
 		this.updateFlg = updateFlg;
 	}
 
@@ -88,7 +87,7 @@ public class WinServiceCreateDialog extends CommonMonitorTruthDialog {
 
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のインスタンス
 	 */
@@ -108,13 +107,14 @@ public class WinServiceCreateDialog extends CommonMonitorTruthDialog {
 		 * チェック設定グループ（条件グループの子グループ）
 		 */
 		Group groupCheckRule = new Group(groupRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, null, groupCheckRule);
 		GridLayout layout = new GridLayout(1, true);
-		layout.marginWidth = 5;
-		layout.marginHeight = 5;
-		layout.numColumns = 15;
+		layout.marginWidth = HALF_MARGIN;
+		layout.marginHeight = HALF_MARGIN;
+		layout.numColumns = BASIC_UNIT;
 		groupCheckRule.setLayout(layout);
 		gridData = new GridData();
-		gridData.horizontalSpan = 15;
+		gridData.horizontalSpan = BASIC_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		groupCheckRule.setLayoutData(gridData);
@@ -125,16 +125,18 @@ public class WinServiceCreateDialog extends CommonMonitorTruthDialog {
 		 */
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "winservicename", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("winservice.name") + " : ");
 		// テキスト
 		this.m_serviceName = new Text(groupCheckRule, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, null, m_serviceName);
 		gridData = new GridData();
-		gridData.horizontalSpan = 8;
+		gridData.horizontalSpan = WIDTH_TEXT_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.m_serviceName.setLayoutData(gridData);
@@ -158,7 +160,8 @@ public class WinServiceCreateDialog extends CommonMonitorTruthDialog {
 		} else {
 			// 変更の場合、情報取得
 			try {
-				info = MonitorSettingEndpointWrapper.getMonitor(this.monitorId, HinemosModuleConstant.MONITOR_WINSERVICE);
+				MonitorSettingEndpointWrapper wrapper = MonitorSettingEndpointWrapper.getWrapper(getManagerName());
+				info = wrapper.getMonitor(this.monitorId, HinemosModuleConstant.MONITOR_WINSERVICE);
 			} catch (InvalidRole_Exception e) {
 				// アクセス権なしの場合、エラーダイアログを表示する
 				MessageDialog.openInformation(
@@ -180,7 +183,7 @@ public class WinServiceCreateDialog extends CommonMonitorTruthDialog {
 
 	/**
 	 * 更新処理
-	 * 
+	 *
 	 */
 	@Override
 	public void update(){
@@ -196,7 +199,7 @@ public class WinServiceCreateDialog extends CommonMonitorTruthDialog {
 
 	/**
 	 * 各項目に入力値を設定します。
-	 * 
+	 *
 	 * @param monitor
 	 *            設定値として用いる通知情報
 	 */
@@ -223,7 +226,7 @@ public class WinServiceCreateDialog extends CommonMonitorTruthDialog {
 
 	/**
 	 * 入力値を用いて通知情報を生成します。
-	 * 
+	 *
 	 * @return 入力値を保持した通知情報
 	 */
 	@Override
@@ -254,8 +257,6 @@ public class WinServiceCreateDialog extends CommonMonitorTruthDialog {
 
 
 		// 通知関連情報とアプリケーションの設定
-		// 通知グループIDの設定
-		monitorInfo.setNotifyGroupId(NotifyGroupIdGenerator.createNotifyGroupId(HinemosModuleConstant.MONITOR_WINSERVICE, monitorInfo.getMonitorId()));
 		validateResult = m_notifyInfo.createInputData(monitorInfo);
 		if (validateResult != null) {
 			if(validateResult.getID() == null){	// 通知ID警告用出力
@@ -274,9 +275,9 @@ public class WinServiceCreateDialog extends CommonMonitorTruthDialog {
 
 	/**
 	 * 入力値をマネージャに登録します。
-	 * 
+	 *
 	 * @return true：正常、false：異常
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#action()
 	 */
 	@Override
@@ -284,12 +285,14 @@ public class WinServiceCreateDialog extends CommonMonitorTruthDialog {
 		boolean result = false;
 
 		MonitorInfo info = this.inputData;
+		String managerName = this.getManagerName();
 		if(info != null){
-			String[] args = { info.getMonitorId() };
+			String[] args = { info.getMonitorId(), managerName };
+			MonitorSettingEndpointWrapper wrapper = MonitorSettingEndpointWrapper.getWrapper(managerName);
 			if(!this.updateFlg){
 				// 作成の場合
 				try {
-					result = MonitorSettingEndpointWrapper.addMonitor(info);
+					result = wrapper.addMonitor(info);
 
 					if(result){
 						MessageDialog.openInformation(
@@ -330,7 +333,7 @@ public class WinServiceCreateDialog extends CommonMonitorTruthDialog {
 				// 変更の場合
 				String errMessage = "";
 				try {
-					result = MonitorSettingEndpointWrapper.modifyMonitor(info);
+					result = wrapper.modifyMonitor(info);
 				} catch (InvalidRole_Exception e) {
 					// アクセス権なしの場合、エラーダイアログを表示する
 					MessageDialog.openInformation(
@@ -359,4 +362,4 @@ public class WinServiceCreateDialog extends CommonMonitorTruthDialog {
 		return result;
 	}
 
-}
\ No newline at end of file
+}
