@@ -120,7 +120,7 @@ public class HttpAuthenticator{
 		// Source IPAddress(HTTP Only)
 		MessageContext messageContext = wsContext.getMessageContext();
 		HttpExchange exchange = (HttpExchange)messageContext.get("com.sun.xml.internal.ws.http.exchange");
-		if(exchange != null & exchange.getRemoteAddress() != null && exchange.getRemoteAddress().getAddress() != null){
+		if(exchange != null && exchange.getRemoteAddress() != null && exchange.getRemoteAddress().getAddress() != null){
 			ipAddress = exchange.getRemoteAddress().getAddress().toString();
 		}
 
